@@ -7,7 +7,7 @@
  * Description : contextmenu helper class
  *
  * SPDX-FileCopyrightText: 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -292,6 +292,15 @@ public:
      */
     void addRemoveTagsMenu(const imageIds& ids);
 
+    /**
+     * Add "Remove all Tags" action.
+     *
+     * Removes all tags from the selected item ids except face tags.
+     *
+     * @param ids the selected items
+     */
+    void addRemoveAllTags(const imageIds& ids);
+
     /**
      * Add a menu to create new tags from adressbook entries.
      */
@@ -411,6 +420,7 @@ private Q_SLOTS:
     void slotDeselectChildren();
     void slotSelectParents();
     void slotDeselectParents();
+    void slotRemoveAllTags();
 
 private:
 
