@@ -7,7 +7,7 @@
  * Description : contextmenu helper class - Private container.
  *
  * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -128,6 +128,7 @@ public:
 
     QMap<int, QAction*>          queueActions;
     QMap<QString, KService::Ptr> servicesMap;
+    QMap<QString, DServiceInfo>  newServicesMap;
 
     ItemFilterModel*             imageFilterModel;
     AbstractCheckableAlbumModel* albumModel;
@@ -169,6 +170,16 @@ public:
 
         return action;
     }
+
+    QList<DPluginAction*> exportPluginActions() const
+    {
+        KXMLGUIClient* const client   = const_cast<KXMLGUIClient*>(stdActionCollection->parentGUIClient());
+        QList<DPluginAction*> actions = DPluginLoader::instance()->pluginsActions(DPluginAction::GenericExport,
+                                        dynamic_cast<KXmlGuiWindow*>(client));
+
+        return actions;
+    }
+
 };
 
 } // namespace Digikam
