@@ -7,7 +7,7 @@
  * Description : Qt model-view for items
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
@@ -36,7 +36,6 @@
 #include "coredboperationgroup.h"
 #include "advancedrenamedialog.h"
 #include "advancedrenameprocessdialog.h"
-#include "applicationsettings.h"
 #include "assignnameoverlay.h"
 #include "contextmenuhelper.h"
 #include "coredbaccess.h"
@@ -53,7 +52,6 @@
 #include "itemfullscreenoverlay.h"
 #include "itemcoordinatesoverlay.h"
 #include "tagslineeditoverlay.h"
-#include "itemviewutilities.h"
 #include "imagewindow.h"
 #include "fileactionmngr.h"
 #include "fileactionprogress.h"
@@ -504,12 +502,18 @@ void DigikamItemView::rejectFaces(const QList<QModelIndex>& indexes)
 
     for (int i = 0 ; i < infos.size() ; ++i)
     {
-        if (FaceTags::isTheUnknownPerson(faces[i].tagId()))
+        if      (FaceTags::isTheUnknownPerson(faces[i].tagId()))
         {
             // Reject signal was sent from an Unknown Face. Mark as Ignored.
 
             d->editPipeline.editTag(infos[i], faces[i], FaceTags::ignoredPersonTagId());
         }
+        else if (FaceTags::isTheIgnoredPerson(faces[i].tagId()))
+        {
+            // Reject signal was sent from an Ignored Face. Remove face.
+
+            d->editPipeline.remove(infos[i], faces[i]);
+        }
         else
         {
             // Reject face suggestion. Mark as Unknown.
@@ -776,3 +780,5 @@ void DigikamItemView::scrollTo(const QModelIndex& index, ScrollHint hint)
 }
 
 } // namespace Digikam
+
+#include "moc_digikamitemview.cpp"
