@@ -11,7 +11,7 @@
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText:      2013 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -81,6 +81,19 @@ DigikamApp::DigikamApp()
     LocalizeSettings::instance();
     NetworkManager::instance();
 
+#ifdef HAVE_GEOLOCATION
+
+    connect(GeolocationSettings::instance(), &GeolocationSettings::signalSetupGeolocation,
+            this, [=](int tab)
+        {
+            Setup::execGeolocation(this, tab);
+        }
+    );
+
+    qCDebug(DIGIKAM_GENERAL_LOG) << GeolocationSettings::instance()->settings();
+
+#endif
+
     connect(LocalizeSettings::instance(), &LocalizeSettings::signalOpenLocalizeSetup,
             this, [=]()
         {
@@ -90,7 +103,7 @@ DigikamApp::DigikamApp()
 
     if (!ExifToolProcess::isCreated())
     {
-        ExifToolThread* const exifToolThread = new ExifToolThread(this);
+        ExifToolThread* const exifToolThread = new ExifToolThread(qApp);
         exifToolThread->start();
     }
 
@@ -141,9 +154,9 @@ DigikamApp::DigikamApp()
     // to access items which were not created yet.
 
     setupView();
+    setupAccelerators();
     setupActions();
     setupStatusBar();
-    setupAccelerators();
 
     initGui();
 
@@ -181,6 +194,10 @@ DigikamApp::DigikamApp()
         loop.exec();
     }
 
+    // Build trash counters from all collections
+
+    DIO::buildCollectionTrashCounters();
+
     // Read albums from database
 
     if (d->splashScreen)
@@ -211,7 +228,7 @@ DigikamApp::DigikamApp()
     BalooWrap* const baloo = BalooWrap::instance();
     Q_UNUSED(baloo);
 
-#endif //HAVE_KFILEMETADATA
+#endif // HAVE_KFILEMETADATA
 
     setAutoSaveSettings(group, true);
 
@@ -321,8 +338,6 @@ void DigikamApp::show()
     if (d->splashScreen)
     {
         d->splashScreen->finish(this);
-        delete d->splashScreen;
-        d->splashScreen = nullptr;
     }
 
     // Display application window.
@@ -376,6 +391,24 @@ void DigikamApp::show()
 
         QTimer::singleShot(1000, tool, SLOT(start()));
     }
+
+    if (d->splashScreen)
+    {
+        delete d->splashScreen;
+        d->splashScreen = nullptr;
+    }
+
+    QScopedPointer<ExifToolParser> const parser(new ExifToolParser(nullptr));
+
+    if (!parser->exifToolAvailable())
+    {
+        QString msg = i18n("ExifTool is not available in your digiKam installation or "
+                           "is not working correctly. Go to the digiKam settings and "
+                           "check the availability of the ExifTool binary file in "
+                           "the metadata section.");
+
+        Q_EMIT signalNotificationError(msg, DNotificationWidget::Warning);
+    }
 }
 
 void DigikamApp::restoreSession()
@@ -456,13 +489,33 @@ void DigikamApp::enableAlbumForwardHistory(bool enable)
 
 void DigikamApp::slotAboutToShowBackwardMenu()
 {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    d->backwardActionMenu->popupMenu()->clear();
+
+#else
+
     d->backwardActionMenu->menu()->clear();
+
+#endif
+
     QStringList titles;
     d->view->getBackwardHistory(titles);
 
     for (int i = 0 ; i < titles.size() ; ++i)
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        QAction* const action = d->backwardActionMenu->popupMenu()->addAction(titles.at(i));
+
+#else
+
         QAction* const action = d->backwardActionMenu->menu()->addAction(titles.at(i));
+
+#endif
+
         int id                = i + 1;
 
         connect(action, &QAction::triggered,
@@ -472,13 +525,33 @@ void DigikamApp::slotAboutToShowBackwardMenu()
 
 void DigikamApp::slotAboutToShowForwardMenu()
 {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    d->forwardActionMenu->popupMenu()->clear();
+
+#else
+
     d->forwardActionMenu->menu()->clear();
+
+#endif
+
     QStringList titles;
     d->view->getForwardHistory(titles);
 
     for (int i = 0 ; i < titles.size() ; ++i)
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        QAction* const action = d->forwardActionMenu->popupMenu()->addAction(titles.at(i));
+
+#else
+
         QAction* const action = d->forwardActionMenu->menu()->addAction(titles.at(i));
+
+#endif
+
         int id                = i + 1;
 
         connect(action, &QAction::triggered,
@@ -758,6 +831,7 @@ void DigikamApp::slotSelectionChanged(int selectionCount)
     d->imagePreviewAction->setEnabled(hasAtLeastCurrent);
     d->imageViewAction->setEnabled(hasAtLeastCurrent);
     d->imageScanForFacesAction->setEnabled(selectionCount > 0);
+    d->imageRemoveAllFacesAction->setEnabled(selectionCount > 0);
     d->imageFindSimilarAction->setEnabled(selectionCount == 1);
     d->imageRenameAction->setEnabled(selectionCount > 0);
     d->imageLightTableAction->setEnabled(selectionCount > 0);
@@ -1009,11 +1083,11 @@ void DigikamApp::slotSwitchedToMapView()
 
     d->zoomBar->setBarMode(DZoomBar::ThumbsSizeCtrl);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->imageMapViewAction->setChecked(true);
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     customizedTrashView(true);
     toggleShowBar();
@@ -1051,7 +1125,7 @@ void DigikamApp::customizedTrashView(bool set)
     d->imageTableViewAction->setEnabled(set);
     d->imageIconViewAction->setEnabled(set);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->imageMapViewAction->setEnabled(set);
 
@@ -1169,3 +1243,5 @@ DInfoInterface* DigikamApp::infoIface(DPluginAction* const ac)
 }
 
 } // namespace Digikam
+
+#include "moc_digikamapp.cpp"
