@@ -6,7 +6,7 @@
  * Date        : 2007-31-01
  * Description : main digiKam interface implementation
  *
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -143,6 +143,11 @@
 #include "facesdetector.h"
 #include "localizesettings.h"
 #include "networkmanager.h"
+#include "dnotificationwidget.h"
+
+#ifdef HAVE_GEOLOCATION
+#   include "geolocationsettings.h"
+#endif
 
 #ifdef HAVE_DBUS
 #   include "digikamadaptor.h"
@@ -217,11 +222,11 @@ public:
         imageViewSelectionAction            (nullptr),
         imagePreviewAction                  (nullptr),
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
         imageMapViewAction                  (nullptr),
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
         imageTableViewAction                (nullptr),
         imageIconViewAction                 (nullptr),
@@ -234,6 +239,7 @@ public:
         imageReadMetadataAction             (nullptr),
         imageScanForFacesAction             (nullptr),
         imageRecognizeFacesAction           (nullptr),
+        imageRemoveAllFacesAction           (nullptr),
         imageFindSimilarAction              (nullptr),
         imageSetExifOrientation1Action      (nullptr),
         imageSetExifOrientation2Action      (nullptr),
@@ -340,11 +346,11 @@ public:
     KSelectAction*                      imageViewSelectionAction;
     QAction*                            imagePreviewAction;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     QAction*                            imageMapViewAction;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     QAction*                            imageTableViewAction;
     QAction*                            imageIconViewAction;
@@ -357,6 +363,7 @@ public:
     QAction*                            imageReadMetadataAction;
     QAction*                            imageScanForFacesAction;
     QAction*                            imageRecognizeFacesAction;
+    QAction*                            imageRemoveAllFacesAction;
     QAction*                            imageFindSimilarAction;
     QAction*                            imageSetExifOrientation1Action;
     QAction*                            imageSetExifOrientation2Action;
