@@ -6,24 +6,15 @@
  * Date        : 2002-16-10
  * Description : Item icon view interface.
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2011 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
+ * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -44,7 +35,8 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     d->tagModificationHelper    = new TagModificationHelper(this, this);
     d->searchModificationHelper = new SearchModificationHelper(this, this);
 
-    const int spacing           = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing           = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     d->splitter    = new SidebarSplitter;
     d->splitter->setFrameStyle(QFrame::NoFrame | QFrame::Plain);
@@ -72,30 +64,30 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     connect(d->leftSideBar, SIGNAL(signalChangedTab(QWidget*)),
             d->errorWidget, SLOT(animatedHide()));
 
-    d->stackedview = new StackedView(vbox);
+    d->stackedView = new StackedView(vbox);
 
     d->dockArea->setCentralWidget(vbox);
-    d->stackedview->setDockArea(d->dockArea);
+    d->stackedView->setDockArea(d->dockArea);
 
-    d->iconView  = d->stackedview->imageIconView();
+    d->iconView  = d->stackedView->imageIconView();
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
-    d->mapView   = d->stackedview->mapWidgetView();
+    d->mapView   = d->stackedView->mapWidgetView();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
-    d->tableView = d->stackedview->tableView();
-    d->trashView = d->stackedview->trashView();
+    d->tableView = d->stackedView->tableView();
+    d->trashView = d->stackedView->trashView();
 
     d->utilities = d->iconView->utilities();
 
-    d->addPageUpDownActions(this, d->stackedview->imagePreviewView());
-    d->addPageUpDownActions(this, d->stackedview->thumbBar());
+    d->addPageUpDownActions(this, d->stackedView->imagePreviewView());
+    d->addPageUpDownActions(this, d->stackedView->thumbBar());
 
 #ifdef HAVE_MEDIAPLAYER
 
-    d->addPageUpDownActions(this, d->stackedview->mediaPlayerView());
+    d->addPageUpDownActions(this, d->stackedView->mediaPlayerView());
 
 #endif // HAVE_MEDIAPLAYER
 
@@ -160,7 +152,7 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     connect(d->fuzzySearchSideBar, SIGNAL(signalNotificationError(QString,int)),
             this, SLOT(slotNotificationError(QString,int)));
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->gpsSearchSideBar    = new GPSSearchSideBarWidget(d->leftSideBar,
                                                         d->modelCollection->getSearchModel(),
@@ -170,7 +162,7 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
 
     d->leftSideBarWidgets << d->gpsSearchSideBar;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     // People Sidebar
 
@@ -181,9 +173,6 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     connect(d->peopleSideBar, SIGNAL(requestFaceMode(bool)),
             d->iconView, SLOT(setFaceMode(bool)));
 
-    connect(d->peopleSideBar, SIGNAL(signalRunningFaceAction(bool)),
-            d->iconView, SLOT(setRunningFaceAction(bool)));
-
     connect(d->peopleSideBar, SIGNAL(signalFindDuplicates(QList<TAlbum*>)),
             this, SLOT(slotNewDuplicatesSearch(QList<TAlbum*>)));
 
@@ -192,7 +181,7 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
 
     d->leftSideBarWidgets << d->peopleSideBar;
 
-    foreach (SidebarWidget* const leftWidget, d->leftSideBarWidgets)
+    Q_FOREACH (SidebarWidget* const leftWidget, d->leftSideBarWidgets)
     {
         d->leftSideBar->appendTab(leftWidget, leftWidget->getIcon(), leftWidget->getCaption());
 
@@ -256,7 +245,7 @@ ItemIconView::~ItemIconView()
 
 void ItemIconView::applySettings()
 {
-    foreach (SidebarWidget* const sidebarWidget, d->leftSideBarWidgets)
+    Q_FOREACH (SidebarWidget* const sidebarWidget, d->leftSideBarWidgets)
     {
         sidebarWidget->applySettings();
     }
@@ -273,9 +262,6 @@ void ItemIconView::setupConnections()
     connect(d->parent, SIGNAL(signalEscapePressed()),
             this, SLOT(slotEscapePreview()));
 
-    connect(d->parent, SIGNAL(signalEscapePressed()),
-            d->stackedview, SLOT(slotEscapePreview()));
-
     connect(d->parent, SIGNAL(signalNextItem()),
             this, SLOT(slotNextItem()));
 
@@ -297,6 +283,9 @@ void ItemIconView::setupConnections()
     connect(d->parent, SIGNAL(signalPasteAlbumItemsSelection()),
             this, SLOT(slotImagePaste()));
 
+    connect(d->parent, SIGNAL(signalNotificationError(QString,int)),
+            this, SLOT(slotNotificationError(QString,int)));
+
     // -- AlbumManager connections --------------------------------
 
     connect(d->albumManager, SIGNAL(signalAlbumCurrentChanged(QList<Album*>)),
@@ -308,6 +297,9 @@ void ItemIconView::setupConnections()
     connect(d->albumManager, SIGNAL(signalAlbumsCleared()),
             this, SLOT(slotAlbumsCleared()));
 
+    connect(d->albumManager, SIGNAL(signalEmptyTrash()),
+            d->trashView, SIGNAL(signalEmptytrash()));
+
     // -- IconView Connections -------------------------------------
 
     connect(d->iconView->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
@@ -391,12 +383,12 @@ void ItemIconView::setupConnections()
     connect(this, SIGNAL(signalNoCurrentItem()),
             d->rightSideBar, SLOT(slotNoCurrentItem()));
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     connect(d->gpsSearchSideBar, SIGNAL(signalMapSoloItems(QList<qlonglong>,QString)),
             d->iconView->imageFilterModel(), SLOT(setIdWhitelist(QList<qlonglong>,QString)));
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     // -- Filter Bars Connections ---------------------------------
 
@@ -423,37 +415,37 @@ void ItemIconView::setupConnections()
 
     // -- Preview image widget Connections ------------------------
 
-    connect(d->stackedview, SIGNAL(signalNextItem()),
+    connect(d->stackedView, SIGNAL(signalNextItem()),
             this, SLOT(slotNextItem()));
 
-    connect(d->stackedview, SIGNAL(signalPrevItem()),
+    connect(d->stackedView, SIGNAL(signalPrevItem()),
             this, SLOT(slotPrevItem()));
 
-    connect(d->stackedview, SIGNAL(signalDeleteItem()),
+    connect(d->stackedView, SIGNAL(signalDeleteItem()),
             this, SLOT(slotImageDelete()));
 
-    connect(d->stackedview, SIGNAL(signalViewModeChanged()),
+    connect(d->stackedView, SIGNAL(signalViewModeChanged()),
             this, SLOT(slotViewModeChanged()));
 
-    connect(d->stackedview, SIGNAL(signalEscapePreview()),
+    connect(d->stackedView, SIGNAL(signalEscapePreview()),
             this, SLOT(slotEscapePreview()));
 
-    connect(d->stackedview, SIGNAL(signalZoomFactorChanged(double)),
+    connect(d->stackedView, SIGNAL(signalZoomFactorChanged(double)),
             this, SLOT(slotZoomFactorChanged(double)));
 
-    connect(d->stackedview, SIGNAL(signalAddToExistingQueue(int)),
+    connect(d->stackedView, SIGNAL(signalAddToExistingQueue(int)),
             this, SLOT(slotImageAddToExistingQueue(int)));
 
-    connect(d->stackedview, SIGNAL(signalGotoAlbumAndItem(ItemInfo)),
+    connect(d->stackedView, SIGNAL(signalGotoAlbumAndItem(ItemInfo)),
             this, SLOT(slotGotoAlbumAndItem(ItemInfo)));
 
-    connect(d->stackedview, SIGNAL(signalGotoDateAndItem(ItemInfo)),
+    connect(d->stackedView, SIGNAL(signalGotoDateAndItem(ItemInfo)),
             this, SLOT(slotGotoDateAndItem(ItemInfo)));
 
-    connect(d->stackedview, SIGNAL(signalGotoTagAndItem(int)),
+    connect(d->stackedView, SIGNAL(signalGotoTagAndItem(int)),
             this, SLOT(slotGotoTagAndItem(int)));
 
-    connect(d->stackedview, SIGNAL(signalPopupTagsView()),
+    connect(d->stackedView, SIGNAL(signalPopupTagsView()),
             d->rightSideBar, SLOT(slotPopupTagsView()));
 
     // -- FileActionMngr progress ---------------
@@ -514,7 +506,7 @@ void ItemIconView::setupConnections()
 
 void ItemIconView::loadViewState()
 {
-    foreach (SidebarWidget* const widget, d->leftSideBarWidgets)
+    Q_FOREACH (SidebarWidget* const widget, d->leftSideBarWidgets)
     {
         widget->loadState();
     }
@@ -536,11 +528,11 @@ void ItemIconView::loadViewState()
 
     d->initialAlbumID = group.readEntry(QLatin1String("InitialAlbumID"), 0);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->mapView->loadState();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     d->tableView->loadState();
     d->rightSideBar->loadState();
@@ -551,7 +543,7 @@ void ItemIconView::saveViewState()
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("MainWindow"));
 
-    foreach (SidebarWidget* const widget, d->leftSideBarWidgets)
+    Q_FOREACH (SidebarWidget* const widget, d->leftSideBarWidgets)
     {
         widget->saveState();
     }
@@ -567,7 +559,7 @@ void ItemIconView::saveViewState()
     // (when the user is in image preview mode) when the layout is saved, it
     // also reappears when restoring the view, while it should always be hidden.
 
-    d->stackedview->thumbBarDock()->close();
+    d->stackedView->thumbBarDock()->close();
     group.writeEntry(QLatin1String("ThumbbarState"), d->dockArea->saveState().toBase64());
 
     QList<Album*> albumList = AlbumManager::instance()->currentAlbums();
@@ -587,14 +579,16 @@ void ItemIconView::saveViewState()
         group.writeEntry(QLatin1String("InitialAlbumID"), 0);
     }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->mapView->saveState();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     d->tableView->saveState();
     d->rightSideBar->saveState();
 }
 
 } // namespace Digikam
+
+#include "moc_itemiconview.cpp"
