@@ -7,7 +7,7 @@
  * Description : Item icon view interface - Item methods.
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
@@ -160,7 +160,7 @@ void ItemIconView::slotDispatchImageSelected()
 
     if (list.isEmpty())
     {
-        d->stackedview->setPreviewItem();
+        d->stackedView->setPreviewItem();
 
         Q_EMIT signalImageSelected(list, allImages);
         Q_EMIT signalNoCurrentItem();
@@ -189,7 +189,7 @@ void ItemIconView::slotDispatchImageSelected()
             (viewMode() != StackedView::TableViewMode)
            )
         {
-            d->stackedview->setPreviewItem(list.first(), previousInfo, nextInfo);
+            d->stackedView->setPreviewItem(list.first(), previousInfo, nextInfo);
         }
 
         Q_EMIT signalImageSelected(list, allImages);
@@ -215,7 +215,7 @@ void ItemIconView::slotRefreshImagePreview()
 {
     if (viewMode() == StackedView::PreviewImageMode)
     {
-        d->stackedview->imagePreviewView()->reload();
+        d->stackedView->imagePreviewView()->reload();
     }
 }
 
@@ -242,8 +242,20 @@ void ItemIconView::slotImageDelete()
             break;
 
         default:
+        {
+
+#ifdef HAVE_MEDIAPLAYER
+
+            if (viewMode() == StackedView::MediaPlayerMode)
+            {
+                d->stackedView->mediaPlayerView()->escapePreview();
+            }
+
+#endif // HAVE_MEDIAPLAYER
+
             d->iconView->deleteSelected(ItemViewUtilities::DeleteUseTrash);
             break;
+        }
     }
 }
 
@@ -256,8 +268,20 @@ void ItemIconView::slotImageDeletePermanently()
             break;
 
         default:
+        {
+
+#ifdef HAVE_MEDIAPLAYER
+
+            if (viewMode() == StackedView::MediaPlayerMode)
+            {
+                d->stackedView->mediaPlayerView()->escapePreview();
+            }
+
+#endif // HAVE_MEDIAPLAYER
+
             d->iconView->deleteSelected(ItemViewUtilities::DeletePermanently);
             break;
+        }
     }
 }
 
@@ -422,7 +446,7 @@ void ItemIconView::slotFocusAndNextImage()
 {
     // slot is called on pressing "return" a second time after assigning a tag
 
-    d->stackedview->currentWidget()->setFocus();
+    d->stackedView->currentWidget()->setFocus();
 
     // select next image, since the user is probably done tagging the current image
 
@@ -448,12 +472,12 @@ ItemInfo ItemIconView::currentInfo() const
         case StackedView::TableViewMode:
             return d->tableView->currentInfo();
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
         case StackedView::MapWidgetMode:
             return d->mapView->currentItemInfo();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
         case StackedView::MediaPlayerMode:
         case StackedView::PreviewImageMode:
