@@ -6,19 +6,11 @@
  * Date        : 2013-02-11
  * Description : Table view
  *
- * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
- * Copyright (C) 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -45,12 +37,10 @@
 
 #include "advancedrenamedialog.h"
 #include "advancedrenameprocessdialog.h"
-#include "applicationsettings.h"
 #include "contextmenuhelper.h"
 #include "digikam_debug.h"
 #include "fileactionmngr.h"
 #include "album.h"
-#include "itemviewutilities.h"
 #include "tableview_columnfactory.h"
 #include "tableview_model.h"
 #include "tableview_selection_model_syncer.h"
@@ -149,7 +139,7 @@ void TableView::doLoadState()
     const KConfigGroup group                        = getConfigGroup();
 
     TableViewColumnProfile profile;
-    const KConfigGroup groupCurrentProfile          = group.group("Current Profile");
+    const KConfigGroup groupCurrentProfile          = group.group(QLatin1String("Current Profile"));
     profile.loadSettings(groupCurrentProfile);
     s->tableViewModel->loadColumnProfile(profile);
 
@@ -169,7 +159,7 @@ void TableView::doSaveState()
 
     TableViewColumnProfile profile   = s->tableViewModel->getColumnProfile();
     profile.headerState              = s->treeView->header()->saveState();
-    KConfigGroup groupCurrentProfile = group.group("Current Profile");
+    KConfigGroup groupCurrentProfile = group.group(QLatin1String("Current Profile"));
     profile.saveSettings(groupCurrentProfile);
     group.writeEntry("Grouping mode", int(s->tableViewModel->groupingMode()));
 }
@@ -183,24 +173,30 @@ void TableView::slotItemActivated(const QModelIndex& tableViewIndex)
         return;
     }
 
-    if (qApp->queryKeyboardModifiers() != Qt::AltModifier)
+    Qt::KeyboardModifiers modifiers = qApp->queryKeyboardModifiers();
+
+    if      (modifiers == Qt::NoModifier)
     {
         int leftClickAction = ApplicationSettings::instance()->getItemLeftClickAction();
 
         if      (leftClickAction == ApplicationSettings::ShowPreview)
         {
-            emit signalPreviewRequested(info);
+            Q_EMIT signalPreviewRequested(info);
         }
         else if (leftClickAction == ApplicationSettings::StartEditor)
         {
             d->imageViewUtilities->openInfos(info, allItemInfos(), currentAlbum());
         }
+        else if (leftClickAction == ApplicationSettings::ShowOnTable)
+        {
+            d->imageViewUtilities->insertToLightTable(allItemInfos(), info, false);
+        }
         else
         {
             d->imageViewUtilities->openInfosWithDefaultApplication(QList<ItemInfo>() << info);
         }
     }
-    else
+    else if (modifiers == Qt::AltModifier)
     {
         d->imageViewUtilities->openInfosWithDefaultApplication(QList<ItemInfo>() << info);
     }
@@ -219,13 +215,13 @@ bool TableView::eventFilter(QObject* watched, QEvent* event)
 
         if (contextMenuIndex.isValid())
         {
-            emit signalShowContextMenuOnInfo(e,
+            Q_EMIT signalShowContextMenuOnInfo(e,
                                              s->tableViewModel->imageInfo(contextMenuIndex),
                                              getExtraGroupingActions());
         }
         else
         {
-            emit signalShowContextMenu(e, getExtraGroupingActions());
+            Q_EMIT signalShowContextMenu(e, getExtraGroupingActions());
         }
 
         // event has been filtered by us
@@ -241,7 +237,7 @@ void TableView::setThumbnailSize(const ThumbnailSize& size)
     d->thumbnailSize                            = size;
     const QList<TableViewColumn*> columnObjects = s->tableViewModel->getColumnObjects();
 
-    foreach (TableViewColumn* const iColumn, columnObjects)
+    Q_FOREACH (TableViewColumn* const iColumn, columnObjects)
     {
         iColumn->updateThumbnailSize();
     }
@@ -302,8 +298,8 @@ bool TableView::selectedNeedGroupResolving(const ApplicationSettings::OperationT
 
 void TableView::slotDeleteSelected(const ItemViewUtilities::DeleteMode deleteMode)
 {
-    const bool allGroupsOpen    = ApplicationSettings::instance()->getAllGroupsOpen();
-    const ItemInfoList infoList = selectedItemInfos(!allGroupsOpen);
+    const bool allGroupsOpen     = ApplicationSettings::instance()->getAllGroupsOpen();
+    const ItemInfoList& infoList = selectedItemInfos(!allGroupsOpen);
 
     /// @todo Update parameter naming for deleteImages
 
@@ -315,8 +311,8 @@ void TableView::slotDeleteSelected(const ItemViewUtilities::DeleteMode deleteMod
 
 void TableView::slotDeleteSelectedWithoutConfirmation(const ItemViewUtilities::DeleteMode deleteMode)
 {
-    const bool allGroupsOpen    = ApplicationSettings::instance()->getAllGroupsOpen();
-    const ItemInfoList infoList = selectedItemInfos(!allGroupsOpen);
+    const bool allGroupsOpen     = ApplicationSettings::instance()->getAllGroupsOpen();
+    const ItemInfoList& infoList = selectedItemInfos(!allGroupsOpen);
 
     d->imageViewUtilities->deleteImagesDirectly(infoList, deleteMode);
     slotAwayFromSelection();
@@ -456,10 +452,10 @@ ItemInfo TableView::previousInfo() const
 
 void TableView::slotSetCurrentUrlWhenAvailable(const QUrl& url)
 {
-    foreach (const ItemInfo& info, allItemInfos())
+    Q_FOREACH (const ItemInfo& info, allItemInfos())
     {
         if (info.fileUrl() == url)
-        {
+        {    // cppcheck-suppress useStlAlgorithm
             slotSetCurrentWhenAvailable(info.id());
             break;
         }
@@ -576,7 +572,7 @@ void TableView::invertSelection()
 
     s->tableViewSelectionModel->clearSelection();
 
-    foreach (const int i, rowsToSelect)
+    Q_FOREACH (const int i, rowsToSelect)
     {
         const QModelIndex iIndex = s->tableViewModel->deepRowIndex(i);
         const QItemSelection is  = s->tableViewSelectionModelSyncer->targetIndexToRowItemSelection(iIndex);
@@ -689,3 +685,5 @@ void TableView::rename()
 }
 
 } // namespace Digikam
+
+#include "moc_tableview.cpp"
