@@ -6,7 +6,7 @@
  * Date        : 2013-02-12
  * Description : Wrapper model for table view
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -29,7 +29,6 @@
 #include "digikam_debug.h"
 #include "coredb.h"
 #include "coredbaccess.h"
-#include "coredbchangesets.h"
 #include "coredbfields.h"
 #include "coredbwatch.h"
 #include "itemfiltermodel.h"
@@ -537,6 +536,8 @@ void TableViewModel::slotSourceRowsAboutToBeRemoved(const QModelIndex& parent, i
         return;
     }
 
+    bool needToResort = false;
+
     for (int i = start ; i <= end ; ++i)
     {
         const QModelIndex imageModelIndex = s->imageModel->index(i, 0, parent);
@@ -558,11 +559,24 @@ void TableViewModel::slotSourceRowsAboutToBeRemoved(const QModelIndex& parent, i
         beginRemoveRows(tableViewIndex.parent(), tableViewIndex.row(), tableViewIndex.row());
         item->parent->takeChild(item);
 
+        // move child items to parent item
+
+        while (!item->children.isEmpty())
+        {
+            item->parent->addChild(item->children.takeFirst());
+            needToResort = true;
+        }
+
         // child items will be deleted when item is deleted
 
         delete item;
         endRemoveRows();
     }
+
+    if (needToResort)
+    {
+        scheduleResort();
+    }
 }
 
 void TableViewModel::slotSourceRowsRemoved(const QModelIndex& parent, int start, int end)
@@ -1684,3 +1698,5 @@ int TableViewModel::findChildSortedPosition(TableViewModel::Item* const parentIt
 }
 
 } // namespace Digikam
+
+#include "moc_tableview_model.cpp"
