@@ -6,18 +6,9 @@
  * Date        : 2019-09-26
  * Description : A HEIF IO file for DImg framework
  *
- * Copyright (C) 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -27,7 +18,6 @@
 
 #include "digikam_config.h"
 #include "digikam_debug.h"
-#include "dimg.h"
 #include "dimgloaderobserver.h"
 
 namespace Digikam
@@ -36,9 +26,6 @@ namespace Digikam
 DImgHEIFLoader::DImgHEIFLoader(DImg* const image)
     : DImgLoader(image)
 {
-    m_hasAlpha   = false;
-    m_sixteenBit = false;
-    m_observer   = nullptr;
 }
 
 DImgHEIFLoader::~DImgHEIFLoader()
@@ -70,7 +57,7 @@ bool DImgHEIFLoader::isReadOnly() const
 
 }
 
-bool DImgHEIFLoader::isHeifSuccess(struct heif_error* const error)
+bool DImgHEIFLoader::isHeifSuccess(const struct heif_error* const error)
 {
     if (error->code == 0)
     {
