@@ -6,18 +6,9 @@
  * Date        : 2019-09-26
  * Description : A HEIF IO file for DImg framework - save operations
  *
- * Copyright (C) 2019-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -62,7 +53,7 @@
 namespace Digikam
 {
 
-static struct heif_error HeifQIODeviceWriter(struct heif_context* /* ctx */,
+static struct heif_error heifQIODeviceWriter(struct heif_context* /* ctx */,
                                              const void* data, size_t size, void* userdata)
 {
     QFile saveFile(QString::fromUtf8(static_cast<const char*>(userdata)));
@@ -70,6 +61,9 @@ static struct heif_error HeifQIODeviceWriter(struct heif_context* /* ctx */,
 
     if (!saveFile.open(QIODevice::WriteOnly))
     {
+        qCWarning(DIGIKAM_DIMG_LOG_HEIF) << "Cannot open target image file:"
+                                         << saveFile.fileName();
+
         error.code    = heif_error_Encoding_error;
         error.subcode = heif_suberror_Cannot_write_output_data;
         error.message = QByteArray("File open error").constData();
@@ -81,9 +75,9 @@ static struct heif_error HeifQIODeviceWriter(struct heif_context* /* ctx */,
     error.subcode       = heif_suberror_Unspecified;
     error.message       = QByteArray("Success").constData();
 
-    qint64 bytesWritten = saveFile.write(static_cast<const char*>(data), size);
+    qint64 bytesWritten = saveFile.write((const char*)data, size);
 
-    if (bytesWritten < static_cast<qint64>(size))
+    if (bytesWritten < (qint64)size)
     {
         error.code    = heif_error_Encoding_error;
         error.subcode = heif_suberror_Cannot_write_output_data;
@@ -133,28 +127,7 @@ int DImgHEIFLoader::x265MaxBitsDepth()
 
 bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const observer)
 {
-    m_observer = observer;
-
-    // -------------------------------------------------------------------
-    // Open the file
-
-#ifdef Q_OS_WIN
-
-    FILE* const file = _wfopen((const wchar_t*)filePath.utf16(), L"wb");
-
-#else
-
-    FILE* const file = fopen(filePath.toUtf8().constData(), "wb");
-
-#endif
-
-    if (!file)
-    {
-        qCWarning(DIGIKAM_DIMG_LOG_HEIF) << "Cannot open target image file.";
-        return false;
-    }
-
-    fclose(file);
+    m_observer             = observer;
 
     QVariant qualityAttr   = imageGetAttribute(QLatin1String("quality"));
     int quality            = qualityAttr.isValid() ? qualityAttr.toInt() : 75;
@@ -186,8 +159,15 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
 
     QElapsedTimer timer;
     timer.start();
+
     qCDebug(DIGIKAM_DIMG_LOG_HEIF) << "HEVC encoder setup...";
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+    heif_init(nullptr);
+
+#endif
+
     struct heif_context* const ctx = heif_context_alloc();
 
     if (!ctx)
@@ -205,6 +185,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
     {
         heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -222,6 +208,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
         heif_encoder_release(encoder);
         heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -246,6 +238,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
         heif_encoder_release(encoder);
         heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -260,6 +258,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
         heif_encoder_release(encoder);
         heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -400,6 +404,11 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
                 heif_encoder_release(encoder);
                 heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+                heif_deinit();
+
+#endif
                 return false;
             }
 
@@ -427,6 +436,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
         heif_encoder_release(encoder);
         heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -457,6 +472,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
             heif_encoder_release(encoder);
             heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+            heif_deinit();
+
+#endif
+
             return false;
         }
 
@@ -481,7 +502,7 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
 
     heif_writer writer;
     writer.writer_api_version = 1;
-    writer.write              = HeifQIODeviceWriter;
+    writer.write              = heifQIODeviceWriter;
 
     error                     = heif_context_write(ctx, &writer, (void*)filePath.toUtf8().constData());
 
@@ -489,6 +510,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
     {
         heif_context_free(ctx);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -497,6 +524,12 @@ bool DImgHEIFLoader::save(const QString& filePath, DImgLoaderObserver* const obs
     imageSetAttribute(QLatin1String("savedFormat"), QLatin1String("HEIF"));
     saveMetadata(filePath);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+    heif_deinit();
+
+#endif
+
     return true;
 }
 
