@@ -6,7 +6,7 @@
  * Date        : 2006-06-14
  * Description : A JPEG-2000 IO file for DImg framework
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Others Linux JPEG-2000 Loader implementation:
  *    https://github.com/ImageMagick/ImageMagick/blob/master/coders/jp2.c
@@ -14,16 +14,7 @@
  *    https://invent.kde.org/kde/krita/tree/fc1d4dce1c12a1a663d02436cde15a77e067af2c/plugins/impex/jp2
  *    https://github.com/darktable-org/darktable/blob/master/src/imageio/format/j2k.c
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -55,6 +46,11 @@ public:
     bool sixteenBit()                                                const override;
     bool isReadOnly()                                                const override;
 
+private:
+
+    int  initJasper();
+    void cleanupJasper();
+
 private:
 
     bool m_sixteenBit;
