@@ -6,7 +6,7 @@
  * Date        : 2004-07-20
  * Description : image histogram adjust levels.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -379,8 +379,18 @@ AdjustLevelsTool::AdjustLevelsTool(QObject* const parent)
     connect(d->resetButton, SIGNAL(clicked()),
             this, SLOT(slotResetCurrentChannel()));
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+
+    connect(d->pickerType, SIGNAL(idReleased(int)),
+            this, SLOT(slotPickerColorButtonActived(int)));
+
+#else
+
     connect(d->pickerType, SIGNAL(buttonReleased(int)),
             this, SLOT(slotPickerColorButtonActived(int)));
+
+#endif
+
 }
 
 AdjustLevelsTool::~AdjustLevelsTool()
@@ -936,3 +946,5 @@ void AdjustLevelsTool::slotSaveAsSettings()
 }
 
 } // namespace DigikamEditorAdjustLevelsToolPlugin
+
+#include "moc_adjustlevelstool.cpp"
