@@ -6,18 +6,9 @@
  * Date        : 2012-02-05
  * Description : film color negative inverter tool
  *
- * Copyright (C) 2012 by Matthias Welwarsky <matthias at welwarsky dot de>
+ * SPDX-FileCopyrightText: 2012 by Matthias Welwarsky <matthias at welwarsky dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -699,3 +690,5 @@ bool FilmTool::eventFilter(QObject* obj, QEvent* ev)
 }
 
 } // namespace DigikamEditorFilmToolPlugin
+
+#include "moc_filmtool.cpp"
