@@ -136,10 +136,15 @@ void HealingCloneToolWidget::mousePressEvent(QMouseEvent* e)
     else if ((d->currentState == HealingCloneState::LASSO_DRAW_BOUNDARY) &&
              (e->buttons() & Qt::LeftButton))
     {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         QPoint dst = QPoint(e->position().toPoint().x(), e->position().toPoint().y());
+
 #else
+
         QPoint dst = QPoint(e->x(), e->y());
+
 #endif
 
         Q_EMIT signalLasso(mapToImageCoordinates(dst));
@@ -192,10 +197,15 @@ void HealingCloneToolWidget::mouseMoveEvent(QMouseEvent* e)
     else if ((d->currentState == HealingCloneState::LASSO_DRAW_BOUNDARY) &&
              (e->buttons() & Qt::LeftButton))
     {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         QPoint dst = QPoint(e->position().toPoint().x(), e->position().toPoint().y());
+
 #else
+
         QPoint dst = QPoint(e->x(), e->y());
+
 #endif
 
         Q_EMIT signalLasso(mapToImageCoordinates(dst));
@@ -681,3 +691,5 @@ void HealingCloneToolWidget::slotImageRegionChanged()
 }
 
 } // namespace DigikamEditorHealingCloneToolPlugin
+
+#include "moc_healingclonetoolwidget.cpp"
