@@ -6,17 +6,9 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to reduce noise
  *
- * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -72,6 +64,21 @@ QString NoiseReductionToolPlugin::details() const
     return i18nc("@info", "This Image Editor tool can reduce noise in image.");
 }
 
+QString NoiseReductionToolPlugin::handbookSection() const
+{
+    return QLatin1String("image_editor");
+}
+
+QString NoiseReductionToolPlugin::handbookChapter() const
+{
+    return QLatin1String("enhancement_tools");
+}
+
+QString NoiseReductionToolPlugin::handbookReference() const
+{
+    return QLatin1String("enhance-nr");
+}
+
 QList<DPluginAuthor> NoiseReductionToolPlugin::authors() const
 {
     return QList<DPluginAuthor>()
@@ -108,3 +115,5 @@ void NoiseReductionToolPlugin::slotNoiseReduction()
 }
 
 } // namespace DigikamEditorNoiseReductionToolPlugin
+
+#include "moc_noisereductiontoolplugin.cpp"
