@@ -7,7 +7,7 @@
  * Description : Content aware resizing tool.
  *
  * SPDX-FileCopyrightText: 2009-2010 by Julien Pontabry <julien dot pontabry at ulp dot u-strasbg dot fr>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2010 by Julien Narboux <julien at narboux dot fr>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -456,9 +456,18 @@ ContentAwareResizeTool::ContentAwareResizeTool(QObject* const parent)
     connect(d->weightMaskBox, SIGNAL(stateChanged(int)),
             this, SLOT(slotWeightMaskBoxStateChanged(int)));
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+
+    connect(d->maskGroup, SIGNAL(idClicked(int)),
+            this, SLOT(slotMaskColorChanged(int)));
+
+#else
+
     connect(d->maskGroup, SIGNAL(buttonClicked(int)),
             this, SLOT(slotMaskColorChanged(int)));
 
+#endif
+
     connect(d->maskPenSize, SIGNAL(valueChanged(int)),
             this, SLOT(slotMaskPenSizeChanged(int)));
 }
@@ -867,3 +876,5 @@ bool ContentAwareResizeTool::eventFilter(QObject* obj, QEvent* ev)
 }
 
 } // namespace DigikamEditorContentAwareResizeToolPlugin
+
+#include "moc_contentawareresizetool.cpp"
