@@ -6,20 +6,11 @@
  * Date        : 2004-12-06
  * Description : digiKam image editor Ratio Crop tool
  *
- * Copyright (C) 2007      by Jaromir Malenko <malenko at email dot cz>
- * Copyright (C) 2008      by Roberto Castagnola <roberto dot castagnola at gmail dot com>
- * Copyright (C) 2004-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007      by Jaromir Malenko <malenko at email dot cz>
+ * SPDX-FileCopyrightText: 2008      by Roberto Castagnola <roberto dot castagnola at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -34,7 +25,6 @@
 #include <QImage>
 #include <QLabel>
 #include <QPixmap>
-#include <QRect>
 #include <QSpinBox>
 #include <QTimer>
 #include <QToolButton>
@@ -434,6 +424,7 @@ RatioCropTool::RatioCropTool(QObject* const parent)
     d->guideLinesCB->addItem(i18n("Diagonal Method"));
     d->guideLinesCB->addItem(i18n("Harmonious Triangles"));
     d->guideLinesCB->addItem(i18n("Golden Mean"));
+    d->guideLinesCB->addItem(i18n("Center Lines"));
     d->guideLinesCB->addItem(i18nc("no geometric form", "None"));
     d->guideLinesCB->setDefaultIndex(RatioCropWidget::GuideNone);
     d->guideLinesCB->setCurrentIndex(3);
@@ -688,6 +679,7 @@ void RatioCropTool::readSettings()
 
     // For the last setting to be applied, activate drawing in
     // the selectionWidget, so that we can see the results.
+
     d->ratioCropWidget->setIsDrawingSelection(true);
 
     slotGuideTypeChanged(d->guideLinesCB->currentIndex());
@@ -747,15 +739,54 @@ void RatioCropTool::writeSettings()
     group.sync();
 }
 
-void RatioCropTool::slotResetSettings()
+void RatioCropTool::slotResetSelection()
 {
     d->ratioCropWidget->resetSelection();
+}
+
+void RatioCropTool::slotResetSettings()
+{
+    d->guideLinesCB->setCurrentIndex(RatioCropWidget::GuideNone);
+    d->goldenSectionBox->setChecked(true);
+    d->goldenSpiralSectionBox->setChecked(false);
+    d->goldenSpiralBox->setChecked(false);
+    d->goldenTriangleBox->setChecked(false);
+    d->flipHorBox->setChecked(false);
+    d->flipVerBox->setChecked(false);
+    d->autoOrientation->setChecked(false);
+    d->preciseCrop->setChecked(false);
+    d->guideColorBt->setColor(QColor(250, 250, 255));
+    d->guideSize->setValue(d->guideSize->defaultValue());
+
+    d->ratioCropWidget->slotGuideLines(d->guideLinesCB->currentIndex());
+    d->ratioCropWidget->slotChangeGuideColor(d->guideColorBt->color());
+    d->ratioCropWidget->setPreciseCrop(d->preciseCrop->isChecked());
+    d->ratioCB->setCurrentIndex(d->ratioCB->defaultIndex());
+
+    if (d->originalIsLandscape)
+    {
+        d->orientCB->setDefaultIndex(RatioCropWidget::Landscape);
+        d->orientCB->setCurrentIndex(RatioCropWidget::Landscape);
+    }
+    else
+    {
+        d->orientCB->setDefaultIndex(RatioCropWidget::Portrait);
+        d->orientCB->setCurrentIndex(RatioCropWidget::Portrait);
+    }
+
+    d->customRatioNInput->setValue(d->customRatioNInput->defaultValue());
+    d->customRatioDInput->setValue(d->customRatioDInput->defaultValue());
+
+    d->ratioCropWidget->setSelectionOrientation(d->orientCB->currentIndex());
+    slotAutoOrientChanged(d->autoOrientation->isChecked());
+    applyRatioChanges(d->ratioCB->currentIndex());
+
+    // For the last setting to be applied, activate drawing in
+    // the selectionWidget, so that we can see the results.
 
-    setInputRange(d->ratioCropWidget->getRegionSelection());
     d->ratioCropWidget->setIsDrawingSelection(true);
 
-    slotGuideTypeChanged(d->guideLinesCB->currentIndex());
-    updateCropInfo();
+    QTimer::singleShot(0, this, SLOT(slotResetSelection()));
 }
 
 void RatioCropTool::slotMaxAspectRatio()
@@ -906,7 +937,7 @@ void RatioCropTool::slotOrientChanged(int o)
     d->ratioCropWidget->setSelectionOrientation(o);
 
     // Reset selection area.
-    slotResetSettings();
+    slotResetSelection();
 }
 
 void RatioCropTool::slotAutoOrientChanged(bool a)
@@ -920,7 +951,7 @@ void RatioCropTool::slotRatioChanged(int a)
     applyRatioChanges(a);
 
     // Reset selection area.
-    slotResetSettings();
+    slotResetSelection();
 }
 
 void RatioCropTool::applyRatioChanges(int a)
@@ -1047,7 +1078,7 @@ void RatioCropTool::slotCustomRatioChanged()
     d->ratioCropWidget->setSelectionAspectRatioValue(d->customRatioNInput->value(), d->customRatioDInput->value());
 
     // Reset selection area.
-    slotResetSettings();
+    slotResetSelection();
 }
 
 void RatioCropTool::updateCropInfo()
@@ -1132,3 +1163,5 @@ void RatioCropTool::setBackgroundColor(const QColor& bg)
 }
 
 } // namespace DigikamEditorRatioCropToolPlugin
+
+#include "moc_ratiocroptool.cpp"
