@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2007      by Jaromir Malenko <malenko at email.cz>
  * SPDX-FileCopyrightText: 2008      by Roberto Castagnola <roberto dot castagnola at gmail dot com>
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -40,7 +40,6 @@
 // Qt includes
 
 #include <QRegion>
-#include <QColor>
 #include <QPainter>
 #include <QBrush>
 #include <QPixmap>
@@ -923,6 +922,15 @@ void RatioCropWidget::drawRulesOfThirds(QPainter& p, const int& xThird, const in
 
 }
 
+void RatioCropWidget::drawRulesOfCenter(QPainter& p, const int& xHalf, const int& yHalf)
+{
+    p.drawLine(d->localRegionSelection.left() + xHalf, d->localRegionSelection.top(),
+               d->localRegionSelection.left() + xHalf, d->localRegionSelection.bottom());
+
+    p.drawLine(d->localRegionSelection.left(),  d->localRegionSelection.top() + yHalf,
+               d->localRegionSelection.right(), d->localRegionSelection.top() + yHalf);
+}
+
 void RatioCropWidget::drawDiagonalMethod(QPainter& p, const int& w, const int& h)
 {
     p.setRenderHint(QPainter::Antialiasing);
@@ -1236,6 +1244,19 @@ void RatioCropWidget::updatePixmap()
 
             break;
         }
+
+        case CenterLines:
+        {
+            int xHalf = d->localRegionSelection.width()  / 2;
+            int yHalf = d->localRegionSelection.height() / 2;
+
+            p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
+            drawRulesOfCenter(p, xHalf, yHalf);
+
+            p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
+            drawRulesOfCenter(p, xHalf, yHalf);
+            break;
+        }
     }
 
     p.setClipping(false);
@@ -1431,7 +1452,7 @@ void RatioCropWidget::mousePressEvent(QMouseEvent* e)
     if (e->button() == Qt::LeftButton)
     {
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
         QPoint pm        = QPoint(e->position().toPoint().x(), e->position().toPoint().y());
 
@@ -1552,10 +1573,15 @@ void RatioCropWidget::mouseMoveEvent(QMouseEvent* e)
         if (d->moving)
         {
             setCursor(Qt::SizeAllCursor);
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
             QPoint newPos = convertPoint(e->position().toPoint().x(), e->position().toPoint().y());
+
 #else
+
             QPoint newPos = convertPoint(e->x(), e->y());
+
 #endif
 
             d->regionSelection.translate(newPos.x() - d->lastPos.x(),
@@ -1570,10 +1596,15 @@ void RatioCropWidget::mouseMoveEvent(QMouseEvent* e)
         }
         else
         {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
             QPoint pmVirtual = convertPoint(e->position().toPoint().x(), e->position().toPoint().y());
+
 #else
+
             QPoint pmVirtual = convertPoint(e->x(), e->y());
+
 #endif
 
             if (d->currentResizing == Private::ResizingNone)
@@ -1636,7 +1667,9 @@ void RatioCropWidget::mouseMoveEvent(QMouseEvent* e)
     }
     else
     {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         if      (d->localTopLeftCorner.contains(e->position().toPoint().x(), e->position().toPoint().y()) ||
                  d->localBottomRightCorner.contains(e->position().toPoint().x(), e->position().toPoint().y()))
         {
@@ -1651,7 +1684,9 @@ void RatioCropWidget::mouseMoveEvent(QMouseEvent* e)
         {
             setCursor(Qt::SizeAllCursor);
         }
+
 #else
+
         if      (d->localTopLeftCorner.contains(e->x(), e->y()) ||
                  d->localBottomRightCorner.contains(e->x(), e->y()))
         {
@@ -1666,7 +1701,9 @@ void RatioCropWidget::mouseMoveEvent(QMouseEvent* e)
         {
             setCursor(Qt::SizeAllCursor);
         }
+
 #endif
+
         else
         {
             setCursor(Qt::ArrowCursor);
@@ -1680,3 +1717,5 @@ void RatioCropWidget::setIsDrawingSelection(bool draw)
 }
 
 } // namespace DigikamEditorRatioCropToolPlugin
+
+#include "moc_ratiocropwidget.cpp"
