@@ -6,18 +6,10 @@
  * Date        : 2006-05-16
  * Description : a tool to export GPS data to KML file.
  *
- * Copyright (C) 2006-2007 by Stephane Pontier <shadow dot walker at free dot fr>
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2007 by Stephane Pontier <shadow dot walker at free dot fr>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -27,12 +19,11 @@
 
 #include <QImageReader>
 #include <QPainter>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 #include <QStandardPaths>
 #include <QApplication>
 #include <QIODevice>
-#include <QDir>
 
 // KDE includes
 
@@ -44,6 +35,7 @@
 
 #include "digikam_debug.h"
 #include "dmessagebox.h"
+#include "dfileoperations.h"
 
 namespace DigikamGenericGeolocationEditPlugin
 {
@@ -82,7 +74,7 @@ QString KmlExport::webifyFileName(const QString& fileName) const
 
     // Remove potentially troublesome chars
 
-    webFileName         = webFileName.replace(QRegExp(QLatin1String("[^-0-9a-z]+")), QLatin1String("_"));
+    webFileName         = webFileName.replace(QRegularExpression(QLatin1String("[^-0-9a-z]+")), QLatin1String("_"));
 
     return webFileName;
 }
@@ -238,7 +230,10 @@ void KmlExport::generateImagesthumb(const QUrl& imageURL, QDomElement& kmlAlbum)
         }
         else if (m_meta->load(imageURL.toLocalFile()))
         {
-            m_meta->getGPSInfo(alt, lat, lng);
+            if (!m_meta->getGPSInfo(alt, lat, lng))
+            {
+                logError(i18n("Cannot get GPS Information from %1 file.", imageURL.toLocalFile()));
+            }
         }
 
         QDomElement kmlPlacemark = addKmlElement(kmlAlbum, QLatin1String("Placemark"));
@@ -496,7 +491,7 @@ void KmlExport::generate()
             logWarning(i18n("No position data for '%1'", info.name()));
         }
 
-        emit signalProgressChanged(pos);
+        Q_EMIT signalProgressChanged(pos);
         QApplication::processEvents();
     }
 
@@ -554,7 +549,7 @@ bool KmlExport::copyDir(const QString& srcFilePath, const QString& dstFilePath)
 
         QStringList files = srcDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
 
-        foreach (const QString& file, files)
+        Q_FOREACH (const QString& file, files)
         {
             const QString newSrcFilePath = srcDir.absolutePath() + QLatin1Char('/') + file;
             const QString newDstFilePath = dstDir.absolutePath() + QLatin1Char('/') + file;
@@ -575,7 +570,7 @@ bool KmlExport::copyDir(const QString& srcFilePath, const QString& dstFilePath)
             }
         }
 
-        if (!QFile::copy(srcFilePath, dstFilePath))
+        if (!DFileOperations::copyFile(srcFilePath, dstFilePath))
         {
             return false;
         }
@@ -669,3 +664,5 @@ QDomElement KmlExport::addKmlHtmlElement(QDomElement& target,
 }
 
 } // namespace DigikamGenericGeolocationEditPlugin
+
+#include "moc_kmlexport.cpp"
