@@ -6,17 +6,9 @@
  * Date        : 2006-10-12
  * Description : EXIF caption settings page.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -25,18 +17,26 @@
 
 // Qt includes
 
+#include <QLabel>
 #include <QWidget>
+#include <QLineEdit>
 
 // Local includes
 
 #include "dmetadata.h"
+#include "metadataeditpage.h"
+
+namespace Digikam
+{
+    class DTextEdit;
+}
 
 using namespace Digikam;
 
 namespace DigikamGenericMetadataEditPlugin
 {
 
-class EXIFCaption : public QWidget
+class EXIFCaption : public MetadataEditPage
 {
     Q_OBJECT
 
