@@ -6,17 +6,9 @@
  * Date        : 2007-11-10
  * Description : IPTC envelope settings page.
  *
- * Copyright (C) 2007-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -45,7 +37,7 @@
 #include "squeezedcombobox.h"
 #include "metadatacheckbox.h"
 #include "timezonecombobox.h"
-#include "limitedtextedit.h"
+#include "dtextedit.h"
 #include "dlayoutbox.h"
 
 namespace DigikamGenericMetadataEditPlugin
@@ -148,7 +140,7 @@ public:
     QDateEdit*                     dateSentSel;
 
     QLabel*                        destinationNote;
-    LimitedTextEdit*               destinationEdit;
+    DPlainTextEdit*                destinationEdit;
 
     MetadataCheckBox*              priorityCheck;
     MetadataCheckBox*              formatCheck;
@@ -157,10 +149,10 @@ public:
 };
 
 IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
-    : QWidget(parent),
-      d(new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    QGridLayout* const grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(widget());
     QString dateFormat      = QLocale().dateFormat(QLocale::ShortFormat);
 
     if (!dateFormat.contains(QLatin1String("yyyy")))
@@ -178,8 +170,9 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     d->destinationNote      = new QLabel(destHeader);
     destHeader->setStretchFactor(d->destinationCheck, 10);
 
-    d->destinationEdit      = new LimitedTextEdit(this);
+    d->destinationEdit      = new DPlainTextEdit(this);
     d->destinationEdit->setMaxLength(1024);
+    d->destinationEdit->setPlaceholderText(i18n("Set here the envelope destination"));
     d->destinationEdit->setWhatsThis(i18n("Enter the envelope destination. "
                                           "This field is limited to 1024 characters."));
 
@@ -189,6 +182,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     d->unoIDEdit  = new QLineEdit(this);
     d->unoIDEdit->setClearButtonEnabled(true);
     d->unoIDEdit->setMaxLength(80);
+    d->unoIDEdit->setPlaceholderText(i18n("Set here the Unique Name of Object identifier"));
     d->unoIDEdit->setWhatsThis(i18n("Set here the Unique Name of Object identifier. "
                                     "This field is limited to 80 characters."));
 
@@ -198,6 +192,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     d->productIDEdit  = new QLineEdit(this);
     d->productIDEdit->setClearButtonEnabled(true);
     d->productIDEdit->setMaxLength(32);
+    d->productIDEdit->setPlaceholderText(i18n("Set here the product identifier"));
     d->productIDEdit->setWhatsThis(i18n("Set here the product identifier. "
                                          "This field is limited to 32 characters."));
 
@@ -207,6 +202,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     d->serviceIDEdit  = new QLineEdit(this);
     d->serviceIDEdit->setClearButtonEnabled(true);
     d->serviceIDEdit->setMaxLength(10);
+    d->serviceIDEdit->setPlaceholderText(i18n("Set here the service identifier"));
     d->serviceIDEdit->setWhatsThis(i18n("Set here the service identifier. "
                                          "This field is limited to 10 characters."));
 
@@ -216,6 +212,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     d->envelopeIDEdit  = new QLineEdit(this);
     d->envelopeIDEdit->setClearButtonEnabled(true);
     d->envelopeIDEdit->setMaxLength(8);
+    d->envelopeIDEdit->setPlaceholderText(i18n("Set here the envelope identifier"));
     d->envelopeIDEdit->setWhatsThis(i18n("Set here the envelope identifier. "
                                          "This field is limited to 8 characters."));
 
@@ -294,9 +291,9 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     grid->addWidget(d->productIDCheck,      3, 0, 1, 1);
     grid->addWidget(d->productIDEdit,       3, 1, 1, 5);
     grid->addWidget(d->serviceIDCheck,      4, 0, 1, 1);
-    grid->addWidget(d->serviceIDEdit,       4, 1, 1, 1);
+    grid->addWidget(d->serviceIDEdit,       4, 1, 1, 5);
     grid->addWidget(d->envelopeIDCheck,     5, 0, 1, 1);
-    grid->addWidget(d->envelopeIDEdit,      5, 1, 1, 1);
+    grid->addWidget(d->envelopeIDEdit,      5, 1, 1, 5);
     grid->addWidget(d->priorityCheck,       6, 0, 1, 1);
     grid->addWidget(d->priorityCB,          6, 1, 1, 1);
     grid->addWidget(d->formatCheck,         7, 0, 1, 1);
@@ -310,8 +307,12 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     grid->addWidget(note,                  10, 0, 1, 6);
     grid->setColumnStretch(4, 10);
     grid->setRowStretch(11, 10);
-    grid->setContentsMargins(QMargins());
-    grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+
+    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
+    grid->setSpacing(spacing);
 
     // --------------------------------------------------------
 
@@ -385,9 +386,6 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     connect(d->destinationEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
 
-    connect(d->destinationEdit, SIGNAL(textChanged()),
-            this, SLOT(slotDestinationLeftCharacters()));
-
     connect(d->serviceIDEdit, SIGNAL(textChanged(QString)),
             this, SIGNAL(signalModified()));
 
@@ -418,7 +416,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* const parent)
     connect(d->timeSentSel, SIGNAL(timeChanged(QTime)),
             this, SIGNAL(signalModified()));
 
-    connect(d->zoneSentSel, SIGNAL(currentIndexChanged(QString)),
+    connect(d->zoneSentSel, SIGNAL(currentTextChanged(QString)),
             this, SIGNAL(signalModified()));
 
     // --------------------------------------------------------
@@ -439,13 +437,6 @@ void IPTCEnvelope::slotSetTodaySent()
     d->zoneSentSel->setToUTC();
 }
 
-void IPTCEnvelope::slotDestinationLeftCharacters()
-{
-    QToolTip::showText(d->destinationCheck->mapToGlobal(QPoint(0, -16)),
-                       i18np("%1 character left", "%1 characters left", d->destinationEdit->maxLength() - d->destinationEdit->toPlainText().size()),
-                       d->destinationEdit);
-}
-
 void IPTCEnvelope::slotLineEditModified()
 {
     QLineEdit* const ledit = dynamic_cast<QLineEdit*>(sender());
@@ -481,7 +472,6 @@ void IPTCEnvelope::readMetadata(const DMetadata& meta)
     }
 
     d->destinationEdit->setEnabled(d->destinationCheck->isChecked());
-    slotDestinationLeftCharacters();
 
     d->envelopeIDEdit->clear();
     d->envelopeIDCheck->setChecked(false);
@@ -727,3 +717,5 @@ void IPTCEnvelope::applyMetadata(const DMetadata& meta)
 }
 
 } // namespace DigikamGenericMetadataEditPlugin
+
+#include "moc_iptcenvelope.cpp"
