@@ -6,17 +6,9 @@
  * Date        : 2006-10-13
  * Description : IPTC origin settings page.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -117,10 +109,10 @@ public:
 };
 
 IPTCOrigin::IPTCOrigin(QWidget* const parent)
-    : QWidget(parent),
-      d(new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    QGridLayout* const grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(widget());
     QString dateFormat      = QLocale().dateFormat(QLocale::ShortFormat);
 
     if (!dateFormat.contains(QLatin1String("yyyy")))
@@ -194,6 +186,7 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
     d->cityEdit  = new QLineEdit(this);
     d->cityEdit->setClearButtonEnabled(true);
     d->cityEdit->setMaxLength(32);
+    d->cityEdit->setPlaceholderText(i18n("Set here the city of the content"));
     d->cityEdit->setWhatsThis(i18n("Set here the city of content origin. "
                                    "This field is limited to 32 characters."));
 
@@ -203,6 +196,7 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
     d->sublocationEdit  = new QLineEdit(this);
     d->sublocationEdit->setClearButtonEnabled(true);
     d->sublocationEdit->setMaxLength(32);
+    d->sublocationEdit->setPlaceholderText(i18n("Set here the content location"));
     d->sublocationEdit->setWhatsThis(i18n("Set here the content location within city. "
                                           "This field is limited to 32 characters."));
 
@@ -212,6 +206,7 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
     d->provinceEdit  = new QLineEdit(this);
     d->provinceEdit->setClearButtonEnabled(true);
     d->provinceEdit->setMaxLength(32);
+    d->provinceEdit->setPlaceholderText(i18n("Set here the Province or State of the content"));
     d->provinceEdit->setWhatsThis(i18n("Set here the Province or State of content origin. "
                                        "This field is limited to 32 characters."));
 
@@ -274,8 +269,12 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
     grid->addWidget(note,                                  12, 0, 1, 6);
     grid->setColumnStretch(4, 10);
     grid->setRowStretch(13, 10);
-    grid->setContentsMargins(QMargins());
-    grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+
+    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
+    grid->setSpacing(spacing);
 
     // --------------------------------------------------------
 
@@ -355,10 +354,10 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
     connect(d->timeDigitalizedSel, SIGNAL(timeChanged(QTime)),
             this, SIGNAL(signalModified()));
 
-    connect(d->zoneCreatedSel, SIGNAL(currentIndexChanged(QString)),
+    connect(d->zoneCreatedSel, SIGNAL(currentTextChanged(QString)),
             this, SIGNAL(signalModified()));
 
-    connect(d->zoneDigitalizedSel, SIGNAL(currentIndexChanged(QString)),
+    connect(d->zoneDigitalizedSel, SIGNAL(currentTextChanged(QString)),
             this, SIGNAL(signalModified()));
 
     // --------------------------------------------------------
@@ -735,3 +734,5 @@ void IPTCOrigin::applyMetadata(const DMetadata& meta)
 }
 
 } // namespace DigikamGenericMetadataEditPlugin
+
+#include "moc_iptcorigin.cpp"
