@@ -6,17 +6,9 @@
  * Date        : 2007-11-10
  * Description : IPTC workflow status properties settings page.
  *
- * Copyright (C) 2007-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -47,6 +39,7 @@
 #include "timezonecombobox.h"
 #include "objectattributesedit.h"
 #include "dexpanderbox.h"
+#include "dtextedit.h"
 
 namespace DigikamGenericMetadataEditPlugin
 {
@@ -102,8 +95,8 @@ public:
     QComboBox*                     objectCycleCB;
     QComboBox*                     objectTypeCB;
 
-    QLineEdit*                     objectTypeDescEdit;
-    QLineEdit*                     originalTransEdit;
+    DPlainTextEdit*               objectTypeDescEdit;
+    DPlainTextEdit*               originalTransEdit;
 
     QComboBox*                     languageBtn;
 
@@ -119,10 +112,10 @@ public:
 };
 
 IPTCProperties::IPTCProperties(QWidget* const parent)
-    : QWidget(parent),
-      d      (new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    QGridLayout* const grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(widget());
     QString dateFormat      = QLocale().dateFormat(QLocale::ShortFormat);
 
     if (!dateFormat.contains(QLatin1String("yyyy")))
@@ -226,9 +219,10 @@ IPTCProperties::IPTCProperties(QWidget* const parent)
 
     d->objectTypeCheck    = new MetadataCheckBox(i18n("Type:"), this);
     d->objectTypeCB       = new QComboBox(this);
-    d->objectTypeDescEdit = new QLineEdit(this);
-    d->objectTypeDescEdit->setClearButtonEnabled(true);
+    d->objectTypeDescEdit = new DPlainTextEdit(this);
+    d->objectTypeDescEdit->setPlaceholderText(i18n("Set here the content type"));
     d->objectTypeDescEdit->setMaxLength(64);
+    d->objectTypeDescEdit->setLinesVisible(1);
     d->objectTypeCB->insertItem(0, i18n("News"));
     d->objectTypeCB->insertItem(1, i18n("Data"));
     d->objectTypeCB->insertItem(2, i18n("Advisory"));
@@ -238,13 +232,14 @@ IPTCProperties::IPTCProperties(QWidget* const parent)
 
     // --------------------------------------------------------
 
-    d->objectAttribute = new ObjectAttributesEdit(this, 64);
+    d->objectAttribute    = new ObjectAttributesEdit(this, 64);
 
     // --------------------------------------------------------
 
     d->originalTransCheck = new QCheckBox(i18n("Reference:"), this);
-    d->originalTransEdit  = new QLineEdit(this);
-    d->originalTransEdit->setClearButtonEnabled(true);
+    d->originalTransEdit  = new DPlainTextEdit(this);
+    d->originalTransEdit->setLinesVisible(1);
+    d->originalTransEdit->setPlaceholderText(i18n("Set here the content reference"));
     d->originalTransEdit->setMaxLength(32);
     d->originalTransEdit->setWhatsThis(i18n("Set here the original content transmission "
                                             "reference. This field is limited to 32 characters."));
@@ -292,8 +287,12 @@ IPTCProperties::IPTCProperties(QWidget* const parent)
     grid->addWidget(note,                                  13, 0, 1, 6);
     grid->setColumnStretch(4, 10);
     grid->setRowStretch(14, 10);
-    grid->setContentsMargins(QMargins());
-    grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+
+    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
+    grid->setSpacing(spacing);
 
     // --------------------------------------------------------
 
@@ -379,10 +378,10 @@ IPTCProperties::IPTCProperties(QWidget* const parent)
     connect(d->timeExpiredSel, SIGNAL(timeChanged(QTime)),
             this, SIGNAL(signalModified()));
 
-    connect(d->zoneReleasedSel, SIGNAL(currentIndexChanged(QString)),
+    connect(d->zoneReleasedSel, SIGNAL(currentTextChanged(QString)),
             this, SIGNAL(signalModified()));
 
-    connect(d->zoneExpiredSel, SIGNAL(currentIndexChanged(QString)),
+    connect(d->zoneExpiredSel, SIGNAL(currentTextChanged(QString)),
             this, SIGNAL(signalModified()));
 
     // --------------------------------------------------------
@@ -395,7 +394,7 @@ IPTCProperties::IPTCProperties(QWidget* const parent)
 
     // --------------------------------------------------------
 
-    connect(d->languageBtn, SIGNAL(activated(QString)),
+    connect(d->languageBtn, SIGNAL(activated(int)),
             this, SIGNAL(signalModified()));
 
     connect(d->priorityCB, SIGNAL(activated(int)),
@@ -407,20 +406,11 @@ IPTCProperties::IPTCProperties(QWidget* const parent)
     connect(d->objectTypeCB, SIGNAL(activated(int)),
             this, SIGNAL(signalModified()));
 
-    connect(d->objectTypeDescEdit, SIGNAL(textChanged(QString)),
+    connect(d->objectTypeDescEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
 
-    connect(d->objectTypeDescEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(slotLineEditModified()));
-
-    connect(d->originalTransEdit, SIGNAL(textChanged(QString)),
+    connect(d->originalTransEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
-
-    connect(d->originalTransEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(slotLineEditModified()));
-
-    connect(d->objectAttribute->valueEdit(), SIGNAL(textChanged(QString)),
-            this, SLOT(slotLineEditModified()));
 }
 
 IPTCProperties::~IPTCProperties()
@@ -442,20 +432,6 @@ void IPTCProperties::slotSetTodayExpired()
     d->zoneExpiredSel->setToUTC();
 }
 
-void IPTCProperties::slotLineEditModified()
-{
-    QLineEdit* const ledit = dynamic_cast<QLineEdit*>(sender());
-
-    if (!ledit)
-    {
-        return;
-    }
-
-    QToolTip::showText(ledit->mapToGlobal(QPoint(0, (-1)*(ledit->height() + 16))),
-                       i18np("%1 character left", "%1 characters left", ledit->maxLength() - ledit->text().size()),
-                       ledit);
-}
-
 void IPTCProperties::readMetadata(const DMetadata& meta)
 {
     blockSignals(true);
@@ -766,3 +742,5 @@ void IPTCProperties::applyMetadata(const DMetadata& meta)
 }
 
 } // namespace DigikamGenericMetadataEditPlugin
+
+#include "moc_iptcproperties.cpp"
