@@ -6,17 +6,9 @@
  * Date        : 2007-10-16
  * Description : XMP keywords settings page.
  *
- * Copyright (C) 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -36,6 +28,10 @@
 
 #include <klocalizedstring.h>
 
+// Local includes
+
+#include "dtextedit.h"
+
 namespace DigikamGenericMetadataEditPlugin
 {
 
@@ -61,24 +57,24 @@ public:
 
     QCheckBox*   keywordsCheck;
 
-    QLineEdit*   keywordEdit;
+    DTextEdit*   keywordEdit;
 
     QListWidget* keywordsBox;
 };
 
 XMPKeywords::XMPKeywords(QWidget* const parent)
-    : QWidget(parent),
-      d(new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    QGridLayout* const grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(widget());
 
     // --------------------------------------------------------
 
     d->keywordsCheck = new QCheckBox(i18n("Use information retrieval words:"), this);
 
-    d->keywordEdit   = new QLineEdit(this);
-    d->keywordEdit->setClearButtonEnabled(true);
-    d->keywordEdit->setWhatsThis(i18n("Enter here a new keyword."));
+    d->keywordEdit   = new DTextEdit(this);
+    d->keywordEdit->setLinesVisible(1);
+    d->keywordEdit->setPlaceholderText(i18n("Set here a new keyword"));
 
     d->keywordsBox   = new QListWidget(this);
     d->keywordsBox->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
@@ -94,7 +90,7 @@ XMPKeywords::XMPKeywords(QWidget* const parent)
 
     // --------------------------------------------------------
 
-    grid->setAlignment( Qt::AlignTop );
+    grid->setAlignment(Qt::AlignTop);
     grid->addWidget(d->keywordsCheck,       0, 0, 1, 2);
     grid->addWidget(d->keywordEdit,         1, 0, 1, 1);
     grid->addWidget(d->keywordsBox,         2, 0, 5, 1);
@@ -103,8 +99,12 @@ XMPKeywords::XMPKeywords(QWidget* const parent)
     grid->addWidget(d->repKeywordButton,    4, 1, 1, 1);
     grid->setColumnStretch(0, 10);
     grid->setRowStretch(5, 10);
-    grid->setContentsMargins(QMargins());
-    grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+
+    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
+    grid->setSpacing(spacing);
 
     // --------------------------------------------------------
 
@@ -160,7 +160,11 @@ XMPKeywords::~XMPKeywords()
 void XMPKeywords::slotDelKeyword()
 {
     QListWidgetItem* const item = d->keywordsBox->currentItem();
-    if (!item) return;
+
+    if (!item)
+    {
+        return;
+    }
 
     d->keywordsBox->takeItem(d->keywordsBox->row(item));
     delete item;
@@ -260,9 +264,11 @@ void XMPKeywords::applyMetadata(const DMetadata& meta)
     }
 
     // We remove in first all existing keywords.
+
     meta.removeXmpTag("Xmp.dc.subject");
 
     // And add new list if necessary.
+
     if (d->keywordsCheck->isChecked())
     {
         meta.setXmpKeywords(newKeywords);
@@ -270,3 +276,5 @@ void XMPKeywords::applyMetadata(const DMetadata& meta)
 }
 
 } // namespace DigikamGenericMetadataEditPlugin
+
+#include "moc_xmpkeywords.cpp"
