@@ -6,17 +6,9 @@
  * Date        : 2007-10-24
  * Description : XMP workflow status settings page.
  *
- * Copyright (C) 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,7 +21,6 @@
 #include <QApplication>
 #include <QStyle>
 #include <QLineEdit>
-#include <QPlainTextEdit>
 
 // KDE includes
 
@@ -39,6 +30,7 @@
 
 #include "altlangstringedit.h"
 #include "multistringsedit.h"
+#include "dtextedit.h"
 
 namespace DigikamGenericMetadataEditPlugin
 {
@@ -57,23 +49,23 @@ public:
     {
     }
 
-    QCheckBox*          nicknameCheck;
-    QCheckBox*          specialInstructionCheck;
+    QCheckBox*           nicknameCheck;
+    QCheckBox*           specialInstructionCheck;
 
-    QLineEdit*          nicknameEdit;
+    DTextEdit*           nicknameEdit;
 
-    QPlainTextEdit*     specialInstructionEdit;
+    DPlainTextEdit*      specialInstructionEdit;
 
-    MultiStringsEdit*   identifiersEdit;
+    MultiStringsEdit*    identifiersEdit;
 
-    AltLangStringsEdit* objectNameEdit;
+    AltLangStringsEdit*  objectNameEdit;
 };
 
 XMPStatus::XMPStatus(QWidget* const parent)
-    : QWidget(parent),
-      d      (new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    QGridLayout* const grid  = new QGridLayout(this);
+    QGridLayout* const grid  = new QGridLayout(widget());
 
     // --------------------------------------------------------
 
@@ -83,8 +75,9 @@ XMPStatus::XMPStatus(QWidget* const parent)
     // --------------------------------------------------------
 
     d->nicknameCheck = new QCheckBox(i18n("Nickname:"), this);
-    d->nicknameEdit  = new QLineEdit(this);
-    d->nicknameEdit->setClearButtonEnabled(true);
+    d->nicknameEdit  = new DTextEdit(this);
+    d->nicknameEdit->setLinesVisible(1);
+    d->nicknameEdit->setPlaceholderText(i18n("Set here a short informal name"));
     d->nicknameEdit->setWhatsThis(i18n("A short informal name for the resource."));
 
     // --------------------------------------------------------
@@ -95,7 +88,9 @@ XMPStatus::XMPStatus(QWidget* const parent)
     // --------------------------------------------------------
 
     d->specialInstructionCheck = new QCheckBox(i18n("Special Instructions:"), this);
-    d->specialInstructionEdit  = new QPlainTextEdit(this);
+    d->specialInstructionEdit  = new DPlainTextEdit(this);
+    d->specialInstructionEdit->setLinesVisible(4);
+    d->specialInstructionEdit->setPlaceholderText(i18n("Set here the editorial usage instructions"));
     d->specialInstructionEdit->setWhatsThis(i18n("Enter the editorial usage instructions."));
 
     // --------------------------------------------------------
@@ -108,8 +103,12 @@ XMPStatus::XMPStatus(QWidget* const parent)
     grid->addWidget(d->specialInstructionEdit,  4, 0, 1, 3);
     grid->setRowStretch(5, 10);
     grid->setColumnStretch(2, 10);
-    grid->setContentsMargins(QMargins());
-    grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+
+    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
+    grid->setSpacing(spacing);
 
     // --------------------------------------------------------
 
@@ -138,7 +137,7 @@ XMPStatus::XMPStatus(QWidget* const parent)
     connect(d->objectNameEdit, SIGNAL(signalModified()),
             this, SIGNAL(signalModified()));
 
-    connect(d->nicknameEdit, SIGNAL(textChanged(QString)),
+    connect(d->nicknameEdit, SIGNAL(textChanged()),
             this, SIGNAL(signalModified()));
 
     connect(d->specialInstructionEdit, SIGNAL(textChanged()),
@@ -242,3 +241,5 @@ void XMPStatus::applyMetadata(const DMetadata& meta)
 }
 
 } // namespace DigikamGenericMetadataEditPlugin
+
+#include "moc_xmpstatus.cpp"
