@@ -7,7 +7,7 @@
  * Description : a tool to generate HTML image galleries
  *
  * SPDX-FileCopyrightText: 2006-2010 by Aurelien Gateau <aurelien dot gateau at free dot fr>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -25,9 +25,8 @@ namespace DigikamGenericHtmlGalleryPlugin
 static const char* THEME_GROUP_PREFIX = "Theme ";
 
 GalleryInfo::GalleryInfo(DInfoInterface* const iface)
+    : m_iface(iface)
 {
-    m_iface     = iface;
-    m_getOption = IMAGES;
 }
 
 GalleryInfo::~GalleryInfo()
@@ -59,6 +58,7 @@ void GalleryInfo::setThemeParameterValue(const QString& theme,
                                          const QString& value)
 {
     // FIXME: This is hackish, but config() is const :'(
+
     KConfig* const localConfig = const_cast<KConfig*>(config());
     QString groupName          = QLatin1String(THEME_GROUP_PREFIX) + theme;
     KConfigGroup group         = localConfig->group(groupName);
@@ -68,6 +68,7 @@ void GalleryInfo::setThemeParameterValue(const QString& theme,
 QString GalleryInfo::getEnumString(const QString& itemName) const
 {
     // findItem is not marked const :-(
+
     GalleryInfo* const that               = const_cast<GalleryInfo*>(this);
     KConfigSkeletonItem* const tmp        = that->findItem(itemName);
     KConfigSkeleton::ItemEnum* const item = dynamic_cast<KConfigSkeleton::ItemEnum*>(tmp);
@@ -75,7 +76,9 @@ QString GalleryInfo::getEnumString(const QString& itemName) const
     Q_ASSERT(item);
 
     if (!item)
+    {
         return QString();
+    }
 
     int value                                                   = item->value();
     QList<KConfigSkeleton::ItemEnum::Choice> lst                = item->choices();
@@ -129,3 +132,5 @@ QDebug operator<<(QDebug dbg, const GalleryInfo& t)
 }
 
 } // namespace DigikamGenericHtmlGalleryPlugin
+
+#include "moc_galleryinfo.cpp"
