@@ -7,17 +7,9 @@
  * Description : a media server to export collections through DLNA.
  *               Implementation inspired on Platinum File Media Server.
  *
- * Copyright (C) 2017-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -219,7 +211,7 @@ NPT_Result DLNAMediaServerDelegate::OnBrowseDirectChildren(PLT_ActionReference&
 
         if (dir == "/")
         {
-            foreach (const QString& s, d->map.keys())
+            Q_FOREACH (const QString& s, d->map.keys())
             {
                 list << s + QLatin1Char('/');
             }
@@ -229,7 +221,7 @@ NPT_Result DLNAMediaServerDelegate::OnBrowseDirectChildren(PLT_ActionReference&
             QString container = QString::fromUtf8(dir.GetChars());
             QList<QUrl> urls  = d->map.value(container.remove(QLatin1Char('/')));
 
-            foreach (const QUrl& u, urls)
+            Q_FOREACH (const QUrl& u, urls)
             {
                 // Internal URL separator between container path and local file path.
                 // Ex: Linux => "/country/town/Paris/?file:/mnt/data/travel/Paris/eiffeltower.jpg
@@ -245,7 +237,7 @@ NPT_Result DLNAMediaServerDelegate::OnBrowseDirectChildren(PLT_ActionReference&
 
         entries = new NPT_List<NPT_String>();
 
-        foreach (const QString& path, list)
+        Q_FOREACH (const QString& path, list)
         {
             qCDebug(DIGIKAM_MEDIASRV_LOG) << "=>" << path;
             entries->Add(NPT_String(path.toUtf8().data(), path.toUtf8().size()));
@@ -726,7 +718,7 @@ NPT_Result DLNAMediaServerDelegate::ServeFile(const NPT_HttpRequest&        requ
     if (dimg.isNull())
     {
         // Not a supported image format. Try to stream file as well, without transcoding.
-        // TODO : support video file as transcoded video stream using QtAV (if possible).
+        // TODO : support video file as transcoded video stream using ffmpeg (if possible).
 
         qCDebug(DIGIKAM_MEDIASRV_LOG) << file_path.GetChars() << "not recognized as an image to stream as preview.";
 
