@@ -6,18 +6,10 @@
  * Date        : 2021-07-21
  * Description : MJPEG Stream Server configuration dialog - Private container
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2021 by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021      by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -54,18 +46,7 @@ MjpegStreamDlg::Private::Private()
       transVal            (nullptr),
       transPreview        (nullptr),
       tabView             (nullptr),
-      showName            (nullptr),
-      showDate            (nullptr),
-      showApertureFocal   (nullptr),
-      showExpoSensitivity (nullptr),
-      showMakeModel       (nullptr),
-      showLensModel       (nullptr),
-      showComment         (nullptr),
-      showTitle           (nullptr),
-      showTags            (nullptr),
-      showRating          (nullptr),
-      showCapIfNoTitle    (nullptr),
-      osdFont             (nullptr)
+      frameOsdWidget      (nullptr)
 {
 }
 
