@@ -6,18 +6,10 @@
  * Date        : 2021-07-21
  * Description : MJPEG Stream Server configuration dialog - Private container
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2021 by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021      by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -61,6 +53,7 @@
 #include "effectpreview.h"
 #include "dcombobox.h"
 #include "dfontselect.h"
+#include "frameosdwidget.h"
 
 namespace DigikamGenericMjpegStreamPlugin
 {
@@ -113,18 +106,8 @@ public:
     DComboBox*          transVal;
     TransitionPreview*  transPreview;
     QTabWidget*         tabView;
-    QCheckBox*          showName;
-    QCheckBox*          showDate;
-    QCheckBox*          showApertureFocal;
-    QCheckBox*          showExpoSensitivity;
-    QCheckBox*          showMakeModel;
-    QCheckBox*          showLensModel;
-    QCheckBox*          showComment;
-    QCheckBox*          showTitle;
-    QCheckBox*          showTags;
-    QCheckBox*          showRating;
-    QCheckBox*          showCapIfNoTitle;
-    DFontSelect*        osdFont;
+
+    FrameOsdWidget*     frameOsdWidget;
 
     MjpegStreamSettings settings;
 };
