@@ -6,18 +6,10 @@
  * Date        : 2021-07-24
  * Description : a plugin to share items with MJPEG Stream server.
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2021 by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021      by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -78,6 +70,16 @@ QString MjpegStreamPlugin::description() const
     return i18n("A tool to export items as MJPEG Stream");
 }
 
+QString MjpegStreamPlugin::handbookSection() const
+{
+    return QLatin1String("post_processing");
+}
+
+QString MjpegStreamPlugin::handbookChapter() const
+{
+    return QLatin1String("mjpeg_stream");
+}
+
 QString MjpegStreamPlugin::details() const
 {
     return i18n(
@@ -101,7 +103,7 @@ QList<DPluginAuthor> MjpegStreamPlugin::authors() const
                              i18n("Developer"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2021"),
+                             QString::fromUtf8("(C) 2021-2024"),
                              i18n("Developer and Maintainer"))
             ;
 }
@@ -129,3 +131,5 @@ void MjpegStreamPlugin::slotMjpegStream()
 }
 
 } // namespace DigikamGenericMjpegStreamPlugin
+
+#include "moc_mjpegstreamplugin.cpp"
