@@ -7,7 +7,7 @@
  * Description : Layouting photos on a page
  *
  * SPDX-FileCopyrightText: 2007-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -34,13 +34,10 @@ class Q_DECL_HIDDEN AtkinsPageLayout::Private
 {
 public:
 
-    explicit Private()
-      : tree(nullptr)
-    {
-    }
+    Private() = default;
 
     QMap<int, int>        indexMap;
-    AtkinsPageLayoutTree* tree;
+    AtkinsPageLayoutTree* tree = nullptr;
     QRectF                pageRect;
 };
 
