@@ -6,17 +6,9 @@
  * Date        : 2017-05-25
  * Description : a tool to print images
  *
- * Copyright (C) 2017-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -28,7 +20,6 @@
 #include <QDir>
 #include <QIcon>
 #include <QPointer>
-#include <QPrinter>
 #include <QPrinterInfo>
 #include <QWidget>
 #include <QMessageBox>
@@ -37,14 +28,12 @@
 #include <QMenu>
 #include <QAction>
 #include <QPageSetupDialog>
-#include <QXmlStreamWriter>
 #include <QXmlStreamAttributes>
 #include <QDomDocument>
 #include <QDomNode>
 
 // KDE includes
 
-#include <klocalizedstring.h>
 #include <kdesktopfile.h>
 
 // Local includes
@@ -53,11 +42,30 @@
 #include "advprintwizard.h"
 #include "advprintcustomdlg.h"
 #include "templateicon.h"
+#include "digikam_globals_p.h"      // For KF6::Ki18n deprecated
 
 namespace DigikamGenericPrintCreatorPlugin
 {
 
-static const char* const CUSTOM_PAGE_LAYOUT_NAME = I18N_NOOP2("@info layout page", "Custom");
+static const struct CustomPageLayoutName
+{
+
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
+    const KLazyLocalizedString    title;
+
+#else
+
+    const char*                   context;
+    const char*                   title;
+
+#endif
+
+}
+CUSTOM_PAGE_LAYOUT_NAME =
+{
+    I18NC_NOOP("@info layout page", "Custom")
+};
 
 class Q_DECL_HIDDEN AdvPrintPhotoPage::Private
 {
@@ -143,7 +151,7 @@ AdvPrintPhotoPage::AdvPrintPhotoPage(QWizard* const wizard, const QString& title
         d->photoUi->m_printer_choice->addSqueezedItem(it->printerName());
     }
 
-    connect(d->photoUi->m_printer_choice, SIGNAL(activated(QString)),
+    connect(d->photoUi->m_printer_choice, SIGNAL(signalItemActivated(QString)),
             this, SLOT(slotOutputChanged(QString)));
 
     connect(d->photoUi->BtnPreviewPageUp, SIGNAL(clicked()),
@@ -235,11 +243,20 @@ void AdvPrintPhotoPage::initializePage()
         d->wizard->setItemsList(d->settings->inputImages);
     }
 
-    initPhotoSizes(d->printer->paperSize(QPrinter::Millimeter));
+    initPhotoSizes(d->printer->pageLayout().pageSize().size(QPageSize::Millimeter));
 
     // restore photoSize
 
-    if (d->settings->savedPhotoSize == i18n(CUSTOM_PAGE_LAYOUT_NAME))
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
+    if (d->settings->savedPhotoSize == CUSTOM_PAGE_LAYOUT_NAME.title.toString())
+
+#else
+
+    if (d->settings->savedPhotoSize == i18nc(CUSTOM_PAGE_LAYOUT_NAME.context, CUSTOM_PAGE_LAYOUT_NAME.title))
+
+#endif
+
     {
         d->photoUi->ListPhotoSizes->setCurrentRow(0);
     }
@@ -282,7 +299,7 @@ void AdvPrintPhotoPage::initializePage()
     slotOutputChanged(d->photoUi->m_printer_choice->itemHighlighted());
 
     d->photoUi->ListPhotoSizes->setIconSize(QSize(32, 32));
-    initPhotoSizes(d->printer->paperSize(QPrinter::Millimeter));
+    initPhotoSizes(d->printer->pageLayout().pageSize().size(QPageSize::Millimeter));
 
     d->wizard->previewPhotos();
 }
@@ -349,7 +366,8 @@ void AdvPrintPhotoPage::slotOutputChanged(const QString& text)
     // default no margins
 
     d->printer->setFullPage(true);
-    d->printer->setPageMargins(0, 0, 0, 0, QPrinter::Millimeter);
+    QMarginsF margins(0, 0, 0, 0);
+    d->printer->setPageMargins(margins, QPageLayout::Millimeter);
 }
 
 void AdvPrintPhotoPage::slotXMLLoadElement(QXmlStreamReader& xmlReader)
@@ -382,7 +400,7 @@ void AdvPrintPhotoPage::slotXMLLoadElement(QXmlStreamReader& xmlReader)
 
                 // get value of each attribute from QXmlStreamAttributes
 
-                QStringRef attr                = attrs.value(QLatin1String("type"));
+                QStringView attr                = attrs.value(QLatin1String("type"));
                 bool ok;
 
                 if (!attr.isEmpty())
@@ -468,7 +486,7 @@ void AdvPrintPhotoPage::slotXMLCustomElement(QXmlStreamWriter& xmlWriter)
 {
     xmlWriter.writeStartElement(QLatin1String("pa_layout"));
     xmlWriter.writeAttribute(QLatin1String("Printer"),   d->photoUi->m_printer_choice->itemHighlighted());
-    xmlWriter.writeAttribute(QLatin1String("PageSize"),  QString::fromUtf8("%1").arg(d->printer->paperSize()));
+    xmlWriter.writeAttribute(QLatin1String("PageSize"),  QString::fromUtf8("%1").arg(d->printer->pageLayout().pageSize().id()));
     xmlWriter.writeAttribute(QLatin1String("PhotoSize"), d->photoUi->ListPhotoSizes->currentItem()->text());
     xmlWriter.writeEndElement(); // pa_layout
 }
@@ -610,7 +628,7 @@ void AdvPrintPhotoPage::slotRemovingItems(const QList<int>& list)
 
     d->photoUi->mPrintList->blockSignals(true);
 
-    foreach (int itemIndex, list)
+    Q_FOREACH (int itemIndex, list)
     {
         if (d->settings->photos.size() && itemIndex >= 0)
         {
@@ -705,16 +723,7 @@ void AdvPrintPhotoPage::slotBtnPrintOrderDownClicked()
                                  << " to  "
                                  << currentIndex;
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
-
     d->settings->photos.swapItemsAt(currentIndex, currentIndex - 1);
-
-#else
-
-    d->settings->photos.swap(currentIndex, currentIndex - 1);
-
-#endif
-
     d->photoUi->mPrintList->blockSignals(false);
     d->wizard->previewPhotos();
 }
@@ -729,16 +738,7 @@ void AdvPrintPhotoPage::slotBtnPrintOrderUpClicked()
                                  << " to  "
                                  << currentIndex + 1;
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
-
     d->settings->photos.swapItemsAt(currentIndex, currentIndex + 1);
-
-#else
-
-    d->settings->photos.swap(currentIndex, currentIndex + 1);
-
-#endif
-
     d->photoUi->mPrintList->blockSignals(false);
     d->wizard->previewPhotos();
 }
@@ -756,7 +756,7 @@ void AdvPrintPhotoPage::slotXMLCustomElement(QXmlStreamReader& xmlReader)
 
             // get value of each attribute from QXmlStreamAttributes
 
-            QStringRef attr            = attrs.value(QLatin1String("Printer"));
+            QStringView attr            = attrs.value(QLatin1String("Printer"));
 
             if (!attr.isEmpty())
             {
@@ -776,8 +776,8 @@ void AdvPrintPhotoPage::slotXMLCustomElement(QXmlStreamReader& xmlReader)
             if (!attr.isEmpty())
             {
                 qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << " found " << attr.toString();
-                QPrinter::PaperSize paperSize = (QPrinter::PaperSize)attr.toString().toInt(&ok);
-                d->printer->setPaperSize(paperSize);
+                QPageSize pageSize((QPageSize::PageSizeId)attr.toString().toInt(&ok));
+                d->printer->setPageSize(pageSize);
             }
 
             attr = attrs.value(QLatin1String("PhotoSize"));
@@ -796,7 +796,7 @@ void AdvPrintPhotoPage::slotXMLCustomElement(QXmlStreamReader& xmlReader)
 
     d->settings->currentPreviewPage = 0;
 
-    initPhotoSizes(d->printer->paperSize(QPrinter::Millimeter));
+    initPhotoSizes(d->printer->pageLayout().pageSize().size(QPageSize::Millimeter));
 
     QList<QListWidgetItem*> list    = d->photoUi->ListPhotoSizes->findItems(d->settings->savedPhotoSize,
                                                                             Qt::MatchExactly);
@@ -920,7 +920,16 @@ void AdvPrintPhotoPage::slotListPhotoSizesSelected()
 
     // if custom page layout we launch a dialog to choose what kind
 
-    if (item->text() == i18n(CUSTOM_PAGE_LAYOUT_NAME))
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
+    if (item->text() == CUSTOM_PAGE_LAYOUT_NAME.title.toString())
+
+#else
+
+    if (item->text() == i18nc(CUSTOM_PAGE_LAYOUT_NAME.context, CUSTOM_PAGE_LAYOUT_NAME.title))
+
+#endif
+
     {
         // check if a custom layout has already been added
 
@@ -1004,29 +1013,31 @@ void AdvPrintPhotoPage::slotListPhotoSizesSelected()
 
                 s->m_layouts.append(new QRect(0, 0, (int)sizeManaged.width(),
                                               (int)sizeManaged.height()));
-                s->m_autoRotate  = custDlg->m_autorotate->isChecked();
-                s->m_label       = item->text();
-                s->m_dpi         = 0;
-                int nColumns     = int(size.width()  / width);
-                int nRows        = int(size.height() / height);
-                int spareWidth   = int(size.width()) % int(width);
+                s->m_autoRotate   = custDlg->m_autorotate->isChecked();
+                s->m_label        = item->text();
+                s->m_dpi          = 0;
+                int nColumns      = int(size.width()  / width);
+                int nRows         = int(size.height() / height);
+                double spareWidth = int(size.width() * scaleValue) % int(width * scaleValue);
+                spareWidth       /= scaleValue;
 
                 // check if there's no room left to separate photos
 
-                if ((nColumns > 1) && (spareWidth == 0))
+                if ((nColumns > 1) && (spareWidth == 0.0))
                 {
                     nColumns  -= 1;
                     spareWidth = width;
                 }
 
-                int spareHeight = int(size.height()) % int(height);
+                double spareHeight = int(size.height() * scaleValue) % int(height * scaleValue);
+                spareHeight       /= scaleValue;
 
                 // check if there's no room left to separate photos
 
-                if ((nRows > 1) && (spareHeight == 0))
+                if ((nRows > 1) && (spareHeight == 0.0))
                 {
                     nRows      -= 1;
-                    spareHeight = int(height);
+                    spareHeight = height;
                 }
 
                 if ((nRows > 0) && (nColumns > 0))
@@ -1103,7 +1114,7 @@ void AdvPrintPhotoPage::slotListPhotoSizesSelected()
 
     if (!s)
     {
-        QMessageBox::warning(this, i18n("Custom layout"),
+        QMessageBox::warning(this, i18nc("@title:window", "Custom Layout"),
                              i18n("The selected custom photo size can "
                                   "not be applied to the paper size."));
 
@@ -1127,14 +1138,16 @@ void AdvPrintPhotoPage::slotPageSetup()
         QPrinter* const printer = d->pageSetupDlg->printer();
 
         qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Dialog exit, new size "
-                                     << printer->paperSize(QPrinter::Millimeter)
+                                     << printer->pageLayout().pageSize().size(QPageSize::Millimeter)
                                      << " internal size "
-                                     << d->printer->paperSize(QPrinter::Millimeter);
+                                     << d->printer->pageLayout().pageSize().size(QPageSize::Millimeter);
 
         qreal left, top, right, bottom;
-        d->printer->getPageMargins(&left, &top,
-                                   &right, &bottom,
-                                   QPrinter::Millimeter);
+        auto margins = d->printer->pageLayout().margins(QPageLayout::Millimeter);
+        left         = margins.left();
+        top          = margins.top();
+        right        = margins.right();
+        bottom       = margins.bottom();
 
         qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Dialog exit, new margins: left "
                                      << left
@@ -1168,11 +1181,20 @@ void AdvPrintPhotoPage::slotPageSetup()
 
     // Fix the page size dialog and preview PhotoPage
 
-    initPhotoSizes(d->printer->paperSize(QPrinter::Millimeter));
+    initPhotoSizes(d->printer->pageLayout().pageSize().size(QPageSize::Millimeter));
 
     // restore photoSize
 
-    if (lastSize == i18n(CUSTOM_PAGE_LAYOUT_NAME))
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
+    if (lastSize == CUSTOM_PAGE_LAYOUT_NAME.title.toString())
+
+#else
+
+    if (lastSize == i18nc(CUSTOM_PAGE_LAYOUT_NAME.context, CUSTOM_PAGE_LAYOUT_NAME.title))
+
+#endif
+
     {
         d->photoUi->ListPhotoSizes->setCurrentRow(0);
     }
@@ -1255,7 +1277,7 @@ void AdvPrintPhotoPage::initPhotoSizes(const QSizeF& pageSize)
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Template XML files list: "
                                          << list;
 
-    foreach (const QString& fn, list)
+    Q_FOREACH (const QString& fn, list)
     {
         parseTemplateFile(dir.absolutePath() + QLatin1Char('/') + fn, pageSize);
     }
@@ -1304,7 +1326,15 @@ void AdvPrintPhotoPage::initPhotoSizes(const QSizeF& pageSize)
 
     // Adding custom choice
 
-    QListWidgetItem* const pWItem = new QListWidgetItem(i18n(CUSTOM_PAGE_LAYOUT_NAME));
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
+    QListWidgetItem* const pWItem = new QListWidgetItem(CUSTOM_PAGE_LAYOUT_NAME.title.toString());
+
+#else
+
+    QListWidgetItem* const pWItem = new QListWidgetItem(i18nc(CUSTOM_PAGE_LAYOUT_NAME.context, CUSTOM_PAGE_LAYOUT_NAME.title));
+
+#endif
 
     TemplateIcon ti(80, pageSize.toSize());
     ti.begin();
@@ -1628,3 +1658,5 @@ void AdvPrintPhotoPage::parseTemplateFile(const QString& fn, const QSizeF& pageS
 }
 
 } // namespace DigikamGenericPrintCreatorPlugin
+
+#include "moc_advprintphotopage.cpp"
