@@ -6,20 +6,12 @@
  * Date        : 2004-02-25
  * Description : a tool to e-mailing images
  *
- * Copyright (C) 2004-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010      by Andi Clemens <andi dot clemens at googlemail dot com>
- * Copyright (C) 2006      by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2006      by Michael Hoechstetter <michael dot hoechstetter at gmx dot de>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010      by Andi Clemens <andi dot clemens at googlemail dot com>
+ * SPDX-FileCopyrightText: 2006      by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2006      by Michael Hoechstetter <michael dot hoechstetter at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -32,7 +24,9 @@
 #include <QProcess>
 #include <QPointer>
 #include <QStringList>
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 #include <QTextCodec>
+#endif
 #include <QTextStream>
 #include <QApplication>
 #include <QMessageBox>
@@ -117,9 +111,9 @@ void MailProcess::firstStage()
 
     if (!tempPath.isValid())
     {
-        emit signalMessage(i18n("Cannot create a temporary directory"), true);
+        Q_EMIT signalMessage(i18n("Cannot create a temporary directory"), true);
         slotCancel();
-        emit signalDone(false);
+        Q_EMIT signalDone(false);
 
         return;
     }
@@ -148,7 +142,7 @@ void MailProcess::firstStage()
             d->settings->setMailUrl(it.key(), it.key());
         }
 
-        emit signalProgress(50);
+        Q_EMIT signalProgress(50);
         secondStage();
     }
 }
@@ -163,7 +157,7 @@ void MailProcess::slotCancel()
         d->threadImgResize->wait();
     }
 
-    emit signalProgress(0);
+    Q_EMIT signalProgress(0);
 
     slotCleanUp();
 }
@@ -176,7 +170,7 @@ void MailProcess::slotStartingResize(const QUrl& orgUrl)
     }
 
     QString text = i18n("Resizing %1", orgUrl.fileName());
-    emit signalMessage(text, false);
+    Q_EMIT signalMessage(text, false);
 }
 
 void MailProcess::slotFinishedResize(const QUrl& orgUrl, const QUrl& emailUrl, int percent)
@@ -186,13 +180,13 @@ void MailProcess::slotFinishedResize(const QUrl& orgUrl, const QUrl& emailUrl, i
         return;
     }
 
-    emit signalProgress((int)(80.0*(percent/100.0)));
+    Q_EMIT signalProgress((int)(80.0*(percent/100.0)));
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << emailUrl;
     d->attachementFiles.append(emailUrl);
     d->settings->setMailUrl(orgUrl, emailUrl);
 
     QString text = i18n("%1 resized successfully", orgUrl.fileName());
-    emit signalMessage(text, false);
+    Q_EMIT signalMessage(text, false);
 }
 
 void MailProcess::slotFailedResize(const QUrl& orgUrl, const QString& error, int percent)
@@ -202,9 +196,9 @@ void MailProcess::slotFailedResize(const QUrl& orgUrl, const QString& error, int
         return;
     }
 
-    emit signalProgress((int)(80.0*(percent/100.0)));
+    Q_EMIT signalProgress((int)(80.0*(percent/100.0)));
     QString text = i18n("Failed to resize %1: %2", orgUrl.fileName(), error);
-    emit signalMessage(text, true);
+    Q_EMIT signalMessage(text, true);
 
     d->failedResizedImages.append(orgUrl);
 }
@@ -239,16 +233,16 @@ void MailProcess::secondStage()
 
     if (d->attachementFiles.isEmpty())
     {
-        emit signalMessage(i18n("There are no files to send"), false);
-        emit signalProgress(0);
+        Q_EMIT signalMessage(i18n("There are no files to send"), false);
+        Q_EMIT signalProgress(0);
 
         return;
     }
 
     buildPropertiesFile();
-    emit signalProgress(90);
+    Q_EMIT signalProgress(90);
     invokeMailAgent();
-    emit signalProgress(100);
+    Q_EMIT signalProgress(100);
 }
 
 void MailProcess::buildPropertiesFile()
@@ -260,7 +254,7 @@ void MailProcess::buildPropertiesFile()
 
     if (d->iface && d->settings->addFileProperties)
     {
-        emit signalMessage(i18n("Build images properties file"), false);
+        Q_EMIT signalMessage(i18n("Build images properties file"), false);
 
         QString propertiesText;
 
@@ -297,12 +291,15 @@ void MailProcess::buildPropertiesFile()
 
         QFile propertiesFile(d->settings->tempPath + i18n("properties.txt"));
         QTextStream stream(&propertiesFile);
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+        // In Qt5 only. Qt6 uses UTF-8 by default.
         stream.setCodec(QTextCodec::codecForName("UTF-8"));
+#endif
         stream.setAutoDetectUnicode(true);
 
         if (!propertiesFile.open(QIODevice::WriteOnly))
         {
-            emit signalMessage(i18n("Image properties file cannot be opened"), true);
+            Q_EMIT signalMessage(i18n("Image properties file cannot be opened"), true);
             qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "File open error:" << propertiesFile.fileName();
 
             return;
@@ -314,7 +311,7 @@ void MailProcess::buildPropertiesFile()
 
         qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Image properties file done" << propertiesFile.fileName();
 
-        emit signalMessage(i18n("Image properties file done"), false);
+        Q_EMIT signalMessage(i18n("Image properties file done"), false);
     }
 }
 
@@ -334,7 +331,7 @@ bool MailProcess::showFailedResizedImages() const
 
         QPointer<QMessageBox> mbox = new QMessageBox(QApplication::activeWindow());
         mbox->setIcon(QMessageBox::Warning);
-        mbox->setWindowTitle(i18n("Processing Failed"));
+        mbox->setWindowTitle(i18nc("@title:window", "Processing Failed"));
         mbox->setText(i18n("Some images cannot be resized.\n"
                            "Do you want them to be added as attachments without resizing?"));
         mbox->setStandardButtons(QMessageBox::StandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel));
@@ -408,7 +405,7 @@ QList<QUrl> MailProcess::divideEmails()
                 QString mess = i18n("The file \"%1\" is too big to be sent, "
                                     "please reduce its size or change your settings",
                                     file.fileName());
-                emit signalMessage(mess, true);
+                Q_EMIT signalMessage(mess, true);
             }
             else
             {
@@ -635,21 +632,21 @@ void MailProcess::invokeMailAgentError(const QString& prog, const QStringList& a
 {
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Command Line: " << prog << args;
     QString text = i18n("Failed to start \"%1\" program. Check your system.", prog);
-    emit signalMessage(text, true);
+    Q_EMIT signalMessage(text, true);
     slotCleanUp();
 
-    emit signalDone(false);
+    Q_EMIT signalDone(false);
 }
 
 void MailProcess::invokeMailAgentDone(const QString& prog, const QStringList& args)
 {
     qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Command Line: " << prog << args;
     QString text = i18n("Starting \"%1\" program...", prog);
-    emit signalMessage(text, false);
+    Q_EMIT signalMessage(text, false);
 
-    emit signalMessage(i18n("After having sent your images by email..."), false);
-    emit signalMessage(i18n("Press 'Finish' button to clean up temporary files"), false);
-    emit signalDone(true);
+    Q_EMIT signalMessage(i18n("After having sent your images by email..."), false);
+    Q_EMIT signalMessage(i18n("Press 'Finish' button to clean up temporary files"), false);
+    Q_EMIT signalDone(true);
 }
 
 void MailProcess::slotCleanUp()
@@ -661,3 +658,5 @@ void MailProcess::slotCleanUp()
 }
 
 } // namespace DigikamGenericSendByMailPlugin
+
+#include "moc_mailprocess.cpp"
