@@ -6,22 +6,14 @@
  * Date        : 2007-11-14
  * Description : a presentation tool.
  *
- * Copyright (C) 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * Copyright (C) 2012-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Parts of this code are based on
  * smoothslidesaver by Carsten Weinhold <carsten dot weinhold at gmx dot de>
  * and slideshowgl by Renchi Raju <renchi dot raju at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -33,13 +25,11 @@
 
 // Qt includes
 
-#include <QList>
 #include <QImage>
 #include <QPainter>
 #include <QFont>
 #include <QCursor>
 #include <QPixmap>
-#include <QMouseEvent>
 #include <QApplication>
 #include <QScreen>
 #include <QWindow>
@@ -50,7 +40,6 @@
 #include <ksharedconfig.h>
 #include <kconfiggroup.h>
 
-
 namespace DigikamGenericPresentationPlugin
 {
 
@@ -185,12 +174,12 @@ float KBViewTrans::yScaleCorrect() const
 
 double KBViewTrans::rnd() const
 {
-    return ((double)qrand() / (double)RAND_MAX);
+    return QRandomGenerator::global()->generateDouble();
 }
 
 double KBViewTrans::rndSign() const
 {
-    return ((qrand() < RAND_MAX / 2) ? 1.0 : -1.0);
+    return ((QRandomGenerator::global()->bounded(2U) == 0) ? 1.0 : -1.0);
 }
 
 // -------------------------------------------------------------------------
@@ -247,18 +236,18 @@ PresentationKB::PresentationKB(PresentationContainer* const sharedData)
         }
     }
 
-    QRect deskRect  = screen->geometry();
-    d->deskX        = deskRect.x();
-    d->deskY        = deskRect.y();
-    d->deskWidth    = deskRect.width();
-    d->deskHeight   = deskRect.height();
+    QRect deskRect = screen->geometry();
+    d->deskX       = deskRect.x();
+    d->deskY       = deskRect.y();
+    d->deskWidth   = deskRect.width();
+    d->deskHeight  = deskRect.height();
 
     move(d->deskX, d->deskY);
     resize(d->deskWidth, d->deskHeight);
 
-    d->sharedData  = sharedData;
+    d->sharedData          = sharedData;
+    d->sharedData->display = this;
 
-    qsrand(QTime::currentTime().msec());
     readSettings();
 
     unsigned frameRate;
@@ -290,7 +279,7 @@ PresentationKB::PresentationKB(PresentationContainer* const sharedData)
 
     d->playbackWidget = new PresentationAudioWidget(this, d->sharedData->soundtrackUrls, d->sharedData);
     d->playbackWidget->hide();
-    d->playbackWidget->move(d->deskX, d->deskY);
+    d->playbackWidget->move(0, 0);
 
 #endif
 
@@ -387,17 +376,23 @@ void PresentationKB::setNewKBEffect()
     switch (type)
     {
         case KBEffect::Fade:
+        {
             d->effect = new FadeKBEffect(this, needFadeIn);
             break;
+        }
 
         case KBEffect::Blend:
+        {
             d->effect = new BlendKBEffect(this, needFadeIn);
             break;
+        }
 
         default:
+        {
             qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Unknown transition effect, falling back to crossfade";
             d->effect = new BlendKBEffect(this, needFadeIn);
             break;
+        }
     }
 }
 
@@ -411,6 +406,7 @@ void PresentationKB::moveSlot()
             d->imageLoadThread->requestNewImage();
             d->endOfShow = !d->haveImages;
         }
+
         if (d->enableSameSpeed)
         {
             d->effect->advanceTime(d->stepSameSpeed);
@@ -606,7 +602,7 @@ void PresentationKB::paintTexture(KBImage* const img)
 void PresentationKB::readSettings()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup group      = config->group("Presentation Settings");
+    KConfigGroup group      = config->group(QLatin1String("Presentation Settings"));
 
     d->delay                = group.readEntry("Delay", 8000) / 1000;
     d->disableFadeInOut     = group.readEntry("KB Disable FadeInOut", false);
@@ -735,8 +731,8 @@ void PresentationKB::mouseMoveEvent(QMouseEvent* e)
 
     QPoint pos(e->pos());
 
-    if ((pos.y() > (d->deskY + 20)) &&
-        (pos.y() < (d->deskY + d->deskHeight - 20 - 1)))
+    if ((pos.y() > 20)                     &&
+        (pos.y() < (d->deskHeight - 20 - 1)))
     {
         if (d->playbackWidget->isHidden())
         {
@@ -764,8 +760,8 @@ void PresentationKB::slotMouseMoveTimeOut()
 {
     QPoint pos(QCursor::pos());
 
-    if ((pos.y() < (d->deskY + 20)) ||
-        (pos.y() > (d->deskY + d->deskHeight - 20 - 1))
+    if ((pos.y() < 20)                    ||
+        (pos.y() > (d->deskHeight - 20 - 1))
 
 #ifdef HAVE_MEDIAPLAYER
 
@@ -810,3 +806,5 @@ void PresentationKB::slotClose()
 }
 
 } // namespace DigikamGenericPresentationPlugin
+
+#include "moc_presentationkb.cpp"
