@@ -9,7 +9,7 @@
  * SPDX-FileCopyrightText: 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2012-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -24,7 +24,6 @@
 // Qt includes
 
 #include <QTime>
-#include <QList>
 #include <QPair>
 #include <QStringList>
 #include <QAction>
@@ -172,3 +171,5 @@ void PresentationMngr::slotSlideShow()
 }
 
 } // namespace DigikamGenericPresentationPlugin
+
+#include "moc_presentationmngr.cpp"
