@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a plugin to render slideshow.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -96,7 +96,7 @@ QString SlideShowPlugin::details() const
                     "<tr><td></td>"                      "<td>Right mouse button</td></tr>"
                     "<tr><td>Pause/Start:</td>"          "<td><i>Space</i> key</td></tr>"
                     "<tr><td>Slideshow Settings:</td>"   "<td><i>F2</i> key</td></tr>"
-                    "<tr><td>Hide/Show Properties:</td>" "<td><i>F4</i> key</td></tr>"
+                    "<tr><td>Hide/Show Overlays:</td>"   "<td><i>F4</i> key</td></tr>"
                     "<tr><td>Quit:</td>"                 "<td><i>Esc</i> key</td></tr>"
 
                     "<tr>"
@@ -142,7 +142,7 @@ QList<DPluginAuthor> SlideShowPlugin::authors() const
                              QString::fromUtf8("(C) 2004-2005"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2021"))
+                             QString::fromUtf8("(C) 2005-2023"))
             << DPluginAuthor(QString::fromUtf8("Minh Nghia Duong"),
                              QString::fromUtf8("minhnghiaduong997 at gmail dot com"),
                              QString::fromUtf8("(C) 2019-2021"))
@@ -360,3 +360,5 @@ void SlideShowPlugin::slideshow(SlideShowSettings* const settings, bool autoPlay
 }
 
 } // namespace DigikamGenericSlideShowPlugin
+
+#include "moc_slideshowplugin.cpp"
