@@ -6,7 +6,7 @@
  * Date        : 2014-09-18
  * Description : slideshow image widget
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -39,7 +39,7 @@ class SlideImage : public QWidget
 
 public:
 
-    explicit SlideImage(QWidget* const parent = nullptr);
+    explicit SlideImage(QWidget* const parent);
     ~SlideImage() override;
 
     void setPreviewSettings(const PreviewSettings& settings);
