@@ -6,20 +6,12 @@
  * Date        : 2008-12-26
  * Description : a tool to export items to Facebook web service
  *
- * Copyright (C) 2008-2010 by Luka Renko <lure at kubuntu dot org>
- * Copyright (c) 2011      by Dirk Tilger <dirk dot kde at miriup dot de>
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2018      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2010 by Luka Renko <lure at kubuntu dot org>
+ * SPDX-FileCopyrightText: 2011      by Dirk Tilger <dirk dot kde at miriup dot de>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -38,8 +30,6 @@
 #include <QtAlgorithms>
 #include <QVBoxLayout>
 #include <QLineEdit>
-#include <QPlainTextEdit>
-#include <QList>
 #include <QDesktopServices>
 #include <QApplication>
 #include <QPushButton>
@@ -166,7 +156,7 @@ FbTalker::~FbTalker()
 // ----------------------------------------------------------------------------------------------
 void FbTalker::link()
 {
-    emit signalBusy(true);
+    Q_EMIT signalBusy(true);
 
     d->loginInProgress = true;
     d->o2->link();
@@ -174,7 +164,7 @@ void FbTalker::link()
 
 void FbTalker::unlink()
 {
-    emit signalBusy(true);
+    Q_EMIT signalBusy(true);
     d->o2->unlink();
 }
 
@@ -204,7 +194,7 @@ FbUser FbTalker::getUser() const
 void FbTalker::authenticate()
 {
     d->loginInProgress = true;
-    emit signalLoginProgress(2, 9, i18n("Validate previous session..."));
+    Q_EMIT signalLoginProgress(2, 9, i18n("Validate previous session..."));
 
     WSTalker::authenticate();
 }
@@ -219,8 +209,8 @@ void FbTalker::getLoggedInUser()
         m_reply = 0;
     }
 
-    emit signalBusy(true);
-    emit signalLoginProgress(3);
+    Q_EMIT signalBusy(true);
+    Q_EMIT signalLoginProgress(3);
 
     QUrl url(d->apiURL.arg(QLatin1String("me"))
                       .arg(QString()));
@@ -289,7 +279,7 @@ void FbTalker::logout()
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Logout URL: " << url;
     QDesktopServices::openUrl(url);
 
-    emit signalBusy(false);
+    Q_EMIT signalBusy(false);
 }
 
 //TODO: Ported to O2
@@ -305,7 +295,7 @@ void FbTalker::listAlbums(long long userID)
         m_reply = 0;
     }
 
-    emit signalBusy(true);
+    Q_EMIT signalBusy(true);
 
     QUrl url;
 
@@ -347,7 +337,7 @@ void FbTalker::createAlbum(const FbAlbum& album)
         m_reply = 0;
     }
 
-    emit signalBusy(true);
+    Q_EMIT signalBusy(true);
 
     QUrlQuery params;
     params.addQueryItem(QLatin1String("access_token"), d->o2->token());
@@ -415,7 +405,7 @@ void FbTalker::addPhoto(const QString& imgPath, const QString& albumID, const QS
         m_reply = 0;
     }
 
-    emit signalBusy(true);
+    Q_EMIT signalBusy(true);
 
     QMap<QString, QString> args;
     args[QLatin1String("access_token")] = d->o2->token();
@@ -431,12 +421,12 @@ void FbTalker::addPhoto(const QString& imgPath, const QString& albumID, const QS
         form.addPair(it.key(), it.value());
     }
 
-    qCDebug(DIGIKAM_WEBSERVICES_LOG) << "FORM: " << endl << form.formData();
+    qCDebug(DIGIKAM_WEBSERVICES_LOG) << "FORM: " << QT_ENDL << form.formData();
 
     if (!form.addFile(QUrl::fromLocalFile(imgPath).fileName(), imgPath))
     {
-        emit signalAddPhotoDone(666, i18n("Cannot open file"));
-        emit signalBusy(false);
+        Q_EMIT signalAddPhotoDone(666, i18n("Cannot open file"));
+        Q_EMIT signalBusy(false);
         return;
     }
 
@@ -522,14 +512,14 @@ void FbTalker::slotFinished(QNetworkReply* reply)
         }
         else if (d->state == Private::FB_ADDPHOTO)
         {
-            emit signalBusy(false);
-            emit signalAddPhotoDone(reply->error(), reply->errorString());
+            Q_EMIT signalBusy(false);
+            Q_EMIT signalAddPhotoDone(reply->error(), reply->errorString());
         }
         else
         {
-            emit signalBusy(false);
+            Q_EMIT signalBusy(false);
             QMessageBox::critical(QApplication::activeWindow(),
-                                  i18n("Error"), reply->errorString());
+                                  i18nc("@title:window", "Error"), reply->errorString());
         }
 
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << reply->error() << " text :"<< QString(reply->readAll());
@@ -571,7 +561,7 @@ void FbTalker::authenticationDone(int errCode, const QString& errMsg)
         saveUserAccount(d->user.name, d->user.id, d->o2->expires(), d->o2->token(), d->o2->refreshToken());
     }
 
-    emit signalLoginDone(errCode, errMsg);
+    Q_EMIT signalLoginDone(errCode, errMsg);
     d->loginInProgress = false;
 
     WSTalker::authenticationDone(errCode, errMsg);
@@ -613,7 +603,7 @@ void FbTalker::parseResponseGetLoggedInUser(const QByteArray& data)
 
     if (err.error != QJsonParseError::NoError)
     {
-        emit signalBusy(false);
+        Q_EMIT signalBusy(false);
         return;
     }
 
@@ -641,7 +631,7 @@ void FbTalker::parseResponseAddPhoto(const QByteArray& data)
 
     if (err.error != QJsonParseError::NoError)
     {
-        emit signalBusy(false);
+        Q_EMIT signalBusy(false);
         return;
     }
 
@@ -662,8 +652,8 @@ void FbTalker::parseResponseAddPhoto(const QByteArray& data)
 
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "add photo : " << doc;
 
-    emit signalBusy(false);
-    emit signalAddPhotoDone(errCode, errorToText(errCode, errMsg));
+    Q_EMIT signalBusy(false);
+    Q_EMIT signalAddPhotoDone(errCode, errorToText(errCode, errMsg));
 }
 
 void FbTalker::parseResponseCreateAlbum(const QByteArray& data)
@@ -677,7 +667,7 @@ void FbTalker::parseResponseCreateAlbum(const QByteArray& data)
 
     if (err.error != QJsonParseError::NoError)
     {
-        emit signalBusy(false);
+        Q_EMIT signalBusy(false);
         return;
     }
 
@@ -699,8 +689,8 @@ void FbTalker::parseResponseCreateAlbum(const QByteArray& data)
 
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "error create photo : " << doc;
 
-    emit signalBusy(false);
-    emit signalCreateAlbumDone(errCode, errorToText(errCode, errMsg),
+    Q_EMIT signalBusy(false);
+    Q_EMIT signalCreateAlbumDone(errCode, errorToText(errCode, errMsg),
                                newAlbumID);
 }
 
@@ -714,7 +704,7 @@ void FbTalker::parseResponseListAlbums(const QByteArray& data)
 
     if (err.error != QJsonParseError::NoError)
     {
-        emit signalBusy(false);
+        Q_EMIT signalBusy(false);
         return;
     }
 
@@ -724,7 +714,7 @@ void FbTalker::parseResponseListAlbums(const QByteArray& data)
     {
         QJsonArray jsonArray = jsonObject[QLatin1String("data")].toArray();
 
-        foreach (const QJsonValue& value, jsonArray)
+        Q_FOREACH (const QJsonValue& value, jsonArray)
         {
             QJsonObject obj   = value.toObject();
             WSAlbum album; //FbAlbum album;
@@ -781,9 +771,11 @@ void FbTalker::parseResponseListAlbums(const QByteArray& data)
      */
     sortAlbumsList(albumsList);
 
-    emit signalBusy(false);
-    emit signalListAlbumsDone(errCode, errorToText(errCode, errMsg),
+    Q_EMIT signalBusy(false);
+    Q_EMIT signalListAlbumsDone(errCode, errorToText(errCode, errMsg),
                               albumsList);
 }
 
 } // namespace DigikamGenericFaceBookPlugin
+
+#include "moc_fbtalker_wizard.cpp"
