@@ -7,7 +7,7 @@
  * Description : file copy actions using threads.
  *
  * SPDX-FileCopyrightText: 2012      by Smit Mehta <smit dot meh at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Maik Qualmann <metzpinguin at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,6 +34,7 @@
 #include "previewloadthread.h"
 #include "dmetadata.h"
 #include "dimg.h"
+#include "metaenginesettings.h"
 
 namespace DigikamGenericFileCopyPlugin
 {
@@ -77,10 +78,8 @@ void FCTask::run()
 
     if (d->settings.iface && d->settings.iface->supportAlbums() && d->settings.albumPath)
     {
-        DInfoInterface::DInfoMap infoMap  = d->settings.iface->itemInfo(d->srcUrl);
-        DItemInfo info(infoMap);
-        DInfoInterface::DInfoMap albumMap = d->settings.iface->albumInfo(info.albumId());
-        DAlbumInfo album(albumMap);
+        DItemInfo info(d->settings.iface->itemInfo(d->srcUrl));
+        DAlbumInfo album(d->settings.iface->albumInfo(info.albumId()));
 
         dest.setPath(dest.path() + album.albumPath());
         dest = dest.adjusted(QUrl::StripTrailingSlash);
@@ -139,6 +138,18 @@ void FCTask::run()
                 DFileOperations::copyFile(DMetadata::sidecarUrl(d->srcUrl).toLocalFile(),
                                           sidecarDest.toLocalFile());
             }
+
+            if (d->settings.writeMetadataToFile &&
+                (MetaEngineSettings::instance()->settings().metadataWritingMode == MetaEngine::WRITE_TO_SIDECAR_ONLY))
+            {
+                QScopedPointer<DMetadata> meta(new DMetadata);
+
+                if (meta->load(d->srcUrl.toLocalFile()))
+                {
+                    meta->setMetadataWritingMode(DMetadata::WRITE_TO_FILE_ONLY);
+                    meta->save(dest.toLocalFile());
+                }
+            }
         }
     }
     else if (ok                                                     &&
@@ -324,3 +335,5 @@ QUrl FCTask::getUrlOrDelete(const QUrl& fileUrl) const
 }
 
 } // namespace DigikamGenericFileCopyPlugin
+
+#include "moc_fctask.cpp"
