@@ -7,7 +7,7 @@
  * Description : a tool to export items to Google web services
  *
  * SPDX-FileCopyrightText: 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009      by Luka Renko <lure at kubuntu dot org>
  * SPDX-FileCopyrightText: 2018      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
  *
@@ -33,7 +33,6 @@
 #include <QFileInfo>
 #include <QImage>
 #include <QStringList>
-#include <QUrl>
 #include <QUrlQuery>
 #include <QApplication>
 #include <QDir>
@@ -925,3 +924,5 @@ void GPTalker::parseResponseUploadPhoto(const QByteArray& data)
 }
 
 } // namespace DigikamGenericGoogleServicesPlugin
+
+#include "moc_gptalker.cpp"
