@@ -20,7 +20,6 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QGroupBox>
-#include <QRadioButton>
 #include <QDialogButtonBox>
 #include <QIcon>
 #include <QApplication>
@@ -155,3 +154,5 @@ void GSNewAlbumDlg::getAlbumProperties(GSFolder& album)
 }
 
 } // namespace DigikamGenericGoogleServicesPlugin
+
+#include "moc_gsnewalbumdlg.cpp"
