@@ -6,19 +6,11 @@
  * Date        : 2013-11-18
  * Description : a tool to export items to Google web services
  *
- * Copyright (C) 2013      by Pankaj Kumar <me at panks dot me>
- * Copyright (C) 2015      by Shourya Singh Gupta <shouryasgupta at gmail dot com>
- * Copyright (C) 2013-2020 by Caulier Gilles <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Pankaj Kumar <me at panks dot me>
+ * SPDX-FileCopyrightText: 2015      by Shourya Singh Gupta <shouryasgupta at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2020 by Caulier Gilles <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -36,9 +28,7 @@
 #include <QStringList>
 #include <QSpinBox>
 #include <QFileInfo>
-#include <QPointer>
 #include <QDesktopServices>
-#include <QUrl>
 #include <QScopedPointer>
 
 // KDE includes
@@ -54,7 +44,6 @@
 #include "digikam_version.h"
 #include "dprogresswdg.h"
 #include "gdtalker.h"
-#include "gsitem.h"
 #include "gsnewalbumdlg.h"
 #include "gswidget.h"
 #include "gptalker.h"
@@ -145,10 +134,10 @@ GSWindow::GSWindow(DInfoInterface* const iface,
     {
         case GoogleService::GDrive:
         {
-            setWindowTitle(i18nc("@title", "Export to Google Drive"));
+            setWindowTitle(i18nc("@title:window", "Export to Google Drive"));
 
-            startButton()->setText(i18nc("@action", "Start Upload"));
-            startButton()->setToolTip(i18nc("@info", "Start upload to Google Drive"));
+            startButton()->setText(i18nc("@action:button", "Start Upload"));
+            startButton()->setToolTip(i18nc("@info:tooltip, button", "Start upload to Google Drive"));
 
             d->widget->setMinimumSize(700, 500);
 
@@ -192,19 +181,19 @@ GSWindow::GSWindow(DInfoInterface* const iface,
         {
             if (d->service == GoogleService::GPhotoExport)
             {
-                setWindowTitle(i18nc("@title", "Export to Google Photos Service"));
+                setWindowTitle(i18nc("@title:window", "Export to Google Photos Service"));
 
-                startButton()->setText(i18nc("@action", "Start Upload"));
-                startButton()->setToolTip(i18nc("@info", "Start upload to Google Photos Service"));
+                startButton()->setText(i18nc("@action:button", "Start Upload"));
+                startButton()->setToolTip(i18nc("@info:tooltip, button", "Start upload to Google Photos service"));
 
                 d->widget->setMinimumSize(700, 500);
             }
             else
             {
-                setWindowTitle(i18nc("@title", "Import from Google Photos Service"));
+                setWindowTitle(i18nc("@title:window", "Import from Google Photos Service"));
 
-                startButton()->setText(i18nc("@action", "Start Download"));
-                startButton()->setToolTip(i18nc("@info", "Start download from Google Photos service"));
+                startButton()->setText(i18nc("@action:button", "Start Download"));
+                startButton()->setToolTip(i18nc("@info:tooltip, button", "Start download from Google Photos service"));
 
                 d->widget->setMinimumSize(300, 400);
             }
@@ -292,11 +281,11 @@ void GSWindow::readSettings()
     switch (d->service)
     {
         case GoogleService::GDrive:
-            grp = config->group("Google Drive Settings");
+            grp = config->group(QLatin1String("Google Drive Settings"));
             break;
 
         default:
-            grp = config->group("Google Photo Settings");
+            grp = config->group(QLatin1String("Google Photo Settings"));
             break;
     }
 
@@ -332,11 +321,11 @@ void GSWindow::writeSettings()
     switch (d->service)
     {
         case GoogleService::GDrive:
-            grp = config->group("Google Drive Settings");
+            grp = config->group(QLatin1String("Google Drive Settings"));
             break;
 
         default:
-            grp = config->group("Google Photo Settings");
+            grp = config->group(QLatin1String("Google Photo Settings"));
             break;
     }
 
@@ -408,7 +397,7 @@ void GSWindow::slotListAlbumsDone(int code, const QString& errMsg, const QList <
 
             if (code == 0)
             {
-                QMessageBox::critical(this, i18nc("@title: window", "Error"),
+                QMessageBox::critical(this, i18nc("@title:window", "Error"),
                                       i18nc("@info", "Google Drive call failed: %1\n", errMsg));
                 return;
             }
@@ -420,7 +409,12 @@ void GSWindow::slotListAlbumsDone(int code, const QString& errMsg, const QList <
                 d->widget->getAlbumsCoB()->addItem(QIcon::fromTheme(QLatin1String("system-users")),
                                                    list.value(i).title, list.value(i).id);
 
-                if (d->currentAlbumId == list.value(i).id)
+                if      (d->widget->getAlbumTitle() == list.at(i).title)
+                {
+                    d->currentAlbumId = list.at(i).id;
+                    d->widget->getAlbumsCoB()->setCurrentIndex(i);
+                }
+                else if (d->currentAlbumId == list.value(i).id)
                 {
                     d->widget->getAlbumsCoB()->setCurrentIndex(i);
                 }
@@ -463,7 +457,12 @@ void GSWindow::slotListAlbumsDone(int code, const QString& errMsg, const QList <
 
                 d->widget->getAlbumsCoB()->addItem(QIcon::fromTheme(albumIcon), list.at(i).title, list.at(i).id);
 
-                if (d->currentAlbumId == list.at(i).id)
+                if      (d->widget->getAlbumTitle() == list.at(i).title)
+                {
+                    d->currentAlbumId = list.at(i).id;
+                    d->widget->getAlbumsCoB()->setCurrentIndex(i);
+                }
+                else if (d->currentAlbumId == list.at(i).id)
                 {
                     d->widget->getAlbumsCoB()->setCurrentIndex(i);
                 }
@@ -494,13 +493,16 @@ void GSWindow::slotStartTransfer()
     {
         case GoogleService::GDrive:
         case GoogleService::GPhotoExport:
+        {
             if (d->widget->imagesList()->imageUrls().isEmpty())
             {
-                QMessageBox::critical(this, i18nc("@title: window", "Error"),
+                QMessageBox::critical(this, i18nc("@title:window", "Error"),
                                       i18nc("@info", "No image selected. Please select which images should be uploaded."));
                 return;
             }
+
             break;
+        }
 
         case GoogleService::GPhotoImport:
             break;
@@ -509,15 +511,16 @@ void GSWindow::slotStartTransfer()
     switch (d->service)
     {
         case GoogleService::GDrive:
+        {
             if (!(d->talker->authenticated()))
             {
                 QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                 i18nc("@title: window", "Warning"),
+                                 i18nc("@title:window", "Warning"),
                                  i18nc("@info", "Authentication failed. Click \"Continue\" to authenticate."),
                                  QMessageBox::Yes | QMessageBox::No);
 
-                (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "Continue"));
-                (warn->button(QMessageBox::No))->setText(i18nc("@action", "Cancel"));
+                (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
+                (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
 
                 if (warn->exec() == QMessageBox::Yes)
                 {
@@ -531,18 +534,23 @@ void GSWindow::slotStartTransfer()
                     return;
                 }
             }
+
             break;
+        }
 
         default:
+        {
+            d->gphotoTalker->cancel();
+
             if (!(d->gphotoTalker->authenticated()))
             {
                 QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                 i18nc("@title: window", "Warning"),
+                                 i18nc("@title:window", "Warning"),
                                  i18nc("@info", "Authentication failed. Click \"Continue\" to authenticate."),
                                  QMessageBox::Yes | QMessageBox::No);
 
-                (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "Continue"));
-                (warn->button(QMessageBox::No))->setText(i18nc("@action", "Cancel"));
+                (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
+                (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
 
                 if (warn->exec() == QMessageBox::Yes)
                 {
@@ -571,6 +579,7 @@ void GSWindow::slotStartTransfer()
 
                 return;
             }
+        }
     }
 
     typedef QPair<QUrl, GSPhoto> Pair;
@@ -658,11 +667,11 @@ void GSWindow::uploadNextPhoto()
          */
         if (d->service == GoogleService::GPhotoExport)
         {
-            emit d->gphotoTalker->signalReadyToUpload();
+            Q_EMIT d->gphotoTalker->signalReadyToUpload();
         }
         else
         {
-            emit d->talker->signalReadyToUpload();
+            Q_EMIT d->talker->signalReadyToUpload();
         }
 
         return;
@@ -710,7 +719,7 @@ void GSWindow::uploadNextPhoto()
                         QPointer<ReplaceDialog> dlg = new ReplaceDialog(this, QLatin1String(""),
                                                                         d->iface, pathComments.first,
                                                                         info.thumbURL);
-                        dlg->exec();
+                        (void)dlg->exec();
 
                         switch (dlg->getResult())
                         {
@@ -950,13 +959,13 @@ void GSWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
         else
         {
             QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                             i18nc("@title: window", "Warning"),
+                             i18nc("@title:window", "Warning"),
                              i18nc("@info", "Failed to save photo: %1\n"
                                    "Do you want to continue?", errText),
                              QMessageBox::Yes | QMessageBox::No);
 
-            (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "Continue"));
-            (warn->button(QMessageBox::No))->setText(i18nc("@action", "Cancel"));
+            (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
+            (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
 
             if (warn->exec() != QMessageBox::Yes)
             {
@@ -971,13 +980,13 @@ void GSWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
     else
     {
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                         i18nc("@title: window", "Warning"),
+                         i18nc("@title:window", "Warning"),
                          i18nc("@info", "Failed to download photo: %1\n"
                               "Do you want to continue?", errMsg),
                          QMessageBox::Yes | QMessageBox::No);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "Continue"));
-        (warn->button(QMessageBox::No))->setText(i18nc("@action", "Cancel"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
+        (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
 
         if (warn->exec() != QMessageBox::Yes)
         {
@@ -998,12 +1007,12 @@ void GSWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
 
     if (!QFile::rename(tmpUrl.toLocalFile(), newUrl.toLocalFile()))
     {
-        QMessageBox::critical(this, i18nc("@title: window", "Error"),
+        QMessageBox::critical(this, i18nc("@title:window", "Error"),
                               i18nc("@info", "Failed to save image to %1",
                                    newUrl.toLocalFile()));
     }
 
-    emit updateHostApp(newUrl);
+    Q_EMIT updateHostApp(newUrl);
     downloadNextPhoto();
 }
 
@@ -1019,14 +1028,14 @@ void GSWindow::slotAddPhotoDone(int err, const QString& msg)
         d->widget->imagesList()->processed(d->transferQueue.first().first,false);
 
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                         i18nc("@title: window", "Warning"),
+                         i18nc("@title:window", "Warning"),
                          i18nc("@info", "Failed to upload photo to %1.\n%2\n"
                               "Do you want to continue?",
                               d->toolName, msg),
                          QMessageBox::Yes | QMessageBox::No);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "Continue"));
-        (warn->button(QMessageBox::No))->setText(i18nc("@action", "Cancel"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
+        (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
 
         if (warn->exec() != QMessageBox::Yes)
         {
@@ -1069,13 +1078,13 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
     if (err == 0)
     {
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                                     i18nc("@title: window", "Warning"),
+                                                     i18nc("@title:window", "Warning"),
                                                      i18nc("@info", "Failed to finish uploading photo to %1.\n%2\n"
                                                            "No image uploaded to your account.",
                                                            d->toolName, msg),
                                                      QMessageBox::Yes);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "OK"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "OK"));
 
         d->uploadQueue.clear();
         d->widget->progressBar()->hide();
@@ -1084,7 +1093,7 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
     }
     else
     {
-        foreach (const QString& photoId, listPhotoId)
+        Q_FOREACH (const QString& photoId, listPhotoId)
         {
             // Remove image from upload list and from UI
 
@@ -1111,7 +1120,7 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
         if (!d->widget->imagesList()->imageUrls().isEmpty())
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "continue to upload";
-            emit d->gphotoTalker->signalReadyToUpload();
+            Q_EMIT d->gphotoTalker->signalReadyToUpload();
         }
     }
 }
@@ -1127,6 +1136,11 @@ void GSWindow::slotNewAlbumRequest()
     {
         case GoogleService::GDrive:
         {
+            if (!d->widget->getAlbumTitle().isEmpty())
+            {
+                d->albumDlg->setAlbumSuggestion(d->widget->getAlbumTitle());
+            }
+
             if (d->albumDlg->exec() == QDialog::Accepted)
             {
                 GSFolder newFolder;
@@ -1140,6 +1154,11 @@ void GSWindow::slotNewAlbumRequest()
 
         default:
         {
+            if (!d->widget->getAlbumTitle().isEmpty())
+            {
+                d->gphotoAlbumDlg->setAlbumSuggestion(d->widget->getAlbumTitle());
+            }
+
             if (d->gphotoAlbumDlg->exec() == QDialog::Accepted)
             {
                 GSFolder newFolder;
@@ -1207,7 +1226,7 @@ void GSWindow::slotCreateFolderDone(int code, const QString& msg, const QString&
         {
             if (code == 0)
             {
-                QMessageBox::critical(this, i18nc("@title: window", "Error"),
+                QMessageBox::critical(this, i18nc("@title:window", "Error"),
                                       i18nc("@info", "Google Drive call failed:\n%1", msg));
             }
             else
@@ -1224,7 +1243,7 @@ void GSWindow::slotCreateFolderDone(int code, const QString& msg, const QString&
         {
             if (code == 0)
             {
-                QMessageBox::critical(this, i18nc("@title: window", "Error"),
+                QMessageBox::critical(this, i18nc("@title:window", "Error"),
                                       i18nc("@info", "Google Photos call failed:\n%1", msg));
             }
             else
@@ -1262,13 +1281,13 @@ void GSWindow::slotTransferCancel()
 void GSWindow::slotUserChangeRequest()
 {
     QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                                    i18nc("@title: window", "Warning"),
+                                                    i18nc("@title:window", "Warning"),
                                                     i18nc("@info", "You will be logged out of your account, "
                                                           "click \"Continue\" to authenticate for another account"),
                                                     QMessageBox::Yes | QMessageBox::No);
 
-    (warn->button(QMessageBox::Yes))->setText(i18nc("@action", "Continue"));
-    (warn->button(QMessageBox::No))->setText(i18nc("@action", "Cancel"));
+    (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
+    (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
 
     if (warn->exec() == QMessageBox::Yes)
     {
@@ -1325,3 +1344,5 @@ void GSWindow::closeEvent(QCloseEvent* e)
 }
 
 } // namespace DigikamGenericGoogleServicesPlugin
+
+#include "moc_gswindow.cpp"
