@@ -191,7 +191,7 @@ static Taxon parseTaxon(const QJsonObject& taxon)
 
     if (taxon.contains(ANCESTORS))
     {
-        for (auto ancestorTaxon : taxon[ANCESTORS].toArray())
+        for (const auto& ancestorTaxon : taxon[ANCESTORS].toArray())
         {
             ancestors << parseTaxon(ancestorTaxon.toObject());
         }
@@ -378,13 +378,13 @@ bool INatTalker::restoreApiToken(const QString& username,
     {
         QDateTime now(QDateTime::currentDateTime());
 
-        for (auto str : cookiesStr.split(QLatin1Char(COOKIE_SEPARATOR)))
+        for (const auto& str : cookiesStr.split(QLatin1Char(COOKIE_SEPARATOR)))
         {
             QList<QNetworkCookie> lst(QNetworkCookie::parseCookies(str.toUtf8()));
 
             Q_ASSERT(lst.count() == 1);
 
-            for (auto cookie : lst)
+            for (const auto& cookie : lst)
             {
                 if (INatBrowserDlg::filterCookie(cookie, true, now))
                 {
@@ -514,7 +514,7 @@ public:
             QDateTime now(QDateTime::currentDateTime());
             QByteArray saveCookies;
 
-            for (auto cookie : m_cookies)
+            for (const auto& cookie : m_cookies)
             {
                 if (!INatBrowserDlg::filterCookie(cookie, true, now))
                 {
@@ -708,7 +708,7 @@ public:
             QJsonArray results = json[RESULTS].toArray();
             QList<Taxon> taxa;
 
-            for (auto result : results)
+            for (const auto& result : results)
             {
                 taxa << parseTaxon(result.toObject());
             }
@@ -791,9 +791,9 @@ public:
             QJsonObject results               = json[RESULTS].toObject();
             QList<Place> places;
 
-            for (auto key : results.keys())
+            for (const auto& key : results.keys())
             {
-                for (auto placeValue : results.value(key).toArray())
+                for (const auto& placeValue : results.value(key).toArray())
                 {
                     QJsonObject place = placeValue.toObject();
                     places.push_front(Place(place[DISPLAY_NAME].toString(),
@@ -804,7 +804,7 @@ public:
             std::sort(places.begin(), places.end());
             QStringList placesStrList;
 
-            for (auto place : places)
+            for (const auto& place : places)
             {
                 placesStrList << place.m_name;
             }
@@ -973,7 +973,7 @@ public:
 
                 QJsonArray results = json[RESULTS].toArray();
 
-                for (auto resultValue : results)
+                for (const auto& resultValue : results)
                 {
                     QJsonObject result = resultValue.toObject();
 
@@ -1181,7 +1181,7 @@ public:
 
         if (json.contains(RESULTS))
         {
-            for (auto result : json[RESULTS].toArray())
+            for (const auto& result : json[RESULTS].toArray())
             {
                 parseScore(result.toObject(), scores);
             }
@@ -1741,7 +1741,10 @@ void INatTalker::uploadNextPhoto(const PhotoUploadRequest& request)
     QString tmpImage;
     QString path = request.m_images.front().toLocalFile();
 
-    if (request.m_rescale)
+    bool isJpeg = (path.endsWith(QLatin1String(".jpg"), Qt::CaseInsensitive) ||
+                   path.endsWith(QLatin1String(".jpeg"), Qt::CaseInsensitive));
+
+    if (request.m_rescale || !isJpeg)
     {
         QImage image = PreviewLoadThread::loadHighQualitySynchronously(path).
                        copyQImage();
@@ -1764,6 +1767,11 @@ void INatTalker::uploadNextPhoto(const PhotoUploadRequest& request)
             }
 
             image.save(tmpImage, "JPEG", request.m_quality);
+
+            if (!isJpeg)
+            {
+                path += QLatin1String(".jpeg");
+            }
         }
     }
 
@@ -1902,7 +1910,7 @@ void INatTalker::slotTimeout()
         }
     }
 
-    for (auto pair : timeoutList)
+    for (const auto& pair : timeoutList)
     {
         QNetworkReply* const reply            = pair.first;
         d->pendingRequests.remove(reply);
@@ -1927,3 +1935,5 @@ void INatTalker::slotTimeout()
 }
 
 } // namespace DigikamGenericINatPlugin
+
+#include "moc_inattalker.cpp"
