@@ -6,20 +6,12 @@
  * Date        : 2021-03-20
  * Description : a tool to export images to iNaturalist web service
  *
- * Copyright (C) 2021      by Joerg Lohse <joergmlpts at gmail dot com>
- * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009      by Luka Renko <lure at kubuntu dot org>
+ * SPDX-FileCopyrightText: 2021      by Joerg Lohse <joergmlpts at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009      by Luka Renko <lure at kubuntu dot org>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -54,10 +46,9 @@
 // Local includes
 
 #include "dprogresswdg.h"
-#include "inattalker.h"
-#include "inattaxon.h"
 #include "ditemslist.h"
 #include "dmetadata.h"
+#include "dtextedit.h"
 #include "wsselectuserdlg.h"
 #include "digikam_debug.h"
 #include "previewloadthread.h"
@@ -148,7 +139,7 @@ public:
     QLabel*                 identificationLabel;
     bool                    identificationFromVision;
     QLabel*                 closestKnownObservation;
-    QPlainTextEdit*         observationDescription;
+    DPlainTextEdit*         observationDescription;
     TaxonEdit*              identificationEdit;
     SuggestTaxonCompletion* taxonPopup;
     QComboBox*              placesComboBox;
@@ -190,7 +181,7 @@ INatWindow::INatWindow(DInfoInterface* const iface,
 {
     d->iface       = iface;
     d->serviceName = serviceName;
-    setWindowTitle(i18n("Export as %1 Observation", d->serviceName));
+    setWindowTitle(i18nc("@title:window", "Export as %1 Observation", d->serviceName));
     setModal(false);
 
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -244,7 +235,7 @@ INatWindow::INatWindow(DInfoInterface* const iface,
     d->dimensionSpinBox->setMaximum(MAX_DIMENSION);
     d->dimensionSpinBox->setValue(MAX_DIMENSION);
 
-    startButton()->setText(i18n("Start Uploading"));
+    startButton()->setText(i18nc("@action:button", "Start Uploading"));
     startButton()->setToolTip(QString());
 
     setMainWidget(d->widget);
@@ -397,14 +388,14 @@ void INatWindow::switchUser(bool restoreToken)
     }
 
     // Pass cookies to browser; if "remember me" is checked on iNaturalist
-    // website, the brower will re-login for 14 days without user interaction.
+    // website, the browser will re-login for 14 days without user interaction.
 
     QPointer<INatBrowserDlg> dlg = new INatBrowserDlg(userName, cookies, this);
 
     connect(dlg, SIGNAL(signalApiToken(QString,QList<QNetworkCookie>)),
             d->talker, SLOT(slotApiToken(QString,QList<QNetworkCookie>)));
 
-    dlg->exec();
+    (void)dlg->exec();
 }
 
 void INatWindow::slotApiTokenExpires()
@@ -571,7 +562,7 @@ void INatWindow::slotLinkingSucceeded(const QString& username,
     d->widget->updateLabels(username);
     KSharedConfigPtr config = KSharedConfig::openConfig();
 
-    foreach (const QString& group, config->groupList())
+    Q_FOREACH (const QString& group, config->groupList())
     {
         if (!(group.contains(d->serviceName)))
         {
@@ -612,7 +603,7 @@ void INatWindow::slotBusy(bool val)
 void INatWindow::slotError(const QString& msg)
 {
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Error" << msg;
-    QMessageBox::critical(this, i18n("Error"), msg);
+    QMessageBox::critical(this, i18nc("@title:window", "Error"), msg);
 }
 
 void INatWindow::slotUserChangeRequest()
@@ -796,9 +787,7 @@ void INatWindow::slotUser1()
 
     // Create an observation.
 
-    QString obsDateTime = d->observationDateTime.toString(Qt::ISODate) +
-                          QLatin1Char(' ')                             +
-                          d->observationDateTime.timeZoneAbbreviation();
+    QString obsDateTime = d->observationDateTime.toString(Qt::ISODate);
     QJsonObject params;
     params.insert(QLatin1String("observed_on_string"), QJsonValue(obsDateTime));
     params.insert(QLatin1String("time_zone"),
@@ -964,7 +953,7 @@ void INatWindow::slotNearbyPlaces(const QStringList& places)
     QString selected = d->placesComboBox->currentText();
     d->placesComboBox->clear();
 
-    for (auto place : d->editedPlaces)
+    for (auto& place : d->editedPlaces)
     {
         d->placesComboBox->addItem(place);
 
@@ -976,7 +965,7 @@ void INatWindow::slotNearbyPlaces(const QStringList& places)
         }
     }
 
-    for (auto place : places)
+    for (auto& place : places)
     {
         d->placesComboBox->addItem(place);
 
@@ -1055,7 +1044,7 @@ void INatWindow::slotImageListChanged()
 
     DItemsListView* const listView = d->widget->d->imglst->listView();
 
-    for (auto url : d->imglst->imageUrls())
+    for (auto& url : d->imglst->imageUrls())
     {
         if (url.isEmpty())
         {
@@ -1074,7 +1063,7 @@ void INatWindow::slotImageListChanged()
             if (!observationTime.isValid())
             {
                 observationTime = dateTime;
-                dt              = dateTime.toString(Qt::SystemLocaleShortDate) + lf +
+                dt              = QLocale().toString(dateTime, QLocale::ShortFormat) + lf +
                                   i18n("observation time");
                 QBrush brush(Qt::black);
                 item->setForeground(ItemDate, brush);
@@ -1211,3 +1200,5 @@ void INatWindow::saveEditedPlaceName(const QString& text)
 }
 
 } // namespace DigikamGenericINatPlugin
+
+#include "moc_inatwindow.cpp"
