@@ -7,7 +7,7 @@
  * Description : a tool to export images to Smugmug web service
  *
  * SPDX-FileCopyrightText: 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -45,7 +45,6 @@
 #include "dprogresswdg.h"
 #include "dmetadata.h"
 #include "previewloadthread.h"
-#include "smugitem.h"
 #include "smugtalker.h"
 #include "smugwidget.h"
 #include "smugnewalbumdlg.h"
@@ -351,7 +350,7 @@ void SmugWindow::authenticate()
 void SmugWindow::readSettings()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup grp        = config->group("Smug Settings");
+    KConfigGroup grp        = config->group(QLatin1String("Smug Settings"));
     d->anonymousImport      = grp.readEntry("AnonymousImport", true);
     d->email                = grp.readEntry("Email");
     d->password             = grp.readEntry("Password");
@@ -378,7 +377,7 @@ void SmugWindow::readSettings()
 void SmugWindow::writeSettings()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup grp        = config->group("Smug Settings");
+    KConfigGroup grp        = config->group(QLatin1String("Smug Settings"));
     grp.writeEntry("AnonymousImport", d->anonymousImport);
     grp.writeEntry("Email",           d->email);
     grp.writeEntry("Password",        d->password);
@@ -1032,3 +1031,5 @@ void SmugWindow::slotImageListChanged()
 }
 
 } // namespace DigikamGenericSmugPlugin
+
+#include "moc_smugwindow.cpp"
