@@ -6,7 +6,7 @@
  * Date        : 2019-09-18
  * Description : DarkTable raw import plugin.
  *
- * SPDX-FileCopyrightText: 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Lua script inspired from Darktable Gimp plugin by Tobias Ellinghaus
  *
@@ -175,6 +175,11 @@ void DarkTableRawImportPlugin::setup(QObject* const /*parent*/)
     // Nothing to do
 }
 
+QString DarkTableRawImportPlugin::getRawProgram() const
+{
+    return DFileOperations::findExecutable(QLatin1String("darktable"));
+}
+
 bool DarkTableRawImportPlugin::run(const QString& filePath, const DRawDecoding& /*def*/)
 {
     QFileInfo fileInfo(filePath);
@@ -201,7 +206,7 @@ bool DarkTableRawImportPlugin::run(const QString& filePath, const DRawDecoding&
 
     // --------
 
-    d->darktable->setProgram(DFileOperations::findExecutable(QLatin1String("darktable")));
+    d->darktable->setProgram(getRawProgram());
     d->darktable->setArguments(QStringList() << QLatin1String("--library")
                                              << QLatin1String(":memory:")                                  // Run DarkTable to process only one file
                                              << QLatin1String("--luacmd")
@@ -311,3 +316,5 @@ void DarkTableRawImportPlugin::slotProcessReadyRead()
 }
 
 } // namespace DigikamRawImportDarkTablePlugin
+
+#include "moc_rawimportdarktableplugin.cpp"
