@@ -7,7 +7,7 @@
  * Description : Albums manager interface.
  *
  * SPDX-FileCopyrightText: 2004      by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -120,9 +120,12 @@ public:
      * Returns true on success, false on failure.
      * A return value of false during startup indicates termination of the program
      * (user is informed)
+     *
+     * ignoreDisappearedLocations is intended to be used in tests, because the path of the collection is hardcoded
+     * but when executing the test on different computers the collection might not be available at that path
      */
     bool setDatabase(const DbEngineParameters& params, bool priority,
-                     const QString& suggestedAlbumRoot = QString());
+                     const QString& suggestedAlbumRoot = QString(), bool ignoreDisappearedLocations = false);
 
     /**
      * Sets new database when chosen by the user in setup.
@@ -567,7 +570,7 @@ public:
      * @param askUser ask user to write metadata to images
      * operation failed
      */
-    bool deleteTAlbum(TAlbum* album, QString& errMsg, bool askUser = true);
+    bool deleteTAlbum(TAlbum* album, QString& errMsg, QList<qlonglong>* imageIds = nullptr);
 
     /**
      * Renames a TAlbum.
@@ -663,6 +666,9 @@ public:
     QList<int> subTags(int tagId, bool recursive = false)                                                const;
     int findTopId(int tagId)                                                                             const;
 
+    void askUserForWriteChangedTAlbumToFiles(TAlbum* const album);
+    void askUserForWriteChangedTAlbumToFiles(const QList<qlonglong>& imageIds);
+
 private:
 
     /**
@@ -673,9 +679,6 @@ private:
      * @return <code>true</code> if there is a child with name, else
      *         <code>false</code>
      */
-    void askUserForWriteChangedTAlbumToFiles(TAlbum* const album);
-    void askUserForWriteChangedTAlbumToFiles(const QList<qlonglong>& imageIds);
-
     void insertTAlbum(TAlbum* album, TAlbum* parent);
     void removeTAlbum(TAlbum* album);
 
