@@ -6,7 +6,7 @@
  * Date        : 2004-06-15
  * Description : Albums manager interface - Database helpers.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
@@ -19,9 +19,9 @@
 // Qt includes
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    #include <QTextCodec>
+#   include <QTextCodec>
 #else
-    #include <QStringConverter>
+#   include <QStringConverter>
 #endif
 
 // KDE includes
@@ -32,7 +32,7 @@
 namespace Digikam
 {
 
-bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority, const QString& suggestedAlbumRoot)
+bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority, const QString& suggestedAlbumRoot, bool ignoreDisappearedLocations)
 {
     // This is to ensure that the setup does not overrule the command line.
     // TODO: there is a bug that setup is showing something different here.
@@ -55,7 +55,7 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
     DatabaseServerStarter::instance()->stopServerManagerProcess();
 
     // Shutdown possibly running collection scans.
-    // Must call resumeCollectionScan further down.
+    // Must call restartCollectionScan further down.
 
     ScanController::instance()->cancelAllAndSuspendCollectionScan();
 
@@ -67,6 +67,8 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
         disconnect(CoreDbAccess::databaseWatch(), nullptr, this, nullptr);
     }
 
+    ItemAttributesWatch::shutDown();
+    ItemAttributesWatch::cleanUp();
     d->albumWatch->clear();
 
     cleanUp();
@@ -105,25 +107,25 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
     {
         if      (!QFileInfo::exists(params.internalServerPath()))
         {
-            databaseError = i18n("The MySQL database directory was not found, please "
-                                 "set the correct location in the next dialog.");
+            databaseError = i18n("The MySQL database directory was not found.");
         }
-        else if ((!QFileInfo::exists(params.internalServerMysqlServCmd)                         &&
-                  QStandardPaths::findExecutable(params.internalServerMysqlServCmd).isEmpty())  ||
-                 (!QFileInfo::exists(params.internalServerMysqlAdminCmd)                        &&
+        else if (
+                 (!QFileInfo::exists(params.internalServerMysqlUpgradeCmd)                        &&
+                  QStandardPaths::findExecutable(params.internalServerMysqlUpgradeCmd).isEmpty()) ||
+                 (!QFileInfo::exists(params.internalServerMysqlServerCmd)                         &&
+                  QStandardPaths::findExecutable(params.internalServerMysqlServerCmd).isEmpty())  ||
+                 (!QFileInfo::exists(params.internalServerMysqlAdminCmd)                          &&
                   QStandardPaths::findExecutable(params.internalServerMysqlAdminCmd).isEmpty())
                 )
         {
-            databaseError = i18n("The MySQL binary tools was not found, please "
-                                 "set the correct location in the next dialog.");
+            databaseError = i18n("The MySQL binary tools was not found.");
         }
     }
     else if (params.isSQLite() && suggestedAlbumRoot.isEmpty() && !settings->getDatabaseDirSetAtCmd())
     {
         if (!QFileInfo::exists(params.databaseNameCore))
         {
-            databaseError = i18n("The SQLite core database was not found, please "
-                                 "set the correct location in the next dialog.");
+            databaseError = i18n("The SQLite core database was not found.");
         }
     }
 
@@ -132,8 +134,8 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
         QString configPath = QStandardPaths::locate(QStandardPaths::GenericConfigLocation,
                                                     QLatin1String("digikamrc"));
 
-        databaseError     += i18n("\n\nIf you want to start with a new configuration and "
-                                  "with a first run wizard, delete the file %1",
+        databaseError     += i18n("<p>If you want to start with a new configuration and "
+                                  "with a first run wizard, delete the file:<br>%1</p>",
                                   QDir::toNativeSeparators(configPath));
 
         return showDatabaseSetupPage(databaseError, priority, suggestedAlbumRoot);
@@ -145,8 +147,8 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
         if (result.getErrorType() != DatabaseServerError::NoErrors)
         {
-            databaseError = i18n("An error occurred during the internal server start.\n\n"
-                                 "Details:\n%1", result.getErrorText());
+            databaseError = i18n("An error occurred during the internal server start."
+                                 "<p>Details:\n%1</p>", result.getErrorText());
 
             return showDatabaseSetupPage(databaseError, priority, suggestedAlbumRoot);
         }
@@ -161,9 +163,7 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     if (!handler->checkDatabaseConnection())
     {
-        databaseError = i18n("Failed to open the database.\n\n"
-                             "You cannot use digiKam without a working database.\n"
-                             "Please check the database settings in the next dialog.");
+        databaseError = i18n("Failed to open the database.");
 
         if (!showDatabaseSetupPage(databaseError, priority, suggestedAlbumRoot))
         {
@@ -188,10 +188,6 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     d->albumWatch->setDbEngineParameters(params);
 
-    // still suspended from above
-
-    ScanController::instance()->resumeCollectionScan();
-
     ScanController::Advice advice = ScanController::instance()->databaseInitialization();
 
     QApplication::restoreOverrideCursor();
@@ -232,7 +228,9 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
         case ScanController::AbortImmediately:
         {
-            return false;
+            databaseError = i18n("Failed to initialize the database.");
+
+            return showDatabaseSetupPage(databaseError, priority, suggestedAlbumRoot);
         }
     }
 
@@ -371,7 +369,7 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
             solveManuallyButton->setChecked(true);
         }
 
-        if (dialog->exec())
+        if (!ignoreDisappearedLocations && dialog->exec())
         {
             if      (migrateButton && migrateButton->isChecked())
             {
@@ -436,6 +434,10 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     QApplication::restoreOverrideCursor();
 
+    // still suspended from above
+
+    ScanController::instance()->restartCollectionScan();
+
     return true;
 }
 
@@ -481,7 +483,7 @@ void AlbumManager::checkDatabaseDirsAfterFirstRun(const QString& dbPath, const Q
                 // Restore this situation.
 
                 KSharedConfigPtr config = KSharedConfig::openConfig();
-                KConfigGroup group      = config->group("Album Settings");
+                KConfigGroup group      = config->group(QLatin1String("Album Settings"));
                 group.writeEntry("Album Path", albumDir.path());
                 group.sync();
             }
@@ -727,6 +729,7 @@ bool AlbumManager::copyToNewLocation(const QFileInfo& oldFile,
     if (!ret)
     {
         QMessageBox::critical(qApp->activeWindow(), qApp->applicationName(), message);
+
         return false;
     }
 
@@ -737,13 +740,18 @@ bool AlbumManager::showDatabaseSetupPage(const QString& error, bool priority, co
 {
     QApplication::restoreOverrideCursor();
 
-    QMessageBox::critical(qApp->activeWindow(),
-                          qApp->applicationName(), error);
+    QString errorMsg = error + i18n("<p><b>Please check the database settings in this dialog.</b></p>");
 
     // We cannot use Setup::execSinglePage() as this already requires a core database.
 
     QPointer<QDialog> setup                  = new QDialog(qApp->activeWindow());
     QVBoxLayout* const layout                = new QVBoxLayout(setup);
+    QLabel* const errorLabel                 = new QLabel(errorMsg, setup);
+    errorLabel->setWordWrap(true);
+    errorLabel->setTextFormat(Qt::RichText);
+    errorLabel->setAlignment(Qt::AlignCenter);
+    errorLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
+    errorLabel->setStyleSheet(QLatin1String("QLabel { background-color: #FFDDDD; color: black; }"));
     DatabaseSettingsWidget* const dbsettings = new DatabaseSettingsWidget(setup);
     QDialogButtonBox* const buttons          = new QDialogButtonBox(QDialogButtonBox::Ok    |
                                                                     QDialogButtonBox::Reset |
@@ -751,6 +759,7 @@ bool AlbumManager::showDatabaseSetupPage(const QString& error, bool priority, co
     buttons->button(QDialogButtonBox::Reset)->setText(i18nc("@action:button", "New database"));
     buttons->button(QDialogButtonBox::Ok)->setDefault(true);
 
+    layout->addWidget(errorLabel);
     layout->addWidget(dbsettings);
     layout->addStretch(10);
     layout->addWidget(buttons);
@@ -764,11 +773,11 @@ bool AlbumManager::showDatabaseSetupPage(const QString& error, bool priority, co
             setup, SLOT(reject()));
 
     connect(buttons->button(QDialogButtonBox::Reset), &QPushButton::clicked,
-            this, [&]()
-            {
-                newDatabase = true;
-                setup->accept();
-            }
+            this, [&newDatabase, setup]()        // clazy:exclude=lambda-in-connect
+        {
+            newDatabase = true;
+            setup->accept();
+        }
     );
 
     ApplicationSettings* const settings = ApplicationSettings::instance();
