@@ -7,7 +7,7 @@
  * Description : Albums folder view.
  *
  * SPDX-FileCopyrightText: 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  *
@@ -32,6 +32,7 @@
 
 #include "digikam_debug.h"
 #include "tagscache.h"
+#include "itemscanner.h"
 #include "albummanager.h"
 #include "facescansettings.h"
 #include "applicationsettings.h"
@@ -327,7 +328,6 @@ void AlbumSelectionTreeView::slotRepairHiddenItems()
         return;
     }
 
-    int needTaggingTag     = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::needTaggingHistoryGraph());
     int originalVersionTag = TagsCache::instance()->getOrCreateInternalTag(InternalTagName::originalVersion());
 
     Q_FOREACH (const qlonglong& id, CoreDbAccess().db()->getItemIDsInAlbum(album->id()))
@@ -344,8 +344,8 @@ void AlbumSelectionTreeView::slotRepairHiddenItems()
 
         if (!info.hasDerivedImages() && info.tagIds().contains(originalVersionTag))
         {
-            info.removeTag(originalVersionTag);
-            info.setTag(needTaggingTag);
+            ItemScanner::resolveImageHistory(info.id());
+            ItemScanner::tagItemHistoryGraph(info.id());
         }
     }
 }
@@ -425,11 +425,17 @@ bool AlbumSelectionTreeView::viewportEvent(QEvent* event)
     }
 
     QStyleOptionViewItem option;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     initViewItemOption(&option);
+
 #else
+
     option = viewOptions();
+
 #endif
+
     option.rect                 = itemRect;
 
     // visualRect can be larger than viewport, intersect with viewport rect
@@ -444,3 +450,5 @@ bool AlbumSelectionTreeView::viewportEvent(QEvent* event)
 } // namespace Digikam
 
 #include "albumselectiontreeview.moc"
+
+#include "moc_albumselectiontreeview.cpp"
