@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2005      by Tom Albers <tomalbers at kde dot nl>
- * SPDX-FileCopyrightText: 2006-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -23,8 +23,6 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QPointer>
-#include <QRegularExpression>
-#include <QValidator>
 #include <QApplication>
 #include <QStyle>
 #include <QComboBox>
@@ -84,29 +82,19 @@ class Q_DECL_HIDDEN AlbumPropsEdit::Private
 
 public:
 
-    explicit Private()
-      : buttons         (nullptr),
-        topLabel        (nullptr),
-        categoryCombo   (nullptr),
-        parentCombo     (nullptr),
-        titleEdit       (nullptr),
-        commentsEdit    (nullptr),
-        datePicker      (nullptr),
-        album           (nullptr)
-    {
-    }
+    Private() = default;
 
-    QDialogButtonBox* buttons;
+    QDialogButtonBox* buttons       = nullptr;
 
-    QLabel*           topLabel;
-    QComboBox*        categoryCombo;
-    QComboBox*        parentCombo;
-    DTextEdit*        titleEdit;
-    DPlainTextEdit*   commentsEdit;
+    QLabel*           topLabel      = nullptr;
+    QComboBox*        categoryCombo = nullptr;
+    QComboBox*        parentCombo   = nullptr;
+    DTextEdit*        titleEdit     = nullptr;
+    DPlainTextEdit*   commentsEdit  = nullptr;
 
-    AlbumDatePicker*  datePicker;
+    AlbumDatePicker*  datePicker    = nullptr;
 
-    PAlbum*           album;
+    PAlbum*           album         = nullptr;
 };
 
 AlbumPropsEdit::AlbumPropsEdit(PAlbum* const album, bool create)
@@ -114,7 +102,8 @@ AlbumPropsEdit::AlbumPropsEdit(PAlbum* const album, bool create)
       d      (new Private)
 {
     setModal(true);
-    setWindowTitle(create ? i18nc("@title:window, album properties", "New Album") : i18nc("@title:window, album properties", "Edit Album"));
+    setWindowTitle(create ? i18nc("@title:window, album properties", "New Album")
+                          : i18nc("@title:window, album properties", "Edit Album"));
 
     d->buttons          = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->buttons->button(QDialogButtonBox::Ok)->setDefault(true);
@@ -489,3 +478,5 @@ void AlbumPropsEdit::slotHelp()
 } // namespace Digikam
 
 #include "albumpropsedit.moc"
+
+#include "moc_albumpropsedit.cpp"
