@@ -114,13 +114,17 @@ CollectionLocation CollectionManager::refreshLocation(const CollectionLocation&
         return CollectionLocation();
     }
 
-    QWriteLocker locker(&d->lock);
+    AlbumRootLocation* albumLoc = nullptr;
 
-    AlbumRootLocation* const albumLoc = d->locations.value(location.id());
-
-    if (!albumLoc)
     {
-        return CollectionLocation();
+        QReadLocker readLocker(&d->lock);
+
+        albumLoc = d->locations.value(location.id());
+
+        if (!albumLoc)
+        {
+            return CollectionLocation();
+        }
     }
 
     QList<SolidVolumeInfo> volumes = d->listVolumes();
@@ -167,8 +171,6 @@ CollectionLocation CollectionManager::refreshLocation(const CollectionLocation&
         albumLoc->setType((CollectionLocation::Type)type);
         albumLoc->setCaseSensitivity(CollectionLocation::UnknownCaseSensitivity);
 
-        locker.unlock();
-
         Q_EMIT locationPropertiesChanged(*albumLoc);
     }
     else
@@ -205,8 +207,6 @@ CollectionLocation CollectionManager::refreshLocation(const CollectionLocation&
         albumLoc->identifier   = d->volumeIdentifier(path);
         albumLoc->setCaseSensitivity(CollectionLocation::UnknownCaseSensitivity);
 
-        locker.unlock();
-
         Q_EMIT locationPropertiesChanged(*albumLoc);
     }
 
@@ -489,13 +489,17 @@ CollectionManager::LocationCheckResult CollectionManager::checkNetworkLocation(c
 
 void CollectionManager::removeLocation(const CollectionLocation& location)
 {
-    QWriteLocker locker(&d->lock);
+    AlbumRootLocation* albumLoc = nullptr;
 
-    AlbumRootLocation* const albumLoc = d->locations.value(location.id());
-
-    if (!albumLoc)
     {
-        return;
+        QReadLocker readLocker(&d->lock);
+
+        albumLoc = d->locations.value(location.id());
+
+        if (!albumLoc)
+        {
+            return;
+        }
     }
 
     // Ensure that all albums are set to orphan and no images will be permanently deleted,
@@ -503,18 +507,16 @@ void CollectionManager::removeLocation(const CollectionLocation& location)
 
     CoreDbAccess access;
     QList<int> albumIds = access.db()->getAlbumsOnAlbumRoot(albumLoc->id());
+
     ChangingDB changing(d);
     CollectionScanner scanner;
     CoreDbTransaction transaction(&access);
-    locker.unlock();
+
     scanner.safelyRemoveAlbums(albumIds);
-    locker.relock();
     access.db()->deleteAlbumRoot(albumLoc->id());
 
     // Do not Q_EMIT the locationRemoved signal here, it is done in updateLocations()
 
-    locker.unlock();
-
     updateLocations();
 }
 
@@ -523,7 +525,7 @@ QList<CollectionLocation> CollectionManager::checkHardWiredLocations()
     QList<CollectionLocation> disappearedLocations;
     QList<SolidVolumeInfo> volumes = d->listVolumes();
 
-    QReadLocker locker(&d->lock);
+    QReadLocker readLocker(&d->lock);
 
     Q_FOREACH (AlbumRootLocation* const location, d->locations)
     {
@@ -548,18 +550,21 @@ void CollectionManager::migrationCandidates(const CollectionLocation& location,
     candidateIdentifiers->clear();
     candidateDescriptions->clear();
 
-    QList<SolidVolumeInfo> volumes = d->listVolumes();
+    AlbumRootLocation* albumLoc = nullptr;
 
-    QReadLocker locker(&d->lock);
-
-    AlbumRootLocation* const albumLoc = d->locations.value(location.id());
-
-    if (!albumLoc)
     {
-        return;
+        QReadLocker readLocker(&d->lock);
+
+        albumLoc = d->locations.value(location.id());
+
+        if (!albumLoc)
+        {
+            return;
+        }
     }
 
-    *description = d->technicalDescription(albumLoc);
+    QList<SolidVolumeInfo> volumes = d->listVolumes();
+    *description                   = d->technicalDescription(albumLoc);
 
     // Find possible new volumes where the specific path is found.
 
@@ -580,13 +585,17 @@ void CollectionManager::migrationCandidates(const CollectionLocation& location,
 
 void CollectionManager::migrateToVolume(const CollectionLocation& location, const QString& identifier)
 {
-    QWriteLocker locker(&d->lock);
+    AlbumRootLocation* albumLoc = nullptr;
 
-    AlbumRootLocation* const albumLoc = d->locations.value(location.id());
-
-    if (!albumLoc)
     {
-        return;
+        QReadLocker readLocker(&d->lock);
+
+        albumLoc = d->locations.value(location.id());
+
+        if (!albumLoc)
+        {
+            return;
+        }
     }
 
     // update db
@@ -598,20 +607,22 @@ void CollectionManager::migrateToVolume(const CollectionLocation& location, cons
 
     albumLoc->identifier = identifier;
 
-    locker.unlock();
-
     updateLocations();
 }
 
 void CollectionManager::setLabel(const CollectionLocation& location, const QString& label)
 {
-    QWriteLocker locker(&d->lock);
+    AlbumRootLocation* albumLoc = nullptr;
 
-    AlbumRootLocation* const albumLoc = d->locations.value(location.id());
-
-    if (!albumLoc)
     {
-        return;
+        QReadLocker readLocker(&d->lock);
+
+        albumLoc = d->locations.value(location.id());
+
+        if (!albumLoc)
+        {
+            return;
+        }
     }
 
     // update db
@@ -623,20 +634,22 @@ void CollectionManager::setLabel(const CollectionLocation& location, const QStri
 
     albumLoc->setLabel(label);
 
-    locker.unlock();
-
     Q_EMIT locationPropertiesChanged(*albumLoc);
 }
 
 void CollectionManager::changeType(const CollectionLocation& location, int type)
 {
-    QWriteLocker locker(&d->lock);
+    AlbumRootLocation* albumLoc = nullptr;
 
-    AlbumRootLocation* const albumLoc = d->locations.value(location.id());
-
-    if (!albumLoc)
     {
-        return;
+        QReadLocker readLocker(&d->lock);
+
+        albumLoc = d->locations.value(location.id());
+
+        if (!albumLoc)
+        {
+            return;
+        }
     }
 
     // update db
@@ -648,14 +661,12 @@ void CollectionManager::changeType(const CollectionLocation& location, int type)
 
     albumLoc->setType((CollectionLocation::Type)type);
 
-    locker.unlock();
-
     Q_EMIT locationPropertiesChanged(*albumLoc);
 }
 
 QList<CollectionLocation> CollectionManager::allLocations()
 {
-    QReadLocker locker(&d->lock);
+    QReadLocker readLocker(&d->lock);
 
     QList<CollectionLocation> list;
 
@@ -669,7 +680,7 @@ QList<CollectionLocation> CollectionManager::allLocations()
 
 QList<CollectionLocation> CollectionManager::allAvailableLocations()
 {
-    QReadLocker locker(&d->lock);
+    QReadLocker readLocker(&d->lock);
 
     QList<CollectionLocation> list;
 
@@ -686,7 +697,7 @@ QList<CollectionLocation> CollectionManager::allAvailableLocations()
 
 CollectionLocation CollectionManager::locationForAlbumRootId(int id)
 {
-    QReadLocker locker(&d->lock);
+    QReadLocker readLocker(&d->lock);
 
     AlbumRootLocation* const location = d->locations.value(id);
 
@@ -717,7 +728,7 @@ CollectionLocation CollectionManager::locationForAlbumRootPath(const QString& al
         updateLocations();
     }
 
-    QReadLocker locker(&d->lock);
+    QReadLocker readLocker(&d->lock);
 
     Q_FOREACH (AlbumRootLocation* const location, d->locations)
     {
@@ -737,7 +748,7 @@ CollectionLocation CollectionManager::locationForUrl(const QUrl& fileUrl)
 
 CollectionLocation CollectionManager::locationForPath(const QString& givenPath)
 {
-    QReadLocker locker(&d->lock);
+    QReadLocker readLocker(&d->lock);
 
     Q_FOREACH (AlbumRootLocation* const location, d->locations)
     {
@@ -760,13 +771,9 @@ CollectionLocation CollectionManager::locationForPath(const QString& givenPath)
 
 void CollectionManager::updateLocations()
 {
-    QList<SolidVolumeInfo> volumes;
-
-    // get information from Solid
-
-    volumes = d->listVolumes();
-
-    QWriteLocker locker(&d->lock);
+    QMap<int, AlbumRootLocation*> newLocations;
+    QMap<int, AlbumRootLocation*> oldLocations;
+    QList<CollectionLocation::Status> oldStatus;
 
     // read information from database
 
@@ -774,39 +781,32 @@ void CollectionManager::updateLocations()
 
     // synchronize map with database
 
-    QMap<int, AlbumRootLocation*> locs = d->locations;
-    d->locations.clear();
+    {
+        QReadLocker locker(&d->lock);
+        oldLocations = d->locations;
+    }
 
     Q_FOREACH (const AlbumRootInfo& info, infos)
     {
-        if (locs.contains(info.id))
+        if (oldLocations.contains(info.id))
         {
-            d->locations[info.id] = locs.value(info.id);
-            locs.remove(info.id);
+            newLocations[info.id] = oldLocations.value(info.id);
+            oldLocations.remove(info.id);
         }
         else
         {
-            d->locations[info.id] = new AlbumRootLocation(info);
+            newLocations[info.id] = new AlbumRootLocation(info);
         }
     }
 
-    // delete old locations
+    // update status with current access state,
+    // store old status in QList oldStatus
 
-    Q_FOREACH (AlbumRootLocation* const location, locs)
-    {
-        CollectionLocation::Status oldStatus = location->status();
-        location->setStatus(CollectionLocation::LocationDeleted);
-        locker.unlock();
-        Q_EMIT locationStatusChanged(*location, oldStatus);
-        locker.relock();
-        delete location;
-    }
+    // get information from Solid
 
-    // update status with current access state, store old status in list
+    QList<SolidVolumeInfo> volumes = d->listVolumes();
 
-    QList<CollectionLocation::Status> oldStatus;
-
-    Q_FOREACH (AlbumRootLocation* const location, d->locations)
+    Q_FOREACH (AlbumRootLocation* const location, newLocations)
     {
         oldStatus << location->status();
         bool available = false;
@@ -816,10 +816,23 @@ void CollectionManager::updateLocations()
         {
             Q_FOREACH (const QString& path, d->networkShareMountPathsFromIdentifier(location))
             {
-                QFileInfo fileInfo(path);
-                available    = (fileInfo.isReadable() &&
-                                QDirIterator(path, QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot).hasNext());
-                absolutePath = path;
+                absolutePath      = path;
+                QUrl url(location->identifier);
+                QString uuidValue = d->getCollectionUUID(path);
+                QString queryItem = QUrlQuery(url).queryItemValue(QLatin1String("fileuuid"));
+
+                if      (!queryItem.isNull() && (queryItem == uuidValue))
+                {
+                    available = true;
+                }
+                else if (queryItem.isNull())
+                {
+                    QFileInfo fileInfo(path);
+                    available = (fileInfo.isReadable() &&
+                                 QDirIterator(path, QDir::Dirs    |
+                                                    QDir::Files   |
+                                                    QDir::NoDotAndDotDot).hasNext());
+                }
 
                 if (available)
                 {
@@ -869,6 +882,15 @@ void CollectionManager::updateLocations()
         location->available = available;
         location->setAbsolutePath(absolutePath);
 
+        if (available)
+        {
+            if (d->checkCollectionUUID(location, absolutePath))
+            {
+                ChangingDB changing(d);
+                CoreDbAccess().db()->migrateAlbumRoot(location->id(), location->identifier);
+            }
+        }
+
         if (available && (location->caseSensitivity() == CollectionLocation::UnknownCaseSensitivity))
         {
             QFileInfo writeInfo(absolutePath);
@@ -896,12 +918,13 @@ void CollectionManager::updateLocations()
                     location->setCaseSensitivity(CollectionLocation::CaseSensitive);
                 }
 
+                ChangingDB changing(d);
                 CoreDbAccess().db()->setAlbumRootCaseSensitivity(location->id(),
                                                                  location->caseSensitivity());
             }
         }
 
-        qCDebug(DIGIKAM_DATABASE_LOG) << "location for" << absolutePath
+        qCDebug(DIGIKAM_DATABASE_LOG) << "Location for" << absolutePath
                                       << "is available:" << available
                                       << "=>" << "case sensitivity:"
                                       << location->caseSensitivity();
@@ -911,17 +934,32 @@ void CollectionManager::updateLocations()
         location->setStatusFromFlags();
     }
 
+    {
+        QWriteLocker locker(&d->lock);
+        d->locations = newLocations;
+    }
+
+    // Q_EMIT deleted old locations
+
+    Q_FOREACH (AlbumRootLocation* const location, oldLocations)
+    {
+        CollectionLocation::Status statusOld = location->status();
+        location->setStatus(CollectionLocation::LocationDeleted);
+
+        Q_EMIT locationStatusChanged(*location, statusOld);
+
+        delete location;
+    }
+
     // Q_EMIT status changes (and new locations)
 
     int i = 0;
 
-    Q_FOREACH (AlbumRootLocation* const location, d->locations)
+    Q_FOREACH (AlbumRootLocation* const location, newLocations)
     {
         if (oldStatus.at(i) != location->status())
         {
-            locker.unlock();
             Q_EMIT locationStatusChanged(*location, oldStatus.at(i));
-            locker.relock();
         }
 
         ++i;
