@@ -6,20 +6,11 @@
  * Date        : 2007-03-21
  * Description : Collection scanning to database - scan operations.
  *
- * Copyright (C) 2005-2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -33,7 +24,7 @@ void CollectionScanner::completeScan()
     QElapsedTimer timer;
     timer.start();
 
-    emit startCompleteScan();
+    Q_EMIT startCompleteScan();
 
     {
         // lock database
@@ -54,17 +45,18 @@ void CollectionScanner::completeScan()
 
         int count = 0;
 
-        foreach (const CollectionLocation& location, allLocations)
+        Q_FOREACH (const CollectionLocation& location, allLocations)
         {
+            // cppcheck-suppress useStlAlgorithm
             count += countItemsInFolder(location.albumRootPath());
         }
 
-        emit totalFilesToScan(count);
+        Q_EMIT totalFilesToScan(count);
     }
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
@@ -80,17 +72,17 @@ void CollectionScanner::completeScan()
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
 
     if (d->wantSignals)
     {
-        emit startScanningAlbumRoots();
+        Q_EMIT startScanningAlbumRoots();
     }
 
-    foreach (const CollectionLocation& location, allLocations)
+    Q_FOREACH (const CollectionLocation& location, allLocations)
     {
         scanAlbumRoot(location);
     }
@@ -99,7 +91,7 @@ void CollectionScanner::completeScan()
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
@@ -108,7 +100,7 @@ void CollectionScanner::completeScan()
     {
         qCDebug(DIGIKAM_DATABASE_LOG) << "Complete scan (file scanning deferred) took:" << timer.elapsed() << "msecs.";
 
-        emit finishedCompleteScan();
+        Q_EMIT finishedCompleteScan();
 
         return;
     }
@@ -121,7 +113,7 @@ void CollectionScanner::completeScan()
 
 void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
 {
-    emit startCompleteScan();
+    Q_EMIT startCompleteScan();
 
     {
         // lock database
@@ -134,14 +126,14 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
 
     if (d->wantSignals)
     {
-        emit startScanningAlbumRoots();
+        Q_EMIT startScanningAlbumRoots();
     }
 
     // remove subalbums from list if parent album is already contained
@@ -168,15 +160,16 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
 
         int count = 0;
 
-        foreach (const QString& path, sortedPaths)
+        Q_FOREACH (const QString& path, sortedPaths)
         {
+            // cppcheck-suppress useStlAlgorithm
             count += countItemsInFolder(path);
         }
 
-        emit totalFilesToScan(count);
+        Q_EMIT totalFilesToScan(count);
     }
 
-    foreach (const QString& path, sortedPaths)
+    Q_FOREACH (const QString& path, sortedPaths)
     {
         CollectionLocation location = CollectionManager::instance()->locationForPath(path);
         QString album               = CollectionManager::instance()->album(path);
@@ -195,7 +188,7 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
@@ -221,7 +214,7 @@ void CollectionScanner::completeScanCleanupPart()
         CoreDbAccess access;
         QList<qlonglong> trashedItems = access.db()->getImageIds(DatabaseItem::Status::Trashed);
 
-        foreach (const qlonglong& item, trashedItems)
+        Q_FOREACH (const qlonglong& item, trashedItems)
         {
             access.db()->setItemStatus(item, DatabaseItem::Status::Obsolete);
         }
@@ -237,7 +230,7 @@ void CollectionScanner::completeScanCleanupPart()
 
     markDatabaseAsScanned();
 
-    emit finishedCompleteScan();
+    Q_EMIT finishedCompleteScan();
 }
 
 void CollectionScanner::partialScan(const QString& filePath)
@@ -315,7 +308,7 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
@@ -333,7 +326,7 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
 
     if (!d->checkObserver())
     {
-        emit cancelled();
+        Q_EMIT cancelled();
 
         return;
     }
@@ -408,6 +401,11 @@ qlonglong CollectionScanner::scanFile(const QFileInfo& fi, int albumId, qlonglon
 {
     mainEntryPoint(false);
 
+    if (!d->nameFilters.contains(fi.suffix().toLower()))
+    {
+        return -1;
+    }
+
     if (imageId == -1)
     {
         switch (mode)
@@ -418,6 +416,7 @@ qlonglong CollectionScanner::scanFile(const QFileInfo& fi, int albumId, qlonglon
                 break;
 
             case Rescan:
+            case CleanScan:
                 imageId = scanNewFileFullScan(fi, albumId);
                 break;
         }
@@ -439,6 +438,10 @@ qlonglong CollectionScanner::scanFile(const QFileInfo& fi, int albumId, qlonglon
             case Rescan:
                 rescanFile(fi, scanInfo);
                 break;
+
+            case CleanScan:
+                cleanScanFile(fi, scanInfo);
+                break;
         }
     }
 
@@ -451,7 +454,7 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
 {
     if (d->wantSignals)
     {
-        emit startScanningAlbumRoot(location.albumRootPath());
+        Q_EMIT startScanningAlbumRoot(location.albumRootPath());
     }
 
     QMap<QString, QDateTime>::const_iterator it;
@@ -477,6 +480,7 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
             else
             {
                 modified = QFileInfo(folder).lastModified();
+                modified.setTimeSpec(Qt::UTC);
             }
 
             if (s_modificationDateEquals(modified, it.value()))
@@ -488,7 +492,7 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
 
                 if (d->wantSignals)
                 {
-                    emit scannedFiles(counter + 1);
+                    Q_EMIT scannedFiles(counter + 1);
                 }
             }
             else
@@ -500,7 +504,7 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
 
     if (d->wantSignals)
     {
-        emit finishedScanningAlbumRoot(location.albumRootPath());
+        Q_EMIT finishedScanningAlbumRoot(location.albumRootPath());
     }
 }
 
@@ -508,7 +512,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<CollectionLocation>& loca
 {
     QList<int> locationIdsToScan;
 
-    foreach (const CollectionLocation& location, locations)
+    Q_FOREACH (const CollectionLocation& location, locations)
     {
         locationIdsToScan << location.id();
     }
@@ -520,7 +524,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
 {
     if (d->wantSignals)
     {
-        emit startScanningForStaleAlbums();
+        Q_EMIT startScanningForStaleAlbums();
     }
 
     QList<AlbumShortInfo> albumList = CoreDbAccess().db()->getAlbumShortInfos();
@@ -529,7 +533,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
 
     if (d->wantSignals && d->needTotalFiles)
     {
-        emit totalFilesToScan(albumList.count());
+        Q_EMIT totalFilesToScan(albumList.count());
     }
 
     QList<AlbumShortInfo>::const_iterator it3;
@@ -540,7 +544,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
 
         if (d->wantSignals && counter && (counter % 10 == 0))
         {
-            emit scannedFiles(counter);
+            Q_EMIT scannedFiles(counter);
             counter = 0;
         }
 
@@ -558,21 +562,17 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
             QFileInfo fileInfo(location.albumRootPath() + (*it3).relativePath);
             bool dirExist = (fileInfo.exists() && fileInfo.isDir());
 
-#ifdef Q_OS_WIN
-
-            if (dirExist                                               &&
-                !(*it3).relativePath.endsWith(QLatin1Char('/'))        &&
-                !s_modificationDateEquals(fileInfo.lastModified(),
-                                          CoreDbAccess().db()->getAlbumModificationDate((*it3).id)))
+            if (location.asQtCaseSensitivity() == Qt::CaseInsensitive)
             {
-                QDir dir(fileInfo.dir());
-                dirExist = dir.entryList(QDir::Dirs |
-                                         QDir::NoDotAndDotDot)
-                                         .contains(fileInfo.fileName());
+                if (dirExist && !(*it3).relativePath.endsWith(QLatin1Char('/')))
+                {
+                    QDir dir(fileInfo.dir());
+                    dirExist = dir.entryList(QDir::Dirs |
+                                             QDir::NoDotAndDotDot)
+                                             .contains(fileInfo.fileName());
+                }
             }
 
-#endif
-
             // let digikam think that ignored directories got deleted
             // (if they already exist in the database, this will delete them)
 
@@ -587,7 +587,9 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
             }
             else
             {
-                d->albumDateCache.insert(fileInfo.filePath(), fileInfo.lastModified());
+                QDateTime dateTime = fileInfo.lastModified();
+                dateTime.setTimeSpec(Qt::UTC);
+                d->albumDateCache.insert(fileInfo.filePath(), dateTime);
             }
         }
     }
@@ -643,18 +645,17 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
                     QFileInfo fileInfo(location.albumRootPath() + it.key().relativePath);
                     bool dirExist = (fileInfo.exists() && fileInfo.isDir());
 
-#ifdef Q_OS_WIN
-
-                    if (dirExist && !it.key().relativePath.endsWith(QLatin1Char('/')))
+                    if (location.asQtCaseSensitivity() == Qt::CaseInsensitive)
                     {
-                        QDir dir(fileInfo.dir());
-                        dirExist = dir.entryList(QDir::Dirs |
-                                                 QDir::NoDotAndDotDot)
-                                                 .contains(fileInfo.fileName());
+                        if (dirExist && !it.key().relativePath.endsWith(QLatin1Char('/')))
+                        {
+                            QDir dir(fileInfo.dir());
+                            dirExist = dir.entryList(QDir::Dirs |
+                                                     QDir::NoDotAndDotDot)
+                                                     .contains(fileInfo.fileName());
+                        }
                     }
 
-#endif
-
                     if (dirExist)
                     {
                         // Just set a new root/relativePath to the album. Further scanning will care for all cases or error.
@@ -674,7 +675,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
 
     if (d->wantSignals)
     {
-        emit finishedScanningForStaleAlbums();
+        Q_EMIT finishedScanningForStaleAlbums();
     }
 }
 
@@ -696,11 +697,12 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
     if (d->wantSignals)
     {
-        emit startScanningAlbum(location.albumRootPath(), album);
+        Q_EMIT startScanningAlbum(location.albumRootPath(), album);
     }
 
     int albumID                          = checkAlbum(location, album);
     QDateTime albumDateTime              = QFileInfo(dir.path()).lastModified();
+    albumDateTime.setTimeSpec(Qt::UTC);
     QDateTime albumModified              = CoreDbAccess().db()->getAlbumModificationDate(albumID);
 
     if (checkDate && s_modificationDateEquals(albumDateTime, albumModified))
@@ -711,7 +713,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
         if (d->wantSignals)
         {
-            emit finishedScanningAlbum(location.albumRootPath(), album, 1);
+            Q_EMIT finishedScanningAlbum(location.albumRootPath(), album, 1);
         }
 
         return;
@@ -730,25 +732,24 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
         itemIdSet << scanInfos.at(i).id;
     }
 
-    const QStringList& list = dir.entryList(QDir::Dirs    |
-                                            QDir::Files   |
-                                            QDir::NoDotAndDotDot,
-                                            QDir::Name | QDir::DirsLast);
+    const QFileInfoList& list = dir.entryInfoList(QDir::Dirs    |
+                                                  QDir::Files   |
+                                                  QDir::NoDotAndDotDot,
+                                                  QDir::Name | QDir::DirsLast);
 
     int counter          = 0;
     bool updateAlbumDate = false;
-    QDate albumDate      = albumDateTime.date();
+    QDate albumDateOld   = albumDateTime.date();
+    QDate albumDateNew   = albumDateTime.date();
     const QString xmpExt(QLatin1String(".xmp"));
 
-    foreach (const QString& entry, list)
+    Q_FOREACH (const QFileInfo& info, list)
     {
         if (!d->checkObserver())
         {
             return; // return directly, do not go to cleanup code after loop!
         }
 
-        QFileInfo info(dir, entry);
-
         if (info.isFile())
         {
             // filter with name filter
@@ -762,7 +763,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
             if (d->wantSignals && counter && (counter % 100 == 0))
             {
-                emit scannedFiles(counter);
+                Q_EMIT scannedFiles(counter);
                 counter = 0;
             }
 
@@ -774,11 +775,35 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
                 itemIdSet.remove(scanInfos.at(index).id);
 
-                bool hasSidecar = (settings.useXMPSidecar4Reading                  &&
-                                   (list.contains(info.fileName() + xmpExt)        ||
-                                    list.contains(info.completeBaseName() + xmpExt)));
+                bool hasSidecar        = false;
+                const QFileInfo* sinfo = nullptr;
 
-                scanFileNormal(info, scanInfos.at(index), hasSidecar);
+                if (settings.useXMPSidecar4Reading)
+                {
+                    QString sidecarName;
+
+                    if (!settings.useCompatibleFileName)
+                    {
+                        sidecarName = info.fileName() + xmpExt;
+                    }
+                    else
+                    {
+                        sidecarName = info.completeBaseName() + xmpExt;
+                    }
+
+                    for (int i = 0 ; i < list.size() ; ++i)
+                    {
+                        if (list.at(i).fileName() == sidecarName)
+                        {
+                            sinfo      = &list.at(i);
+                            hasSidecar = true;
+
+                            break;
+                        }
+                    }
+                }
+
+                scanFileNormal(info, scanInfos.at(index), hasSidecar, sinfo);
             }
             else if (info.completeSuffix().contains(QLatin1String("digikamtempfile.")))
             {
@@ -792,25 +817,44 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
                 qlonglong imageId = scanNewFile(info, albumID);
 
-                ItemInfo itemInfo(imageId);
-                QDate itemDate    = itemInfo.dateTime().date();
-
-                if (itemDate.isValid())
+                if (imageId > 0)
                 {
-                    // Change album date only if the item date is older.
+                    ItemInfo itemInfo(imageId);
+                    QDate itemDate    = itemInfo.dateTime().date();
 
-                    if (itemDate < albumDate)
+                    if (itemDate.isValid())
                     {
-                        albumDate       = itemDate;
-                        updateAlbumDate = true;
+                        if ((settings.albumDateFrom == MetaEngineSettingsContainer::NewestItemDate) ||
+                            (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate))
+                        {
+                            // Change album date only if the item date is newer.
+
+                            if (itemDate > albumDateNew)
+                            {
+                                albumDateNew    = itemDate;
+                                updateAlbumDate = true;
+                            }
+                        }
+
+                        if ((settings.albumDateFrom == MetaEngineSettingsContainer::OldestItemDate) ||
+                            (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate))
+                        {
+                            // Change album date only if the item date is older.
+
+                            if (itemDate < albumDateOld)
+                            {
+                                albumDateOld    = itemDate;
+                                updateAlbumDate = true;
+                            }
+                        }
                     }
                 }
 
-                // emit signals for scanned files with much higher granularity
+                // Q_EMIT signals for scanned files with much higher granularity
 
                 if (d->wantSignals && counter && (counter % 2 == 0))
                 {
-                    emit scannedFiles(counter);
+                    Q_EMIT scannedFiles(counter);
                     counter = 0;
                 }
             }
@@ -856,12 +900,30 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     {
         // Write the new album date from the image information
 
-        CoreDbAccess().db()->setAlbumDate(albumID, albumDate);
+        if      (settings.albumDateFrom == MetaEngineSettingsContainer::OldestItemDate)
+        {
+            CoreDbAccess().db()->setAlbumDate(albumID, albumDateOld);
+        }
+        else if (settings.albumDateFrom == MetaEngineSettingsContainer::NewestItemDate)
+        {
+            CoreDbAccess().db()->setAlbumDate(albumID, albumDateNew);
+        }
+        else if (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate)
+        {
+            qint64 julianDayCount = albumDateOld.toJulianDay();
+            julianDayCount       += albumDateNew.toJulianDay();
+
+            CoreDbAccess().db()->setAlbumDate(albumID, QDate::fromJulianDay(julianDayCount / 2));
+        }
+        else if (settings.albumDateFrom == MetaEngineSettingsContainer::FolderDate)
+        {
+            CoreDbAccess().db()->setAlbumDate(albumID, albumDateTime.date());
+        }
     }
 
     if (d->wantSignals && counter)
     {
-        emit scannedFiles(counter);
+        Q_EMIT scannedFiles(counter);
     }
 
     // Mark items in the db which we did not see on disk.
@@ -880,13 +942,16 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
     if (d->wantSignals)
     {
-        emit finishedScanningAlbum(location.albumRootPath(), album, list.count());
+        Q_EMIT finishedScanningAlbum(location.albumRootPath(), album, list.count());
     }
 }
 
-void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo& scanInfo, bool checkSidecar)
+void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo& scanInfo,
+                                       bool checkSidecar, const QFileInfo* const sidecarInfo)
 {
-    bool hasAnyHint = d->hints && d->hints->hasAnyNormalHint(scanInfo.id);
+    bool hasAnyHint            = d->hints && d->hints->hasAnyNormalHint(scanInfo.id);
+    QDateTime modificationDate = fi.lastModified();
+    modificationDate.setTimeSpec(Qt::UTC);
 
     // if the date is null, this signals a full rescan
 
@@ -938,7 +1003,7 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     {
         // if the file need not be scanned because of modification, update the hash
 
-        if (s_modificationDateEquals(fi.lastModified(), scanInfo.modificationDate) &&
+        if (s_modificationDateEquals(modificationDate, scanInfo.modificationDate) &&
             (fi.size() == scanInfo.fileSize))
         {
             scanFileUpdateHashReuseThumbnail(fi, scanInfo, false);
@@ -948,19 +1013,29 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     }
 
     MetaEngineSettingsContainer settings = MetaEngineSettings::instance()->settings();
-    QDateTime modificationDate           = fi.lastModified();
 
-    if (checkSidecar                   &&
-        settings.updateFileTimeStamp   &&
-        settings.useXMPSidecar4Reading &&
-        DMetadata::hasSidecar(fi.filePath()))
+    if (checkSidecar && settings.useXMPSidecar4Reading)
     {
-        QString filePath      = DMetadata::sidecarPath(fi.filePath());
-        QDateTime sidecarDate = QFileInfo(filePath).lastModified();
-
-        if (sidecarDate > modificationDate)
+        if      (sidecarInfo)
         {
-            modificationDate = sidecarDate;
+            QDateTime sidecarDate = sidecarInfo->lastModified();
+            sidecarDate.setTimeSpec(Qt::UTC);
+
+            if (sidecarDate > modificationDate)
+            {
+                modificationDate = sidecarDate;
+            }
+        }
+        else if (DMetadata::hasSidecar(fi.filePath()))
+        {
+            QString filePath      = DMetadata::sidecarPath(fi.filePath());
+            QDateTime sidecarDate = QFileInfo(filePath).lastModified();
+            sidecarDate.setTimeSpec(Qt::UTC);
+
+            if (sidecarDate > modificationDate)
+            {
+                modificationDate = sidecarDate;
+            }
         }
     }
 
@@ -969,7 +1044,7 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     {
         if (settings.rescanImageIfModified)
         {
-            rescanFile(fi, scanInfo);
+            cleanScanFile(fi, scanInfo);
         }
         else
         {
@@ -998,7 +1073,7 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
         srcId = d->hints->itemHints.value(NewlyAppearedFile(albumId, info.fileName()));
     }
 
-    if (srcId != 0)
+    if (srcId > 0)
     {
         scanner.copiedFrom(albumId, srcId);
     }
@@ -1015,7 +1090,7 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
             srcId = CoreDbAccess().db()->getImageId(srcAlbum, info.fileName());
         }
 
-        if (srcId != 0)
+        if (srcId > 0)
         {
             scanner.copiedFrom(albumId, srcId);
         }
@@ -1028,6 +1103,7 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
     }
 
     d->finishScanner(scanner);
+    d->newIdsList << scanner.id();
 
     return scanner.id();
 }
@@ -1102,6 +1178,19 @@ void CollectionScanner::scanFileUpdateHashReuseThumbnail(const QFileInfo& info,
     d->finishScanner(scanner);
 }
 
+void CollectionScanner::cleanScanFile(const QFileInfo& info, const ItemScanInfo& scanInfo)
+{
+    if (d->checkDeferred(info))
+    {
+        return;
+    }
+
+    ItemScanner scanner(info, scanInfo);
+    scanner.setCategory(category(info));
+    scanner.cleanScan();
+    d->finishScanner(scanner);
+}
+
 void CollectionScanner::rescanFile(const QFileInfo& info, const ItemScanInfo& scanInfo)
 {
     if (d->checkDeferred(info))
@@ -1156,7 +1245,7 @@ void CollectionScanner::finishHistoryScanning()
 
 void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
 {
-    foreach (const qlonglong& id, ids)
+    Q_FOREACH (const qlonglong& id, ids)
     {
         if (!d->checkObserver())
         {
@@ -1170,7 +1259,7 @@ void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
             QList<qlonglong> needTaggingIds;
             ItemScanner::resolveImageHistory(id, &needTaggingIds);
 
-            foreach (const qlonglong& needTag, needTaggingIds)
+            Q_FOREACH (const qlonglong& needTag, needTaggingIds)
             {
                 d->needTaggingHistorySet << needTag;
             }
@@ -1184,7 +1273,7 @@ void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
 
 void CollectionScanner::historyScanningStage3(const QList<qlonglong>& ids)
 {
-    foreach (const qlonglong& id, ids)
+    Q_FOREACH (const qlonglong& id, ids)
     {
         if (!d->checkObserver())
         {
