@@ -6,20 +6,11 @@
  * Date        : 2007-03-21
  * Description : Collection scanning to database - scan utilities.
  *
- * Copyright (C) 2005-2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -42,10 +33,10 @@ void CollectionScanner::loadNameFilters()
 
     // three sets to find category of a file
 
-    d->imageFilterSet  = imageFilter.toSet();
-    d->audioFilterSet  = audioFilter.toSet();
-    d->videoFilterSet  = videoFilter.toSet();
-    d->ignoreDirectory = ignoreDirectory.toSet();
+    d->imageFilterSet  = QSet<QString>(imageFilter.begin(),     imageFilter.end());
+    d->audioFilterSet  = QSet<QString>(audioFilter.begin(),     audioFilter.end());
+    d->videoFilterSet  = QSet<QString>(videoFilter.begin(),     videoFilter.end());
+    d->ignoreDirectory = QSet<QString>(ignoreDirectory.begin(), ignoreDirectory.end());
 
     d->nameFilters     = d->imageFilterSet + d->audioFilterSet + d->videoFilterSet;
 }
@@ -64,7 +55,7 @@ void CollectionScanner::safelyRemoveAlbums(const QList<int>& albumIds)
     CoreDbAccess access;
     CoreDbTransaction transaction(&access);
 
-    foreach (int albumId, albumIds)
+    Q_FOREACH (int albumId, albumIds)
     {
         QList<qlonglong> ids = access.db()->getItemIDsInAlbum(albumId);
         access.db()->removeItemsFromAlbum(albumId, ids);
@@ -138,7 +129,7 @@ void CollectionScanner::copyFileProperties(const ItemInfo& source, const ItemInf
 
     // Copy public tags
 
-    foreach (int tagId, TagsCache::instance()->publicTags(source.tagIds()))
+    Q_FOREACH (int tagId, TagsCache::instance()->publicTags(source.tagIds()))
     {
         dest.setTag(tagId);
     }
@@ -192,7 +183,7 @@ void CollectionScanner::itemsWereRemoved(const QList<qlonglong>& removedIds)
 
     if (d->recordHistoryIds)
     {
-        foreach (const qlonglong& id, relatedImages)
+        Q_FOREACH (const qlonglong& id, relatedImages)
         {
             d->needTaggingHistorySet << id;
         }
@@ -215,7 +206,7 @@ int CollectionScanner::countItemsInFolder(const QString& path)
 
     CollectionLocation location = CollectionManager::instance()->locationForPath(path);
 
-    if (!location.isNull())
+    if (!location.isNull() && databaseInitialScanDone())
     {
         QString album = CollectionManager::instance()->album(path);
         int albumID   = CoreDbAccess().db()->getAlbumForPath(location.id(), album, false);
@@ -307,11 +298,11 @@ void CollectionScanner::resetDeleteRemovedSettings()
 
 bool CollectionScanner::checkDeleteRemoved()
 {
-    // returns true if removed items shall be deleted
+    // Returns true if removed items shall be deleted
 
     CoreDbAccess access;
 
-    // retrieve last time an item was removed (not deleted, but set to status removed)
+    // Retrieve last time an item was removed (not deleted, but set to status removed)
 
     QString removedItemsTimeString = access.db()->getSetting(QLatin1String("RemovedItemsTime"));
 
@@ -320,15 +311,11 @@ bool CollectionScanner::checkDeleteRemoved()
         return false;
     }
 
-    // retrieve last time removed items were (definitely) deleted from db
+    // Retrieve last time removed items were (definitely) deleted from db
 
     QString deleteRemovedTimeString = access.db()->getSetting(QLatin1String("DeleteRemovedTime"));
-    QDateTime removedItemsTime, deleteRemovedTime;
-
-    if (!removedItemsTimeString.isNull())
-    {
-        removedItemsTime = QDateTime::fromString(removedItemsTimeString, Qt::ISODate);
-    }
+    QDateTime removedItemsTime      = QDateTime::fromString(removedItemsTimeString, Qt::ISODate);
+    QDateTime deleteRemovedTime;
 
     if (!deleteRemovedTimeString.isNull())
     {
@@ -337,7 +324,7 @@ bool CollectionScanner::checkDeleteRemoved()
 
     QDateTime now     = QDateTime::currentDateTime();
 
-    // retrieve number of complete collection scans since the last time that removed items were deleted
+    // Retrieve number of complete collection scans since the last time that removed items were deleted
 
     int completeScans = access.db()->getSetting(QLatin1String("DeleteRemovedCompleteScanCount")).toInt();
 
@@ -348,7 +335,7 @@ bool CollectionScanner::checkDeleteRemoved()
         return false;
     }
 
-    // give at least a week between removed item deletions
+    // Give at least a week between removed item deletions
 
     if (deleteRemovedTime.isValid())
     {
@@ -471,7 +458,7 @@ void CollectionScanner::scanAlbums()
         count += countItemsInFolder(*it);
     }
 
-    emit totalFilesToScan(count);
+    Q_EMIT totalFilesToScan(count);
 
     for (QStringList::const_iterator it = albumRootPaths.constBegin() ; it != albumRootPaths.constEnd() ; ++it)
     {
@@ -479,7 +466,7 @@ void CollectionScanner::scanAlbums()
         QStringList fileList(dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot));
         CoreDbTransaction transaction;
 
-        foreach (const QString& dir, fileList)
+        Q_FOREACH (const QString& dir, fileList)
         {
             scanAlbum(*it, QLatin1Char('/') + dir);
         }
@@ -510,7 +497,7 @@ void CollectionScanner::scan(const QString& albumRoot, const QString& album)
     scanForStaleAlbums(albumRoot);
     removeStaleAlbums();
 
-    emit totalFilesToScan(countItemsInFolder(albumRoot + album));
+    Q_EMIT totalFilesToScan(countItemsInFolder(albumRoot + album));
 
     // Step two: Scan directories
 
@@ -563,7 +550,7 @@ void CollectionScanner::scanAlbum(const QString& albumRoot, const QString& album
         return;
     }
 
-    emit startScanningAlbum(albumRoot, album);
+    Q_EMIT startScanningAlbum(albumRoot, album);
 
     // get album id if album exists
 
@@ -631,14 +618,14 @@ void CollectionScanner::scanAlbum(const QString& albumRoot, const QString& album
         }
     }
 
-    emit finishedScanningAlbum(albumRoot, album, list.count());
+    Q_EMIT finishedScanningAlbum(albumRoot, album, list.count());
 }
 
 void CollectionScanner::updateItemsWithoutDate()
 {
     QStringList urls  = CoreDbAccess().db()->getAllItemURLsWithoutDate();
 
-    emit totalFilesToScan(urls.count());
+    Q_EMIT totalFilesToScan(urls.count());
 
     QString albumRoot = CoreDbAccess::albumRoot();
 
@@ -647,7 +634,7 @@ void CollectionScanner::updateItemsWithoutDate()
 
         for (QStringList::const_iterator it = urls.constBegin() ; it != urls.constEnd() ; ++it)
         {
-            emit scanningFile(*it);
+            Q_EMIT scanningFile(*it);
 
             QFileInfo fi(*it);
             QString albumURL = fi.path();
