@@ -6,21 +6,12 @@
  * Date        : 2004-06-18
  * Description : Core database interface.
  *
- * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,11 +31,12 @@
 
 // Local includes
 
+#include "digikam_export.h"
+#include "collectionlocation.h"
 #include "coredbalbuminfo.h"
 #include "coredbfields.h"
 #include "coredbaccess.h"
 #include "coredbconstants.h"
-#include "digikam_export.h"
 #include "dbenginesqlquery.h"
 #include "album.h"
 
@@ -115,6 +107,13 @@ public:
      */
     QUuid databaseUuid();
 
+    /**
+     * Returns database encoding.
+     * For SQLite should UTF-8.
+     * For MySQL like UTF8MB4.
+     */
+    QString getDatabaseEncoding()                                                                                   const;
+
     /**
      * Returns the version used for the unique hash in this database.
      * The value is cached.
@@ -140,7 +139,7 @@ public:
      * @param label        An (optional) user-visible label
      * @returns the album root id of the newly created root
      */
-    int addAlbumRoot(AlbumRoot::Type type, const QString& identifier,
+    int addAlbumRoot(CollectionLocation::Type type, const QString& identifier,
                      const QString& specificPath, const QString& label)                                             const;
 
     /**
@@ -173,7 +172,12 @@ public:
     /**
      * Sets the type of the specified album root to a new value.
      */
-    void changeAlbumRootType(int rootId, AlbumRoot::Type newType);
+    void setAlbumRootType(int rootId, CollectionLocation::Type newType);
+
+    /**
+     * Sets the case sensitivity of the specified album root to a new value.
+     */
+    void setAlbumRootCaseSensitivity(int rootId, CollectionLocation::CaseSensitivity caseSensitivity);
 
     // ----------- Album Listing operations -----------
     /**
@@ -374,10 +378,10 @@ public:
     QMap<QString, QDateTime> getAlbumModificationMap(int albumRootId)                                               const;
 
     /**
-     * Returns a QMap<int, int> of album id -> count of items
+     * Returns a QHash<int, int> of album id -> count of items
      * in the album
      */
-    QMap<int, int> getNumberOfImagesInAlbums()                                                                      const;
+    QHash<int, int> getNumberOfImagesInAlbums()                                                                      const;
 
     // ----------- Operations on TAlbums -----------
 
@@ -537,6 +541,12 @@ public:
      */
     void deleteItem(qlonglong imageId);
 
+    /**
+     * Deletes an item from the database without checking the album.
+     * @param imageId The id of the image.
+     */
+    void deleteObsoleteItem(qlonglong imageId);
+
     /**
      * Marks all items in the specified album as removed,
      * resets their dirids.
@@ -557,7 +567,7 @@ public:
      * @param albumIDs this parameter is purely informational.
      *                 it shall contain the albums that the items are removed from.
      */
-    void removeItems(QList<qlonglong> itemIDs, const QList<int>& albumIDs = QList<int>());
+    void removeItems(const QList<qlonglong>& itemIDs, const QList<int>& albumIDs = QList<int>());
 
     /**
      * Marks all items in the list as obsolete,
@@ -567,7 +577,7 @@ public:
      * @param albumIDs this parameter is purely informational.
      *                 it shall contain the albums that the items are removed from.
      */
-    void removeItemsPermanently(QList<qlonglong> itemIDs, const QList<int>& albumIDs = QList<int>());
+    void removeItemsPermanently(const QList<qlonglong>& itemIDs, const QList<int>& albumIDs = QList<int>());
 
     /**
      * Delete all items from the database that are marked as removed.
@@ -722,6 +732,11 @@ public:
      */
     QVariantList getAllCreationDates()                                                                              const;
 
+    /**
+     * Get obsolete item Ids.
+     */
+    QList<qlonglong> getObsoleteItemIds()                                                                           const;
+
     // ----------- Item properties -----------
 
     /**
@@ -951,7 +966,7 @@ public:
     QVariantList getItemPosition(qlonglong imageID,
                                  DatabaseFields::ItemPositions positionFields = DatabaseFields::ItemPositionsAll)   const;
 
-    QVariantList getItemPositions(QList<qlonglong> imageIDs, DatabaseFields::ItemPositions fields)                  const;
+    QVariantList getItemPositions(const QList<qlonglong>& imageIDs, DatabaseFields::ItemPositions fields)                  const;
 
     /**
      * Remove the entry in ItemPositions for the given image
@@ -1002,7 +1017,12 @@ public:
     /**
      * Remove the specified entry in ItemComments
      */
-    void removeImageComment(int commentId, qlonglong imageid);
+    void removeImageComment(int commentId, qlonglong imageID);
+
+    /**
+     * Remove all ItemComments
+     */
+    void removeAllImageComments(qlonglong imageID);
 
     /**
      * Returns the property with the specified name for the specified image
@@ -1015,6 +1035,9 @@ public:
     void setImageProperty(qlonglong imageID, const QString& property, const QString& value);
     void removeImageProperty(qlonglong imageID, const QString& property);
     void removeImagePropertyByName(const QString& property);
+    void removeAllImageProperties(qlonglong imageID);
+
+    QStringList getAllImagePropertiesByName(const QString& property)                                                const;
 
     /**
      * Returns the copyright properties of the specified image.
@@ -1046,6 +1069,11 @@ public:
                                         const QString& extraValue = QString(),
                                         const QString& value = QString() /* NOTE parameter order */);
 
+    /**
+     * Removes all copyright properties for the given image id.
+     */
+    void removeAllItemCopyrightProperties(qlonglong imageID);
+
     /**
      * Returns all items with the given file name and creation date.
      */
@@ -1170,6 +1198,11 @@ public:
      */
     QStringList getItemsURLsWithTag(int tagId)                                                                      const;
 
+    /**
+     * Returns the first item that has a confirmed face with the tag.
+     */
+    qlonglong getFirstItemWithFaceTag(int tagId)                                                                    const;
+
     // ----------- Items and their tags -----------
 
     /**
@@ -1192,7 +1225,7 @@ public:
      * Add each tag of a list of tags
      * to each member of a list of items.
      */
-    void addTagsToItems(QList<qlonglong> imageIDs, QList<int> tagIDs);
+    void addTagsToItems(const QList<qlonglong>& imageIDs, const QList<int>& tagIDs);
 
     /**
      * Remove a specific tag for the item
@@ -1212,7 +1245,7 @@ public:
      * Remove each tag from a list of tags
      * from a each member of a list of items.
      */
-    void removeTagsFromItems(QList<qlonglong> imageIDs, const QList<int>& tagIDs);
+    void removeTagsFromItems(const QList<qlonglong>& imageIDs, const QList<int>& tagIDs);
 
     /**
      * Get a list of names of all the tags for the item
@@ -1281,16 +1314,16 @@ public:
     QList<int> getItemCommonTagIDs(const QList<qlonglong>& imageIDList)                                             const;
 
     /**
-     * Returns a QMap<int,int> of tag id -> count of items
+     * Returns a QHash<int, int> of tag id -> count of items
      * with the tag
      */
-    QMap<int, int> getNumberOfImagesInTags()                                                                        const;
+    QHash<int, int> getNumberOfImagesInTags()                                                                        const;
 
     /**
-     * Returns a QMap<int,int> of tag id -> count of items
+     * Returns a QHash<int, int> of tag id -> count of items
      * with the given tag property
      */
-    QMap<int, int> getNumberOfImagesInTagProperties(const QString& property)                                        const;
+    QHash<int, int> getNumberOfImagesInTagProperties(const QString& property)                                        const;
 
     /**
      * Returns the count of images that have a tag property for the given tag.
@@ -1342,8 +1375,8 @@ public:
      * @param  dstName    the name of the destination file
      * @return the id of item added or -1 if it fails
      */
-    int copyItem(int srcAlbumID, const QString& srcName,
-                 int dstAlbumID, const QString& dstName);
+    qlonglong copyItem(int srcAlbumID, const QString& srcName,
+                       int dstAlbumID, const QString& dstName);
 
     /**
      * Copies all image-specific information, in all tables, from image srcId to destId.
@@ -1360,14 +1393,6 @@ public:
      */
     void copyImageTags(qlonglong srcId, qlonglong dstId);
 
-    // ------------ Clear all Item Metadata -----------
-
-    /**
-     * Clear all metadata of an item
-     * @param  imageID the ID of the item
-     */
-    void clearMetadataFromImage(qlonglong imageID);
-
     // ----------- Download history methods -----------
 
     /**
