@@ -7,7 +7,7 @@
  * Description : Core database access wrapper.
  *
  * SPDX-FileCopyrightText: 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -39,7 +39,6 @@
 #include "coredbbackend.h"
 #include "dbengineerrorhandler.h"
 #include "tagscache.h"
-#include "dbengineparameters.h"
 #include "dbengineaccess.h"
 
 namespace Digikam
@@ -49,31 +48,24 @@ class Q_DECL_HIDDEN CoreDbAccessStaticPriv
 {
 public:
 
-    CoreDbAccessStaticPriv()
-        : backend              (nullptr),
-          db                   (nullptr),
-          databaseWatch        (nullptr),
-          // Create a unique identifier for this application (as an application accessing a database
-          applicationIdentifier(QUuid::createUuid()),
-          initializing         (false)
-    {
-    };
-
-    ~CoreDbAccessStaticPriv()
-    {
-    };
+    CoreDbAccessStaticPriv()  = default;
+    ~CoreDbAccessStaticPriv() = default;
 
 public:
 
-    CoreDbBackend*      backend;
-    CoreDB*             db;
-    CoreDbWatch*        databaseWatch;
+    CoreDbBackend*      backend               = nullptr;
+    CoreDB*             db                    = nullptr;
+    CoreDbWatch*        databaseWatch         = nullptr;
     DbEngineParameters  parameters;
     DbEngineLocking     lock;
     QString             lastError;
-    QUuid               applicationIdentifier;
 
-    bool                initializing;
+    /**
+     * Create a unique identifier for this application (as an application accessing a database.
+     */
+    QUuid               applicationIdentifier = QUuid::createUuid();
+
+    bool                initializing          = false;
 };
 
 CoreDbAccessStaticPriv* CoreDbAccess::d = nullptr;
@@ -82,7 +74,7 @@ CoreDbAccessStaticPriv* CoreDbAccess::d = nullptr;
 
 class Q_DECL_HIDDEN CoreDbAccessMutexLocker
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
     : public QMutexLocker<QRecursiveMutex>
 
