@@ -6,19 +6,10 @@
  * Date        : 2007-04-16
  * Description : Core database Schema updater
  *
- * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -42,7 +33,6 @@
 
 #include "drawdecoder.h"
 #include "digikam_debug.h"
-#include "coredbbackend.h"
 #include "coredbtransaction.h"
 #include "coredbchecker.h"
 #include "collectionmanager.h"
@@ -51,18 +41,19 @@
 #include "itemquerybuilder.h"
 #include "collectionscannerobserver.h"
 #include "digikam_config.h"
+#include "digikam_globals.h"
 
 namespace Digikam
 {
 
 int CoreDbSchemaUpdater::schemaVersion()
 {
-    return 15;
+    return 16;
 }
 
 int CoreDbSchemaUpdater::filterSettingsVersion()
 {
-    return 16;
+    return 17;
 }
 
 int CoreDbSchemaUpdater::uniqueHashVersion()
@@ -82,29 +73,22 @@ class Q_DECL_HIDDEN CoreDbSchemaUpdater::Private
 
 public:
 
-    explicit Private()
-      : setError(false),
-        backend (nullptr),
-        albumDB (nullptr),
-        dbAccess(nullptr),
-        observer(nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                    setError;
+    bool                    setError                = false;
 
     QVariant                currentVersion;
     QVariant                currentRequiredVersion;
 
-    CoreDbBackend*          backend;
-    CoreDB*                 albumDB;
+    CoreDbBackend*          backend                 = nullptr;
+    CoreDB*                 albumDB                 = nullptr;
     DbEngineParameters      parameters;
 
     // legacy
-    CoreDbAccess*           dbAccess;
+    CoreDbAccess*           dbAccess                = nullptr;
 
     QString                 lastErrorMessage;
-    InitializationObserver* observer;
+    InitializationObserver* observer                = nullptr;
 };
 
 CoreDbSchemaUpdater::CoreDbSchemaUpdater(CoreDB* const albumDB,
@@ -336,6 +320,7 @@ bool CoreDbSchemaUpdater::startUpdates()
 
         // No legacy handling: start with a fresh db
 
+        // cppcheck-suppress knownConditionTrueFalse
         if (!createDatabase() || !createFilterSettings())
         {
             QString errorMsg    = i18n("Failed to create tables in database.\n ") + d->backend->lastError();
@@ -516,7 +501,7 @@ void CoreDbSchemaUpdater::defaultFilterSettings(QStringList& defaultItemFilter,
                       << QLatin1String("tga")                                                     // Truevision Graphics Adapter
                       << QLatin1String("sgi")  << QLatin1String("rgb")  << QLatin1String("rgba")  // Silicon Graphics Image
                       << QLatin1String("bw")
-                      << QLatin1String("heic") << QLatin1String("heif")                           // High Efficiency Image File Format
+                      << QLatin1String("heic") << QLatin1String("heif") << QLatin1String("hif")   // High Efficiency Image File Format
                       << QLatin1String("jxl")                                                     // JPEG-XL
                       << QLatin1String("avif")                                                    // AV1 Image File Format
                       << QLatin1String("wbmp")                                                    // Wireless Application Protocol Bitmap Format
@@ -594,7 +579,7 @@ bool CoreDbSchemaUpdater::updateFilterSettings()
 
 bool CoreDbSchemaUpdater::createDatabase()
 {
-    if ( createTables() && createIndices() && createTriggers())
+    if (createTables() && createIndices() && createTriggers())
     {
         setLegacySettingEntries();
 
@@ -667,6 +652,7 @@ bool CoreDbSchemaUpdater::updateUniqueHash()
             setVersionSettings();
         }
     }
+
     return true;
 }
 
@@ -817,9 +803,18 @@ bool CoreDbSchemaUpdater::updateToVersion(int targetVersion)
             return performUpdateToVersion(QLatin1String("UpdateSchemaFromV14ToV15"), 15, 5);
         }
 
+        case 16:
+        {
+            // digiKam for database version 15 can work with version 16,
+            // add caseSensitivity column to the AlbumRoots table.
+
+            return performUpdateToVersion(QLatin1String("UpdateSchemaFromV15ToV16"), 16, 5);
+        }
+
         default:
         {
             qCDebug(DIGIKAM_COREDB_LOG) << "Core database: unsupported update to version" << targetVersion;
+
             return false;
         }
     }
@@ -919,9 +914,9 @@ static QStringList cleanUserFilterString(const QString& filterString)
         sep = QChar(QLatin1Char(' '));
     }
 
-    QStringList sepList = filterString.split(sep, QString::SkipEmptyParts);
+    QStringList sepList = filterString.split(sep, QT_SKIP_EMPTY_PARTS);
 
-    foreach (const QString& f, sepList)
+    Q_FOREACH (const QString& f, sepList)
     {
         if (f.startsWith(wildcard))
         {
@@ -1201,18 +1196,21 @@ bool CoreDbSchemaUpdater::updateV4toV7()
     QStringList defaultItemFilter, defaultVideoFilter, defaultAudioFilter;
     defaultFilterSettings(defaultItemFilter, defaultVideoFilter, defaultAudioFilter);
 
-    QSet<QString> configItemFilter, configVideoFilter, configAudioFilter;
+    auto listFileFilter    = cleanUserFilterString(group.readEntry(QLatin1String("File Filter"),       QString()));
+    auto listRawFileFilter = cleanUserFilterString(group.readEntry(QLatin1String("Raw File Filter"),   QString()));
+    auto listMovieFilter   = cleanUserFilterString(group.readEntry(QLatin1String("Movie File Filter"), QString()));
+    auto listAudioFilter   = cleanUserFilterString(group.readEntry(QLatin1String("Audio File Filter"), QString()));
 
-    configItemFilter   = cleanUserFilterString(group.readEntry(QLatin1String("File Filter"),       QString())).toSet();
-    configItemFilter  += cleanUserFilterString(group.readEntry(QLatin1String("Raw File Filter"),   QString())).toSet();
-    configVideoFilter  = cleanUserFilterString(group.readEntry(QLatin1String("Movie File Filter"), QString())).toSet();
-    configAudioFilter  = cleanUserFilterString(group.readEntry(QLatin1String("Audio File Filter"), QString())).toSet();
+    QSet<QString> configItemFilter(listFileFilter.begin(), listFileFilter.end());
+    configItemFilter  += QSet<QString>(listRawFileFilter.begin(), listRawFileFilter.end());
+    QSet<QString> configVideoFilter(listMovieFilter.begin(), listMovieFilter.end());
+    QSet<QString> configAudioFilter(listAudioFilter.begin(), listAudioFilter.end());
 
     // remove those that are included in the default filter
 
-    configItemFilter.subtract(defaultItemFilter.toSet());
-    configVideoFilter.subtract(defaultVideoFilter.toSet());
-    configAudioFilter.subtract(defaultAudioFilter.toSet());
+    configItemFilter.subtract(QSet<QString>(defaultItemFilter.begin(), defaultItemFilter.end()));
+    configVideoFilter.subtract(QSet<QString>(defaultVideoFilter.begin(), defaultVideoFilter.end()));
+    configAudioFilter.subtract(QSet<QString>(defaultAudioFilter.begin(), defaultAudioFilter.end()));
 
     d->albumDB->setUserFilterSettings(configItemFilter.values(), configVideoFilter.values(), configAudioFilter.values());
     qCDebug(DIGIKAM_COREDB_LOG) << "Core database: set initial filter settings with user settings" << configItemFilter;
@@ -1374,7 +1372,7 @@ void CoreDbSchemaUpdater::preAlpha010Update1()
         return;
     }
 
-    if ( !d->backend->execSql(
+    if (!d->backend->execSql(
              QString::fromUtf8( "CREATE TABLE IF NOT EXISTS Searches  \n"
                                 " (id INTEGER PRIMARY KEY, \n"
                                 "  type INTEGER, \n"
