@@ -6,24 +6,21 @@
  * Date        : 2008-01-09
  * Description : Core database searches XML queries manager
  *
- * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #include "coredbsearchxml.h"
 
+#include <QRegularExpression>
+
+// Local includes
+
+#include "digikam_globals.h"
+
 namespace Digikam
 {
 
@@ -259,9 +256,11 @@ QList<int> SearchXmlReader::valueToIntOrIntList()
     QList<int> list;
 
     // poke at next token
+
     QXmlStreamReader::TokenType token = QXmlStreamReader::readNext();
 
     // Found text? Treat text as with valueToInt(), return single element list
+
     if (token == QXmlStreamReader::Characters)
     {
         list << text().toString().toInt();
@@ -271,6 +270,7 @@ QList<int> SearchXmlReader::valueToIntOrIntList()
     }
 
     // treat as with valueToIntList()
+
     while (!atEnd())
     {
         if (token != QXmlStreamReader::StartElement || name() != QLatin1String("listitem"))
@@ -291,9 +291,11 @@ QList<double> SearchXmlReader::valueToDoubleOrDoubleList()
     QList<double> list;
 
     // poke at next token
+
     QXmlStreamReader::TokenType token = QXmlStreamReader::readNext();
 
     // Found text? Treat text as with valueToInt(), return single element list
+
     if (token == QXmlStreamReader::Characters)
     {
         list << text().toString().toDouble();
@@ -303,6 +305,7 @@ QList<double> SearchXmlReader::valueToDoubleOrDoubleList()
     }
 
     // treat as with valueToIntList()
+
     while (!atEnd())
     {
         if (token != QXmlStreamReader::StartElement || name() != QLatin1String("listitem"))
@@ -323,9 +326,11 @@ QList<QString> SearchXmlReader::valueToStringOrStringList()
     QList<QString> list;
 
     // poke at next token
+
     QXmlStreamReader::TokenType token = QXmlStreamReader::readNext();
 
     // Found text? Treat text as with valueToString(), return single element list
+
     if (token == QXmlStreamReader::Characters)
     {
         list << text().toString();
@@ -335,6 +340,7 @@ QList<QString> SearchXmlReader::valueToStringOrStringList()
     }
 
     // treat as with valueToStringList()
+
     while (!atEnd())
     {
         if (token != QXmlStreamReader::StartElement || name() != QLatin1String("listitem"))
@@ -353,7 +359,7 @@ QList<QString> SearchXmlReader::valueToStringOrStringList()
 SearchXml::Operator SearchXmlReader::readOperator(const QString& attributeName,
                                                   SearchXml::Operator defaultOperator) const
 {
-    QStringRef op = attributes().value(attributeName);
+    QStringView op = attributes().value(attributeName);
 
     if      (op == QLatin1String("and"))
     {
@@ -378,7 +384,7 @@ SearchXml::Operator SearchXmlReader::readOperator(const QString& attributeName,
 SearchXml::Relation SearchXmlReader::readRelation(const QString& attributeName,
                                                   SearchXml::Relation defaultRelation) const
 {
-    QStringRef relation = attributes().value(attributeName);
+    QStringView relation = attributes().value(attributeName);
 
     if (relation == QLatin1String("equal"))
     {
@@ -452,7 +458,7 @@ SearchXml::Relation SearchXmlReader::readRelation(const QString& attributeName,
 bool SearchXmlReader::readToStartOfElement(const QString& elementName)
 {
     // go to next start element
-    forever
+    Q_FOREVER
     {
         bool atStart = isStartElement();
 
@@ -469,10 +475,12 @@ bool SearchXmlReader::readToStartOfElement(const QString& elementName)
                 (void)atStart;  // Remove clang warning.
                 break;
             }
+
             case EndDocument:
             {
                 return false;
             }
+
             default:
             {
                 break;
@@ -482,7 +490,7 @@ bool SearchXmlReader::readToStartOfElement(const QString& elementName)
 
     int stack = 1;
 
-    forever
+    Q_FOREVER
     {
         switch (QXmlStreamReader::readNext())
         {
@@ -496,6 +504,7 @@ bool SearchXmlReader::readToStartOfElement(const QString& elementName)
                 ++stack;
                 break;
             }
+
             case EndElement:
             {
                 if (!--stack)
@@ -505,10 +514,12 @@ bool SearchXmlReader::readToStartOfElement(const QString& elementName)
 
                 break;
             }
+
             case EndDocument:
             {
                 return false;
             }
+
             default:
             {
                 break;
@@ -525,7 +536,7 @@ void SearchXmlReader::readToEndOfElement()
     {
         int stack = 1;
 
-        forever
+        Q_FOREVER
         {
             switch (QXmlStreamReader::readNext())
             {
@@ -534,6 +545,7 @@ void SearchXmlReader::readToEndOfElement()
                     ++stack;
                     break;
                 }
+
                 case EndElement:
                 {
                     if (!--stack)
@@ -543,10 +555,12 @@ void SearchXmlReader::readToEndOfElement()
 
                     break;
                 }
+
                 case EndDocument:
                 {
                     return;
                 }
+
                 default:
                 {
                     break;
@@ -665,7 +679,7 @@ void SearchXmlWriter::writeValue(const QList<int>& valueList)
 {
     QString listitem(QLatin1String("listitem"));
 
-    foreach (int i, valueList)
+    Q_FOREACH (int i, valueList)
     {
         writeTextElement(listitem, QString::number(i));
     }
@@ -675,7 +689,7 @@ void SearchXmlWriter::writeValue(const QList<qlonglong>& valueList)
 {
     QString listitem(QLatin1String("listitem"));
 
-    foreach (int i, valueList)
+    Q_FOREACH (int i, valueList)
     {
         writeTextElement(listitem, QString::number(i));
     }
@@ -685,7 +699,7 @@ void SearchXmlWriter::writeValue(const QList<float>& valueList, int precision)
 {
     QString listitem(QLatin1String("listitem"));
 
-    foreach (double i, valueList)
+    Q_FOREACH (double i, valueList)
     {
         writeTextElement(listitem, QString::number(i, 'g', precision));
     }
@@ -695,7 +709,7 @@ void SearchXmlWriter::writeValue(const QList<double>& valueList, int precision)
 {
     QString listitem(QLatin1String("listitem"));
 
-    foreach (double i, valueList)
+    Q_FOREACH (double i, valueList)
     {
         writeTextElement(listitem, QString::number(i, 'g', precision));
     }
@@ -705,7 +719,7 @@ void SearchXmlWriter::writeValue(const QList<QDateTime>& valueList)
 {
     QString listitem(QLatin1String("listitem"));
 
-    foreach (const QDateTime& dt, valueList)
+    Q_FOREACH (const QDateTime& dt, valueList)
     {
         writeTextElement(listitem, dt.toString(Qt::ISODate));
     }
@@ -715,7 +729,7 @@ void SearchXmlWriter::writeValue(const QStringList& valueList)
 {
     QString listitem(QLatin1String("listitem"));
 
-    foreach (const QString& str, valueList)
+    Q_FOREACH (const QString& str, valueList)
     {
         writeTextElement(listitem, str);
     }
@@ -742,17 +756,28 @@ void SearchXmlWriter::writeOperator(const QString& attributeName, SearchXml::Ope
     {
         default:
         case SearchXml::And:
+        {
             writeAttribute(attributeName, QLatin1String("and"));
             break;
+        }
+
         case SearchXml::Or:
+        {
             writeAttribute(attributeName, QLatin1String("or"));
             break;
+        }
+
         case SearchXml::AndNot:
+        {
             writeAttribute(attributeName, QLatin1String("andnot"));
             break;
+        }
+
         case SearchXml::OrNot:
+        {
             writeAttribute(attributeName, QLatin1String("ornot"));
             break;
+        }
     }
 }
 
@@ -762,53 +787,100 @@ void SearchXmlWriter::writeRelation(const QString& attributeName, SearchXml::Rel
     {
         default:
         case SearchXml::Equal:
+        {
             writeAttribute(attributeName, QLatin1String("equal"));
             break;
+        }
+
         case SearchXml::Unequal:
+        {
             writeAttribute(attributeName, QLatin1String("unequal"));
             break;
+        }
+
         case SearchXml::Like:
+        {
             writeAttribute(attributeName, QLatin1String("like"));
             break;
+        }
+
         case SearchXml::NotLike:
+        {
             writeAttribute(attributeName, QLatin1String("notlike"));
             break;
+        }
+
         case SearchXml::LessThan:
+        {
             writeAttribute(attributeName, QLatin1String("lessthan"));
             break;
+        }
+
         case SearchXml::GreaterThan:
+        {
             writeAttribute(attributeName, QLatin1String("greaterthan"));
             break;
+        }
+
         case SearchXml::LessThanOrEqual:
+        {
             writeAttribute(attributeName, QLatin1String("lessthanequal"));
             break;
+        }
+
         case SearchXml::GreaterThanOrEqual:
+        {
             writeAttribute(attributeName, QLatin1String("greaterthanequal"));
             break;
+        }
+
         case SearchXml::Interval:
+        {
             writeAttribute(attributeName, QLatin1String("interval"));
             break;
+        }
+
         case SearchXml::IntervalOpen:
+        {
             writeAttribute(attributeName, QLatin1String("intervalopen"));
             break;
+        }
+
         case SearchXml::OneOf:
+        {
             writeAttribute(attributeName, QLatin1String("oneof"));
             break;
+        }
+
         case SearchXml::AllOf:
+        {
             writeAttribute(attributeName, QLatin1String("allof"));
             break;
+        }
+
         case SearchXml::InTree:
+        {
             writeAttribute(attributeName, QLatin1String("intree"));
             break;
+        }
+
         case SearchXml::NotInTree:
+        {
             writeAttribute(attributeName, QLatin1String("notintree"));
             break;
+        }
+
         case SearchXml::Near:
+        {
             writeAttribute(attributeName, QLatin1String("near"));
             break;
+        }
+
         case SearchXml::Inside:
+        {
             writeAttribute(attributeName, QLatin1String("inside"));
             break;
+        }
     }
 }
 
@@ -830,17 +902,20 @@ QString SearchXmlWriter::keywordSearch(const QString& keyword)
 QStringList KeywordSearch::split(const QString& keywords)
 {
     // get groups with quotation marks
-    QStringList quotationMarkList = keywords.split(QLatin1Char('"'), QString::KeepEmptyParts);
+
+    QStringList quotationMarkList = keywords.split(QLatin1Char('"'), QT_KEEP_EMPTY_PARTS);
 
     // split down to single words
+
     QStringList keywordList;
     int quotationMarkCount = (keywords.startsWith(QLatin1Char('"')) ? 1 : 0);
 
-    foreach (const QString& group, quotationMarkList)
+    Q_FOREACH (const QString& group, quotationMarkList)
     {
         if (quotationMarkCount % 2)
         {
             // inside marks: leave as is
+
             if (!group.isEmpty())
             {
                 keywordList << group;
@@ -849,7 +924,8 @@ QStringList KeywordSearch::split(const QString& keywords)
         else
         {
             // not in quotation marks: split by whitespace
-            keywordList << group.split(QRegExp(QLatin1String("\\s+")), QString::SkipEmptyParts);
+
+            keywordList << group.split(QRegularExpression(QLatin1String("\\s+")), QT_SKIP_EMPTY_PARTS);
         }
 
         ++quotationMarkCount;
@@ -863,6 +939,7 @@ QString KeywordSearch::merge(const QStringList& keywordList)
     QStringList list(keywordList);
 
     // group keyword with spaces in quotation marks
+
     for (QStringList::iterator it = list.begin() ; it != list.end() ; ++it)
     {
         if ((*it).contains(QLatin1Char(' ')))
@@ -872,6 +949,7 @@ QString KeywordSearch::merge(const QStringList& keywordList)
     }
 
     // join in a string
+
     return list.join(QLatin1Char(' '));
 }
 
@@ -953,6 +1031,7 @@ bool KeywordSearchReader::isSimpleKeywordSearch()
 {
     // Find out if this XML conforms to a simple keyword search,
     // as created with KeywordSearchWriter
+
     SearchXml::Element element;
     int groupCount = 0;
 
@@ -963,6 +1042,7 @@ bool KeywordSearchReader::isSimpleKeywordSearch()
         if (element == SearchXml::Group)
         {
             // only one group please
+
             if (++groupCount > 1)
             {
                 return false;
@@ -1000,12 +1080,14 @@ bool KeywordSearchReader::isSimpleKeywordSearchGroup()
         element = readNext();
 
         // subgroups not allowed
+
         if (element == SearchXml::Group)
         {
             return false;
         }
 
         // only "keyword" fields allowed
+
         if (element == SearchXml::Field)
         {
             if (fieldName() != QLatin1String("keyword"))
@@ -1044,7 +1126,7 @@ QString KeywordSearchWriter::xml(const QStringList& keywordList)
 {
     writeGroup();
 
-    foreach (const QString& keyword, keywordList)
+    Q_FOREACH (const QString& keyword, keywordList)
     {
         writeField(QLatin1String("keyword"), SearchXml::Like);
         writeValue(keyword);
@@ -1072,7 +1154,7 @@ SearchXml::Element SearchXmlCachingReader::readNext()
 {
     SearchXml::Element element = SearchXmlReader::readNext();
 
-    if (element == SearchXml::Group)
+    if      (element == SearchXml::Group)
     {
         m_groupOperator = SearchXmlReader::groupOperator();
         m_groupCaption  = SearchXmlReader::groupCaption();
@@ -1172,10 +1254,11 @@ QList<int> SearchXmlCachingReader::valueToIntList()
 {
     // with no QVariant support for QList<int>,
     // we convert here from string list (equivalent result)
+
     QStringList list = valueToStringList();
     QList<int> intList;
 
-    foreach (const QString& s, list)
+    Q_FOREACH (const QString& s, list)
     {
         double val = s.toDouble();
         intList << (int)val;
@@ -1188,10 +1271,11 @@ QList<qlonglong> SearchXmlCachingReader::valueToLongLongList()
 {
     // with no QVariant support for QList<qlonglong>,
     // we convert here from string list (equivalent result)
+
     QStringList list = valueToStringList();
     QList<qlonglong> qlonglongList;
 
-    foreach (const QString& s, list)
+    Q_FOREACH (const QString& s, list)
     {
         double val = s.toDouble();
         qlonglongList << (qlonglong)val;
@@ -1204,10 +1288,11 @@ QList<double> SearchXmlCachingReader::valueToDoubleList()
 {
     // with no QVariant support for QList<double>,
     // we convert here from string list (equivalent result)
+
     QStringList list = valueToStringList();
     QList<double> doubleList;
 
-    foreach (const QString& s, list)
+    Q_FOREACH (const QString& s, list)
     {
         doubleList << s.toDouble();
     }
@@ -1219,10 +1304,11 @@ QList<QDateTime> SearchXmlCachingReader::valueToDateTimeList()
 {
     // with no QVariant support for QList<QDateTime>,
     // we convert here from string list (equivalent result)
+
     QStringList list = valueToStringList();
     QList<QDateTime> doubleList;
 
-    foreach (const QString& s, list)
+    Q_FOREACH (const QString& s, list)
     {
         doubleList << QDateTime::fromString(s, Qt::ISODate);
     }
@@ -1248,7 +1334,7 @@ QList<int> SearchXmlCachingReader::valueToIntOrIntList()
         QList<int> intList = SearchXmlReader::valueToIntOrIntList();
         QList<QVariant> varList;
 
-        foreach (int v, intList)
+        Q_FOREACH (int v, intList)
         {
             varList << v;
         }
@@ -1262,7 +1348,7 @@ QList<int> SearchXmlCachingReader::valueToIntOrIntList()
     QList<int> intList;
     QList<QVariant> varList = m_value.toList();
 
-    foreach (const QVariant& var, varList)
+    Q_FOREACH (const QVariant& var, varList)
     {
         intList << var.toInt();
     }
@@ -1277,7 +1363,7 @@ QList<double> SearchXmlCachingReader::valueToDoubleOrDoubleList()
         QList<double> doubleList = SearchXmlReader::valueToDoubleOrDoubleList();
         QList<QVariant> varList;
 
-        foreach (double v, doubleList)
+        Q_FOREACH (double v, doubleList)
         {
             varList << v;
         }
@@ -1291,7 +1377,7 @@ QList<double> SearchXmlCachingReader::valueToDoubleOrDoubleList()
     QList<double> doubleList;
     QList<QVariant> varList = m_value.toList();
 
-    foreach (const QVariant& var, varList)
+    Q_FOREACH (const QVariant& var, varList)
     {
         doubleList << var.toDouble();
     }
@@ -1306,20 +1392,21 @@ QList<QString> SearchXmlCachingReader::valueToStringOrStringList()
         QList<QString> QStringList = SearchXmlReader::valueToStringOrStringList();
         QList<QVariant> varList;
 
-        foreach (const QString& v, QStringList)
+        Q_FOREACH (const QString& v, QStringList)
         {
             varList << v;
         }
 
         m_value     = varList;
         m_readValue = true;
+
         return QStringList;
     }
 
     QList<QString> lst;
     QList<QVariant> varList = m_value.toList();
 
-    foreach (const QVariant& var, varList)
+    Q_FOREACH (const QVariant& var, varList)
     {
         lst << var.toString();
     }
