@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
  * SPDX-FileCopyrightText: 2003      by Ricardo Niederberger Cabral <nieder at mail dot ru>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -18,6 +18,13 @@
 
 #include "haariface_p.h"
 
+#define ENABLE_DEBUG_DUPLICATES 0
+#if ENABLE_DEBUG_DUPLICATES
+#   define DEBUG_DUPLICATES(x) qCDebug(DIGIKAM_DATABASE_LOG) << x;
+#else
+#   define DEBUG_DUPLICATES(x)
+#endif
+
 namespace Digikam
 {
 
@@ -751,6 +758,8 @@ QSet<qlonglong> HaarIface::imagesFromAlbumsAndTags(const QList<int>& albums2Scan
 HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>& images2Scan,
                                                           const QSet<qlonglong>::const_iterator& rangeBegin,
                                                           const QSet<qlonglong>::const_iterator& rangeEnd,
+                                                          RefImageSelMethod refImageSelectionMethod,
+                                                          const QSet<qlonglong>& refs,
                                                           double requiredPercentage,
                                                           double maximumPercentage,
                                                           DuplicatesSearchRestrictions searchResultRestriction,
@@ -775,6 +784,18 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
 
     for (images2ScanIterator = rangeBegin ; images2ScanIterator != rangeEnd ; ++images2ScanIterator)
     {
+
+#if ENABLE_DEBUG_DUPLICATES
+
+        {
+            ItemInfo info(*images2ScanIterator);
+            const QString path = info.filePath();
+            const QString name = info.name();
+            DEBUG_DUPLICATES("Iterate image: " << name << "Path: " << path);
+        }
+
+#endif
+
         if (observer && observer->isCanceled())
         {
             break;
@@ -799,33 +820,141 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
 
             if (!(duplicates.isEmpty()) && !((duplicates.count() == 1) && (duplicates.first() == *images2ScanIterator)))
             {
+                DEBUG_DUPLICATES("\tHas duplicates");
+
                 // Use the oldest image date or larger pixel/file size as the reference image.
+                // Or if the image is in the refImage list
 
                 QDateTime refDateTime;
+                QDateTime refModDateTime;
                 quint64   refPixelSize  = 0;
                 qlonglong refFileSize   = 0;
                 qlonglong reference     = *images2ScanIterator;
 
-                Q_FOREACH (const qlonglong& refId, duplicates)
-                {
-                    ItemInfo info(refId);
-                    quint64 infoPixelSize = (quint64)info.dimensions().width() *
-                                            (quint64)info.dimensions().height();
+                const bool useReferenceImages = ((refImageSelectionMethod == RefImageSelMethod::PreferFolder) ||
+                                                 (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder));
 
-                    if (
-                        !refDateTime.isValid()             ||
-                        (infoPixelSize    >  refPixelSize) ||
-                        ((infoPixelSize   == refPixelSize) &&
-                         (info.fileSize() >  refFileSize)) ||
-                        ((infoPixelSize   == refPixelSize) &&
-                         (info.fileSize() == refFileSize)  &&
-                         (info.dateTime() <  refDateTime))
-                       )
+                bool referenceFound = false;
+
+                if (useReferenceImages)
+                {
+                    for (auto it = refs.begin() ; it != refs.end() ; ++it)
                     {
-                        reference    = refId;
-                        refDateTime  = info.dateTime();
-                        refFileSize  = info.fileSize();
-                        refPixelSize = infoPixelSize;
+
+#if ENABLE_DEBUG_DUPLICATES
+
+                        {
+                            ItemInfo info(*it);
+                            const QString path = info.filePath();
+                            const QString name = info.name();
+                            DEBUG_DUPLICATES("\tReference image: " << name << "Path: " << path << ", Id: " << info.id());
+                        }
+
+#endif
+
+                        if (*it == *images2ScanIterator)
+                        {
+                            // image of images2ScanIterator is already in the references present, so take it as the
+                            // reference
+
+                            DEBUG_DUPLICATES("\tReference found!");
+                            referenceFound = true;
+                            break;
+                        }
+                    }
+                }
+
+                if (!useReferenceImages                                                               ||
+                    (!referenceFound && (refImageSelectionMethod == RefImageSelMethod::PreferFolder)) ||
+                    (referenceFound  && (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder)))
+                {
+                    DEBUG_DUPLICATES("\tChecking Duplicates")
+
+                    Q_FOREACH (const qlonglong& refId, duplicates)
+                    {
+
+#if ENABLE_DEBUG_DUPLICATES
+
+                        {
+                            ItemInfo info(refId);
+                            const QString path = info.filePath();
+                            const QString name = info.name();
+                            DEBUG_DUPLICATES("\t\tDuplicates: " << name << "Path: " << path << ", Id: " << info.id());
+                        }
+
+#endif
+
+                        ItemInfo info(refId);
+                        quint64 infoPixelSize = (quint64)info.dimensions().width() *
+                                                (quint64)info.dimensions().height();
+
+                        referenceFound = false;
+
+                        if (useReferenceImages)
+                        {
+                            for (auto it = refs.begin() ; it != refs.end() ; ++it)
+                            {
+
+#if ENABLE_DEBUG_DUPLICATES
+
+                                {
+                                    ItemInfo info(*it);
+                                    const QString path = info.filePath();
+                                    const QString name = info.name();
+                                    DEBUG_DUPLICATES("\t\tReference image: " << name << "Path: " << path << ", Id: " << info.id());
+                                }
+
+#endif
+
+                                if (*it == refId)
+                                {
+                                    DEBUG_DUPLICATES("\t\tReference found!");
+                                    referenceFound = true;
+                                    break;
+                                }
+                            }
+                        }
+
+                        const bool preferFolderCond  = (referenceFound && (refImageSelectionMethod == RefImageSelMethod::PreferFolder));
+
+                        const bool excludeFolderCond = (!referenceFound && (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder));
+
+                        const bool newerCreationCond = ((refImageSelectionMethod == RefImageSelMethod::NewerCreationDate) &&
+                                                        (!refDateTime.isValid() || (info.dateTime() >  refDateTime)));
+
+                        const bool newerModCond      = ((refImageSelectionMethod == RefImageSelMethod::NewerModificationDate) &&
+                                                        (!refModDateTime.isValid() || (info.modDateTime() >  refModDateTime)));
+
+                        const bool olderOrLargerCond = ((refImageSelectionMethod == RefImageSelMethod::OlderOrLarger)          &&
+                                                        (!refDateTime.isValid()                                                ||
+                                                        (infoPixelSize   >  refPixelSize)                                      ||
+                                                        ((infoPixelSize  == refPixelSize) && (info.fileSize() >  refFileSize)) ||
+                                                        ((infoPixelSize  == refPixelSize) && (info.fileSize() == refFileSize)  &&
+                                                        (info.dateTime() <  refDateTime))));
+
+                        if (preferFolderCond || excludeFolderCond || newerCreationCond || newerModCond || olderOrLargerCond)
+                        {
+                            reference      = refId;
+                            refDateTime    = info.dateTime();
+                            refModDateTime = info.modDateTime();
+                            refFileSize    = info.fileSize();
+                            refPixelSize   = infoPixelSize;
+
+#if ENABLE_DEBUG_DUPLICATES
+
+                            {
+                                const QString path = info.filePath();
+                                const QString name = info.name();
+                                DEBUG_DUPLICATES("\t\tUse as eference image: " << name << "Path: " << path << ", Id: " << info.id() << "Pixelsize: " << infoPixelSize << ", File size: " << refFileSize << ", Datetime: " << refDateTime);
+                            }
+
+#endif
+
+                            if (preferFolderCond || excludeFolderCond)
+                            {
+                                break;
+                            }
+                        }
                     }
                 }
 
@@ -850,6 +979,19 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
             observer->imageProcessed();
         }
     }
+#if ENABLE_DEBUG_DUPLICATES
+
+    DEBUG_DUPLICATES("Results:");
+
+    for (auto i = resultsMap.constBegin() ; i != resultsMap.constEnd() ; ++i)
+    {
+        ItemInfo info(i.key());
+        const QString path = info.filePath();
+        const QString name = info.name();
+        DEBUG_DUPLICATES("\t\tReference image: " << name << "Path: " << path << ", Id: " << info.id());
+    }
+
+#endif
 
     return resultsMap;
 }
