@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -77,10 +77,7 @@ QString ItemQueryBuilder::buildQueryFromXml(const QString& xml, QList<QVariant>
         {
             addSqlOperator(sql, reader.groupOperator(), firstGroup);
 
-            if (firstGroup)
-            {
-                firstGroup = false;
-            }
+            firstGroup = false;
 
             buildGroup(sql, reader, boundValues, hooks);
         }
@@ -116,10 +113,7 @@ void ItemQueryBuilder::buildGroup(QString& sql, SearchXmlCachingReader& reader,
             hasContent = true;
             addSqlOperator(sql, reader.groupOperator(), firstField);
 
-            if (firstField)
-            {
-                firstField = false;
-            }
+            firstField = false;
 
             buildGroup(sql, reader, boundValues, hooks);
         }
@@ -130,10 +124,7 @@ void ItemQueryBuilder::buildGroup(QString& sql, SearchXmlCachingReader& reader,
             SearchXml::Operator fieldOperator = reader.fieldOperator();
             addSqlOperator(sql, fieldOperator, firstField);
 
-            if (firstField)
-            {
-                firstField = false;
-            }
+            firstField = false;
 
             if (!buildField(sql, reader, reader.fieldName(), boundValues, hooks))
             {
@@ -163,7 +154,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     }
     else if (name == QLatin1String("albumid"))
     {
-        if ((relation == SearchXml::Equal) || (relation == SearchXml::Unequal))
+        if      ((relation == SearchXml::Equal) || (relation == SearchXml::Unequal))
         {
             fieldQuery.addIntField(QLatin1String("Images.album"));
         }
@@ -394,7 +385,8 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     {
         fieldQuery.addDateField(QLatin1String("Images.modificationDate"));
     }
-    else if (name == QLatin1String("filesize"))
+    else if ((name == QLatin1String("filesize")) ||
+             (name == QLatin1String("bytesize")))
     {
         fieldQuery.addLongField(QLatin1String("Images.fileSize"));
     }
@@ -474,7 +466,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
             int denominator = ratioNum.at(1).toInt();
             query                = QString::fromUtf8("ABS((ImageInformation.width/CAST(ImageInformation.height AS DOUBLE)) - ?)  < 0.1");
             sql                 += QString::fromUtf8(" (") + query + QString::fromUtf8(") ");
-            *boundValues << (double)num/denominator;
+            *boundValues << (double)num / denominator;
         }
         else if (readerString.contains(QRegularExpression(QLatin1String("^\\d+(.\\d+)?$"))))
         {
@@ -526,7 +518,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
                      QStringList ratioNum = value.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
                      int num              = ratioNum.at(0).toInt();
                      int denominator      = ratioNum.at(1).toInt();
-                     ratioValues << (double)num/denominator;
+                     ratioValues << (double)num / denominator;
                  }
             }
 
@@ -553,7 +545,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
                 QStringList ratioNum = value.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
                 int num              = ratioNum.at(0).toInt();
                 int denominator      = ratioNum.at(1).toInt();
-                *boundValues << (double)num/denominator;
+                *boundValues << (double)num / denominator;
             }
 
             sql += QString::fromUtf8("(VideoMetadata.aspectRatio=? OR ABS((CAST(VideoMetadata.aspectRatio AS DOUBLE) - ?)  < 0.1 )) ");
@@ -1048,11 +1040,11 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     }
     else if (name == QLatin1String("imagetagproperty"))
     {
-        if (relation == SearchXml::Equal || relation == SearchXml::InTree)
+        if ((relation == SearchXml::Equal) || (relation == SearchXml::InTree))
         {
             // First, read attributes
             QStringView tagAttribute = reader.attributes().value(QLatin1String("tagid"));
-            int tagId               = 0;
+            int tagId                = 0;
 
             if (!tagAttribute.isEmpty())
             {
@@ -1069,7 +1061,9 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
             }
 
             QString selectQuery;
+
             // %1 is resolved to either "ImageTagProperties." or the empty string
+
             if (tagId)
             {
                 if (relation == SearchXml::Equal)
@@ -1084,7 +1078,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
                 }
             }
 
-            if (values.size() == 1)
+            if      (values.size() == 1)
             {
                 selectQuery += QString::fromUtf8("%1property=? ");
                 *boundValues << values.first();
@@ -1099,6 +1093,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
 
             // This indicates that the ImageTagProperties is joined in the SELECT query,
             // so one entry is listed for each property entry (not for each image id)
+
             if (m_imageTagPropertiesJoined)
             {
                 sql += QString::fromUtf8(" ( ");
@@ -1192,6 +1187,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     else
     {
         qCDebug(DIGIKAM_DATABASE_LOG) << "Search field" << name << "not known by this version of ItemQueryBuilder";
+
         return false;
     }
 
@@ -1213,17 +1209,25 @@ void ItemQueryBuilder::addSqlOperator(QString& sql, SearchXml::Operator op, bool
     switch (op)
     {
         case SearchXml::And:
+        {
             sql += QLatin1String("AND");
             break;
+        }
         case SearchXml::Or:
+        {
             sql += QLatin1String("OR");
             break;
+        }
         case SearchXml::AndNot:
+        {
             sql += QLatin1String("AND NOT");
             break;
+        }
         case SearchXml::OrNot:
+        {
             sql += QLatin1String("OR NOT");
             break;
+        }
     }
 }
 
@@ -1233,48 +1237,71 @@ void ItemQueryBuilder::addSqlRelation(QString& sql, SearchXml::Relation rel)
     {
         default:
         case SearchXml::Equal:
+        {
             sql += QLatin1Char('=');
             break;
+        }
         case SearchXml::Unequal:
+        {
             sql += QLatin1String("<>");
             break;
+        }
         case SearchXml::Like:
+        {
             sql += QLatin1String("LIKE");
             break;
+        }
         case SearchXml::NotLike:
+        {
             sql += QLatin1String("NOT LIKE");
             break;
+        }
         case SearchXml::LessThan:
+        {
             sql += QLatin1Char('<');
             break;
+        }
         case SearchXml::GreaterThan:
+        {
             sql += QLatin1Char('>');
             break;
+        }
         case SearchXml::LessThanOrEqual:
+        {
             sql += QLatin1String("<=");
             break;
+        }
         case SearchXml::GreaterThanOrEqual:
+        {
             sql += QLatin1String(">=");
             break;
+        }
         case SearchXml::OneOf:
+        {
             sql += QLatin1String("IN");
             break;
+        }
     }
 }
 
 void ItemQueryBuilder::addNoEffectContent(QString& sql, SearchXml::Operator op)
 {
     // add a condition statement with no effect
+
     switch (op)
     {
         case SearchXml::And:
         case SearchXml::Or:
+        {
             sql += QLatin1String(" 1 ");
             break;
+        }
         case SearchXml::AndNot:
         case SearchXml::OrNot:
+        {
             sql += QLatin1String(" 0 ");
             break;
+        }
     }
 }
 
@@ -1320,6 +1347,7 @@ QString ItemQueryBuilder::convertFromUrlToXml(const QUrl& url) const
         {
             // other field names did not change:
             // albumname, albumcaption, albumcollection, tagname, keyword, rating
+
             rule.key = key;
         }
 
@@ -1378,6 +1406,7 @@ QString ItemQueryBuilder::convertFromUrlToXml(const QUrl& url) const
     SearchXmlWriter writer;
 
     // set an attribute marking this search as converted from 0.9 style search
+
     writer.writeAttribute(QLatin1String("convertedFrom09Url"), QLatin1String("true"));
     writer.writeGroup();
 
@@ -1406,6 +1435,7 @@ QString ItemQueryBuilder::convertFromUrlToXml(const QUrl& url) const
             else if (expr == QLatin1String("OR"))
             {
                 // open a new group
+
                 writer.finishGroup();
                 writer.writeGroup();
                 writer.setGroupOperator(SearchXml::Or);
@@ -1413,6 +1443,7 @@ QString ItemQueryBuilder::convertFromUrlToXml(const QUrl& url) const
             else if (expr == QLatin1String("("))
             {
                 // open a subgroup
+
                 writer.writeGroup();
             }
             else if (expr == QLatin1String(")"))
@@ -1632,15 +1663,18 @@ QString ItemQueryBuilder::possibleDate(const QString& str, bool& exact) const
     if (ok)
     {
         // ok. its an int, does it look like a year?
+
         if ((1970 <= num) && (num <= QDate::currentDate().year()))
         {
             // very sure its a year
+
             return QString::fromUtf8("%1-%-%").arg(num);
         }
     }
     else
     {
         // hmm... not a year. is it a particular month?
+
         for (int i = 1 ; i <= 12 ; ++i)
         {
             if ((str.toLower() == m_shortMonths[i-1]) ||
