@@ -6,19 +6,10 @@
  * Date        : 2007-09-19
  * Description : Scanning a single item - photo metadata helper.
  *
- * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -30,11 +21,13 @@ namespace Digikam
 QString ItemScanner::iptcCorePropertyName(MetadataInfo::Field field)
 {
     // These strings are specified in DBSCHEMA.ods
+
     switch (field)
     {
-            // copyright table
+        // Copyright table                                     krazy:exclude=copyright
+
         case MetadataInfo::IptcCoreCopyrightNotice:
-            return QLatin1String("copyrightNotice");
+            return QLatin1String("copyrightNotice");        // krazy:exclude=copyright
         case MetadataInfo::IptcCoreCreator:
             return QLatin1String("creator");
         case MetadataInfo::IptcCoreProvider:
@@ -48,7 +41,8 @@ QString ItemScanner::iptcCorePropertyName(MetadataInfo::Field field)
         case MetadataInfo::IptcCoreInstructions:
             return QLatin1String("instructions");
 
-            // ImageProperties table
+        // ImageProperties table
+
         case MetadataInfo::IptcCoreCountryCode:
             return QLatin1String("countryCode");
         case MetadataInfo::IptcCoreCountry:
@@ -115,6 +109,16 @@ QString ItemScanner::detectImageFormat() const
         case DImg::NONE:
         case DImg::QIMAGE:
         {
+            QString ext = d->fileInfo.suffix().toUpper();
+
+            if (
+                (ext == QLatin1String("AVIF")) ||       // See bug #109060
+                (ext == QLatin1String("JPX"))
+               )
+            {
+                return ext;
+            }
+
             QByteArray format = QImageReader::imageFormat(d->fileInfo.filePath());
 
             if (!format.isEmpty())
@@ -127,6 +131,7 @@ QString ItemScanner::detectImageFormat() const
     }
 
     // See BUG #339341: Take file name suffix instead type mime analyze.
+
     return d->fileInfo.suffix().toUpper();
 }
 
@@ -149,6 +154,7 @@ void ItemScanner::commitImageMetadata()
 void ItemScanner::scanItemPosition()
 {
     // This list must reflect the order required by CoreDB::addItemPosition
+
     MetadataFields fields;
     fields << MetadataInfo::Latitude
            << MetadataInfo::LatitudeNumber
@@ -178,33 +184,32 @@ void ItemScanner::commitItemPosition()
 void ItemScanner::scanItemComments()
 {
     MetadataFields fields;
-    fields << MetadataInfo::Headline
-           << MetadataInfo::Title;
+    fields << MetadataInfo::Headline;
 
     QVariantList metadataInfos = d->metadata->getMetadataFields(fields);
 
     // handles all possible fields, multi-language, author, date
-    CaptionsMap captions = d->metadata->getItemComments();
 
-    if (captions.isEmpty() && !hasValidField(metadataInfos))
+    CaptionsMap captions = d->metadata->getItemComments();
+    CaptionsMap titles   = d->metadata->getItemTitles();
+
+    if (titles.isEmpty()            &&
+        captions.isEmpty()          &&
+        !hasValidField(metadataInfos))
     {
         return;
     }
 
     d->commit.commitItemComments = true;
     d->commit.captions           = captions;
+    d->commit.titles             = titles;
 
     // Headline
+
     if (!metadataInfos.at(0).isNull())
     {
         d->commit.headline = metadataInfos.at(0).toString();
     }
-
-    // Title
-    if (!metadataInfos.at(1).isNull())
-    {
-        d->commit.title = metadataInfos.at(1).toMap()[QLatin1String("x-default")].toString();
-    }
 }
 
 void ItemScanner::commitItemComments()
@@ -213,21 +218,36 @@ void ItemScanner::commitItemComments()
     ItemComments comments(access, d->scanInfo.id);
 
     // Description
+
     if (!d->commit.captions.isEmpty())
     {
-        comments.replaceComments(d->commit.captions);
+        CaptionsMap::const_iterator it;
+
+        for (it = d->commit.captions.constBegin() ; it != d->commit.captions.constEnd() ; ++it)
+        {
+            CaptionValues val = it.value();
+            comments.addComment(val.caption, it.key(), val.author, val.date);
+        }
     }
 
     // Headline
+
     if (!d->commit.headline.isNull())
     {
         comments.addHeadline(d->commit.headline);
     }
 
     // Title
-    if (!d->commit.title.isNull())
+
+    if (!d->commit.titles.isEmpty())
     {
-        comments.addTitle(d->commit.title);
+        CaptionsMap::const_iterator it;
+
+        for (it = d->commit.titles.constBegin() ; it != d->commit.titles.constEnd() ; ++it)
+        {
+            CaptionValues val = it.value();
+            comments.addTitle(val.caption, it.key(), val.author, val.date);
+        }
     }
 }
 
@@ -247,7 +267,9 @@ void ItemScanner::scanItemCopyright()
 void ItemScanner::commitItemCopyright()
 {
     ItemCopyright copyright(d->scanInfo.id);
+
     // It is not clear if removeAll() should be called if d->scanMode == Rescan
+
     copyright.removeAll();
     copyright.setFromTemplate(d->commit.copyrightTemplate);
 }
@@ -316,6 +338,7 @@ void ItemScanner::scanTags()
     QStringList filteredKeywords;
 
     // Extra empty tags check, empty tag = root tag which is not asignable
+
     for (int index = 0 ; index < keywords.size() ; ++index)
     {
         QString keyword = keywords.at(index);
@@ -325,9 +348,10 @@ void ItemScanner::scanTags()
 
             // _Digikam_root_tag_ is present in some photos tagged with older
             // version of digiKam, must be removed
-            if (keyword.contains(QRegExp(QLatin1String("(_Digikam_root_tag_/|/_Digikam_root_tag_|_Digikam_root_tag_)"))))
+
+            if (keyword.contains(QRegularExpression(QLatin1String("(_Digikam_root_tag_/|/_Digikam_root_tag_|_Digikam_root_tag_)"))))
             {
-                keyword = keyword.replace(QRegExp(QLatin1String("(_Digikam_root_tag_/|/_Digikam_root_tag_|_Digikam_root_tag_)")),
+                keyword = keyword.replace(QRegularExpression(QLatin1String("(_Digikam_root_tag_/|/_Digikam_root_tag_|_Digikam_root_tag_)")),
                                           QLatin1String(""));
             }
 
@@ -338,6 +362,7 @@ void ItemScanner::scanTags()
     if (!filteredKeywords.isEmpty())
     {
         // get tag ids, create if necessary
+
         QList<int> tagIds = TagsCache::instance()->getOrCreateTags(filteredKeywords);
         d->commit.tagIds += tagIds;
     }
@@ -389,18 +414,21 @@ void ItemScanner::scanTags()
 
 void ItemScanner::commitTags()
 {
-    QList<int> currentTags = CoreDbAccess().db()->getItemTagIDs(d->scanInfo.id);
-    QVector<int> colorTags = TagsCache::instance()->colorLabelTags();
-    QVector<int> pickTags  = TagsCache::instance()->pickLabelTags();
+    const QList<int>& currentTags = CoreDbAccess().db()->getItemTagIDs(d->scanInfo.id);
+    const QVector<int>& colorTags = TagsCache::instance()->colorLabelTags();
+    const QVector<int>& pickTags  = TagsCache::instance()->pickLabelTags();
     QList<int> removeTags;
 
-    foreach (int cTag, currentTags)
+    if (d->commit.hasColorTag || d->commit.hasPickTag)
     {
-        if ((d->commit.hasColorTag && colorTags.contains(cTag)) ||
-            (d->commit.hasPickTag && pickTags.contains(cTag)))
+        Q_FOREACH (int tag, currentTags)
         {
-            removeTags << cTag;
+            if (colorTags.contains(tag) || pickTags.contains(tag))
+            {
+                removeTags << tag;
+            }
         }
+
     }
 
     if (!removeTags.isEmpty())
@@ -435,15 +463,10 @@ void ItemScanner::commitFaces()
 {
     FaceTagsEditor editor;
     QList<QRect> assignedRects;
-    QList<QRect> databaseRects;
     QMultiMap<QString, QVariant>::const_iterator it;
     QSize size                         = d->img.size();
     int orientation                    = d->img.orientation();
-
-    foreach (const FaceTagsIface& face, editor.databaseFaces(d->scanInfo.id))
-    {
-        databaseRects << face.region().toRect();
-    }
+    QList<FaceTagsIface> databaseFaces = editor.databaseFaces(d->scanInfo.id);
 
     for (it = d->commit.metadataFacesMap.constBegin() ; it != d->commit.metadataFacesMap.constEnd() ; ++it)
     {
@@ -468,48 +491,37 @@ void ItemScanner::commitFaces()
 
         QRect rect = TagRegion::relativeToAbsolute(rectF, size);
         TagRegion::adjustToOrientation(rect, orientation, size);
+        TagRegion newRegion(rect);
 
         if (assignedRects.contains(rect))
         {
             continue;
         }
 
-        QList<QRect>::iterator it1;
+        assignedRects << rect;
+        QList<FaceTagsIface>::iterator it1;
 
-        for (it1 = databaseRects.begin() ; it1 != databaseRects.end() ; )
+        for (it1 = databaseFaces.begin() ; it1 != databaseFaces.end() ; )
         {
-            // Is the face rectangle located
-            // inside or outside completely?
+             double minOverlap = (*it1).isConfirmedName() ? 0.25 : 0.5;
 
-            if ((*it1).contains(rect) ||
-                rect.contains((*it1)))
+            if ((*it1).region().intersects(newRegion, minOverlap))
             {
-                QPoint point = (*it1).center() - rect.center();
-                int smax     = qMax(size.width(), size.height());
+                // Remove the duplicate face in the database.
 
-                // Check the percentage deviation from the center.
+                editor.removeFace((*it1));
+                it1 = databaseFaces.erase(it1);
 
-                if ((point.manhattanLength() * 100 / smax) <= 5)
-                {
-                    // Remove the duplicate face in the database.
-
-                    editor.removeFace(d->scanInfo.id, (*it1));
-                    it1 = databaseRects.erase(it1);
-
-                    continue;
-                }
+                continue;
             }
 
             ++it1;
         }
 
-        TagRegion region(rect);
-        assignedRects << rect;
-
         if (name.isEmpty())
         {
             int tagId = FaceTags::unknownPersonTagId();
-            FaceTagsIface face(FaceTagsIface::UnknownName, d->scanInfo.id, tagId, region);
+            FaceTagsIface face(FaceTagsIface::UnknownName, d->scanInfo.id, tagId, newRegion);
 
             editor.addManually(face);
         }
@@ -519,7 +531,7 @@ void ItemScanner::commitFaces()
 
             if (tagId)
             {
-                editor.add(d->scanInfo.id, tagId, region, false);
+                editor.add(d->scanInfo.id, tagId, newRegion, false);
             }
             else
             {
@@ -532,6 +544,7 @@ void ItemScanner::commitFaces()
 void ItemScanner::checkCreationDateFromMetadata(QVariant& dateFromMetadata) const
 {
     // creation date: fall back to file system property
+
     if (dateFromMetadata.isNull() || !dateFromMetadata.toDateTime().isValid())
     {
         dateFromMetadata = creationDateFromFilesystem(d->fileInfo);
@@ -541,7 +554,8 @@ void ItemScanner::checkCreationDateFromMetadata(QVariant& dateFromMetadata) cons
 bool ItemScanner::checkRatingFromMetadata(const QVariant& ratingFromMetadata) const
 {
     // should only be overwritten if set in metadata
-    if (d->scanMode == Rescan)
+
+    if ((d->scanMode == Rescan) || (d->scanMode == CleanScan))
     {
         if (ratingFromMetadata.isNull() || (ratingFromMetadata.toInt() == -1))
         {
@@ -555,6 +569,7 @@ bool ItemScanner::checkRatingFromMetadata(const QVariant& ratingFromMetadata) co
 MetadataFields ItemScanner::allImageMetadataFields()
 {
     // This list must reflect the order required by CoreDB::addImageMetadata
+
     MetadataFields fields;
     fields << MetadataInfo::Make
            << MetadataInfo::Model
