@@ -6,19 +6,10 @@
  * Date        : 2010-04-02
  * Description : Cache for Tag information
  *
- * Copyright (C) 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -30,7 +21,9 @@
 #include <QReadWriteLock>
 #include <QReadLocker>
 #include <QWriteLocker>
+#include <QStringList>
 #include <QMap>
+#include <QRegularExpression>
 
 // Local includes
 
@@ -65,24 +58,18 @@ class Q_DECL_HIDDEN TagsCache::Private
 public:
 
     explicit Private(TagsCache* const q)
-      : initialized(false),
-        needUpdateInfos(true),
-        needUpdateHash(true),
-        needUpdateProperties(true),
-        needUpdateLabelTags(true),
-        changingDB(false),
-        q(q)
+        : q(q)
     {
     }
 
 public:
 
-    volatile bool               initialized;
-    volatile bool               needUpdateInfos;
-    volatile bool               needUpdateHash;
-    volatile bool               needUpdateProperties;
-    volatile bool               needUpdateLabelTags;
-    volatile bool               changingDB;
+    volatile bool               initialized             = false;
+    volatile bool               needUpdateInfos         = true;
+    volatile bool               needUpdateHash          = true;
+    volatile bool               needUpdateProperties    = true;
+    volatile bool               needUpdateLabelTags     = true;
+    volatile bool               changingDB              = false;
 
     QReadWriteLock              lock;
     QList<TagShortInfo>         infos;
@@ -94,7 +81,7 @@ public:
     QVector<int>                colorLabelsTags; ///< index = Label enum, value = tagId
     QVector<int>                pickLabelsTags;
 
-    TagsCache* const            q;
+    TagsCache* const            q                       = nullptr;
 
 public:
 
@@ -118,7 +105,7 @@ public:
             QWriteLocker locker(&lock);
             nameHash.clear();
 
-            foreach (const TagShortInfo& info, infos)
+            Q_FOREACH (const TagShortInfo& info, infos)
             {
                 nameHash.insert(info.name, info.id);
             }
@@ -143,7 +130,7 @@ public:
 
             QLatin1String internalProp = TagsCache::propertyNameDigikamInternalTag();
 
-            foreach (const TagProperty& property, tagProperties)
+            Q_FOREACH (const TagProperty& property, tagProperties)
             {
                 if (property.property == internalProp)
                 {
@@ -430,7 +417,7 @@ QStringList TagsCache::tagNames(const QList<int>& ids, HiddenTagsPolicy hiddenTa
 
     if (!ids.isEmpty())
     {
-        foreach (int id, ids)
+        Q_FOREACH (int id, ids)
         {
             if ((hiddenTagsPolicy == IncludeHiddenTags) || !isInternalTag(id))
             {
@@ -445,9 +432,36 @@ QStringList TagsCache::tagNames(const QList<int>& ids, HiddenTagsPolicy hiddenTa
 QString TagsCache::tagPath(int id, LeadingSlashPolicy slashPolicy) const
 {
     d->checkInfos();
-    QReadLocker locker(&d->lock);
 
-    return d->tagPath(id, slashPolicy);
+    QString path;
+    QReadLocker locker(&d->lock);
+    QList<TagShortInfo>::const_iterator it;
+
+    for (it = d->find(id) ; it != d->infos.constEnd() ; it = d->find(it->pid))
+    {
+        if (path.isNull())
+        {
+            path = it->name;
+        }
+        else
+        {
+            if ((it->name).contains(QRegularExpression(QLatin1String("(_Digikam_root_tag_/|/_Digikam_root_tag_|_Digikam_root_tag_)"))))
+            {
+                continue;
+            }
+            else
+            {
+                path = it->name + QLatin1Char('/') + path;
+            }
+        }
+    }
+
+    if (slashPolicy == IncludeLeadingSlash)
+    {
+        path.prepend(QLatin1Char('/'));
+    }
+
+    return path;
 }
 
 QStringList TagsCache::tagPaths(const QList<int>& ids, LeadingSlashPolicy slashPolicy,
@@ -457,7 +471,7 @@ QStringList TagsCache::tagPaths(const QList<int>& ids, LeadingSlashPolicy slashP
 
     if (!ids.isEmpty())
     {
-        foreach (int id, ids)
+        Q_FOREACH (int id, ids)
         {
             if ((hiddenTagsPolicy == IncludeHiddenTags) || !isInternalTag(id))
             {
@@ -503,7 +517,7 @@ int TagsCache::tagForName(const QString& tagName, int parentId) const
 
     QList<TagShortInfo>::const_iterator tag;
 
-    foreach (int id, d->nameHash.values(tagName))
+    Q_FOREACH (int id, d->nameHash.values(tagName))
     {
         tag = d->find(id);
 
@@ -551,14 +565,10 @@ QList<int> TagsCache::parentTags(int id) const
     QReadLocker locker(&d->lock);
     QList<TagShortInfo>::const_iterator it;
 
-    for (it = d->find(id);
-         (it != d->infos.constEnd()) && it->pid;
+    for (it = d->find(id) ; (it != d->infos.constEnd()) && (it->pid != 0) ;
          it = d->find(it->pid))
     {
-        if ((it->pid) != 0)
-        {
-            ids.prepend(it->pid);
-        }
+        ids.prepend(it->pid);
     }
 
     return ids;
@@ -575,7 +585,7 @@ int TagsCache::tagForPath(const QString& path) const
 
     // split the path into its components
 
-    QStringList tagHierarchy = path.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    QStringList tagHierarchy = path.split(QLatin1Char('/'), QT_SKIP_EMPTY_PARTS);
 
     if (tagHierarchy.isEmpty())
     {
@@ -589,10 +599,11 @@ int TagsCache::tagForPath(const QString& path) const
     // to lookup all the tag ids with that name, then find the one
     // with a matching full path
 
-    int tagID       = 0;
-    QString tagName = tagHierarchy.last();
+    int tagID                       = 0;
+    QString tagName                 = tagHierarchy.last();
+    const QList<int> possibleTagIds = d->nameHash.values(tagName);
 
-    for (int const id : d->nameHash.values(tagName))
+    for (int const id : possibleTagIds)
     {
         if (d->tagPath(id, NoLeadingSlash) == fullPath)
         {
@@ -601,6 +612,17 @@ int TagsCache::tagForPath(const QString& path) const
         }
     }
 
+    // We only have one entry in tagHierarchy (no path),
+    // if only a tag exists, we can assign it to this.
+    // Otherwise we recreate it in the root.
+
+    if ((tagID == 0)               &&
+        (tagHierarchy.size() == 1) &&
+        (possibleTagIds.size() == 1))
+    {
+        tagID = possibleTagIds.first();
+    }
+
     return tagID;
 }
 
@@ -610,7 +632,7 @@ QList<int> TagsCache::tagsForPaths(const QStringList& tagPaths) const
 
     if (!tagPaths.isEmpty())
     {
-        foreach (const QString& path, tagPaths)
+        Q_FOREACH (const QString& path, tagPaths)
         {
             ids << tagForPath(path);
         }
@@ -623,7 +645,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
 {
     // split full tag "url" into list of single tag names
 
-    QStringList tagHierarchy = tagPathToCreate.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    QStringList tagHierarchy = tagPathToCreate.split(QLatin1Char('/'), QT_SKIP_EMPTY_PARTS);
 
     if (tagHierarchy.isEmpty())
     {
@@ -643,7 +665,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
 
         // Traverse hierarchy from top to bottom
 
-        foreach (const QString& tagName, tagHierarchy)
+        Q_FOREACH (const QString& tagName, tagHierarchy)
         {
             tagID = 0;
 
@@ -657,7 +679,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
                 // and parent ID identical to the ID of the tag we found in
                 // the previous run.
 
-                foreach (int id, d->nameHash.values(tagName))
+                Q_FOREACH (int id, d->nameHash.values(tagName))
                 {
                     tag = d->find(id);
 
@@ -696,7 +718,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
     {
         CoreDbAccess access;
 
-        foreach (const QString& tagName, tagsToCreate)
+        Q_FOREACH (const QString& tagName, tagsToCreate)
         {
             tagID = access.db()->addTag(parentTagIDForCreation, tagName, QString(), 0);
 
@@ -727,7 +749,7 @@ QList<int> TagsCache::createTags(const QStringList& tagPaths)
 
     if (!tagPaths.isEmpty())
     {
-        foreach (const QString& path, tagPaths)
+        Q_FOREACH (const QString& path, tagPaths)
         {
             ids << createTag(path);
         }
@@ -742,7 +764,7 @@ QList<int> TagsCache::getOrCreateTags(const QStringList& tagPaths)
 
     if (!tagPaths.isEmpty())
     {
-        foreach (const QString& path, tagPaths)
+        Q_FOREACH (const QString& path, tagPaths)
         {
             ids << getOrCreateTag(path);
         }
@@ -970,7 +992,7 @@ bool TagsCache::containsPublicTags(const QList<int>& tagIds) const
     d->checkProperties();
     QReadLocker locker(&d->lock);
 
-    foreach (int id, tagIds)
+    Q_FOREACH (int id, tagIds)
     {
         if (!d->internalTags.contains(id))
         {
@@ -1014,7 +1036,8 @@ void TagsCache::slotTagChanged(const TagChangeset& changeset)
     if (changeset.operation() == TagChangeset::Deleted)
     {
         QString name = this->tagName(changeset.tagId());
-        emit tagAboutToBeDeleted(name);
+
+        Q_EMIT tagAboutToBeDeleted(name);
     }
 
     if (!d->changingDB && (changeset.operation() != TagChangeset::IconChanged))
@@ -1024,11 +1047,11 @@ void TagsCache::slotTagChanged(const TagChangeset& changeset)
 
     if      (changeset.operation() == TagChangeset::Added)
     {
-        emit tagAdded(changeset.tagId());
+        Q_EMIT tagAdded(changeset.tagId());
     }
     else if (changeset.operation() == TagChangeset::Deleted)
     {
-        emit tagDeleted(changeset.tagId());
+        Q_EMIT tagDeleted(changeset.tagId());
     }
 }
 
@@ -1061,12 +1084,12 @@ int TagsCache::colorLabelForTag(int tagId)
     return d->colorLabelsTags.indexOf(tagId);
 }
 
-int TagsCache::colorLabelFromTags(QList<int> tagIds)
+int TagsCache::colorLabelFromTags(const QList<int>& tagIds)
 {
     d->checkLabelTags();
     QReadLocker locker(&d->lock);
 
-    foreach (int tagId, tagIds)
+    Q_FOREACH (int tagId, tagIds)
     {
         for (int i = FirstColorLabel ; i <= LastColorLabel ; ++i)
         {
@@ -1109,12 +1132,12 @@ int TagsCache::pickLabelForTag(int tagId)
     return d->pickLabelsTags.indexOf(tagId);
 }
 
-int TagsCache::pickLabelFromTags(QList<int> tagIds)
+int TagsCache::pickLabelFromTags(const QList<int>& tagIds)
 {
     d->checkLabelTags();
     QReadLocker locker(&d->lock);
 
-    foreach (int tagId, tagIds)
+    Q_FOREACH (int tagId, tagIds)
     {
         for (int i = FirstPickLabel ; i <= LastPickLabel ; ++i)
         {
@@ -1138,7 +1161,7 @@ QStringList TagsCache::shortenedTagPaths(const QList<int>& ids,
 
     // duplicates tagPath(), but we need the additional list of tag ids
 
-    foreach (int id, ids)
+    Q_FOREACH (int id, ids)
     {
         if ((hiddenTagsPolicy == IncludeHiddenTags) || !isInternalTag(id))
         {
@@ -1151,7 +1174,7 @@ QStringList TagsCache::shortenedTagPaths(const QList<int>& ids,
 
     QStringList shortenedPaths = ItemPropertiesTab::shortenedTagPaths(paths, &variantIds);
 
-    foreach (const QVariant& var, variantIds)
+    Q_FOREACH (const QVariant& var, variantIds)
     {
         (*sortedIds) << var.toInt();
     }
@@ -1179,3 +1202,5 @@ QList<int> TagsCache::tagsContaining(const QString& fragment, Qt::CaseSensitivit
 }
 
 } // namespace Digikam
+
+#include "moc_tagscache.cpp"
