@@ -6,7 +6,7 @@
  * Date        : 2017-05-06
  * Description : interface to database information for shared tools.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  * SPDX-FileCopyrightText: 2017      by Mario Frank <mario dot frank at uni minus potsdam dot de>
  *
@@ -24,7 +24,6 @@
 // Local includes
 
 #include "albumselecttabs.h"
-#include "applicationsettings.h"
 #include "album.h"
 #include "albummodel.h"
 #include "albummanager.h"
@@ -55,7 +54,7 @@
 #include "tagsactionmngr.h"
 #include "setup.h"
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 #   include "itemgps.h"
 #endif
 
@@ -66,32 +65,24 @@ class Q_DECL_HIDDEN DBInfoIface::Private
 {
 public:
 
-    explicit Private()
-      : albumManager    (AlbumManager::instance()),
-        albumsChooser   (nullptr),
-        albumSelector   (nullptr),
-        operationType   (ApplicationSettings::Unspecified),
-        withGroupedIsSet(false),
-        withGrouped     (false)
-    {
-    }
+    Private() = default;
 
-    AlbumManager*                      albumManager;
-    AlbumSelectTabs*                   albumsChooser;
-    AlbumSelectWidget*                 albumSelector;
+    AlbumManager*                      albumManager     = AlbumManager::instance();
+    AlbumSelectTabs*                   albumsChooser    = nullptr;
+    AlbumSelectWidget*                 albumSelector    = nullptr;
 
     QList<QUrl>                        itemUrls;
 
-    ApplicationSettings::OperationType operationType;
-    bool                               withGroupedIsSet;
-    bool                               withGrouped;
+    ApplicationSettings::OperationType operationType    = ApplicationSettings::Unspecified;
+    bool                               withGroupedIsSet = false;
+    bool                               withGrouped      = false;
 
 public:
 
     /**
      * get the images from the Physical album in database and return the items found.
      */
-    QList<QUrl> imagesFromPAlbum(PAlbum* const album) const
+    QList<QUrl> imagesFromPAlbum(const PAlbum* const album) const
     {
         // get the images from the database and return the items found
 
@@ -145,7 +136,7 @@ public:
     /**
      * get the images from the Tags album in database and return the items found.
      */
-    QList<QUrl> imagesFromTAlbum(TAlbum* const album) const
+    QList<QUrl> imagesFromTAlbum(const TAlbum* const album) const
     {
         QStringList list = CoreDbAccess().db()->getItemURLsInTag(album->id());
         QList<QUrl> urlList;
@@ -165,7 +156,7 @@ public:
     /**
      * get the images from the search album in database and return the items found.
      */
-    QList<QUrl> imagesFromSAlbum(SAlbum* const album) const
+    QList<QUrl> imagesFromSAlbum(const SAlbum* const album) const
     {
         QList<QUrl> urlList;
         CoreDbNameFilter nameFilter(ApplicationSettings::instance()->getAllFileFilter());
@@ -804,7 +795,7 @@ QAbstractItemModel* DBInfoIface::tagFilterModel()
     return filterModel;
 }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
 QList<GPSItemContainer*> DBInfoIface::currentGPSItems() const
 {
@@ -872,3 +863,5 @@ void DBInfoIface::openSetupPage(SetupPage page)
 }
 
 } // namespace Digikam
+
+#include "moc_dbinfoiface.cpp"
