@@ -22,6 +22,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QMessageBox>
+#include <QMutexLocker>
 #include <QApplication>
 #include <QAbstractButton>
 
@@ -35,7 +36,6 @@
 #include "iteminfo.h"
 #include "diofinders.h"
 #include "albummanager.h"
-#include "tagscache.h"
 #include "coredb.h"
 #include "coredbaccess.h"
 #include "coredbtransaction.h"
@@ -43,6 +43,7 @@
 #include "dmetadata.h"
 #include "metaenginesettings.h"
 #include "scancontroller.h"
+#include "itemscanner.h"
 #include "thumbsdb.h"
 #include "thumbsdbaccess.h"
 #include "iojobsmanager.h"
@@ -75,6 +76,8 @@ DIO* DIO::instance()
 
 DIO::DIO()
 {
+    qRegisterMetaType<QMap<QString,int>>("QMap<QString,int>");
+
     m_processingCount = 0;
 }
 
@@ -224,6 +227,18 @@ void DIO::del(PAlbum* const album, bool useTrash)
                                                  : IOJobData::Delete, album));
 }
 
+// Get Trash Counter --------------------------------------------------
+
+int DIO::getTrashCounter(const QString& albumRootPath)
+{
+    QUrl url = QUrl::fromLocalFile(albumRootPath);
+    url      = url.adjusted(QUrl::StripTrailingSlash);
+
+    QMutexLocker locker(&instance()->m_trashCounterMutex);
+
+    return instance()->m_trashCounterMap.value(url.toLocalFile(), 0);
+}
+
 // Restore Trash ------------------------------------------------------
 
 void DIO::restoreTrash(const DTrashItemInfoList& infos)
@@ -238,6 +253,16 @@ void DIO::emptyTrash(const DTrashItemInfoList& infos)
     instance()->createJob(new IOJobData(IOJobData::Empty, infos));
 }
 
+// Build Trash Counters -----------------------------------------------
+
+void DIO::buildCollectionTrashCounters()
+{
+    IOJobsThread* const jobThread = IOJobsManager::instance()->buildCollectionTrashCounters();
+
+    connect(jobThread, SIGNAL(signalTrashCountersMap(QMap<QString,int>)),
+            instance(), SLOT(slotTrashCounterMap(QMap<QString,int>)));
+}
+
 // ------------------------------------------------------------------------------------------------
 
 void DIO::processJob(IOJobData* const data)
@@ -252,13 +277,6 @@ void DIO::processJob(IOJobData* const data)
         GroupedImagesFinder finder(data->itemInfos());
         data->setItemInfos(finder.infos);
     }
-    else if (operation == IOJobData::CopyAlbum)
-    {
-        ScanController::instance()->hintAtMoveOrCopyOfAlbum(data->srcAlbum(), data->destAlbum());
-        createJob(data);
-
-        return;
-    }
     else if ((operation == IOJobData::Trash) ||
              (operation == IOJobData::Delete))
     {
@@ -267,8 +285,7 @@ void DIO::processJob(IOJobData* const data)
 
         qCDebug(DIGIKAM_DATABASE_LOG) << "Number of files to be deleted:" << data->sourceUrls().count();
     }
-
-    if (operation == IOJobData::Rename)
+    else if (operation == IOJobData::Rename)
     {
         SidecarFinder finder(data->sourceUrls());
         data->setSourceUrls(finder.localFiles);
@@ -458,6 +475,23 @@ void DIO::slotResult()
                 updateAlbumDate(albumID);
             }
         }
+
+        if (data->errorOrCancel())
+        {
+            if ((operation == IOJobData::CopyAlbum) ||
+                (operation == IOJobData::MoveAlbum))
+            {
+                QString scanPath = data->destUrl().adjusted(QUrl::StripTrailingSlash).toLocalFile();
+                ScanController::instance()->scheduleCollectionScanRelaxed(scanPath);
+            }
+        }
+
+        if ((operation == IOJobData::Trash) ||
+            (operation == IOJobData::Empty) ||
+            (operation == IOJobData::Restore))
+        {
+            buildCollectionTrashCounters();
+        }
     }
 
     if (m_processingCount)
@@ -555,8 +589,44 @@ void DIO::slotOneProccessed(const QUrl& url)
 
         case IOJobData::CopyAlbum:
         {
-            QString scanPath = data->destUrl().adjusted(QUrl::StripTrailingSlash).toLocalFile();
-            ScanController::instance()->scheduleCollectionScanRelaxed(scanPath);
+            if (data->srcAlbum() && data->destAlbum())
+            {
+                CoreDbAccess access;
+                QList<int> albumsToCopy;
+                QString newName  = data->destName(url);
+                QString basePath = data->srcAlbum()->albumPath();
+                QString destPath = data->destAlbum()->albumPath();
+
+                if (!destPath.endsWith(QLatin1Char('/')))
+                {
+                    destPath.append(QLatin1Char('/'));
+                }
+
+                addAlbumChildrenToList(albumsToCopy, data->srcAlbum());
+
+                Q_FOREACH (int albumId, albumsToCopy)
+                {
+                    QString relativePath = access.db()->getAlbumRelativePath(albumId);
+                    relativePath         = relativePath.section(basePath, 1, -1);
+                    relativePath         = destPath + newName + relativePath;
+
+                    int copyId = access.db()->addAlbum(data->srcAlbum()->albumRootId(),
+                                                       relativePath, QString(), QDate(), QString());
+                    access.db()->copyAlbumProperties(albumId, copyId);
+                    const QList<qlonglong>& imageIds = access.db()->getItemIDsInAlbum(albumId);
+
+                    Q_FOREACH (const qlonglong& id, imageIds)
+                    {
+                        QString name     = access.db()->getItemName(id);
+                        qlonglong itemId = access.db()->copyItem(albumId, name, copyId, name);
+
+                        // Remove grouping for copied items.
+
+                        access.db()->removeAllImageRelationsFrom(itemId, DatabaseRelation::Grouped);
+                        access.db()->removeAllImageRelationsTo(itemId, DatabaseRelation::Grouped);
+                    }
+                }
+            }
 
             break;
         }
@@ -596,12 +666,7 @@ void DIO::slotOneProccessed(const QUrl& url)
             // Mark the images as obsolete and remove them
             // from their album and from the grouped
 
-            int originalVersionTag = TagsCache::instance()->
-                getOrCreateInternalTag(InternalTagName::originalVersion());
-            int needTaggingTag     = TagsCache::instance()->
-                getOrCreateInternalTag(InternalTagName::needTaggingHistoryGraph());
-
-            PAlbum* const album    = data->srcAlbum();
+            PAlbum* const album = data->srcAlbum();
 
             if (album)
             {
@@ -622,26 +687,35 @@ void DIO::slotOneProccessed(const QUrl& url)
 
                 Q_FOREACH (const qlonglong& removeId, imagesToRemove)
                 {
-                    const QList<qlonglong>& imageIds = access.db()->
-                          getImagesRelatedFrom(removeId, DatabaseRelation::DerivedFrom);
+                    ItemInfo info(removeId);
 
-                    Q_FOREACH (const qlonglong& id, imageIds)
+                    if (info.isNull())
                     {
-                        access.db()->removeItemTag(id, originalVersionTag);
-                        access.db()->addItemTag(id, needTaggingTag);
+                        continue;
                     }
 
-                    access.db()->removeAllImageRelationsFrom(removeId,
-                                                             DatabaseRelation::Grouped);
-                }
+                    const QList<qlonglong>& imageIdsFrom = access.db()->
+                          getImagesRelatedFrom(info.id(), DatabaseRelation::DerivedFrom);
 
-                if (operation == IOJobData::Trash)
-                {
-                    access.db()->removeItems(imagesToRemove, albumsToDelete);
-                }
-                else
-                {
-                    access.db()->removeItemsPermanently(imagesToRemove, albumsToDelete);
+                    access.db()->removeAllImageRelationsFrom(info.id(),
+                                                             DatabaseRelation::Grouped);
+
+                    if (operation == IOJobData::Trash)
+                    {
+                        access.db()->removeItems(QList<qlonglong>() << info.id(),
+                                                 QList<int>() << info.albumId());
+                    }
+                    else
+                    {
+                        access.db()->removeItemsPermanently(QList<qlonglong>() << info.id(),
+                                                            QList<int>() << info.albumId());
+                    }
+
+                    Q_FOREACH (const qlonglong& id, imageIdsFrom)
+                    {
+                        ItemScanner::resolveImageHistory(id);
+                        ItemScanner::tagItemHistoryGraph(id);
+                    }
                 }
 
                 Q_FOREACH (int albumId, albumsToDelete)
@@ -663,14 +737,9 @@ void DIO::slotOneProccessed(const QUrl& url)
                 if (!info.isNull())
                 {
                     CoreDbAccess access;
-                    const QList<qlonglong>& imageIds = access.db()->
-                          getImagesRelatedFrom(info.id(), DatabaseRelation::DerivedFrom);
 
-                    Q_FOREACH (const qlonglong& id, imageIds)
-                    {
-                        access.db()->removeItemTag(id, originalVersionTag);
-                        access.db()->addItemTag(id, needTaggingTag);
-                    }
+                    const QList<qlonglong>& imageIdsFrom = access.db()->
+                          getImagesRelatedFrom(info.id(), DatabaseRelation::DerivedFrom);
 
                     access.db()->removeAllImageRelationsFrom(info.id(),
                                                              DatabaseRelation::Grouped);
@@ -685,6 +754,12 @@ void DIO::slotOneProccessed(const QUrl& url)
                         access.db()->removeItemsPermanently(QList<qlonglong>() << info.id(),
                                                             QList<int>() << info.albumId());
                     }
+
+                    Q_FOREACH (const qlonglong& id, imageIdsFrom)
+                    {
+                        ItemScanner::resolveImageHistory(id);
+                        ItemScanner::tagItemHistoryGraph(id);
+                    }
                 }
             }
 
@@ -724,7 +799,13 @@ void DIO::slotOneProccessed(const QUrl& url)
 
         case IOJobData::Restore:
         {
-            ScanController::instance()->scannedInfo(url.toLocalFile());
+            ItemInfo info = ScanController::instance()->scannedInfo(url.toLocalFile());
+
+            if (!info.isNull())
+            {
+                ItemScanner::resolveImageHistory(info.id());
+                ItemScanner::tagItemHistoryGraph(info.id());
+            }
 
             break;
         }
@@ -851,6 +932,17 @@ void DIO::slotCancel(ProgressItem* item)
     }
 }
 
+void DIO::slotTrashCounterMap(const QMap<QString, int>& counterMap)
+{
+    {
+        QMutexLocker locker(&m_trashCounterMutex);
+
+        m_trashCounterMap = counterMap;
+    }
+
+    Q_EMIT signalTrashCounters();
+}
+
 void DIO::addAlbumChildrenToList(QList<int>& list, Album* const album)
 {
     // simple recursive helper function
@@ -873,3 +965,5 @@ void DIO::addAlbumChildrenToList(QList<int>& list, Album* const album)
 }
 
 } // namespace Digikam
+
+#include "moc_dio.cpp"
