@@ -6,22 +6,13 @@
  * Date        : 2005-05-07
  * Description : a dialog to delete item.
  *
- * Copyright (C) 2004      by Michael Pyne <michael dot pyne at kdemail dot net>
- * Copyright (C) 2006      by Ian Monroe <ian at monroe dot nu>
- * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2008-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004      by Michael Pyne <michael dot pyne at kdemail dot net>
+ * SPDX-FileCopyrightText: 2006      by Ian Monroe <ian at monroe dot nu>
+ * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -54,6 +45,7 @@
 #include "digikam_debug.h"
 #include "applicationsettings.h"
 #include "coredburl.h"
+#include "dxmlguiwindow.h"
 
 namespace Digikam
 {
@@ -63,12 +55,9 @@ class Q_DECL_HIDDEN DeleteItem::Private
 
 public:
 
-    explicit Private()
-      : hasThumb(false)
-    {
-    }
+    Private() = default;
 
-    bool hasThumb;
+    bool hasThumb = false;
 
     QUrl url;
 };
@@ -130,11 +119,11 @@ QString DeleteItem::fileUrl() const
 void DeleteItem::setThumb(const QPixmap& pix, bool hasThumb)
 {
     int iconSize = treeWidget()->iconSize().width();
-    QPixmap pixmap(iconSize+2, iconSize+2);
+    QPixmap pixmap(iconSize + 2, iconSize + 2);
     pixmap.fill(Qt::transparent);
     QPainter p(&pixmap);
-    p.drawPixmap((pixmap.width()/2)  - (pix.width()/2),
-                 (pixmap.height()/2) - (pix.height()/2), pix);
+    p.drawPixmap((pixmap.width()  / 2) - (pix.width()  / 2),
+                 (pixmap.height() / 2) - (pix.height() / 2), pix);
 
     QIcon icon = QIcon(pixmap);
 
@@ -158,15 +147,11 @@ class Q_DECL_HIDDEN DeleteItemList::Private
 
 public:
 
-    explicit Private()
-        : iconSize       (64),
-          thumbLoadThread(nullptr)
-    {
-    }
+    Private() = default;
 
-    const int            iconSize;
+    const int            iconSize        = 64;
 
-    ThumbnailLoadThread* thumbLoadThread;
+    ThumbnailLoadThread* thumbLoadThread = nullptr;
 };
 
 DeleteItemList::DeleteItemList(QWidget* const parent)
@@ -176,6 +161,7 @@ DeleteItemList::DeleteItemList(QWidget* const parent)
     d->thumbLoadThread = ThumbnailLoadThread::defaultThread();
 
     setRootIsDecorated(false);
+    setUniformRowHeights(true);
     setSelectionMode(QAbstractItemView::SingleSelection);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     setAllColumnsShowFocus(true);
@@ -236,32 +222,21 @@ class Q_DECL_HIDDEN DeleteWidget::Private
 {
 public:
 
-    explicit Private()
-      : checkBoxStack (nullptr),
-        warningIcon   (nullptr),
-        deleteText    (nullptr),
-        numFiles      (nullptr),
-        shouldDelete  (nullptr),
-        doNotShowAgain(nullptr),
-        fileList      (nullptr),
-        listMode      (DeleteDialogMode::Files),
-        deleteMode    (DeleteDialogMode::UseTrash)
-    {
-    }
+    Private() = default;
 
-    QStackedWidget*              checkBoxStack;
+    QStackedWidget*              checkBoxStack      = nullptr;
 
-    QLabel*                      warningIcon;
-    QLabel*                      deleteText;
-    QLabel*                      numFiles;
+    QLabel*                      warningIcon        = nullptr;
+    QLabel*                      deleteText         = nullptr;
+    QLabel*                      numFiles           = nullptr;
 
-    QCheckBox*                   shouldDelete;
-    QCheckBox*                   doNotShowAgain;
+    QCheckBox*                   shouldDelete       = nullptr;
+    QCheckBox*                   doNotShowAgain     = nullptr;
 
-    QTreeWidget*                 fileList;
+    QTreeWidget*                 fileList           = nullptr;
 
-    DeleteDialogMode::ListMode   listMode;
-    DeleteDialogMode::DeleteMode deleteMode;
+    DeleteDialogMode::ListMode   listMode           = DeleteDialogMode::Files;
+    DeleteDialogMode::DeleteMode deleteMode         = DeleteDialogMode::UseTrash;
 };
 
 DeleteWidget::DeleteWidget(QWidget* const parent)
@@ -273,7 +248,8 @@ DeleteWidget::DeleteWidget(QWidget* const parent)
     resize(540, 370);
     setMinimumSize(QSize(420, 320));
 
-    const int spacing  = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing  = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     d->checkBoxStack   = new QStackedWidget(this);
     QLabel* const logo = new QLabel(this);
@@ -349,7 +325,7 @@ void DeleteWidget::setUrls(const QList<QUrl>& urls)
 {
     d->fileList->clear();
 
-    foreach (const QUrl& url, urls)
+    Q_FOREACH (const QUrl& url, urls)
     {
         new DeleteItem(d->fileList, url);
     }
@@ -472,22 +448,15 @@ class Q_DECL_HIDDEN DeleteDialog::Private
 {
 public:
 
-    explicit Private()
-      : saveShouldDeleteUserPreference(true),
-        saveDoNotShowAgainTrash       (false),
-        saveDoNotShowAgainPermanent   (false),
-        page                          (nullptr),
-        buttons                       (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool              saveShouldDeleteUserPreference;
-    bool              saveDoNotShowAgainTrash;
-    bool              saveDoNotShowAgainPermanent;
+    bool              saveShouldDeleteUserPreference = true;
+    bool              saveDoNotShowAgainTrash        = false;
+    bool              saveDoNotShowAgainPermanent    = false;
 
-    DeleteWidget*     page;
+    DeleteWidget*     page                           = nullptr;
 
-    QDialogButtonBox* buttons;
+    QDialogButtonBox* buttons                        = nullptr;
 };
 
 DeleteDialog::DeleteDialog(QWidget* const parent)
@@ -496,7 +465,7 @@ DeleteDialog::DeleteDialog(QWidget* const parent)
 {
     setModal(true);
 
-    d->buttons             = new QDialogButtonBox(QDialogButtonBox::Apply | QDialogButtonBox::Cancel, this);
+    d->buttons             = new QDialogButtonBox(QDialogButtonBox::Apply | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     d->buttons->button(QDialogButtonBox::Apply)->setDefault(true);
 
     d->page                = new DeleteWidget(this);
@@ -520,6 +489,10 @@ DeleteDialog::DeleteDialog(QWidget* const parent)
 
     connect(d->buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
             this, SLOT(reject()));
+
+    connect(d->buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this, SLOT(slotHelp()));
+
 }
 
 DeleteDialog::~DeleteDialog()
@@ -659,14 +632,14 @@ void DeleteDialog::setListMode(DeleteDialogMode::ListMode mode)
     {
         case DeleteDialogMode::Files:
         {
-            setWindowTitle(i18n("About to delete selected items"));
+            setWindowTitle(i18nc("@title:window", "About to Delete Selected Items"));
             break;
         }
 
         case DeleteDialogMode::Albums:
         case DeleteDialogMode::Subalbums:
         {
-            setWindowTitle(i18n("About to delete selected albums"));
+            setWindowTitle(i18nc("@title:window", "About to Delete Selected Albums"));
             break;
         }
     }
@@ -696,4 +669,11 @@ void DeleteDialog::keyPressEvent(QKeyEvent* e)
     QDialog::keyPressEvent(e);
 }
 
+void DeleteDialog::slotHelp()
+{
+    openOnlineDocumentation(QLatin1String("main_window"), QLatin1String("image_view"), QLatin1String("deleting-photograph"));
+}
+
 } // namespace Digikam
+
+#include "moc_deletedialog.cpp"
