@@ -7,7 +7,7 @@
  * Description : a widget to display splash with progress bar
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -41,26 +41,20 @@ class Q_DECL_HIDDEN DSplashScreen::Private
 
 public:
 
-    explicit Private()
-      : state               (0),
-        progressBarSize     (3),
-        version             (QLatin1String(digikam_version_short)),
-        messageColor        (Qt::white),
-        versionColor        (Qt::white),
-        lastStateUpdateTime (QTime::currentTime())
-    {
-    }
+    Private() = default;
 
-    int     state;
-    int     progressBarSize;
+    int     state               = 0;
+    int     progressBarSize     = 3;
+
+    QTimer* timer               = nullptr;
 
     QString message;
-    QString version;
+    QString version             = QLatin1String(digikam_version_short);
 
-    QColor  messageColor;
-    QColor  versionColor;
+    QColor  messageColor        = Qt::white;
+    QColor  versionColor        = Qt::white;
 
-    QTime   lastStateUpdateTime;
+    QTime   lastStateUpdateTime = QTime::currentTime();
 };
 
 DSplashScreen::DSplashScreen()
@@ -87,16 +81,18 @@ DSplashScreen::DSplashScreen()
 
     setPixmap(splash);
 
-    QTimer* const timer = new QTimer(this);
+    d->timer = new QTimer(this);
 
-    connect(timer, SIGNAL(timeout()),
+    connect(d->timer, SIGNAL(timeout()),
             this, SLOT(slotAnimate()));
 
-    timer->start(150);
+    d->timer->start(150);
 }
 
 DSplashScreen::~DSplashScreen()
 {
+    d->timer->stop();
+
     delete d;
 }
 
@@ -210,3 +206,5 @@ void DSplashScreen::drawContents(QPainter* p)
 }
 
 } // namespace Digikam
+
+#include "moc_dsplashscreen.cpp"
