@@ -6,7 +6,7 @@
  * Date        : 2008-07-11
  * Description : shared libraries list dialog common to digiKam and Showfoto
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -34,8 +34,9 @@
 
 // KDE includes
 
-#include <kxmlgui_version.h>
 #include <klocalizedstring.h>
+#include <kmemoryinfo.h>
+#include <kxmlgui_version.h>
 
 // Local includes
 
@@ -47,28 +48,31 @@
 #include "metaengine.h"
 #include "dngwriter.h"
 #include "exiftoolparser.h"
-#include "dmemoryinfo.h"
+#include "loadingcache.h"
 #include "itempropertiestab.h"
 
 #ifdef HAVE_LENSFUN
 #   include "lensfuniface.h"
 #endif
 
-#ifdef HAVE_MARBLE
-#   include "mapwidget.h"
+#ifdef HAVE_GEOLOCATION
+#   include "backendmarble.h"
 #endif
 
 #ifdef HAVE_IMAGE_MAGICK
 
 // Pragma directives to reduce warnings from ImageMagick header files.
-#   if defined(Q_CC_GNU)
+#   if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #       pragma GCC diagnostic push
+#       pragma GCC diagnostic ignored "-Wignored-qualifiers"
 #       pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #   endif
 
 #   if defined(Q_CC_CLANG)
 #       pragma clang diagnostic push
+#       pragma clang diagnostic ignored "-Wignored-qualifiers"
 #       pragma clang diagnostic ignored "-Wkeyword-macro"
+#       pragma clang diagnostic ignored "-Wzero-as-null-pointer-constant"
 #   endif
 
 #   include <Magick++.h>
@@ -79,7 +83,7 @@
 #       pragma clang diagnostic pop
 #   endif
 
-#   if defined(Q_CC_GNU)
+#   if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #       pragma GCC diagnostic pop
 #   endif
 
@@ -93,7 +97,19 @@ extern "C"
 #endif
 
 #ifdef HAVE_JASPER
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic push
+#       pragma clang diagnostic ignored "-Werror"
+#       pragma clang diagnostic ignored "-Wundef"
+#   endif
+
 #   include <jasper/jas_version.h>
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic pop
+#   endif
+
 #endif
 
 #include <png.h>
@@ -110,6 +126,7 @@ extern "C"
 #   pragma clang diagnostic ignored "-Wundef"
 #   pragma clang diagnostic ignored "-Wgnu-anonymous-struct"
 #   pragma clang diagnostic ignored "-Wnested-anon-types"
+#   pragma clang diagnostic ignored "-Wzero-as-null-pointer-constant"
 #endif
 
 #ifdef HAVE_X265
@@ -165,21 +182,24 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
     listView()->addTopLevelItem(m_features);
 
     new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "Parallelized demosaicing") <<       checkTriState(DRawDecoder::librawUseGomp()));
+                        i18nc(CONTEXT, "Parallelized demosaicing") <<        checkTriState(DRawDecoder::librawUseGomp()));
 
 #ifdef HAVE_QTXMLPATTERNS
     new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "Rajce support") <<                  SUPPORTED_YES);
+                        i18nc(CONTEXT, "Rajce support") <<                   SUPPORTED_YES);
 #else
     new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "Rajce support") <<                  SUPPORTED_YES);
+                        i18nc(CONTEXT, "Rajce support") <<                   SUPPORTED_NO);
 #endif
 
     new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "Exiv2 supports XMP metadata") <<    (MetaEngine::supportXmp() ?  SUPPORTED_YES : SUPPORTED_NO));
+                        i18nc(CONTEXT, "Exiv2 supports XMP metadata") <<     (MetaEngine::supportXmp() ?  SUPPORTED_YES : SUPPORTED_NO));
 
     new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "Exiv2 supports Base Media") <<      (MetaEngine::supportBmff() ? SUPPORTED_YES : SUPPORTED_NO));
+                        i18nc(CONTEXT, "Exiv2 supports Base Media") <<       (MetaEngine::supportBmff() ? SUPPORTED_YES : SUPPORTED_NO));
+
+    new QTreeWidgetItem(m_features, QStringList() <<
+                        i18nc(CONTEXT, "Exiv2 supports JPEG-XL metadata") << (MetaEngine::supportJpegXL() ? SUPPORTED_YES : SUPPORTED_NO));
 
     // ---
 
@@ -188,10 +208,10 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
 
 
     new QTreeWidgetItem(m_libraries, QStringList() <<
-                        i18nc(CONTEXT, "Qt") <<                             QLatin1String(qVersion()));
+                        i18nc(CONTEXT, "Qt Framework") <<                   QLatin1String(qVersion()));
 
     new QTreeWidgetItem(m_libraries, QStringList() <<
-                        i18nc(CONTEXT, "KF5") <<                            QLatin1String(KXMLGUI_VERSION_STRING));
+                        i18nc(CONTEXT, "KDE Framework") <<                  QLatin1String(KXMLGUI_VERSION_STRING));
 
     new QTreeWidgetItem(m_libraries, QStringList() <<
                         i18nc(CONTEXT, "LibRaw") <<                         DRawDecoder::librawVersion());
@@ -212,6 +232,14 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
                         i18nc(CONTEXT, "Qt WebKit version") <<              QLatin1String(QTWEBKITWIDGETS_VERSION_STR));
 #endif
 
+#ifdef HAVE_QMULTIMEDIA
+    new QTreeWidgetItem(m_features, QStringList() <<
+                        i18nc(CONTEXT, "Qt Multimedia support") <<          SUPPORTED_YES);
+#else
+    new QTreeWidgetItem(m_features, QStringList() <<
+                        i18nc(CONTEXT, "Qt Multimedia support") <<          SUPPORTED_YES);
+#endif
+
     new QTreeWidgetItem(m_libraries, QStringList() <<
                         i18nc(CONTEXT, "Exiv2") <<                          MetaEngine::Exiv2Version());
 
@@ -239,22 +267,6 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
                         i18nc(CONTEXT, "LensFun support") <<                SUPPORTED_NO);
 #endif
 
-#ifdef HAVE_LIBLQR_1
-    new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "LibLqr support") <<                 SUPPORTED_YES);
-#else
-    new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "LibLqr support") <<                 SUPPORTED_NO);
-#endif
-
-#ifdef HAVE_VKONTAKTE
-    new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "VKontakte support") <<              SUPPORTED_YES);
-#else
-    new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "VKontakte support") <<              SUPPORTED_NO);
-#endif
-
 #ifdef HAVE_IMAGE_MAGICK
     new QTreeWidgetItem(m_libraries, QStringList() <<
                         i18nc(CONTEXT, "ImageMagick codecs") <<             QLatin1String(MagickLibVersionText));
@@ -321,12 +333,12 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
                         i18nc(CONTEXT, "LibJasper support") <<              SUPPORTED_NO);
 #endif
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
     new QTreeWidgetItem(m_libraries, QStringList() <<
-                        i18nc(CONTEXT, "Marble") <<                         MapWidget::MarbleWidgetVersion());
+                        i18nc(CONTEXT, "Geolocation support") <<            SUPPORTED_YES);
 #else
     new QTreeWidgetItem(m_features, QStringList() <<
-                        i18nc(CONTEXT, "Marble support") <<                 SUPPORTED_NO);
+                        i18nc(CONTEXT, "Geolocation support") <<            SUPPORTED_NO);
 #endif
 
 #ifdef HAVE_SONNET
@@ -345,11 +357,11 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
     new QTreeWidgetItem(m_features, QStringList() <<
                         i18ncp(CONTEXT, "CPU core", "CPU cores", nbcore) << QString::fromLatin1("%1").arg(nbcore));
 
-    DMemoryInfo memory;
+    KMemoryInfo memInfo;
 
-    if (!memory.isNull())
+    if (!memInfo.isNull())
     {
-        qint64 available = memory.totalPhysical();
+        quint64 available = memInfo.totalPhysical();
 
         if (available > 0)
         {
@@ -363,6 +375,11 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
         }
     }
 
+    quint64 cacheSize = LoadingCache::cache()->getCacheSize();
+
+    new QTreeWidgetItem(m_features, QStringList() <<
+                        i18nc(CONTEXT, "Image cache size") << ItemPropertiesTab::humanReadableBytesCount(cacheSize));
+
     // NOTE: MANIFEST.txt is a text file generated with the bundles and listing all git revisions of rolling release components.
     //       One section title start with '+'.
     //       All component revisions are listed below line by line with the name and the revision separated by ':'.
@@ -554,7 +571,7 @@ LibsInfoDlg::LibsInfoDlg(QWidget* const parent)
             if (enabled)
             {
                 count++;
-                new QTreeWidgetItem(ocvhdw, QStringList() << name << (enabled ? SUPPORTED_YES : SUPPORTED_NO));
+                new QTreeWidgetItem(ocvhdw, QStringList() << name << SUPPORTED_YES);
             }
         }
     }
@@ -675,3 +692,5 @@ QString LibsInfoDlg::openCVGetDeviceTypeString(const cv::ocl::Device& device)
 }
 
 } // namespace Digikam
+
+#include "moc_libsinfodlg.cpp"
