@@ -4,20 +4,11 @@
  * https://www.digikam.org
  *
  * Date        : 2008-07-11
- * Description : shared libraries list dialog
+ * Description : shared libraries list dialog common to digiKam and Showfoto
  *
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -34,6 +25,11 @@
 #include "digikam_export.h"
 #include "infodlg.h"
 
+namespace cv::ocl
+{
+    class Device;
+}
+
 namespace Digikam
 {
 
@@ -54,6 +50,9 @@ protected:
 private:
 
     QString checkTriState(int value) const;
+
+    QString openCVBytesToStringRepr(size_t value) const;
+    QString openCVGetDeviceTypeString(const cv::ocl::Device& device);
 };
 
 } // namespace Digikam
