@@ -6,7 +6,7 @@
  * Date        : 2004-12-01
  * Description : image curves manipulation methods.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -34,7 +34,6 @@
 #include "digikam_config.h"
 #include "curvescontainer.h"
 #include "filteraction.h"
-#include "digikam_globals.h"
 
 namespace Digikam
 {
@@ -68,13 +67,7 @@ public:
 
 public:
 
-    explicit Private()
-      : curves      (nullptr),
-        lut         (nullptr),
-        segmentMax  (0),
-        dirty       (false)
-    {
-    }
+    Private() = default;
 
     ~Private()
     {
@@ -117,14 +110,14 @@ public:
     }
 
     /// Curves data.
-    struct _Curves* curves;
+    struct _Curves* curves      = nullptr;
 
     /// Lut data.
-    struct _Lut*    lut;
+    struct _Lut*    lut         = nullptr;
 
-    int             segmentMax;
+    int             segmentMax  = 0;
 
-    bool            dirty;
+    bool            dirty       = false;
 };
 
 ImageCurves::CRMatrix CR_basis =
@@ -162,10 +155,11 @@ ImageCurves::~ImageCurves()
 ImageCurves& ImageCurves::operator=(const ImageCurves& other)
 {
     d = other.d;
+
     return *this;
 }
 
-void ImageCurves::fillFromOtherCurves(ImageCurves* const otherCurves)
+void ImageCurves::fillFromOtherCurves(const ImageCurves* const otherCurves)
 {
     //qCDebug(DIGIKAM_DIMG_LOG) << "Filling this curve from other curve " << otherCurves;
 
@@ -211,6 +205,7 @@ void ImageCurves::fillFromOtherCurves(ImageCurves* const otherCurves)
 
     // other curve is 8 bit and this curve is 16 bit
 
+    // cppcheck-suppress knownConditionTrueFalse
     else if (isSixteenBits() && !otherCurves->isSixteenBits())
     {
         //qCDebug(DIGIKAM_DIMG_LOG) << "This curve is 16 bit and the other is 8 bit";
@@ -251,6 +246,7 @@ void ImageCurves::fillFromOtherCurves(ImageCurves* const otherCurves)
 
     // other curve is 16 bit and this is 8 bit
 
+    // cppcheck-suppress knownConditionTrueFalse
     else if (!isSixteenBits() && otherCurves->isSixteenBits())
     {
         //qCDebug(DIGIKAM_DIMG_LOG) << "This curve is 8 bit and the other is 16 bit";
@@ -899,6 +895,7 @@ CurvesContainer ImageCurves::getContainer() const
         if ((type = getCurveType(i)) == CURVE_FREE)
         {
             type = CURVE_FREE;
+
             break;
         }
     }
@@ -986,9 +983,10 @@ void ImageCurves::setCurveValue(int channel, int bin, int val)
 
 void ImageCurves::setCurveValues(int channel, const QPolygon& vals)
 {
-    //qCDebug(DIGIKAM_DIMG_LOG) << "vals size: " << vals.size();
-    //qCDebug(DIGIKAM_DIMG_LOG) << "segmentMax: " << d->segmentMax + 1;
-
+/*
+    qCDebug(DIGIKAM_DIMG_LOG) << "vals size: " << vals.size();
+    qCDebug(DIGIKAM_DIMG_LOG) << "segmentMax: " << d->segmentMax + 1;
+*/
     if (d->curves && (channel >= 0) && (channel < NUM_CHANNELS))
     {
         if (vals.isEmpty())
@@ -1215,12 +1213,14 @@ bool ImageCurves::loadCurvesFromGimpCurvesFile(const QUrl& fileUrl)
     if (! fgets(buf, sizeof(buf), file))
     {
         fclose(file);
+
         return false;
     }
 
     if (strcmp(buf, "# GIMP Curves File\n") != 0)
     {
         fclose(file);
+
         return false;
     }
 
@@ -1236,6 +1236,7 @@ bool ImageCurves::loadCurvesFromGimpCurvesFile(const QUrl& fileUrl)
             {
                 qCWarning(DIGIKAM_DIMG_LOG) <<  "Invalid Gimp curves file!";
                 fclose(file);
+
                 return false;
             }
         }
@@ -1518,6 +1519,7 @@ bool ImageCurves::setChannelFromBinary(int channel, const QByteArray& data)
     if (data.isEmpty())
     {
         curvesChannelReset(channel);
+
         return false;
     }
 
