@@ -6,7 +6,7 @@
  * Date        : 2005-05-25
  * Description : filter to add Film Grain to image.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2005-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010      by Julien Narboux <julien at narboux dot fr>
  *
@@ -251,11 +251,17 @@ void FilmGrainFilter::filterImage()
     for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
     {
         tasks.append(QtConcurrent::run(
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                                        &FilmGrainFilter::filmgrainMultithreaded, this,
+
 #else
+
                                        this, &FilmGrainFilter::filmgrainMultithreaded,
+
 #endif
+
                                        vals[j],
                                        vals[j+1]
                                       )
@@ -455,3 +461,5 @@ void FilmGrainFilter::readParameters(const Digikam::FilterAction& action)
 }
 
 } // namespace Digikam
+
+#include "moc_filmgrainfilter.cpp"
