@@ -6,7 +6,7 @@
  * Date        : 2010-03-15
  * Description : Anti vignetting settings view.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -44,7 +44,7 @@ public:
     AntiVignettingContainer settings()        const;
     void setSettings(const AntiVignettingContainer& settings);
 
-    void readSettings(KConfigGroup& group);
+    void readSettings(const KConfigGroup& group);
     void writeSettings(KConfigGroup& group);
 
     void setMaskPreviewPixmap(const QPixmap& pix);
