@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -45,20 +45,15 @@ class Q_DECL_HIDDEN LensFunFilter::Private
 {
 public:
 
-    explicit Private()
-      : iface   (nullptr),
-        modifier(nullptr),
-        loop    (0)
-    {
-    }
+    Private() = default;
 
     DImg          tempImage;
 
-    LensFunIface* iface;
+    LensFunIface* iface    = nullptr;
 
-    lfModifier*   modifier;
+    lfModifier*   modifier = nullptr;
 
-    int           loop;
+    int           loop     = 0;
 };
 
 LensFunFilter::LensFunFilter(QObject* const parent)
@@ -97,12 +92,18 @@ QString LensFunFilter::DisplayableName()
 {
     static const struct FilterName
     {
+
 #if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
         const KLazyLocalizedString    title;
+
 #else
+
         const char*                   context;
         const char*                   title;
+
 #endif
+
     }
     FILTER_NAME =
     {
@@ -110,10 +111,15 @@ QString LensFunFilter::DisplayableName()
     };
 
 #if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+
     return FILTER_NAME.title.toString();
+
 #else
+
     return i18nc(FILTER_NAME.context, FILTER_NAME.title);
+
 #endif
+
 }
 
 void LensFunFilter::filterCCAMultithreaded(uint start, uint stop)
@@ -282,11 +288,17 @@ void LensFunFilter::filterImage()
         for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
         {
             tasks.append(QtConcurrent::run(
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                                            &LensFunFilter::filterCCAMultithreaded, this,
+
 #else
+
                                            this, &LensFunFilter::filterCCAMultithreaded,
+
 #endif
+
                                            vals[j],
                                            vals[j+1])
             );
@@ -311,11 +323,17 @@ void LensFunFilter::filterImage()
         for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
         {
             tasks.append(QtConcurrent::run(
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                                            &LensFunFilter::filterVIGMultithreaded, this,
+
 #else
+
                                            this, &LensFunFilter::filterVIGMultithreaded,
+
 #endif
+
                                            vals[j],
                                            vals[j+1])
             );
@@ -350,11 +368,17 @@ void LensFunFilter::filterImage()
         for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
         {
             tasks.append(QtConcurrent::run(
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                                            &LensFunFilter::filterDSTMultithreaded, this,
+
 #else
+
                                            this, &LensFunFilter::filterDSTMultithreaded,
+
 #endif
+
                                            vals[j],
                                            vals[j+1])
             );
@@ -463,3 +487,5 @@ void LensFunFilter::readParameters(const Digikam::FilterAction& action)
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic pop
 #endif
+
+#include "moc_lensfunfilter.cpp"
