@@ -6,7 +6,7 @@
  * Date        : 2010-02-10
  * Description : sharp settings view.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -56,27 +56,7 @@ class Q_DECL_HIDDEN SharpSettings::Private
 
 public:
 
-    explicit Private()
-      : stack           (nullptr),
-        sharpMethod     (nullptr),
-        radiusInput     (nullptr),
-
-#ifdef HAVE_EIGEN3
-
-        radius          (nullptr),
-        correlation     (nullptr),
-        noise           (nullptr),
-        gauss           (nullptr),
-        matrixSize      (nullptr),
-
-#endif // HAVE_EIGEN3
-
-        radiusInput2    (nullptr),
-        amountInput     (nullptr),
-        thresholdInput  (nullptr),
-        luma            (nullptr)
-    {
-    }
+    Private() = default;
 
     static const QString configSharpenMethodEntry;
     static const QString configSimpleSharpRadiusAdjustmentEntry;
@@ -90,27 +70,32 @@ public:
     static const QString configRefocusGaussAdjustmentEntry;
     static const QString configRefocusMatrixSizeEntry;
 
-    QStackedWidget*      stack;
+    QStackedWidget*      stack          = nullptr;
 
-    DComboBox*           sharpMethod;
+    DComboBox*           sharpMethod    = nullptr;
 
     // Simple sharp.
-    DIntNumInput*        radiusInput;
+
+    DIntNumInput*        radiusInput    = nullptr;
 
 #ifdef HAVE_EIGEN3
+
     // Refocus.
-    DDoubleNumInput*     radius;
-    DDoubleNumInput*     correlation;
-    DDoubleNumInput*     noise;
-    DDoubleNumInput*     gauss;
-    DIntNumInput*        matrixSize;
+
+    DDoubleNumInput*     radius         = nullptr;
+    DDoubleNumInput*     correlation    = nullptr;
+    DDoubleNumInput*     noise          = nullptr;
+    DDoubleNumInput*     gauss          = nullptr;
+    DIntNumInput*        matrixSize     = nullptr;
+
 #endif // HAVE_EIGEN3
 
     // Unsharp mask.
-    DDoubleNumInput*     radiusInput2;
-    DDoubleNumInput*     amountInput;
-    DDoubleNumInput*     thresholdInput;
-    QCheckBox*           luma;
+
+    DDoubleNumInput*     radiusInput2   = nullptr;
+    DDoubleNumInput*     amountInput    = nullptr;
+    DDoubleNumInput*     thresholdInput = nullptr;
+    QCheckBox*           luma           = nullptr;
 };
 
 const QString SharpSettings::Private::configSharpenMethodEntry(QLatin1String("SharpenMethod"));
@@ -132,7 +117,7 @@ SharpSettings::SharpSettings(QWidget* const parent)
       d      (new Private)
 {
     const int spacing       = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+                                   QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     QGridLayout* const grid = new QGridLayout(parent);
 
     QLabel* const label1    = new QLabel(i18n("Method:"));
@@ -458,7 +443,7 @@ SharpContainer SharpSettings::defaultSettings() const
     return prm;
 }
 
-void SharpSettings::readSettings(KConfigGroup& group)
+void SharpSettings::readSettings(const KConfigGroup& group)
 {
     SharpContainer prm;
     SharpContainer defaultPrm = defaultSettings();
@@ -598,3 +583,5 @@ void SharpSettings::saveAsSettings()
 }
 
 } // namespace Digikam
+
+#include "moc_sharpsettings.cpp"
