@@ -8,7 +8,7 @@
  *               This class do not depend of digiKam database library
  *               to permit to re-use plugins with Showfoto.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -70,7 +70,7 @@ DInfoInterface::DInfoMap DInfoInterface::itemInfo(const QUrl&) const
     return DInfoMap();
 }
 
-void DInfoInterface::setItemInfo(const QUrl&, const DInfoMap&) const
+void DInfoInterface::setItemInfo(const QUrl&, const DInfoMap&)
 {
     qCWarning(DIGIKAM_GENERAL_LOG) << "setItemInfo() not implemented in host interface";
 }
@@ -130,7 +130,7 @@ QAbstractItemModel* DInfoInterface::tagFilterModel()
     return nullptr;
 }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
 QList<GPSItemContainer*> DInfoInterface::currentGPSItems() const
 {
@@ -493,7 +493,7 @@ QString DAlbumInfo::title() const
 QString DAlbumInfo::caption() const
 {
     QString ret;
-    DInfoInterface::DInfoMap::const_iterator it = m_info.find(QLatin1String("comment"));
+    DInfoInterface::DInfoMap::const_iterator it = m_info.find(QLatin1String("caption"));
 
     if (it != m_info.end())
     {
@@ -543,3 +543,5 @@ QString DAlbumInfo::albumPath() const
 }
 
 } // namespace Digikam
+
+#include "moc_dinfointerface.cpp"
