@@ -6,19 +6,11 @@
  * Date        : 2008-05-21
  * Description : widget to display a list of items
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2008-2010 by Andi Clemens <andi dot clemens at googlemail dot com>
- * Copyright (C) 2009-2010 by Luka Renko <lure at kubuntu dot org>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2010 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Luka Renko <lure at kubuntu dot org>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -43,6 +35,7 @@ public:
         clearButton          (nullptr),
         loadButton           (nullptr),
         saveButton           (nullptr),
+        extraWidget          (nullptr),
         progressPix          (nullptr),
         progressCount        (0),
         progressTimer        (nullptr),
@@ -65,6 +58,7 @@ public:
     CtrlButton*                 clearButton;
     CtrlButton*                 loadButton;
     CtrlButton*                 saveButton;
+    QWidget*                    extraWidget;        ///< Extra widget append to the end of control buttons layout.
 
     QList<QUrl>                 processItems;
     DWorkingPixmap*             progressPix;
@@ -184,11 +178,18 @@ void DItemsList::enableDragAndDrop(const bool enable)
     d->listView->enableDragAndDrop(enable);
 }
 
-void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
+void DItemsList::appendControlButtonsWidget(QWidget* const widget)
+{
+    d->extraWidget = widget;
+}
+
+QBoxLayout* DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
 {
     delete layout();
 
-    const int spacing             = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    QBoxLayout* lay               = nullptr;        // Layout instance to return;
+    const int spacing             = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                                         QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     QGridLayout* const mainLayout = new QGridLayout;
     mainLayout->addWidget(d->listView, 1, 1, 1, 1);
@@ -200,7 +201,6 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
     // --------------------------------------------------------
 
     QHBoxLayout* const hBtnLayout = new QHBoxLayout;
-    hBtnLayout->addStretch(10);
     hBtnLayout->addWidget(d->moveUpButton);
     hBtnLayout->addWidget(d->moveDownButton);
     hBtnLayout->addWidget(d->addButton);
@@ -208,12 +208,16 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
     hBtnLayout->addWidget(d->loadButton);
     hBtnLayout->addWidget(d->saveButton);
     hBtnLayout->addWidget(d->clearButton);
-    hBtnLayout->addStretch(10);
+    hBtnLayout->addStretch(1);
+
+    if (d->extraWidget)
+    {
+        hBtnLayout->addWidget(d->extraWidget);
+    }
 
     // --------------------------------------------------------
 
     QVBoxLayout* const vBtnLayout = new QVBoxLayout;
-    vBtnLayout->addStretch(10);
     vBtnLayout->addWidget(d->moveUpButton);
     vBtnLayout->addWidget(d->moveDownButton);
     vBtnLayout->addWidget(d->addButton);
@@ -221,7 +225,12 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
     vBtnLayout->addWidget(d->loadButton);
     vBtnLayout->addWidget(d->saveButton);
     vBtnLayout->addWidget(d->clearButton);
-    vBtnLayout->addStretch(10);
+    vBtnLayout->addStretch(1);
+
+    if (d->extraWidget)
+    {
+        vBtnLayout->addWidget(d->extraWidget);
+    }
 
     // --------------------------------------------------------
 
@@ -229,6 +238,7 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
     {
         case ControlButtonsAbove:
         {
+            lay = hBtnLayout;
             mainLayout->addLayout(hBtnLayout, 0, 1, 1, 1);
             delete vBtnLayout;
             break;
@@ -236,6 +246,7 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
 
         case ControlButtonsBelow:
         {
+            lay = hBtnLayout;
             mainLayout->addLayout(hBtnLayout, 2, 1, 1, 1);
             delete vBtnLayout;
             break;
@@ -243,6 +254,7 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
 
         case ControlButtonsLeft:
         {
+            lay = vBtnLayout;
             mainLayout->addLayout(vBtnLayout, 1, 0, 1, 1);
             delete hBtnLayout;
             break;
@@ -250,6 +262,7 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
 
         case ControlButtonsRight:
         {
+            lay = vBtnLayout;
             mainLayout->addLayout(vBtnLayout, 1, 2, 1, 1);
             delete hBtnLayout;
             break;
@@ -264,11 +277,19 @@ void DItemsList::setControlButtonsPlacement(ControlButtonPlacement placement)
             // set all buttons invisible
 
             setControlButtons(ControlButtons());
+
+            if (d->extraWidget)
+            {
+                d->extraWidget->setVisible(false);
+            }
+
             break;
         }
     }
 
     setLayout(mainLayout);
+
+    return lay;
 }
 
 void DItemsList::setControlButtons(ControlButtons buttonMask)
@@ -329,13 +350,8 @@ void DItemsList::loadImagesFromCurrentSelection()
 {
     bool selection = checkSelection();
 
-    if (selection == true)
+    if (selection && d->iface)
     {
-        if (!d->iface)
-        {
-            return;
-        }
-
         QList<QUrl> images = d->iface->currentSelectedItems();
 
         if (!images.isEmpty())
@@ -423,9 +439,9 @@ void DItemsList::slotAddImages(const QList<QUrl>& list)
         }
     }
 
-    emit signalAddItems(urls);
-    emit signalImageListChanged();
-    emit signalFoundRAWImages(raw);
+    Q_EMIT signalAddItems(urls);
+    Q_EMIT signalImageListChanged();
+    Q_EMIT signalFoundRAWImages(raw);
 }
 
 void DItemsList::slotAddItems()
@@ -469,8 +485,8 @@ void DItemsList::slotRemoveItems()
         }
     }
 
-    emit signalRemovedItems(itemsIndex);
-    emit signalImageListChanged();
+    Q_EMIT signalRemovedItems(itemsIndex);
+    Q_EMIT signalImageListChanged();
 }
 
 void DItemsList::slotMoveUpItems()
@@ -503,8 +519,8 @@ void DItemsList::slotMoveUpItems()
         uw->updateItemWidgets();
     }
 
-    emit signalImageListChanged();
-    emit signalMoveUpItem();
+    Q_EMIT signalImageListChanged();
+    Q_EMIT signalMoveUpItem();
 }
 
 void DItemsList::slotMoveDownItems()
@@ -537,8 +553,8 @@ void DItemsList::slotMoveDownItems()
         uw->updateItemWidgets();
     }
 
-    emit signalImageListChanged();
-    emit signalMoveDownItem();
+    Q_EMIT signalImageListChanged();
+    Q_EMIT signalMoveDownItem();
 }
 
 void DItemsList::slotClearItems()
@@ -556,7 +572,7 @@ void DItemsList::slotLoadItems()
                                                   QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)));
     QUrl loadLevelsFile;
     loadLevelsFile          = DFileDialog::getOpenFileUrl(this,
-                                                          i18nc("@info", "Select the image file list to load"), lastFileUrl,
+                                                          i18nc("@title:window", "Select the Image File List to Load"), lastFileUrl,
                                                           i18nc("@option", "All Files (*)"));
 
     if (loadLevelsFile.isEmpty())
@@ -588,7 +604,7 @@ void DItemsList::slotLoadItems()
 
             // get value of each attribute from QXmlStreamAttributes
 
-            QStringRef url             = attrs.value(QLatin1String("url"));
+            QStringView url             = attrs.value(QLatin1String("url"));
 
             if (url.isEmpty())
             {
@@ -605,13 +621,13 @@ void DItemsList::slotLoadItems()
 
             // read tool Image custom attributes and children element
 
-            emit signalXMLLoadImageElement(xmlReader);
+            Q_EMIT signalXMLLoadImageElement(xmlReader);
         }
         else if (xmlReader.isStartElement() && (xmlReader.name() != QLatin1String("Images")))
         {
             // unmanaged start element (it should be tools one)
 
-            emit signalXMLCustomElements(xmlReader);
+            Q_EMIT signalXMLCustomElements(xmlReader);
         }
         else if (xmlReader.isEndElement() && (xmlReader.name() == QLatin1String("Images")))
         {
@@ -637,7 +653,7 @@ void DItemsList::slotSaveItems()
                                                   QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)));
     QUrl saveLevelsFile;
     saveLevelsFile          = DFileDialog::getSaveFileUrl(this,
-                                                          i18nc("@info", "Select the image file list to save"),
+                                                          i18nc("@title:window", "Select the Image File List to Save"),
                                                           lastFileUrl,
                                                           i18nc("@option", "All Files (*)"));
 
@@ -677,7 +693,7 @@ void DItemsList::slotSaveItems()
 
             xmlWriter.writeAttribute(QLatin1String("url"), lvItem->url().toDisplayString());
 
-            emit signalXMLSaveItem(xmlWriter, listView()->indexFromItem(lvItem).row());
+            Q_EMIT signalXMLSaveItem(xmlWriter, listView()->indexFromItem(lvItem).row());
 
             xmlWriter.writeEndElement(); // Image
         }
@@ -685,7 +701,7 @@ void DItemsList::slotSaveItems()
         ++it;
     }
 
-    emit signalXMLCustomElements(xmlWriter);
+    Q_EMIT signalXMLCustomElements(xmlWriter);
 
     xmlWriter.writeEndElement();  // Images
 
@@ -729,8 +745,8 @@ void DItemsList::removeItemByUrl(const QUrl& url)
     }
     while (found);
 
-    emit signalRemovedItems(itemsIndex);
-    emit signalImageListChanged();
+    Q_EMIT signalRemovedItems(itemsIndex);
+    Q_EMIT signalImageListChanged();
 }
 
 QList<QUrl> DItemsList::imageUrls(bool onlyUnprocessed) const
@@ -760,7 +776,7 @@ void DItemsList::slotProgressTimerDone()
 {
     if (!d->processItems.isEmpty())
     {
-        foreach (const QUrl& url, d->processItems)
+        Q_FOREACH (const QUrl& url, d->processItems)
         {
             DItemsListViewItem* const item = listView()->findItem(url);
 
@@ -815,7 +831,7 @@ void DItemsList::processed(const QUrl& url, bool success)
 
 void DItemsList::cancelProcess()
 {
-    foreach (const QUrl& url, d->processItems)
+    Q_FOREACH (const QUrl& url, d->processItems)
     {
         processed(url, false);
     }
@@ -949,3 +965,7 @@ DItemsListIsLessThanHandler DItemsList::isLessThanHandler() const
 }
 
 } // namespace Digikam
+
+#include "moc_ditemslist.cpp"
+
+#include "moc_ditemslist_p.cpp"
