@@ -6,7 +6,7 @@
  * Date        : 2009-12-13
  * Description : a widget to preview image effect.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008      by Kare Sars <kare dot sars at iki dot fi>
  * SPDX-FileCopyrightText: 2012      by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
@@ -25,7 +25,6 @@
 #include <QPaintEvent>
 #include <QPainter>
 #include <QPixmap>
-#include <QGraphicsPixmapItem>
 #include <QGraphicsScene>
 #include <QWheelEvent>
 #include <QScrollBar>
@@ -815,15 +814,21 @@ void DPreviewImage::mousePressEvent(QMouseEvent* e)
 {
     if (e->button() & Qt::LeftButton)
     {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         d->lastdx          = e->position().toPoint().x();
         d->lastdy          = e->position().toPoint().y();
         QPointF scenePoint = mapToScene(e->position().toPoint());
+
 #else
+
         d->lastdx          = e->x();
         d->lastdy          = e->y();
         QPointF scenePoint = mapToScene(e->pos());
+
 #endif
+
         d->lastMousePoint  = scenePoint;
 
         if (e->modifiers() != Qt::ControlModifier && d->enableSelection)
@@ -882,11 +887,16 @@ void DPreviewImage::mouseReleaseEvent(QMouseEvent* e)
             }
         }
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         if (!d->selection->isVisible() || !d->selection->contains(e->position().toPoint()))
+
 #else
+
         if (!d->selection->isVisible() || !d->selection->contains(e->pos()))
+
 #endif
+
         {
             setCursor(Qt::CrossCursor);
         }
@@ -900,32 +910,49 @@ void DPreviewImage::mouseReleaseEvent(QMouseEvent* e)
 
 void DPreviewImage::mouseMoveEvent(QMouseEvent* e)
 {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     QPointF scenePoint = mapToScene(e->position().toPoint());
+
 #else
+
     QPointF scenePoint = mapToScene(e->pos());
+
 #endif
 
     if (e->buttons() & Qt::LeftButton)
     {
         if (d->mouseDragAction == Private::LOOKAROUND)
         {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
             int dx    = e->position().toPoint().x() - d->lastdx;
             int dy    = e->position().toPoint().y() - d->lastdy;
+
 #else
+
             int dx    = e->x() - d->lastdx;
             int dy    = e->y() - d->lastdy;
+
 #endif
+
             verticalScrollBar()->setValue(verticalScrollBar()->value() - dy);
             horizontalScrollBar()->setValue(horizontalScrollBar()->value() - dx);
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
             d->lastdx = e->position().toPoint().x();
             d->lastdy = e->position().toPoint().y();
+
 #else
+
             d->lastdx = e->x();
             d->lastdy = e->y();
+
 #endif
+
         }
         else if (d->mouseDragAction == Private::DRAWSELECTION  ||
                  d->mouseDragAction == Private::EXPANDORSHRINK ||
@@ -1233,11 +1260,16 @@ void DPreviewImage::mouseMoveEvent(QMouseEvent* e)
     QGraphicsView::mouseMoveEvent(e);
 }
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
 void DPreviewImage::enterEvent(QEnterEvent* /*event*/)
+
 #else
+
 void DPreviewImage::enterEvent(QEvent* /*event*/)
+
 #endif
+
 {
     d->toolBar->show();
 }
@@ -1377,3 +1409,5 @@ void DPreviewImage::updateHighlight()
 }
 
 } // namespace Digikam
+
+#include "moc_dpreviewimage.cpp"
