@@ -6,19 +6,10 @@
  * Date        : 2009-05-05
  * Description : file action manager
  *
- * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -95,6 +86,7 @@ bool FileActionMngr::requestShutDown()
     dialog->exec();
 
     // Either, we finished and all is fine, or the user cancelled and we kill
+
     shutDown();
 
     return true;
@@ -296,3 +288,5 @@ void FileActionMngr::copyAttributes(const ItemInfo& source, const QStringList& d
 }
 
 } // namespace Digikam
+
+#include "moc_fileactionmngr.cpp"
