@@ -19,7 +19,6 @@
 
 #include <QDir>
 #include <QFile>
-#include <QDirIterator>
 
 // KDE includes
 
@@ -34,6 +33,7 @@
 #include "coredbaccess.h"
 #include "albummanager.h"
 #include "dfileoperations.h"
+#include "collectionmanager.h"
 #include "coredboperationgroup.h"
 
 namespace Digikam
@@ -252,7 +252,10 @@ void CopyOrMoveJob::run()
         Q_EMIT signalOneProccessed(srcUrl);
     }
 
-    m_data->setErrorOrCancel(m_cancel);
+    if (m_data)
+    {
+        m_data->setErrorOrCancel(m_cancel);
+    }
 
     Q_EMIT signalDone();
 }
@@ -432,8 +435,9 @@ void DTrashItemsListingJob::run()
 {
     DTrashItemInfo itemInfo;
 
-    QString collectionTrashFilesPath = m_collectionPath + QLatin1Char('/') + DTrash::TRASH_FOLDER +
-                                       QLatin1Char('/') + DTrash::FILES_FOLDER;
+    QString collectionTrashFilesPath = m_collectionPath     + QLatin1Char('/') +
+                                       DTrash::TRASH_FOLDER + QLatin1Char('/') +
+                                       DTrash::FILES_FOLDER;
 
     qCDebug(DIGIKAM_IOJOB_LOG) << "Collection trash files path:" << collectionTrashFilesPath;
 
@@ -441,6 +445,11 @@ void DTrashItemsListingJob::run()
 
     Q_FOREACH (const QFileInfo& fileInfo, filesDir.entryInfoList(QDir::Files))
     {
+        if (m_cancel)
+        {
+            break;
+        }
+
         qCDebug(DIGIKAM_IOJOB_LOG) << "File in trash:" << fileInfo.filePath();
         itemInfo.trashPath = fileInfo.filePath();
 
@@ -532,4 +541,40 @@ void EmptyDTrashItemsJob::run()
     Q_EMIT signalDone();
 }
 
+// ----------------------------------------------
+
+BuildTrashCountersJob::BuildTrashCountersJob()
+{
+}
+
+void BuildTrashCountersJob::run()
+{
+    QMap<QString, int> trashCountersMap;
+    QList<CollectionLocation> allLocations = CollectionManager::instance()->allAvailableLocations();
+
+    Q_FOREACH (const CollectionLocation& location, allLocations)
+    {
+        QString path = location.albumRootPath() + QLatin1Char('/') +
+                       DTrash::TRASH_FOLDER     + QLatin1Char('/') +
+                       DTrash::FILES_FOLDER;
+
+        QDir dir(path, QLatin1String(""), QDir::Unsorted, QDir::Files);
+
+        if (dir.exists() && dir.isReadable())
+        {
+            trashCountersMap.insert(location.albumRootPath(), dir.count());
+        }
+        else
+        {
+            trashCountersMap.insert(location.albumRootPath(), 0);
+        }
+    }
+
+    Q_EMIT signalTrashCountersMap(trashCountersMap);
+
+    Q_EMIT signalDone();
+}
+
 } // namespace Digikam
+
+#include "moc_iojob.cpp"
