@@ -6,25 +6,16 @@
  * Date        : 2004-09-29
  * Description : helper methods for JPEG image format.
  *
- * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * Parts of the loading code is taken from qjpeghandler.cpp
- * Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2011 Nokia Corporation and/or its subsidiary(-ies).
  * All rights reserved.
  * Contact: Nokia Corporation (qt-info@nokia.com)
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -73,11 +64,10 @@ extern "C"
 
 // Qt includes
 
-#include <QImageReader>
-#include <QByteArray>
-#include <QUuid>
 #include <QFile>
 #include <QFileInfo>
+#include <QByteArray>
+#include <QImageReader>
 #include <QScopedPointer>
 #include <qplatformdefs.h>
 
@@ -85,7 +75,6 @@ extern "C"
 
 #include "dimg.h"
 #include "digikam_debug.h"
-#include "digikam_config.h"
 #include "dfileoperations.h"
 #include "metaenginesettings.h"
 #include "filereadwritelock.h"
@@ -426,22 +415,25 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
     {
         if (m_file != m_destFile)
         {
-            return QFile::copy(m_file, m_destFile);
+            return DFileOperations::copyFile(m_file, m_destFile);
         }
 
         return true;
     }
 
+    bool        ret  = true;
     QString     dest = m_destFile;
     QString     src  = m_file;
     QString     dir  = fi.path();
     QStringList removeLater;
 
+    MetaEngineSettingsContainer::RotationBehaviorFlags behavior;
+    behavior = MetaEngineSettings::instance()->settings().rotationBehavior;
+
     for (int i = 0 ; i < actions.size() ; ++i)
     {
-        QString random                = QUuid::createUuid().toString().mid(1, 8);
-        SafeTemporaryFile* const temp = new SafeTemporaryFile(dir + QLatin1String("/JpegRotator-XXXXXX-") +
-                                                              random + QLatin1String(".digikamtempfile.jpg"));
+        SafeTemporaryFile* const temp = new SafeTemporaryFile(dir + QLatin1String("/JpegRotator-XXXXXX"
+                                                                                  ".digikamtempfile.jpg"));
         temp->setAutoRemove(false);
         temp->open();
         QString tempFile = temp->safeFilePath();
@@ -450,20 +442,49 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
 
         delete temp;
 
-        if (!performJpegTransform(actions[i], src, tempFile))
+        bool canLosslessTransform = true;
+
+#if (JPEG_LIB_VERSION < 80)
+
+        PhotoInfoContainer photoInfo = m_metadata->getPhotographInformation();
+        QStringList unsupportedModels({ QLatin1String("Redmi Note 6 Pro") });
+
+        Q_FOREACH (const QString& model, unsupportedModels)
+        {
+            if (model == photoInfo.model)
+            {
+                qCDebug(DIGIKAM_GENERAL_LOG) << "Unsupported camera model for lossless transform:"
+                                             << photoInfo.model;
+                canLosslessTransform = false;
+                break;
+            }
+        }
+
+#endif
+
+        if (!canLosslessTransform || !performJpegTransform(actions[i], src, tempFile))
         {
             qCDebug(DIGIKAM_GENERAL_LOG) << "JPEG lossless transform failed for" << src;
 
-            // See bug 320107 : if lossless transform cannot be achieve, do lossy transform.
+            // See bug 320107 : if lossless transform cannot be achieve,
+            // do lossy transform if enabled in the settings.
+
+            if (!(behavior & MetaEngineSettingsContainer::RotateByLossyRotation))
+            {
+                removeLater << tempFile;
+                ret = false;
+                break;
+            }
 
             DImg srcImg;
 
-            qCDebug(DIGIKAM_GENERAL_LOG) << "Trying lossy transform for " << src;
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Trying lossy transform for" << src;
 
             if (!srcImg.load(src))
             {
-                QFile::remove(tempFile);
-                return false;
+                removeLater << tempFile;
+                ret = false;
+                break;
             }
 
             if (actions[i] != MetaEngineRotation::NoTransformation)
@@ -477,11 +498,12 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
             {
                 qCDebug(DIGIKAM_GENERAL_LOG) << "Lossy transform failed for" << src;
 
-                QFile::remove(tempFile);
-                return false;
+                removeLater << tempFile;
+                ret = false;
+                break;
             }
 
-            qCDebug(DIGIKAM_GENERAL_LOG) << "Lossy transform done for " << src;
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Lossy transform done for" << src;
         }
 
         if (i + 1 != actions.size())
@@ -513,8 +535,11 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
 
             if (!QFile::rename(sidecarTemp, sidecarDest))
             {
-                qCDebug(DIGIKAM_GENERAL_LOG) << "Renaming sidecar file" << sidecarTemp << "to" << sidecarDest << "failed";
+                qCDebug(DIGIKAM_GENERAL_LOG) << "Renaming sidecar file" << sidecarTemp
+                                             << "to" << sidecarDest << "failed";
+
                 removeLater << sidecarTemp;
+                ret = false;
                 break;
             }
         }
@@ -528,23 +553,26 @@ bool JpegRotator::exifTransform(const MetaEngineRotation& matrix)
 
         if (!QFile::rename(tempFile, dest))
         {
-            qCDebug(DIGIKAM_GENERAL_LOG) << "Renaming" << tempFile << "to" << dest << "failed";
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Renaming" << tempFile
+                                         << "to" << dest << "failed";
+
             removeLater << tempFile;
+            ret = false;
             break;
         }
     }
 
-    foreach (const QString& tempFile, removeLater)
+    Q_FOREACH (const QString& temp, removeLater)
     {
-        QFile::remove(tempFile);
+        QFile::remove(temp);
     }
 
-    return true;
+    return ret;
 }
 
 void JpegRotator::updateMetadata(const QString& fileName, const MetaEngineRotation &matrix)
 {
-    QMatrix qmatrix = matrix.toMatrix();
+    QTransform qmatrix = matrix.toTransform();
     QRect r(QPoint(0, 0), m_originalSize);
     QSize newSize   = qmatrix.mapRect(r).size();
 
@@ -556,7 +584,7 @@ void JpegRotator::updateMetadata(const QString& fileName, const MetaEngineRotati
 
     // Update the image thumbnail.
 
-    QImage exifThumb = m_metadata->getExifThumbnail(true);
+    QImage exifThumb = m_metadata->getExifThumbnail(false);
 
     if (!exifThumb.isNull())
     {
@@ -714,6 +742,17 @@ bool JpegRotator::performJpegTransform(TransformAction action, const QString& sr
 
 #else
 
+    if (((srcinfo.image_width % 8) != 0) || ((srcinfo.image_height % 8) != 0))
+    {
+        qCDebug(DIGIKAM_GENERAL_LOG) << "ExifRotate: Transformation is not perfect";
+        jpeg_destroy_decompress(&srcinfo);
+        jpeg_destroy_compress(&dstinfo);
+        fclose(input_file);
+        fclose(output_file);
+
+        return false;
+    }
+
     jtransform_request_workspace(&srcinfo, &transformoption);
 
 #endif
@@ -826,12 +865,28 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
             image.setAttribute(QLatin1String("quality"), 100);    // LossLess
         }
 
+        if (format.toUpper() == QLatin1String("JXL"))
+        {
+            image.setAttribute(QLatin1String("quality"), 100);    // LossLess
+        }
+
+        if (format.toUpper() == QLatin1String("WEBP"))
+        {
+            image.setAttribute(QLatin1String("quality"), 100);    // LossLess
+        }
+
+        if (format.toUpper() == QLatin1String("AVIF"))
+        {
+            image.setAttribute(QLatin1String("quality"), 100);    // LossLess
+        }
+
         if (format.toUpper() == QLatin1String("PGF"))
         {
             image.setAttribute(QLatin1String("quality"), 0);      // LossLess
         }
 
-        if ((format.toUpper() == QLatin1String("HEIF")) || (format.toUpper() == QLatin1String("HEIC")))
+        if ((format.toUpper() == QLatin1String("HEIF")) || (format.toUpper() == QLatin1String("HEIC")) ||
+            (format.toUpper() == QLatin1String("HIF")))
         {
             image.setAttribute(QLatin1String("quality"), 0);      // LossLess
         }
