@@ -6,20 +6,11 @@
  * Date        : 2006-02-23
  * Description : item metadata interface - comments helpers.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011      by Leif Huhn <leif at dkstat dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011      by Leif Huhn <leif at dkstat dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,11 +31,6 @@ namespace Digikam
 
 CaptionsMap DMetadata::getItemComments(const DMetadataSettingsContainer& settings) const
 {
-    if (getFilePath().isEmpty())
-    {
-        return CaptionsMap();
-    }
-
     CaptionsMap            captionsMap;
     MetaEngine::AltLangMap authorsMap;
     MetaEngine::AltLangMap datesMap;
@@ -58,7 +44,7 @@ CaptionsMap DMetadata::getItemComments(const DMetadataSettingsContainer& setting
         authorsMap = getXmpTagStringListLangAlt("Xmp.digiKam.CaptionsAuthorNames",    false);
         datesMap   = getXmpTagStringListLangAlt("Xmp.digiKam.CaptionsDateTimeStamps", false);
 
-        if (authorsMap.isEmpty() && commonAuthor.isEmpty())
+        if (authorsMap.isEmpty())
         {
             QString xmpAuthors = getXmpTagString("Xmp.acdsee.author", false);
 
@@ -84,7 +70,7 @@ CaptionsMap DMetadata::getItemComments(const DMetadataSettingsContainer& setting
     bool iptcSupported = hasIptc();
     bool exivSupported = hasExif();
 
-    foreach (const NamespaceEntry& entry, settings.getReadMapping(NamespaceEntry::DM_COMMENT_CONTAINER()))
+    Q_FOREACH (const NamespaceEntry& entry, settings.getReadMapping(NamespaceEntry::DM_COMMENT_CONTAINER()))
     {
         if (entry.isDisabled)
         {
@@ -163,7 +149,15 @@ CaptionsMap DMetadata::getItemComments(const DMetadataSettingsContainer& setting
             {
                 if (exivSupported)
                 {
-                    commentString = getExifComment();
+                    commentString = getExifTagComment(nameSpace);
+
+                    if (commentString.isEmpty() && !entry.alternativeName.isEmpty())
+                    {
+                        const std::string altStr   = entry.alternativeName.toStdString();
+                        const char* alternateSpace = altStr.data();
+
+                        commentString              = getExifTagComment(alternateSpace);
+                    }
                 }
 
                 break;
@@ -349,7 +343,31 @@ bool DMetadata::setItemComments(const CaptionsMap& comments, const DMetadataSett
 
             case NamespaceEntry::EXIF:
             {
-                if (!setExifComment(defaultComment))
+                if (entry.namespaceName == QLatin1String("Exif.Image.XPComment"))
+                {
+                    if      (writeWithExifTool() && !defaultComment.isEmpty())
+                    {
+                        QByteArray xpData  = QByteArray((char*)defaultComment.utf16(), defaultComment.size() * 2);
+                        xpData.append("\x00\x00");
+
+                        if (!setExifTagData(nameSpace, xpData))
+                        {
+                            return false;
+                        }
+                    }
+                    else if (removeExifTag(nameSpace))
+                    {
+                        qCDebug(DIGIKAM_METAENGINE_LOG) << "Remove image comment" << nameSpace;
+                    }
+                }
+                else if (entry.namespaceName == QLatin1String("Exif.Photo.UserComment"))
+                {
+                    if (!setExifComment(defaultComment, false))
+                    {
+                        return false;
+                    }
+                }
+                else if (!setExifTagString(nameSpace, defaultComment))
                 {
                     return false;
                 }
@@ -369,11 +387,6 @@ bool DMetadata::setItemComments(const CaptionsMap& comments, const DMetadataSett
 
 CaptionsMap DMetadata::getItemTitles(const DMetadataSettingsContainer& settings) const
 {
-    if (getFilePath().isEmpty())
-    {
-        return CaptionsMap();
-    }
-
     CaptionsMap            captionsMap;
     MetaEngine::AltLangMap authorsMap;
     MetaEngine::AltLangMap datesMap;
@@ -393,8 +406,9 @@ CaptionsMap DMetadata::getItemTitles(const DMetadataSettingsContainer& settings)
 
     bool xmpSupported  = hasXmp();
     bool iptcSupported = hasIptc();
+    bool exivSupported = hasExif();
 
-    foreach (const NamespaceEntry& entry, settings.getReadMapping(NamespaceEntry::DM_TITLE_CONTAINER()))
+    Q_FOREACH (const NamespaceEntry& entry, settings.getReadMapping(NamespaceEntry::DM_TITLE_CONTAINER()))
     {
         if (entry.isDisabled)
         {
@@ -450,6 +464,16 @@ CaptionsMap DMetadata::getItemTitles(const DMetadataSettingsContainer& settings)
                 break;
             }
 
+            case NamespaceEntry::EXIF:
+            {
+                if (exivSupported)
+                {
+                    titleString = getExifTagString(nameSpace);
+                }
+
+                break;
+            }
+
             default:
             {
                 break;
@@ -477,8 +501,9 @@ CaptionsMap DMetadata::getItemTitles(const DMetadataSettingsContainer& settings)
 
 bool DMetadata::setItemTitles(const CaptionsMap& titles, const DMetadataSettingsContainer& settings) const
 {
-    //qCDebug(DIGIKAM_METAENGINE_LOG) << getFilePath() << " ==> Title: " << titles;
-
+/*
+    qCDebug(DIGIKAM_METAENGINE_LOG) << getFilePath() << " ==> Title: " << titles;
+*/
     QString defaultTitle          = titles[QLatin1String("x-default")].caption;
     QList<NamespaceEntry> toWrite = settings.getReadMapping(NamespaceEntry::DM_TITLE_CONTAINER());
 
@@ -580,6 +605,33 @@ bool DMetadata::setItemTitles(const CaptionsMap& titles, const DMetadataSettings
                 break;
             }
 
+            case NamespaceEntry::EXIF:
+            {
+                if (entry.namespaceName == QLatin1String("Exif.Image.XPTitle"))
+                {
+                    if      (writeWithExifTool() && !defaultTitle.isEmpty())
+                    {
+                        QByteArray xpData  = QByteArray((char*)defaultTitle.utf16(), defaultTitle.size() * 2);
+                        xpData.append("\x00\x00");
+
+                        if (!setExifTagData(nameSpace, xpData))
+                        {
+                            return false;
+                        }
+                    }
+                    else if (removeExifTag(nameSpace))
+                    {
+                        qCDebug(DIGIKAM_METAENGINE_LOG) << "Remove image title" << nameSpace;
+                    }
+                }
+                else if (!setExifTagString(nameSpace, defaultTitle))
+                {
+                    return false;
+                }
+
+                break;
+            }
+
             default:
             {
                 break;
@@ -599,7 +651,16 @@ MetaEngine::AltLangMap DMetadata::toAltLangMap(const QVariant& var)
         return map;
     }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    switch (var.typeId())
+
+#else
+
     switch (var.type())
+
+#endif
+
     {
         case QVariant::String:
         {
