@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Internal private container.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -89,6 +89,7 @@
 #   define AutoPtr UniquePtr
 #   define AnyError Error
 #   define kerErrorMessage ErrorCode::kerErrorMessage
+#   include <exiv2/photoshop.hpp>
 #endif
 
 #if EXIV2_TEST_VERSION(0,27,4)
@@ -130,8 +131,11 @@ public:
 
     bool saveToXMPSidecar(const QFileInfo& finfo)                                 const;
     bool saveToFile(const QFileInfo& finfo)                                       const;
-    bool saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::AutoPtr image)      const;
-    bool saveUsingExifTool(const QFileInfo& finfo)                                const;
+    bool saveUsingExiv2(const QFileInfo& finfo,
+                        const QDateTime& modTime,
+                        Exiv2::Image::AutoPtr image)                              const;
+    bool saveUsingExifTool(const QFileInfo& finfo,
+                           const QDateTime& modTime)                              const;
 
     bool exportChanges(const QString& exvTmpFile)                                 const;
 
@@ -150,15 +154,22 @@ public:
      */
     bool isUtf8(const char* const buffer)                                         const;
 
+    /**
+     * Decodes Latitude or Longitude from EXIF tag name.
+     */
+    bool decodeGPSCoordinate(const char* exifTagName, double* const coordinate)   const;
+
     int getXMPTagsListFromPrefix(const QString& pf, MetaEngine::TagsMap& tagsMap) const;
 
-    const Exiv2::ExifData& exifMetadata()                                         const;
-    const Exiv2::IptcData& iptcMetadata()                                         const;
-    const std::string&     itemComments()                                         const;
+    const Exiv2::ExifData&  exifMetadata()                                        const;
+    const Exiv2::IptcData&  iptcMetadata()                                        const;
+    const std::string&      itemComments()                                        const;
+    const Exiv2::ByteOrder& exifByteOrder()                                       const;
 
-    Exiv2::ExifData&       exifMetadata();
-    Exiv2::IptcData&       iptcMetadata();
-    std::string&           itemComments();
+    Exiv2::ExifData&        exifMetadata();
+    Exiv2::IptcData&        iptcMetadata();
+    std::string&            itemComments();
+    Exiv2::ByteOrder&       exifByteOrder();
 
 public:
 
@@ -194,25 +205,25 @@ public:
 
 public:
 
-    bool                                                  writeWithExifTool;
-    bool                                                  writeRawFiles;
-    bool                                                  writeDngFiles;
-    bool                                                  updateFileTimeStamp;
+    bool                                                  writeWithExifTool         = false;
+    bool                                                  writeRawFiles             = false;
+    bool                                                  writeDngFiles             = false;
+    bool                                                  updateFileTimeStamp       = false;
 
-    bool                                                  useXMPSidecar4Reading;
-    bool                                                  useCompatibleFileName;
+    bool                                                  useXMPSidecar4Reading     = false;
+    bool                                                  useCompatibleFileName     = false;
 
     /// A mode from #MetadataWritingMode enum.
-    int                                                   metadataWritingMode;
+    int                                                   metadataWritingMode       = WRITE_TO_FILE_ONLY;
 
     /// XMP, and parts of EXIF/IPTC, were loaded from an XMP sidecar file
-    bool                                                  loadedFromSidecar;
+    bool                                                  loadedFromSidecar         = false;
 
     QString                                               filePath;
     QSize                                                 pixelSize;
     QString                                               mimeType;
 
-    MetaEngine*                                           parent;
+    MetaEngine*                                           parent                    = nullptr;
 
     QExplicitlySharedDataPointer<MetaEngineData::Private> data;
 };
