@@ -6,7 +6,7 @@
  * Date        : 2020-11-28
  * Description : ExifTool process stream parser.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -66,7 +66,7 @@ bool ExifToolParser::load(const QString& path)
 */
 
     cmdArgs << d->filePathEncoding(fileInfo);
-    d->currentPath  = fileInfo.filePath();
+    d->currentPath = fileInfo.filePath();
 
     return (d->startProcess(cmdArgs, ExifToolProcess::LOAD_METADATA));
 }
@@ -142,7 +142,9 @@ bool ExifToolParser::applyChanges(const QString& path, const ExifToolData& newTa
     return (d->startProcess(cmdArgs, ExifToolProcess::APPLY_CHANGES));
 }
 
-bool ExifToolParser::applyChanges(const QString& path, const QString& exvTempFile, bool hasExif, bool hasIptcCSet)
+bool ExifToolParser::applyChanges(const QString& path,
+                                  const QString& exvTempFile,
+                                  bool hasExif, bool hasXmp, bool hasCSet)
 {
     if (exvTempFile.isEmpty())
     {
@@ -160,21 +162,73 @@ bool ExifToolParser::applyChanges(const QString& path, const QString& exvTempFil
 
     d->prepareProcess();
 
+    // QMimeDatabase mimeDB;
     QByteArrayList cmdArgs;
-    QString suffix(fileInfo.suffix().toUpper());
+/*
+    QString suffix = fileInfo.suffix().toUpper();
 
-    if (suffix != QLatin1String("JXL"))
+    bool isJXLFile = (suffix == QLatin1String("JXL"));
+
+    bool isVideo   = (mimeDB.mimeTypeForFile(fileInfo).name().startsWith(QLatin1String("video/")));
+
+    if (isVideo)
+    {
+        cmdArgs << QByteArray("-api");
+        cmdArgs << QByteArray("QuickTimeHandler=1");
+        cmdArgs << QByteArray("-itemlist:title=");
+        cmdArgs << QByteArray("-itemlist:comment=");
+        cmdArgs << QByteArray("-microsoft:category=");
+        cmdArgs << QByteArray("-itemlist:description=");
+    }
+*/
+    if (hasExif)
+    {
+        cmdArgs << QByteArray("-ifd0:all=");
+        cmdArgs << QByteArray("-gps:all=");
+    }
+    else
+    {
+        cmdArgs << QByteArray("-exif:all=");
+    }
+
+    cmdArgs << QByteArray("-iptc:all=");
+    cmdArgs << QByteArray("-file:comment=");
+
+    if (hasXmp)
+    {
+        cmdArgs << QByteArray("-xmp-dc:all=");
+        cmdArgs << QByteArray("-xmp-lr:all=");
+        cmdArgs << QByteArray("-xmp-mp:all=");
+        cmdArgs << QByteArray("-xmp-xmp:all=");
+        cmdArgs << QByteArray("-xmp-exif:all=");
+        cmdArgs << QByteArray("-xmp-tiff:all=");
+        cmdArgs << QByteArray("-xmp-xmpdm:all=");
+        cmdArgs << QByteArray("-xmp-acdsee:all=");
+        cmdArgs << QByteArray("-xmp-mwg-rs:all=");
+        cmdArgs << QByteArray("-xmp-digikam:all=");
+        cmdArgs << QByteArray("-xmp-mediapro:all=");
+        cmdArgs << QByteArray("-xmp-iptccore:all=");
+        cmdArgs << QByteArray("-xmp-microsoft:all=");
+        cmdArgs << QByteArray("-xmp-photoshop:all=");
+    }
+    else
     {
         cmdArgs << QByteArray("-xmp:all=");
-        cmdArgs << QByteArray("-exif:all=");
-        cmdArgs << QByteArray("-iptc:all=");
     }
 
     cmdArgs << QByteArray("-TagsFromFile");
     cmdArgs << d->filePathEncoding(QFileInfo(exvTempFile));
     cmdArgs << QByteArray("-all:all");
-
-    if (hasIptcCSet)
+/*
+    if (isVideo)
+    {
+        cmdArgs << QByteArray("-itemlist:title<xmp:title");
+        cmdArgs << QByteArray("-microsoft:category<xmp:tagslist");
+        cmdArgs << QByteArray("-itemlist:comment<xmp:description");
+        cmdArgs << QByteArray("-itemlist:description<xmp:description");
+    }
+*/
+    if (hasCSet)
     {
         cmdArgs << QByteArray("-codedcharacterset=UTF8");
     }
@@ -193,6 +247,45 @@ bool ExifToolParser::applyChanges(const QString& path, const QString& exvTempFil
     return (d->startProcess(cmdArgs, ExifToolProcess::APPLY_CHANGES_EXV));
 }
 
+bool ExifToolParser::applyMetadataFile(const QString& path, const QString& meta)
+{
+    QFileInfo metaInfo(meta);
+
+    if (!metaInfo.exists())
+    {
+        qCWarning(DIGIKAM_METAENGINE_LOG) << "Metadata file to apply with ExifTool not exists";
+        return false;
+    }
+
+    QFileInfo fileInfo(path);
+
+    if (!fileInfo.exists())
+    {
+        qCCritical(DIGIKAM_GENERAL_LOG) << "Cannot open source file to process with ExifTool...";
+        return false;
+    }
+
+    d->prepareProcess();
+
+    QByteArrayList cmdArgs;
+
+    if (metaInfo.suffix().toUpper() == QLatin1String("JSON"))
+    {
+        cmdArgs << (QByteArray("-json=") + d->filePathEncoding(metaInfo));
+    }
+    else
+    {
+        cmdArgs << QByteArray("-TagsFromFile");
+        cmdArgs << d->filePathEncoding(metaInfo);
+        cmdArgs << QByteArray("-all:all");
+    }
+
+    cmdArgs << QByteArray("-overwrite_original");
+    cmdArgs << d->filePathEncoding(fileInfo);
+
+    return (d->startProcess(cmdArgs, ExifToolProcess::APPLY_METADATA_FILE));
+}
+
 bool ExifToolParser::readableFormats()
 {
     d->prepareProcess();
