@@ -6,7 +6,7 @@
  * Date        : 2020-11-28
  * Description : ExifTool process stream parser.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -112,7 +112,7 @@ void ExifToolParser::cmdCompleted(const ExifToolProcess::Result& result)
                 QVariantMap propsMap = it.value().toMap();
                 QString data;
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
                 if (propsMap.find(QLatin1String("val")).value().typeId() == QVariant::List)
 
@@ -192,6 +192,12 @@ void ExifToolParser::cmdCompleted(const ExifToolProcess::Result& result)
             break;
         }
 
+        case ExifToolProcess::APPLY_METADATA_FILE:
+        {
+            printExifToolOutput(result.output);
+            break;
+        }
+
         case ExifToolProcess::COPY_TAGS:
         {
             printExifToolOutput(result.output);
@@ -325,8 +331,13 @@ void ExifToolParser::cmdCompleted(const ExifToolProcess::Result& result)
                                         }
                                         else if (e2.tagName() == QLatin1String("tag"))           // One tag from group
                                         {
+                                            QString a1   = e2.attribute(QLatin1String("g1"));
+                                            QString a2   = e2.attribute(QLatin1String("g2"));
                                             QString name = e2.attribute(QLatin1String("name"));
-                                            tag          = QString::fromLatin1("%1.%2.%3.%4").arg(g0).arg(g1).arg(g2).arg(name);
+                                            tag          = QString::fromLatin1("%1.%2.%3.%4").arg(g0)
+                                                                                             .arg(a1.isNull() ? g1 : a1)
+                                                                                             .arg(a2.isNull() ? g2 : a2)
+                                                                                             .arg(name);
                                             type         = e2.attribute(QLatin1String("type"));
                                             writable     = e2.attribute(QLatin1String("writable"));
 
