@@ -8,31 +8,21 @@
  *               Based on ZExifTool Qt interface published at 18 Feb 2021
  *               https://github.com/philvl/ZExifTool
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (c) 2021 by Philippe Vianney Liaud <philvl dot dev at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021 by Philippe Vianney Liaud <philvl dot dev at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #ifndef DIGIKAM_EXIFTOOL_PROCESS_H
 #define DIGIKAM_EXIFTOOL_PROCESS_H
 
-// Qt Core
+// Qt includes
 
-#include <QObject>
 #include <QString>
 #include <QProcess>
-#include <QMutex>
+#include <QPointer>
 
 // Local includes
 
@@ -40,8 +30,9 @@
 
 namespace Digikam
 {
+class ExifToolParser;
 
-class DIGIKAM_EXPORT ExifToolProcess : public QObject
+class DIGIKAM_EXPORT ExifToolProcess : public QProcess
 {
     Q_OBJECT
 
@@ -56,6 +47,7 @@ public:
         LOAD_CHUNKS,                                ///< Load Exif, Iptc, and Xmp chunks from a file as byte-array for MetaEngine.
         APPLY_CHANGES,                              ///< Apply tag changes in a file with ExifTool.
         APPLY_CHANGES_EXV,                          ///< Apply tag changes in a file with ExifTool using an EXV container.
+        APPLY_METADATA_FILE,                        ///< Apply a metadata file to a file with ExifTool.
         READ_FORMATS,                               ///< Return the list of readable ExifTool file formats.
         WRITE_FORMATS,                              ///< Return the list of writable ExifTool file formats.
         TRANSLATIONS_LIST,                          ///< List of ExifTool languages available for translations.
@@ -103,12 +95,45 @@ public:
         TRANS_ALL_EXIF      = 0x04                  ///< Translate all existing Tags from source file to Exif.
     };
 
+    /**
+     * Command result state.
+     */
+    enum ResultStatus
+    {
+        COMMAND_RESULT      = 0,
+        FINISH_RESULT,
+        ERROR_RESULT
+    };
+
+public:
+
+    class Result
+    {
+    public:
+
+        Result()
+          : waitError (false),
+            cmdStatus (ExifToolProcess::COMMAND_RESULT),
+            cmdAction (ExifToolProcess::NO_ACTION),
+            cmdNumber (0),
+            elapsed   (0)
+        {
+        }
+
+        bool       waitError;
+        int        cmdStatus;
+        int        cmdAction;
+        int        cmdNumber;
+        int        elapsed;
+        QByteArray output;
+    };
+
 public:
 
     /**
-     * Constructs a ExifToolProcess object with the given parent.
+     * Constructs a ExifToolProcess.
      */
-    explicit ExifToolProcess(QObject* const parent);
+    explicit ExifToolProcess();
 
     /**
      * Destructs the ExifToolProcess object, i.e., killing the process.
@@ -116,125 +141,122 @@ public:
      */
     ~ExifToolProcess();
 
+    /**
+     * @brief internalPtr - singleton implementation
+     */
+    static QPointer<ExifToolProcess> internalPtr;
+    static ExifToolProcess*          instance();
+    static bool                      isCreated();
+
+    /**
+     * Setup connections, apply Settings and start ExifTool process.
+     * This function cannot be called from another thread.
+     */
+    void initExifTool();
+
 public:
 
     /**
-     * Setup the ExifTool configuration. This function must be called before start().
+     * Change the ExifTool path configuration.
+     * This function can be called from another thread.
      */
-    void setProgram(const QString& etExePath,
-                    const QString& perlExePath = QString());
+    void setExifToolProgram(const QString& etExePath);
 
-    QString program() const;
+    QString getExifToolProgram()                             const;
 
-    bool checkExifToolProgram();
+public:
+
+    /**
+     * Returns true if ExifToolProcess is available (process state == Running)
+     */
+    bool                    exifToolAvailable()              const;
+
+    /**
+     * Returns true if a command is running.
+     */
+    bool                    exifToolIsBusy()                 const;
+
+    /**
+     * Returns the type of error that occurred last.
+     */
+    QProcess::ProcessError  exifToolError()                  const;
+
+    /**
+     * Returns an error message.
+     */
+    QString                 exifToolErrorString()            const;
+
+    /**
+     * Returns the ExifToolProcess result.
+     */
+    ExifToolProcess::Result getExifToolResult(int cmdId)     const;
+
+    /**
+     * WatCondition for the ExifToolParser class.
+     * Returns the ExifToolProcess result.
+     */
+    ExifToolProcess::Result waitForExifToolResult(int cmdId) const;
+
+    /**
+     * Send a command to exiftool process.
+     * This function can be called from another thread.
+     * Return 0: ExitTool not running, write channel is closed or args is empty.
+     */
+    int command(const QByteArrayList& args, Action ac);
+
+Q_SIGNALS:
+
+    void signalExifToolResult(int cmdId);
+
+private:
 
     /**
      * Starts exiftool in a new process.
      */
-    bool start();
+    bool startExifTool();
+
+    /**
+     * Restart exiftool in a new process.
+     */
+    void restartExifTool();
 
     /**
      * Attempts to terminate the process.
      */
-    void terminate();
+    void terminateExifTool();
 
     /**
      * Kills the current process, causing it to exit immediately.
      * On Windows, kill() uses TerminateProcess, and on Unix and macOS,
      * the SIGKILL signal is sent to the process.
      */
-    void kill();
+    void killExifTool();
 
-public:
+    QString exifToolBin()                                    const;
 
-    /**
-     * Returns true if ExifToolProcess is running (process state == Running)
-     */
-    bool                   isRunning()                  const;
+    bool checkExifToolProgram()                              const;
 
-    /**
-     * Returns true if a command is running
-     */
-    bool                   isBusy()                     const;
-
-    /**
-     * Returns the native process identifier for the running process, if available.
-     * If no process is currently running, 0 is returned.
-     */
-    qint64                 processId()                  const;
-
-    /**
-     * Returns the current state of the process.
-     */
-    QProcess::ProcessState state()                      const;
-
-    /**
-     * Returns the type of error that occurred last.
-     */
-    QProcess::ProcessError error()                      const;
-
-    /**
-     * Returns an error message.
-     */
-    QString                errorString()                const;
-
-    /**
-     * Returns the exit status of the last process that finished.
-     */
-    QProcess::ExitStatus   exitStatus()                 const;
-
-    int                    exitCode()                   const;
-
-    /**
-     * Blocks until the process has started and the started() signal has been emitted,
-     * or until msecs milliseconds have passed.
-     */
-    bool waitForStarted(int msecs = 30000)              const;
-
-    /**
-     * Blocks until the process has finished and the finished() signal has been emitted,
-     * or until msecs milliseconds have passed.
-     */
-    bool waitForFinished(int msecs = 30000)             const;
-
-    /**
-     * Send a command to exiftool process
-     * Return 0: ExitTool not running, write channel is closed or args is empty
-     */
-    int command(const QByteArrayList& args, Action ac);
+    void changeExifToolProgram(const QString& etExePath);
 
 Q_SIGNALS:
 
-    void signalStarted(int cmdAction);
-
-    void signalStateChanged(int cmdAction,
-                            QProcess::ProcessState newState);
-
-    void signalErrorOccurred(int cmdAction,
-                             QProcess::ProcessError error);
-
-    void signalFinished(int cmdAction,
-                        int exitCode,
-                        QProcess::ExitStatus exitStatus);
-
-    void signalCmdCompleted(int cmdAction,
-                            int execTime,
-                            const QByteArray& cmdOutputChannel,
-                            const QByteArray& cmdErrorChannel);
+    void signalExecNextCmd();
+    void signalChangeProgram(const QString& etExePath);
 
 private Q_SLOTS:
 
     void slotStarted();
-    void slotStateChanged(QProcess::ProcessState newState);
-    void slotErrorOccurred(QProcess::ProcessError error);
-    void slotReadyReadStandardOutput();
+    void slotApplySettingsAndStart();
     void slotReadyReadStandardError();
-    void slotFinished(int exitCode,
-                      QProcess::ExitStatus exitStatus);
+    void slotReadyReadStandardOutput();
+    void slotChangeProgram(const QString& etExePath);
+    void slotErrorOccurred(QProcess::ProcessError error);
+    void slotFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 private:
 
-    QString exifToolBin()                               const;
+    // Disable
+    explicit ExifToolProcess(QObject*) = delete;
 
 private:
 
