@@ -6,7 +6,7 @@
  * Date        : 2009-05-29
  * Description : static helper methods for PGF image format.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -29,8 +29,6 @@ extern "C"
 
 // Qt includes
 
-#include <QImage>
-#include <QByteArray>
 #include <QFile>
 #include <qplatformdefs.h>
 
@@ -384,7 +382,9 @@ bool writePGFImageDataToStream(const QImage& image,
 #   endif
 
 #else
+
         pgfImg.Write(&stream, 0, 0, &nWrittenBytes);
+
 #endif
 
     }
@@ -407,6 +407,7 @@ bool writePGFImageDataToStream(const QImage& image,
 
 bool loadPGFScaled(QImage& img, const QString& path, int maximumSize)
 {
+
 #ifdef Q_OS_WIN
 
     FILE* const file = _wfopen((const wchar_t*)path.utf16(), L"rb");
@@ -522,6 +523,17 @@ bool loadPGFScaled(QImage& img, const QString& path, int maximumSize)
             int map[] = {0, 1, 2, 3};
             pgf.GetBitmap(img.bytesPerLine(), (UINT8*)img.bits(), img.depth(), map);
         }
+
+#ifdef Q_OS_WIN
+
+        CloseHandle(fd);
+
+#else
+
+        close(fd);
+
+#endif
+
     }
     catch (IOException& e)
     {
@@ -534,6 +546,16 @@ bool loadPGFScaled(QImage& img, const QString& path, int maximumSize)
 
         qCDebug(DIGIKAM_GENERAL_LOG) << "PGFUtils: Error running libpgf (" << err << ")!";
 
+#ifdef Q_OS_WIN
+
+        CloseHandle(fd);
+
+#else
+
+        close(fd);
+
+#endif
+
         return false;
     }
 
