@@ -6,7 +6,7 @@
  * Date        : 2008-10-09
  * Description : internal private container for DRawDecoder
  *
- * SPDX-FileCopyrightText: 2008-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,7 +17,6 @@
 // Qt includes
 
 #include <QString>
-#include <QFile>
 #include <QScopedPointer>
 
 // DNG SDK includes
@@ -28,8 +27,6 @@
 
 // Local includes
 
-#include "digikam_debug.h"
-#include "digikam_config.h"
 #include "metaengine.h"
 
 namespace Digikam
@@ -59,8 +56,7 @@ void s_exifParserCallbackForLibRaw(void* context, int tag, int type, int len, un
 // --------------------------------------------------------------------------------------------------
 
 DRawDecoder::Private::Private(DRawDecoder* const p)
-    : m_progress(0.0),
-      m_parent  (p)
+    : m_parent(p)
 {
 }
 
