@@ -7,7 +7,7 @@
  * Description : application settings interface
  *
  * SPDX-FileCopyrightText: 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2007      by Arnd Baecker <arnd dot baecker at web dot de>
  * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
@@ -34,6 +34,7 @@
 #include "dbengineparameters.h"
 #include "versionmanager.h"
 #include "digikam_export.h"
+#include "haariface.h"
 
 class KConfigGroup;
 
@@ -164,9 +165,6 @@ public:
     void setAlbumSortRole(const AlbumSortRole role);
     AlbumSortRole getAlbumSortRole() const;
 
-    void setAlbumSortChanged(bool val);
-    bool getAlbumSortChanged() const;
-
     void setShowFolderTreeViewItemsCount(bool val);
     bool getShowFolderTreeViewItemsCount() const;
 
@@ -275,6 +273,9 @@ public:
     void setPreviewShowIcons(bool val);
     bool getPreviewShowIcons() const;
 
+    void setScaleFitToWindow(bool val);
+    bool getScaleFitToWindow() const;
+
     // -- Mime-Types Settings -------------------------------------------------------
 
     QString getImageFileFilter() const;
@@ -547,6 +548,9 @@ public:
     void setDuplicatesAlbumTagRelation(int val);
     int  getDuplicatesAlbumTagRelation() const;
 
+    void setDuplicatesReferenceImageSelectionMethod(HaarIface::RefImageSelMethod val);
+    HaarIface::RefImageSelMethod getDuplicatesRefImageSelMethod() const;
+
     void setDuplicatesSearchRestrictions(int val);
     int  getDuplicatesSearchRestrictions() const;
 
