@@ -6,7 +6,7 @@
  * Date        : 2008-12-10
  * Description : misc file operation methods
  *
- * SPDX-FileCopyrightText: 2014-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -21,12 +21,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#ifndef Q_CC_MSVC
-#   include <utime.h>
-#else
-#   include <sys/utime.h>
-#endif
-
 // Qt includes
 
 #include <QByteArray>
@@ -42,6 +36,7 @@
 #include <QStandardPaths>
 #include <qplatformdefs.h>
 #include <QRegularExpression>
+#include <QProcessEnvironment>
 
 #ifdef HAVE_DBUS
 #   include <QDBusInterface>
@@ -148,6 +143,8 @@ void DFileOperations::openFilesWithDefaultApplication(const QList<QUrl>& urls)
 
 #ifdef Q_OS_LINUX
 
+#   ifdef HAVE_KIO
+
     KService::List offers = DServiceMenu::servicesForOpenWith(urls);
 
     if (!offers.isEmpty())
@@ -158,6 +155,8 @@ void DFileOperations::openFilesWithDefaultApplication(const QList<QUrl>& urls)
         return;
     }
 
+#   endif // HAVE_KIO
+
 #endif
 
     Q_FOREACH (const QUrl& url, urls)
@@ -387,17 +386,22 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
                                             const QString& dstPath,
                                             const QString& itemId,
                                             bool* const cancel,
-                                            bool  countTotal)
+                                            bool  useDstPath)
 {
     QDir srcDir(srcPath);
-    QString newCopyPath = dstPath + QLatin1Char('/') + srcDir.dirName();
+    QString newCopyPath = dstPath;
+
+    if (!useDstPath)
+    {
+        newCopyPath += QLatin1Char('/') + srcDir.dirName();
+    }
 
     if (!srcDir.mkpath(newCopyPath))
     {
         return false;
     }
 
-    if (countTotal && !itemId.isEmpty())
+    if (!itemId.isEmpty())
     {
         int count = 0;
 
@@ -479,27 +483,12 @@ bool DFileOperations::renameFile(const QString& srcFile,
         return true;
     }
 
-#ifdef Q_OS_WIN64
+    QFileInfo srcInfo(srcFile);
+    QDateTime birDateTime = srcInfo.fileTime(QFileDevice::FileBirthTime);
+    QDateTime accDateTime = srcInfo.fileTime(QFileDevice::FileAccessTime);
+    QDateTime modDateTime = srcInfo.fileTime(QFileDevice::FileModificationTime);
 
-    struct __utimbuf64 ut;
-    struct __stat64    st;
-    int stat = _wstat64((const wchar_t*)srcFile.utf16(), &st);
-
-#elif defined Q_OS_WIN
-
-    struct _utimbuf    ut;
-    struct _stat       st;
-    int stat = _wstat((const wchar_t*)srcFile.utf16(), &st);
-
-#else
-
-    struct utimbuf     ut;
-    QT_STATBUF         st;
-    int stat = QT_STAT(srcFile.toUtf8().constData(), &st);
-
-#endif
-
-    bool ret = (!QFileInfo::exists(dstFile));
+    bool ret              = (!QFileInfo::exists(dstFile));
 
     if (ret)
     {
@@ -511,30 +500,34 @@ bool DFileOperations::renameFile(const QString& srcFile,
         }
     }
 
-    if (ret && (stat == 0))
+    if (ret)
     {
-        ut.modtime = st.st_mtime;
-        ut.actime  = st.st_atime;
+        QFile modFile(dstFile);
 
-#ifdef Q_OS_WIN64
-
-        stat       = _wutime64((const wchar_t*)dstFile.utf16(), &ut);
-
-#elif defined Q_OS_WIN
-
-        stat       = _wutime((const wchar_t*)dstFile.utf16(), &ut);
-
-#else
-
-        stat       = ::utime(dstFile.toUtf8().constData(), &ut);
-
-#endif
-
-        if (stat != 0)
+        if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
         {
-            qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to restore modification time for file"
-                                           << dstFile;
+            if (modDateTime.isValid())
+            {
+                modFile.setFileTime(modDateTime, QFileDevice::FileModificationTime);
+            }
+
+            if (accDateTime.isValid())
+            {
+                modFile.setFileTime(accDateTime, QFileDevice::FileAccessTime);
+            }
+
+            if (birDateTime.isValid())
+            {
+                modFile.setFileTime(birDateTime, QFileDevice::FileBirthTime);
+            }
+
+            modFile.close();
+
+            return ret;
         }
+
+        qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to restore modification time for file"
+                                       << dstFile;
     }
 
     return ret;
@@ -560,9 +553,10 @@ bool DFileOperations::copyFile(const QString& srcFile,
 
     if (!dFile.open(QIODevice::WriteOnly | QIODevice::Unbuffered))
     {
-        sFile.close();
         qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to open destination file for writing:" << tmpFile;
 
+        sFile.close();
+
         return false;
     }
 
@@ -574,9 +568,6 @@ bool DFileOperations::copyFile(const QString& srcFile,
     {
         if ((cancel && *cancel) || (len == -1) || (dFile.write(buffer.data(), len) != len))
         {
-            sFile.close();
-            dFile.close();
-
             ret = false;
 
             break;
@@ -610,134 +601,120 @@ bool DFileOperations::copyFile(const QString& srcFile,
 bool DFileOperations::copyModificationTime(const QString& srcFile,
                                            const QString& dstFile)
 {
+    QFileInfo srcInfo(srcFile);
+    QDateTime birDateTime = srcInfo.fileTime(QFileDevice::FileBirthTime);
+    QDateTime accDateTime = srcInfo.fileTime(QFileDevice::FileAccessTime);
+    QDateTime modDateTime = srcInfo.fileTime(QFileDevice::FileModificationTime);
 
-#ifdef Q_OS_WIN64
+    QFile modFile(dstFile);
 
-    struct __utimbuf64 ut;
-    struct __stat64    st;
-    int ret = _wstat64((const wchar_t*)srcFile.utf16(), &st);
-
-#elif defined Q_OS_WIN
-
-    struct _utimbuf    ut;
-    struct _stat       st;
-    int ret = _wstat((const wchar_t*)srcFile.utf16(), &st);
-
-#else
-
-    struct utimbuf     ut;
-    QT_STATBUF         st;
-    int ret = QT_STAT(srcFile.toUtf8().constData(), &st);
-
-#endif
-
-    if (ret == 0)
+    if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
     {
-        ut.modtime = st.st_mtime;
-        ut.actime  = st.st_atime;
+        if (modDateTime.isValid())
+        {
+            modFile.setFileTime(modDateTime, QFileDevice::FileModificationTime);
+        }
 
-#ifdef Q_OS_WIN64
+        if (accDateTime.isValid())
+        {
+            modFile.setFileTime(accDateTime, QFileDevice::FileAccessTime);
+        }
 
-        ret        = _wutime64((const wchar_t*)dstFile.utf16(), &ut);
+        if (birDateTime.isValid())
+        {
+            modFile.setFileTime(birDateTime, QFileDevice::FileBirthTime);
+        }
 
-#elif defined Q_OS_WIN
-
-        ret        = _wutime((const wchar_t*)dstFile.utf16(), &ut);
-
-#else
-
-        ret        = ::utime(dstFile.toUtf8().constData(), &ut);
-
-#endif
+        modFile.close();
 
+        return true;
     }
 
-    if (ret != 0)
-    {
-        qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to restore modification time for file"
-                                       << dstFile;
-        return false;
-    }
+    qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to restore modification time for file"
+                                   << dstFile;
 
-    return true;
+    return false;
 }
 
 bool DFileOperations::setModificationTime(const QString& srcFile,
                                           const QDateTime& dateTime)
 {
-
-#ifdef Q_OS_WIN64
-
-    struct __utimbuf64 ut;
-    struct __stat64    st;
-    int ret = _wstat64((const wchar_t*)srcFile.utf16(), &st);
-
-#elif defined Q_OS_WIN
-
-    struct _utimbuf    ut;
-    struct _stat       st;
-    int ret = _wstat((const wchar_t*)srcFile.utf16(), &st);
-
-#else
-
-    struct utimbuf     ut;
-    QT_STATBUF         st;
-    int ret = QT_STAT(srcFile.toUtf8().constData(), &st);
-
-#endif
-
-    if (ret == 0)
+    if (dateTime.isValid())
     {
-        ut.modtime = dateTime.toSecsSinceEpoch();
-        ut.actime  = st.st_atime;
+        QFile modFile(srcFile);
 
-#ifdef Q_OS_WIN64
-
-        ret        = _wutime64((const wchar_t*)srcFile.utf16(), &ut);
-
-#elif defined Q_OS_WIN
-
-        ret        = _wutime((const wchar_t*)srcFile.utf16(), &ut);
-
-#else
-
-        ret        = ::utime(srcFile.toUtf8().constData(), &ut);
-
-#endif
+        if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
+        {
+            modFile.setFileTime(dateTime, QFileDevice::FileModificationTime);
+            modFile.close();
 
+            return true;
+        }
     }
 
-    if (ret != 0)
-    {
-        qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to set modification time for file"
-                                       << srcFile;
-        return false;
-    }
+    qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to set modification time for file"
+                                   << srcFile;
 
-    return true;
+    return false;
 }
 
 QString DFileOperations::findExecutable(const QString& name)
 {
     QString path;
     QString program = name;
+    program.remove(QLatin1Char('"'));
 
 #ifdef Q_OS_WIN
 
-    program.append(QLatin1String(".exe"));
+    if (!program.endsWith(QLatin1String(".exe"), Qt::CaseInsensitive))
+    {
+        program.append(QLatin1String(".exe"));
+    }
 
-    QSettings settings(QString::fromUtf8("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\"
-                                         "CurrentVersion\\App Paths\\%1").arg(program),
-                                         QSettings::NativeFormat);
+    // We will use Unix file path separators.
 
-    path = settings.value(QLatin1String("Default"), QString()).toString();
+    if (!program.contains(QLatin1Char('/')))
+    {
+        QSettings settings(QString::fromUtf8("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\"
+                                             "CurrentVersion\\App Paths\\%1").arg(program),
+                                             QSettings::NativeFormat);
+
+        path = settings.value(QLatin1String("Default"), QString()).toString();
+    }
+    else
+    {
+        path = QDir::toNativeSeparators(program);
+    }
+
+    if (!path.isEmpty())
+    {
+        QStringList variables({ QLatin1String("SystemRoot"),
+                                QLatin1String("ProgramFiles"),
+                                QLatin1String("ProgramFiles(x86)") });
+        QProcessEnvironment env(QProcessEnvironment::systemEnvironment());
+
+        for (int i = 0 ; i < variables.size() ; ++i)
+        {
+            if (path.contains(QString::fromLatin1("%%1%").arg(variables.at(i))))
+            {
+                path.replace(QString::fromLatin1("%%1%").arg(variables.at(i)),
+                             env.value(variables.at(i)));
+            }
+        }
+
+        qCDebug(DIGIKAM_GENERAL_LOG) << "Resolved file path:" << path;
+
+        if (!QFileInfo::exists(path))
+        {
+            path.clear();
+        }
+
+        return path;
+    }
 
 #endif
 
-    if (path.isEmpty())
-    {
-        path = QStandardPaths::findExecutable(program);
-    }
+    path = QStandardPaths::findExecutable(program);
 
     return path;
 }
