@@ -6,19 +6,11 @@
  * Date        : 2004-05-16
  * Description : time adjust settings widget.
  *
- * Copyright (C) 2012      by Smit Mehta <smit dot meh at gmail dot com>
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (c) 2018      by Maik Qualmann <metzpinguin at gmail dot com>
+ * SPDX-FileCopyrightText: 2012      by Smit Mehta <smit dot meh at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018      by Maik Qualmann <metzpinguin at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -152,7 +144,8 @@ TimeAdjustSettings::TimeAdjustSettings(QWidget* const parent, bool timeAdjustToo
     QVBoxLayout* const vlay = new QVBoxLayout(panel);
     vlay->addWidget(d->settingsExpander);
 
-    const int spacing       = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing       = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     // -- Settings View Used Timestamps ---------------------------------------------------------
 
@@ -165,7 +158,7 @@ TimeAdjustSettings::TimeAdjustSettings(QWidget* const parent, bool timeAdjustToo
 
     if      (appName == QLatin1String("digikam"))
     {
-        appName = i18n("DigiKam");
+        appName = i18n("digiKam");
     }
     else if (appName == QLatin1String("showfoto"))
     {
@@ -190,12 +183,15 @@ TimeAdjustSettings::TimeAdjustSettings(QWidget* const parent, bool timeAdjustToo
 
     d->useMetaDateBtn         = new QRadioButton(QString(), d->useSettingsBox);
     d->useMetaDateTypeChooser = new QComboBox(d->useSettingsBox);
-    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFIPTCXMP,   i18n("EXIF/IPTC/XMP"));
-    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFCREATED,   i18n("EXIF: created"));
-    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFORIGINAL,  i18n("EXIF: original"));
-    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFDIGITIZED, i18n("EXIF: digitized"));
-    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::IPTCCREATED,   i18n("IPTC: created"));
-    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::XMPCREATED,    i18n("XMP: created"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFIPTCXMP,    i18n("EXIF/IPTC/XMP"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFCREATED,    i18n("EXIF: created"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFORIGINAL,   i18n("EXIF: original"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::EXIFDIGITIZED,  i18n("EXIF: digitized"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::IPTCCREATED,    i18n("IPTC: created"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::XMPCREATED,     i18n("XMP: created"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::FUZZYCREATED,   i18n("EXIF: created (fuzzy)"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::FUZZYORIGINAL,  i18n("EXIF: original (fuzzy)"));
+    d->useMetaDateTypeChooser->insertItem(TimeAdjustContainer::FUZZYDIGITIZED, i18n("EXIF: digitized (fuzzy)"));
 
     d->useCustomDateBtn       = new QRadioButton(d->useSettingsBox);
     d->useCustDateInput       = new QDateEdit(d->useSettingsBox);
@@ -313,9 +309,18 @@ TimeAdjustSettings::TimeAdjustSettings(QWidget* const parent, bool timeAdjustToo
 
     // -- Settings View Slots/Signals ----------------------------------------
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+
+    connect(d->useButtonGroup, SIGNAL(idReleased(int)),
+            this, SLOT(slotSrcTimestampChanged()));
+
+#else
+
     connect(d->useButtonGroup, SIGNAL(buttonReleased(int)),
             this, SLOT(slotSrcTimestampChanged()));
 
+#endif
+
     connect(d->useFileDateTypeChooser, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotSrcTimestampChanged()));
 
@@ -518,7 +523,7 @@ void TimeAdjustSettings::detAdjustmentByClockPhotoUrl(const QUrl& url)
         deltaTime.setHMS(dvalues.deltaHours, dvalues.deltaMinutes, dvalues.deltaSeconds);
         d->adjTimeInput->setTime(deltaTime);
 
-        emit signalSettingsChanged();
+        Q_EMIT signalSettingsChanged();
     }
 
     delete dlg;
@@ -547,16 +552,17 @@ void TimeAdjustSettings::slotSrcTimestampChanged()
         d->useCustomDateTodayBtn->setEnabled(true);
     }
 
-    emit signalSettingsChanged();
+    Q_EMIT signalSettingsChanged();
 }
 
 void TimeAdjustSettings::slotResetDateToCurrent()
 {
     QDateTime currentDateTime(QDateTime::currentDateTime());
+    currentDateTime.setTimeSpec(Qt::UTC);
     d->useCustDateInput->setDateTime(currentDateTime);
     d->useCustTimeInput->setDateTime(currentDateTime);
 
-    emit signalSettingsChanged();
+    Q_EMIT signalSettingsChanged();
 }
 
 void TimeAdjustSettings::slotAdjustmentTypeChanged()
@@ -568,7 +574,7 @@ void TimeAdjustSettings::slotAdjustmentTypeChanged()
     d->adjDaysLabel->setEnabled(isAdjustment);
     d->adjTimeInput->setEnabled(isAdjustment);
 
-    emit signalSettingsChanged();
+    Q_EMIT signalSettingsChanged();
 }
 
 void TimeAdjustSettings::slotDetAdjustmentByClockPhotoUrl(const QUrl& url)
@@ -589,3 +595,5 @@ void TimeAdjustSettings::setCurrentItemUrl(const QUrl& url)
 }
 
 } // namespace Digikam
+
+#include "moc_timeadjustsettings.cpp"
