@@ -6,17 +6,9 @@
  * Date        : 2017-05-25
  * Description : a tool to generate video slideshow from images.
  *
- * Copyright (C) 2017-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -31,6 +23,10 @@
 #include <klocalizedstring.h>
 #include <kconfiggroup.h>
 
+// Local includes
+
+#include "digikam_globals.h"
+
 namespace Digikam
 {
 
@@ -46,8 +42,11 @@ VidSlideSettings::VidSlideSettings()
       vFormat       (MP4),
       vEffect       (EffectMngr::None),
       conflictRule  (FileSaveConflictBox::OVERWRITE),
-      outputDir     (QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation))),
-      outputPlayer  (INTERNAL)
+      outputDir     (QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)),
+      outputPlayer  (INTERNAL),
+      equalize      (false),
+      strength      (5),
+      iface         (nullptr)
 {
 }
 
@@ -80,9 +79,17 @@ void VidSlideSettings::readSettings(KConfigGroup& group)
     conflictRule = (FileSaveConflictBox::ConflictRule)group.readEntry("ConflictRule",
                    (int)FileSaveConflictBox::OVERWRITE);
     outputDir    = group.readEntry("OutputDir",
-                   QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)));
+                   QStandardPaths::writableLocation(QStandardPaths::MoviesLocation));
+    audioTrack   = group.readEntry("AudioTrack",
+                   QString());
     outputPlayer = (VidPlayer)group.readEntry("OutputPlayer",
                    (int)INTERNAL);
+    ffmpegPath   = group.readEntry("FFmpegPath",
+                   defaultFFmpegSearchPaths().first());
+    equalize     = group.readEntry("Equalize",
+                   false);
+    strength     = group.readEntry("Strength",
+                   5);
 }
 
 void VidSlideSettings::writeSettings(KConfigGroup& group)
@@ -99,7 +106,11 @@ void VidSlideSettings::writeSettings(KConfigGroup& group)
     group.writeEntry("ABitRate",     abitRate);
     group.writeEntry("ConflictRule", (int)conflictRule);
     group.writeEntry("OutputDir",    outputDir);
+    group.writeEntry("AudioTrack",   audioTrack);
     group.writeEntry("OutputPlayer", (int)outputPlayer);
+    group.writeEntry("FFmpegPath",   ffmpegPath);
+    group.writeEntry("Equalize",     equalize);
+    group.writeEntry("Strength",     strength);
 }
 
 QSize VidSlideSettings::videoSize() const
@@ -791,7 +802,7 @@ QMap<VidSlideSettings::VidCodec, QString> VidSlideSettings::videoCodecNames()
 {
     QMap<VidCodec, QString> codecs;
 
-    // NOTE: Some video codecs are currently disabled due to QtAV incompatibility
+    // NOTE: Some video codecs are currently disabled due to incompatibility
     //       with bits rate, frames rate, or video sizes. This need some investiguations.
 
     codecs[X264]    = i18nc("Video Codec X264",    "High Quality H.264 AVC/MPEG-4 AVC");
@@ -832,4 +843,37 @@ QMap<VidSlideSettings::VidPlayer, QString> VidSlideSettings::videoPlayerNames()
     return pla;
 }
 
+QStringList VidSlideSettings::defaultFFmpegSearchPaths() const
+{
+    QStringList defPaths;
+
+#ifdef Q_OS_MACOS
+
+    defPaths << QLatin1String("/usr/local/bin");
+
+    // digiKam Bundle PKG install path
+    defPaths << macOSBundlePrefix() + QLatin1String("bin");
+
+    // Std Macports install path
+    defPaths << QLatin1String("/opt/local/bin");
+
+#endif
+
+#ifdef Q_OS_WIN
+
+    defPaths << QLatin1String("C:/Program Files/digiKam");
+
+#endif
+
+#ifdef Q_OS_UNIX
+
+    defPaths << QLatin1String("/usr/bin");
+    defPaths << QLatin1String("/usr/local/bin");
+    defPaths << QLatin1String("/bin");
+
+#endif
+
+    return defPaths;
+}
+
 } // namespace Digikam
