@@ -7,7 +7,7 @@
  * Description : Qt item view for images
  *
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -39,20 +39,8 @@ class Q_DECL_HIDDEN ItemViewCategorized::Private
 {
 public:
 
-    explicit Private(ItemViewCategorized* const q)
-      : delegate                    (nullptr),
-        toolTip                     (nullptr),
-        notificationToolTip         (nullptr),
-        showToolTip                 (false),
-        usePointingHand             (true),
-        scrollStepFactor            (10),
-        currentMouseEvent           (nullptr),
-        ensureOneSelectedItem       (false),
-        ensureInitialSelectedItem   (false),
-        scrollCurrentToCenter       (false),
-        mouseButtonPressed          (Qt::NoButton),
-        hintAtSelectionRow          (-1),
-        q                           (q)
+    explicit Private(ItemViewCategorized* const qq)
+        : q(qq)
     {
     }
 
@@ -60,20 +48,20 @@ public:
 
 public:
 
-    DItemDelegate*             delegate;
-    ItemViewToolTip*           toolTip;
-    ItemViewToolTip*           notificationToolTip;
-    bool                       showToolTip;
-    bool                       usePointingHand;
-    int                        scrollStepFactor;
+    DItemDelegate*             delegate                     = nullptr;
+    ItemViewToolTip*           toolTip                      = nullptr;
+    ItemViewToolTip*           notificationToolTip          = nullptr;
+    bool                       showToolTip                  = false;
+    bool                       usePointingHand              = true;
+    int                        scrollStepFactor             = 10;
 
-    QMouseEvent*               currentMouseEvent;
-    bool                       ensureOneSelectedItem;
-    bool                       ensureInitialSelectedItem;
-    bool                       scrollCurrentToCenter;
-    Qt::MouseButton            mouseButtonPressed;
+    QMouseEvent*               currentMouseEvent            = nullptr;
+    bool                       ensureOneSelectedItem        = false;
+    bool                       ensureInitialSelectedItem    = false;
+    bool                       scrollCurrentToCenter        = false;
+    Qt::MouseButton            mouseButtonPressed           = Qt::NoButton;
     QPersistentModelIndex      hintAtSelectionIndex;
-    int                        hintAtSelectionRow;
+    int                        hintAtSelectionRow           = -1;
     QPersistentModelIndex      hintAtScrollPosition;
 
     ItemViewCategorized* const q;
@@ -150,7 +138,15 @@ ItemViewCategorized::ItemViewCategorized(QWidget* const parent)
 
 ItemViewCategorized::~ItemViewCategorized()
 {
-    delete d;
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        delete d->currentMouseEvent;
+        d->currentMouseEvent = nullptr;
+
+#endif
+
+        delete d;
 }
 
 void ItemViewCategorized::setToolTip(ItemViewToolTip* tip)
@@ -351,11 +347,17 @@ void ItemViewCategorized::slotGridSizeChanged(const QSize& gridSize)
 void ItemViewCategorized::updateDelegateSizes()
 {
     QStyleOptionViewItem option;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     initViewItemOption(&option);
+
 #else
+
     option = viewOptions();
+
 #endif
+
 /*
     int frameAroundContents = 0;
 
@@ -417,6 +419,12 @@ void ItemViewCategorized::slotActivated(const QModelIndex& index)
         }
     }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    delete d->currentMouseEvent;
+
+#endif
+
     d->currentMouseEvent = nullptr;
     indexActivated(index, modifiers);
 }
@@ -591,7 +599,7 @@ QModelIndex ItemViewCategorized::nextIndexHint(const QModelIndex& indexToAnchor,
             return QModelIndex();
         }
 
-        return model()->index(removed.topLeft().row() - 1, 0);    // last remaining, no next one left
+        return model()->index(removed.topLeft().row() - 1, 0);        // last remaining, no next one left
     }
     else
     {
@@ -645,7 +653,10 @@ void ItemViewCategorized::ensureSelectionAfterChanges()
             // we want ensureInitial set to false if and only if the selection
             // is done from any other place than the previous line (i.e., by user action)
             // Effect: we select whatever is the current index(0,0)
+            // TODO: cppcheck report here that hadInitial condition is always true.
+            //       This code must be refactored later.
 
+            // cppcheck-suppress knownConditionTrueFalse
             if (hadInitial)
             {
                 d->ensureInitialSelectedItem = true;
@@ -849,10 +860,28 @@ void ItemViewCategorized::mousePressEvent(QMouseEvent* event)
 
     if (!rightButtonPressed)
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        delete d->currentMouseEvent;
+        d->currentMouseEvent = event->clone();
+
+#else
+
         d->currentMouseEvent = event;
+
+#endif
+
     }
     else
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        delete d->currentMouseEvent;
+
+#endif
+
         d->currentMouseEvent = nullptr;
     }
 
@@ -934,6 +963,7 @@ void ItemViewCategorized::wheelEvent(QWheelEvent* event)
         }
 
         event->accept();
+
         return;
     }
 
@@ -960,12 +990,14 @@ void ItemViewCategorized::keyPressEvent(QKeyEvent* event)
     {
         copy();
         event->accept();
+
         return;
     }
     else if (event == QKeySequence::Paste)
     {
         paste();
         event->accept();
+
         return;
     }
 
@@ -979,6 +1011,7 @@ void ItemViewCategorized::keyPressEvent(QKeyEvent* event)
     if (trigger)
     {
         const QModelIndexList indexList = selModel->selectedIndexes();
+
         Q_FOREACH (const QModelIndex& index, indexList)
         {
             Q_EMIT itemTriggered(itemForIndex(index));
@@ -1005,6 +1038,7 @@ bool ItemViewCategorized::viewportEvent(QEvent* event)
         case QEvent::FontChange:
         {
             updateDelegateSizes();
+
             break;
         }
 
@@ -1024,14 +1058,21 @@ bool ItemViewCategorized::viewportEvent(QEvent* event)
             }
 
             QStyleOptionViewItem option;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
             initViewItemOption(&option);
+
 #else
+
             option = viewOptions();
+
 #endif
+
             option.rect                 =  visualRect(index);
             option.state               |= ((index == currentIndex()) ? QStyle::State_HasFocus : QStyle::State_None);
             showToolTip(index, option, he);
+
             return true;
         }
 
@@ -1061,11 +1102,17 @@ void ItemViewCategorized::showIndexNotification(const QModelIndex& index, const
     d->notificationToolTip->setTipContents(message);
 
     QStyleOptionViewItem option;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     initViewItemOption(&option);
+
 #else
+
     option = viewOptions();
+
 #endif
+
     option.rect                 = visualRect(index);
     option.state               |= ((index == currentIndex()) ? QStyle::State_HasFocus : QStyle::State_None);
     d->notificationToolTip->show(option, index);
@@ -1091,11 +1138,17 @@ QModelIndex ItemViewCategorized::mapIndexForDragDrop(const QModelIndex& index) c
 QPixmap ItemViewCategorized::pixmapForDrag(const QList<QModelIndex>& indexes) const
 {
     QStyleOptionViewItem option;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     initViewItemOption(&option);
+
 #else
+
     option = viewOptions();
+
 #endif
+
     option.rect                 = viewport()->rect();
 
     return d->delegate->pixmapForDrag(option, indexes);
@@ -1118,3 +1171,5 @@ void ItemViewCategorized::scrollTo(const QModelIndex& index, ScrollHint hint)
 }
 
 } // namespace Digikam
+
+#include "moc_itemviewcategorized.cpp"
