@@ -6,7 +6,7 @@
  * Date        : 2013-04-29
  * Description : digiKam XML GUI window
  *
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -186,7 +186,7 @@ bool DXmlGuiWindow::eventFilter(QObject* obj, QEvent* ev)
                     if (mev)
                     {
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
                         QPoint pos(mev->position().toPoint());
 
@@ -281,6 +281,7 @@ void DXmlGuiWindow::unminimizeAndActivateWindow()
 #endif
 
     setWindowState(windowState() | Qt::WindowActive);
+    raise();
 }
 
 bool DXmlGuiWindow::restoreWindowSize(QWindow* const win, const KConfigGroup& group)
@@ -513,3 +514,5 @@ void DXmlGuiWindow::setupIconTheme()
 }
 
 } // namespace Digikam
+
+#include "moc_dxmlguiwindow.cpp"
