@@ -6,18 +6,9 @@
  * Date        : 2006-02-22
  * Description : a generic widget to display metadata
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -124,7 +115,8 @@ MetadataWidget::MetadataWidget(QWidget* const parent, const QString& name)
 {
     setObjectName(name);
 
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     d->mainLayout     = new QGridLayout(this);
 
     // -----------------------------------------------------------------
@@ -215,7 +207,7 @@ void MetadataWidget::slotFilterChanged(QAction* action)
 {
     if      (action == d->settingsAction)
     {
-        emit signalSetupMetadataFilters();
+        Q_EMIT signalSetupMetadataFilters();
     }
     else if ((action == d->noneAction)  ||
              (action == d->photoAction) ||
@@ -441,7 +433,7 @@ QUrl MetadataWidget::saveMetadataToFile(const QString& caption, const QString& f
 
     // Check for cancel.
 
-    if (!fileSaveDialog || !fileSaveDialog->hasAcceptedUrls())
+    if (!fileSaveDialog->hasAcceptedUrls())
     {
         delete fileSaveDialog;
 
@@ -521,7 +513,8 @@ void MetadataWidget::setFileName(const QString& fileName)
 void MetadataWidget::setUserAreaWidget(QWidget* const w)
 {
     QVBoxLayout* const vLayout = new QVBoxLayout();
-    vLayout->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    vLayout->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
     vLayout->addWidget(w);
     vLayout->addStretch();
     d->mainLayout->addLayout(vLayout, 3, 0, 1, 5);
@@ -533,3 +526,5 @@ void MetadataWidget::buildView()
 }
 
 } // namespace Digikam
+
+#include "moc_metadatawidget.cpp"
