@@ -6,18 +6,9 @@
  * Date        : 2021-08-27
  * Description : Showfoto folder view model.
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -136,7 +127,7 @@ void ShowfotoFolderViewModel::refreshThumbnails(const LoadingDescription& desc,
 
     if (current.isValid() && !pix.isNull())
     {
-        emit dataChanged(current, current);
+        Q_EMIT dataChanged(current, current);
     }
 }
 
@@ -162,3 +153,5 @@ QStringList ShowfotoFolderViewModel::currentFilesPath() const
 }
 
 } // namespace ShowFoto
+
+#include "moc_showfotofolderviewmodel.cpp"
