@@ -8,7 +8,7 @@
  *               editor with no support of digiKam database.
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -36,19 +36,35 @@
 
 // ImageMagick includes
 
-#if defined(Q_CC_CLANG)
-#   pragma clang diagnostic push
-#   pragma clang diagnostic ignored "-Wkeyword-macro"
-#endif
 
 #ifdef HAVE_IMAGE_MAGICK
+
+// Pragma directives to reduce warnings from ImageMagick header files.
+#   if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#       pragma GCC diagnostic push
+#       pragma GCC diagnostic ignored "-Wignored-qualifiers"
+#       pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic push
+#       pragma clang diagnostic ignored "-Wignored-qualifiers"
+#       pragma clang diagnostic ignored "-Wkeyword-macro"
+#   endif
+
 #   include <Magick++.h>
 using namespace Magick;
-#endif
 
-#if defined(Q_CC_CLANG)
-#   pragma clang diagnostic pop
-#endif
+// Restore warnings
+#   if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#       pragma GCC diagnostic pop
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic pop
+#   endif
+
+#endif // HAVE_IMAGE_MAGICK
 
 // Local includes
 
@@ -99,10 +115,27 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
 
 #else
 
-    QImageReader::setAllocationLimit(0);
+    QImageReader::setAllocationLimit(2048);
 
 #endif
 
+    if (system.softwareOpenGL)
+    {
+        QCoreApplication::setAttribute(Qt::AA_UseSoftwareOpenGL);
+    }
+
+    // OpenCV crash with face engine with OpenCL support
+    // https://bugs.kde.org/show_bug.cgi?id=423632
+    // https://bugs.kde.org/show_bug.cgi?id=426175
+
+    if (system.disableOpenCL)
+    {
+        qputenv("OPENCV_OPENCL_RUNTIME", "disabled");
+        qputenv("OPENCV_OPENCL_DEVICE",  "disabled");
+    }
+
+    QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor);
+
 #ifdef HAVE_QWEBENGINE
 
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
@@ -117,6 +150,13 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
 
 #ifdef HAVE_IMAGE_MAGICK
 
+#ifdef Q_CC_MSVC
+
+    qputenv("MAGICK_CODER_MODULE_PATH", qApp->applicationDirPath().toUtf8());
+    qputenv("MAGICK_CODER_FILTER_PATH", qApp->applicationDirPath().toUtf8());
+
+#endif
+
     InitializeMagick(nullptr);
 
 #endif
@@ -163,8 +203,6 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
     QString iconTheme         = group.readEntry(QLatin1String("Icon Theme"), QString());
     QString colorTheme        = group.readEntry(QLatin1String("Theme"), QString::fromLatin1("Standard"));
 
-    setupKSycocaDatabaseFile();
-
     // See bug #438701
 
     installQtTranslationFiles(app);
@@ -233,7 +271,7 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
 
     w->show();
 
-    if (!system.disableFaceEngine)
+    if (system.enableFaceEngine || system.enableAesthetic || system.enableAutoTags)
     {
         QPointer<FilesDownloader> floader = new FilesDownloader(qApp->activeWindow());
 
