@@ -6,18 +6,9 @@
  * Date        : 2005-04-02
  * Description : showFoto setup dialog.
  *
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -37,6 +28,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "setupeditoriface.h"
 #include "setupicc.h"
 #include "setupiofiles.h"
@@ -49,6 +41,10 @@
 #include "dxmlguiwindow.h"
 #include "onlineversiondlg.h"
 
+#ifdef HAVE_GEOLOCATION
+#   include "setupgeolocation.h"
+#endif
+
 namespace ShowFoto
 {
 
@@ -63,6 +59,13 @@ public:
         page_raw        (nullptr),
         page_iofiles    (nullptr),
         page_icc        (nullptr),
+
+#ifdef HAVE_GEOLOCATION
+
+        page_geolocation(nullptr),
+
+#endif
+
         page_plugins    (nullptr),
         page_misc       (nullptr),
         metadataPage    (nullptr),
@@ -70,6 +73,13 @@ public:
         miscPage        (nullptr),
         rawPage         (nullptr),
         pluginsPage     (nullptr),
+
+#ifdef HAVE_GEOLOCATION
+
+        geolocationPage (nullptr),
+
+#endif
+
         editorIfacePage (nullptr),
         iofilesPage     (nullptr),
         iccPage         (nullptr)
@@ -82,6 +92,13 @@ public:
     DConfigDlgWdgItem*            page_raw;
     DConfigDlgWdgItem*            page_iofiles;
     DConfigDlgWdgItem*            page_icc;
+
+#ifdef HAVE_GEOLOCATION
+
+    DConfigDlgWdgItem*            page_geolocation;
+
+#endif
+
     DConfigDlgWdgItem*            page_plugins;
     DConfigDlgWdgItem*            page_misc;
 
@@ -91,6 +108,12 @@ public:
     ShowfotoSetupRaw*             rawPage;
     ShowfotoSetupPlugins*         pluginsPage;
 
+#ifdef HAVE_GEOLOCATION
+
+    Digikam::SetupGeolocation*    geolocationPage;
+
+#endif
+
     Digikam::SetupEditorIface*    editorIfacePage;
     Digikam::SetupIOFiles*        iofilesPage;
     Digikam::SetupICC*            iccPage;
@@ -104,7 +127,7 @@ ShowfotoSetup::ShowfotoSetup(QWidget* const parent, ShowfotoSetup::Page page)
     : DConfigDlg(parent),
       d         (new Private)
 {
-    setWindowTitle(i18n("Configure"));
+    setWindowTitle(i18nc("@title:window", "Configure"));
     setStandardButtons(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     button(QDialogButtonBox::Ok)->setDefault(true);
     setFaceType(DConfigDlg::List);
@@ -146,6 +169,15 @@ ShowfotoSetup::ShowfotoSetup(QWidget* const parent, ShowfotoSetup::Page page)
                                     "<i>Set default configuration used to save images</i></qt>"));
     d->page_iofiles->setIcon(QIcon::fromTheme(QLatin1String("document-save-all")));
 
+#ifdef HAVE_GEOLOCATION
+
+    d->geolocationPage  = new SetupGeolocation();
+    d->page_geolocation = addPage(d->geolocationPage, i18nc("@title: settings section", "Geolocation"));
+    d->page_geolocation->setHeader(i18nc("@title", "Geolocation Settings\nCustomize view to geolocalize items"));
+    d->page_geolocation->setIcon(QIcon::fromTheme(QLatin1String("map-globe")));
+
+#endif
+
     d->pluginsPage    = new ShowfotoSetupPlugins();
     d->page_plugins   = addPage(d->pluginsPage, i18n("Plugins"));
     d->page_plugins->setHeader(i18n("<qt>Main Interface Plug-in Settings<br/>"
@@ -176,8 +208,11 @@ ShowfotoSetup::ShowfotoSetup(QWidget* const parent, ShowfotoSetup::Page page)
         }
     }
 
-    connect(buttonBox()->button(QDialogButtonBox::Ok),
-            &QPushButton::clicked, this, &ShowfotoSetup::slotOkClicked);
+    connect(buttonBox()->button(QDialogButtonBox::Ok), &QPushButton::clicked,
+            this, &ShowfotoSetup::slotOkClicked);
+
+    connect(buttonBox()->button(QDialogButtonBox::Cancel), &QPushButton::clicked,
+            this, &ShowfotoSetup::slotCancelClicked);
 
     connect(buttonBox(), SIGNAL(helpRequested()),
             this, SLOT(slotHelp()));
@@ -188,6 +223,18 @@ ShowfotoSetup::ShowfotoSetup(QWidget* const parent, ShowfotoSetup::Page page)
     if (page != LastPageUsed)
     {
         showPage(page);
+        d->metadataPage->setActiveTab((ShowfotoSetupMetadata::MetadataTab)group.readEntry(QLatin1String("Metadata Tab"), (int)ShowfotoSetupMetadata::Behavior));
+        d->rawPage->setActiveTab((ShowfotoSetupRaw::RAWTab)group.readEntry(QLatin1String("RAW Tab"), (int)ShowfotoSetupRaw::RAWBehavior));
+        d->iccPage->setActiveTab((Digikam::SetupICC::ICCTab)group.readEntry(QLatin1String("ICC Tab"), (int)Digikam::SetupICC::Behavior));
+        d->pluginsPage->setActiveTab((ShowfotoSetupPlugins::PluginTab)group.readEntry(QLatin1String("Plugin Tab"), (int)ShowfotoSetupPlugins::Generic));
+
+#ifdef HAVE_GEOLOCATION
+
+        d->geolocationPage->setActiveTab((SetupGeolocation::GeolocationTab)group.readEntry(QLatin1String("Geolocation Tab"), (int)SetupGeolocation::MarbleView));
+
+#endif
+
+        d->miscPage->setActiveTab((ShowfotoSetupMisc::MiscTab)group.readEntry(QLatin1String("Misc Tab"), (int)ShowfotoSetupMisc::Behaviour));
     }
     else
     {
@@ -195,7 +242,8 @@ ShowfotoSetup::ShowfotoSetup(QWidget* const parent, ShowfotoSetup::Page page)
     }
 
     winId();
-    Digikam::DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
+    DXmlGuiWindow::setGoodDefaultWindowSize(windowHandle());
+    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size());
 }
 
@@ -203,7 +251,19 @@ ShowfotoSetup::~ShowfotoSetup()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("Setup Dialog"));
-    group.writeEntry(QLatin1String("Setup Page"), (int)activePageIndex());
+    group.writeEntry(QLatin1String("Setup Page"),      (int)activePageIndex());
+    group.writeEntry(QLatin1String("Metadata Tab"),    (int)d->metadataPage->activeTab());
+    group.writeEntry(QLatin1String("RAW Tab"),         (int)d->rawPage->activeTab());
+    group.writeEntry(QLatin1String("ICC Tab"),         (int)d->iccPage->activeTab());
+    group.writeEntry(QLatin1String("Plugin Tab"),      (int)d->pluginsPage->activeTab());
+
+#ifdef HAVE_GEOLOCATION
+
+    group.writeEntry(QLatin1String("Geolocation Tab"), (int)d->geolocationPage->activeTab());
+
+#endif
+
+    group.writeEntry(QLatin1String("Misc Tab"),        (int)d->miscPage->activeTab());
     Digikam::DXmlGuiWindow::saveWindowSize(windowHandle(), group);
     config->sync();
 
@@ -212,7 +272,18 @@ ShowfotoSetup::~ShowfotoSetup()
 
 void ShowfotoSetup::slotHelp()
 {
-    Digikam::DXmlGuiWindow::openHandbook();
+    Digikam::openOnlineDocumentation(QLatin1String("showfoto_editor"), QLatin1String("showfoto_setup"));
+}
+
+void ShowfotoSetup::slotCancelClicked()
+{
+
+#ifdef HAVE_GEOLOCATION
+
+    d->geolocationPage->cancel();
+
+#endif
+
 }
 
 void ShowfotoSetup::slotOkClicked()
@@ -232,6 +303,13 @@ void ShowfotoSetup::slotOkClicked()
     d->iofilesPage->applySettings();
     d->iccPage->applySettings();
     d->pluginsPage->applySettings();
+
+#ifdef HAVE_GEOLOCATION
+
+    d->geolocationPage->applySettings();
+
+#endif
+
     d->miscPage->applySettings();
 
     qApp->restoreOverrideCursor();
@@ -279,6 +357,16 @@ void ShowfotoSetup::showPage(ShowfotoSetup::Page page)
             break;
         }
 
+#ifdef HAVE_GEOLOCATION
+
+        case GeolocationPage:
+        {
+            setCurrentPage(d->page_geolocation);
+            break;
+        }
+
+#endif
+
         case MiscellaneousPage:
         {
             setCurrentPage(d->page_misc);
@@ -327,6 +415,15 @@ ShowfotoSetup::Page ShowfotoSetup::activePageIndex()
         return PluginsPage;
     }
 
+#ifdef HAVE_GEOLOCATION
+
+    if (cur == d->page_geolocation)
+    {
+        return GeolocationPage;
+    }
+
+#endif
+
     if (cur == d->page_misc)
     {
         return MiscellaneousPage;
@@ -374,6 +471,15 @@ DConfigDlgWdgItem* ShowfotoSetup::Private::pageItem(ShowfotoSetup::Page page) co
             return page_plugins;
         }
 
+#ifdef HAVE_GEOLOCATION
+
+        case ShowfotoSetup::GeolocationPage:
+        {
+            return page_geolocation;
+        }
+
+#endif
+
         case ShowfotoSetup::MiscellaneousPage:
         {
             return page_misc;
@@ -403,6 +509,38 @@ bool ShowfotoSetup::execSinglePage(QWidget* const parent, Page page)
     return success;
 }
 
+#ifdef HAVE_GEOLOCATION
+
+bool ShowfotoSetup::execGeolocation(QWidget* const parent, int tab)
+{
+    QPointer<ShowfotoSetup> setup  = new ShowfotoSetup(parent);
+    setup->showPage(GeolocationPage);
+    setup->setFaceType(Plain);
+
+    DConfigDlgWdgItem* const cur   = setup->currentPage();
+
+    if (!cur)
+    {
+        return false;
+    }
+
+    Digikam::SetupGeolocation* const widget = dynamic_cast<Digikam::SetupGeolocation*>(cur->widget());
+
+    if (!widget)
+    {
+        return false;
+    }
+
+    widget->setActiveTab((Digikam::SetupGeolocation::GeolocationTab)tab);
+
+    bool success                   = (setup->DConfigDlg::exec() == QDialog::Accepted);
+    delete setup;
+
+    return success;
+}
+
+#endif
+
 bool ShowfotoSetup::execMetadataFilters(QWidget* const parent, int tab)
 {
     QPointer<ShowfotoSetup> setup = new ShowfotoSetup(parent);
@@ -459,6 +597,34 @@ bool ShowfotoSetup::execExifTool(QWidget* const parent)
     return success;
 }
 
+bool ShowfotoSetup::execLocalize(QWidget* const parent)
+{
+    QPointer<ShowfotoSetup> setup        = new ShowfotoSetup(parent);
+    setup->showPage(MiscellaneousPage);
+    setup->setFaceType(Plain);
+
+    DConfigDlgWdgItem* const cur         = setup->currentPage();
+
+    if (!cur)
+    {
+        return false;
+    }
+
+    ShowfotoSetupMisc* const widget  = dynamic_cast<ShowfotoSetupMisc*>(cur->widget());
+
+    if (!widget)
+    {
+        return false;
+    }
+
+    widget->setActiveTab(ShowfotoSetupMisc::Localize);
+
+    bool success                         = (setup->DConfigDlg::exec() == QDialog::Accepted);
+    delete setup;
+
+    return success;
+}
+
 void ShowfotoSetup::onlineVersionCheck()
 {
     OnlineVersionDlg* const dlg = new OnlineVersionDlg(qApp->activeWindow(),
@@ -478,3 +644,5 @@ void ShowfotoSetup::onlineVersionCheck()
 }
 
 } // namespace ShowFoto
+
+#include "moc_showfotosetup.cpp"
