@@ -6,18 +6,9 @@
  * Date        : 2005-04-02
  * Description : showFoto setup dialog.
  *
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -26,6 +17,7 @@
 
 // Local includes
 
+#include "digikam_config.h"
 #include "dconfigdlg.h"
 
 using namespace Digikam;
@@ -49,6 +41,13 @@ public:
         RawPage,
         IOFilesPage,
         ICCPage,
+
+#ifdef HAVE_GEOLOCATION
+
+        GeolocationPage,
+
+#endif
+
         PluginsPage,
         MiscellaneousPage,
 
@@ -63,17 +62,26 @@ public:
     static bool execMetadataFilters(QWidget* const parent, int tab);
     static bool execExifTool(QWidget* const parent);
 
+    static bool execLocalize(QWidget* const parent);
+
     /**
      * Show a setup dialog. Only the specified page will be available.
      */
     static bool execSinglePage(Page page);
     static bool execSinglePage(QWidget* const parent, Page page);
 
+#ifdef HAVE_GEOLOCATION
+
+    static bool execGeolocation(QWidget* const parent, int tab);
+
+#endif
+
     static void onlineVersionCheck();
 
 private Q_SLOTS:
 
     void slotOkClicked();
+    void slotCancelClicked();
     void slotHelp();
 
 private:
