@@ -6,18 +6,9 @@
  * Date        : 2021-09-27
  * Description : Showfoto stack view favorite item edit dialog
  *
- * Copyright (C) 2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -28,7 +19,6 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QPointer>
-#include <QLineEdit>
 #include <QApplication>
 #include <QStyle>
 #include <QDir>
@@ -60,6 +50,7 @@
 #include "dlayoutbox.h"
 #include "dexpanderbox.h"
 #include "drawdecoder.h"
+#include "dtextedit.h"
 #include "dxmlguiwindow.h"
 #include "showfotostackviewfavoritelist.h"
 #include "showfotostackviewfavoriteitem.h"
@@ -115,8 +106,8 @@ public:
 
     QDialogButtonBox*              buttons;
 
-    QLineEdit*                     nameEdit;
-    QLineEdit*                     descEdit;
+    DTextEdit*                     nameEdit;
+    DTextEdit*                     descEdit;
     QComboBox*                     favoriteTypeBox;
     QDateTimeEdit*                 dateEdit;
     DItemsList*                    urlsEdit;
@@ -143,7 +134,7 @@ ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStack
 
     d->create               = create;
     d->list                 = list;
-    d->buttons              = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    d->buttons              = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     d->buttons->button(QDialogButtonBox::Ok)->setDefault(true);
 
 
@@ -155,8 +146,8 @@ ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStack
     QLabel* const nameLabel = new QLabel(page);
     nameLabel->setText(i18nc("@label: favorite item title properties", "&Name:"));
 
-    d->nameEdit             = new QLineEdit(page);
-    d->nameEdit->setClearButtonEnabled(true);
+    d->nameEdit             = new DTextEdit(page);
+    d->nameEdit->setLinesVisible(1);
     d->nameEdit->setPlaceholderText(i18nc("@info", "Enter favorite entry name here..."));
     d->nameEdit->setWhatsThis(i18nc("@info", "The favorite item name which must be unique and not empty"));
     nameLabel->setBuddy(d->nameEdit);
@@ -188,8 +179,8 @@ ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStack
     d->descLabel            = new QLabel(page);
     d->descLabel->setText(i18nc("@label: favorite item caption properties", "&Description:"));
 
-    d->descEdit             = new QLineEdit(page);
-    d->descEdit->setClearButtonEnabled(true);
+    d->descEdit             = new DTextEdit(page);
+    d->descEdit->setLinesVisible(1);
     d->descEdit->setPlaceholderText(i18nc("@info", "Enter favorite item description here..."));
     d->descLabel->setBuddy(d->descEdit);
 
@@ -303,7 +294,10 @@ ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStack
 
     // --------------------------------------------------------
 
-    connect(d->nameEdit, SIGNAL(textChanged(QString)),
+    connect(d->nameEdit, SIGNAL(textChanged()),
+            this, SLOT(slotModified()));
+
+    connect(d->descEdit, SIGNAL(textChanged()),
             this, SLOT(slotModified()));
 
     connect(d->favoriteTypeBox, SIGNAL(activated(int)),
@@ -327,6 +321,9 @@ ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStack
     connect(d->buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
             this, SLOT(reject()));
 
+    connect(d->buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this, SLOT(slotHelp()));
+
     connect(d->dateLowButton, SIGNAL(clicked()),
             this, SLOT(slotDateLowButtonClicked()));
 
@@ -695,22 +692,22 @@ void ShowfotoStackViewFavoriteItemDlg::slotTypeActivated()
     {
         if (d->create)
         {
-            setWindowTitle(i18nc("@title", "New Favorite Item"));
+            setWindowTitle(i18nc("@title:window", "New Favorite Item"));
         }
         else
         {
-            setWindowTitle(i18nc("@title", "Edit Favorite Item"));
+            setWindowTitle(i18nc("@title:window", "Edit Favorite Item"));
         }
     }
     else
     {
         if (d->create)
         {
-            setWindowTitle(i18nc("@title", "New Favorite Folder"));
+            setWindowTitle(i18nc("@title:window", "New Favorite Folder"));
         }
         else
         {
-            setWindowTitle(i18nc("@title", "Edit Favorite Folder"));
+            setWindowTitle(i18nc("@title:window", "Edit Favorite Folder"));
         }
     }
 
@@ -752,7 +749,7 @@ void ShowfotoStackViewFavoriteItemDlg::slotDateAverageButtonClicked()
     QList<QDate> dates = getItemDates();
     qint64 julianDays  = 0;
 
-    foreach (const QDate& date, dates)
+    Q_FOREACH (const QDate& date, dates)
     {
         julianDays += date.toJulianDay();
     }
@@ -767,7 +764,7 @@ void ShowfotoStackViewFavoriteItemDlg::slotDateAverageButtonClicked()
     }
     else
     {
-        QMessageBox::critical(this, i18nc("@title: favorite item properties", "Could Not Calculate Average"),
+        QMessageBox::critical(this, i18nc("@title:window, favorite item properties", "Could not Calculate Average"),
                                     i18nc("@info: favorite item properties",  "Could not calculate date average for this favorite item."));
     }
 }
@@ -816,4 +813,13 @@ bool ShowfotoStackViewFavoriteItemDlg::itemIsLessThanHandler(const QTreeWidgetIt
     return (result < 0);
 }
 
+void ShowfotoStackViewFavoriteItemDlg::slotHelp()
+{
+    Digikam::openOnlineDocumentation(QLatin1String("showfoto_editor"),
+                                         QLatin1String("showfoto_leftsidebar"),
+                                         QLatin1String("showfoto-stacktab"));
+}
+
 } // namespace ShowFoto
+
+#include "moc_showfotostackviewfavoriteitemdlg.cpp"
