@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -332,13 +332,6 @@ void FaceGroup::load()
     QList<FaceTagsIface> faces = FaceTagsEditor().databaseFaces(d->info.id());
     d->visibilityController->clear();
 
-    // See bug 408982
-
-    if (!faces.isEmpty())
-    {
-        d->view->setFocus();
-    }
-
     Q_FOREACH (const FaceTagsIface& face, faces)
     {
         d->addItem(face);
@@ -350,6 +343,13 @@ void FaceGroup::load()
     {
         d->visibilityController->show();
     }
+
+    // See bug 408982
+
+    if (d->visibilityController->hasVisibleItems())
+    {
+        d->view->setFocus();
+    }
 }
 
 void FaceGroup::clear()
@@ -452,7 +452,17 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const
         }
         else if (action.shallCreateNewTag())
         {
-            tagId = FaceTags::getOrCreateTagForPerson(action.newTagName(), action.parentTagId());
+            QStringList faceNames = action.newTagName().split(QLatin1Char('/'),
+                                                              QT_SKIP_EMPTY_PARTS);
+            if (!faceNames.isEmpty())
+            {
+                tagId             = action.parentTagId();
+
+                Q_FOREACH (const QString& name, faceNames)
+                {
+                    tagId = FaceTags::getOrCreateTagForPerson(name.trimmed(), tagId);
+                }
+            }
         }
 
         if (FaceTags::isTheUnknownPerson(tagId))
@@ -485,7 +495,9 @@ void FaceGroup::focusRandomFace()
 
         if ((comboBox) && (!face.isConfirmedName()))
         {
+            comboBox->lineEdit()->selectAll();
             comboBox->lineEdit()->setFocus();
+
             return;
         }
     }
@@ -773,3 +785,5 @@ void ItemPreviewView::suggestFaces()
 */
 
 } // namespace Digikam
+
+#include "moc_facegroup.cpp"
