@@ -6,20 +6,11 @@
  * Date        : 2010-09-12
  * Description : Widget for assignment and confirmation of names for faces
  *
- * Copyright (C) 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
- * Copyright (C) 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -121,7 +112,7 @@ void AssignNameWidget::Private::setupAddTagsWidget(T* const widget)
 {
     if (modelsGiven)
     {
-        widget->setModel(tagModel, tagFilteredModel, tagFilterModel);
+        widget->setAlbumModels(tagModel, tagFilteredModel, tagFilterModel);
     }
 
     if (parentTag)
