@@ -7,7 +7,7 @@
  * Description : Find Duplicates View.
  *
  * SPDX-FileCopyrightText: 2016-2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -28,6 +28,7 @@
 #include <QStyle>
 #include <QTimer>
 #include <QElapsedTimer>
+#include <QGroupBox>
 
 // KDE includes
 
@@ -36,11 +37,12 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "album.h"
 #include "albummanager.h"
 #include "albumselectors.h"
 #include "similaritydb.h"
 #include "similaritydbaccess.h"
+#include "albumselectcombobox.h"
+#include "albumtreeview.h"
 #include "findduplicatesalbum.h"
 #include "findduplicatesalbumitem.h"
 #include "duplicatesfinder.h"
@@ -66,12 +68,14 @@ public:
         similarityRange        (nullptr),
         searchResultRestriction(nullptr),
         albumTagRelation       (nullptr),
+        refImageSelMethod      (nullptr),
         findDuplicatesBtn      (nullptr),
         updateFingerPrtBtn     (nullptr),
         removeDuplicatesBtn    (nullptr),
         listView               (nullptr),
         progressItem           (nullptr),
         albumSelectors         (nullptr),
+        refImageAlbumSelector  (nullptr),
         settings               (nullptr),
         active                 (false)
     {
@@ -85,6 +89,7 @@ public:
     DIntRangeBox*        similarityRange;
     SqueezedComboBox*    searchResultRestriction;
     SqueezedComboBox*    albumTagRelation;
+    SqueezedComboBox*    refImageSelMethod;
 
     QPushButton*         findDuplicatesBtn;
     QPushButton*         updateFingerPrtBtn;
@@ -95,6 +100,7 @@ public:
     ProgressItem*        progressItem;
 
     AlbumSelectors*      albumSelectors;
+    AlbumSelectors*      refImageAlbumSelector;
 
     ApplicationSettings* settings;
 
@@ -128,7 +134,8 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
 
     // ---------------------------------------------------------------
 
-    d->albumSelectors  = new AlbumSelectors(i18nc("@label", "Search in:"), QLatin1String("Find Duplicates View"));
+    d->albumSelectors  = new AlbumSelectors(i18nc("@label", "Search in:"), QLatin1String("Find Duplicates View"),
+                                            nullptr, AlbumSelectors::AlbumType::All, true);
 
     // ---------------------------------------------------------------
 
@@ -181,13 +188,56 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
      */
 
     d->albumTagRelation      = new SqueezedComboBox();
-    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation", "Only selected tab") ,  HaarIface::AlbumTagRelation::NoMix);
-    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation", "One of"),              HaarIface::AlbumTagRelation::Union);
-    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation", "Both"),                HaarIface::AlbumTagRelation::Intersection);
-    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation", "Albums but not tags"), HaarIface::AlbumTagRelation::AlbumExclusive);
-    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation", "Tags but not albums"), HaarIface::AlbumTagRelation::TagExclusive);
+    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation",
+                                               "Only selected tab"),
+                                         (int)HaarIface::AlbumTagRelation::NoMix);
+    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation",
+                                               "One of"),
+                                         (int)HaarIface::AlbumTagRelation::Union);
+    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation",
+                                               "Both"),
+                                         (int)HaarIface::AlbumTagRelation::Intersection);
+    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation",
+                                               "Albums but not tags"),
+                                         (int)HaarIface::AlbumTagRelation::AlbumExclusive);
+    d->albumTagRelation->addSqueezedItem(i18nc("@label:listbox similarity album tag relation",
+                                               "Tags but not albums"),
+                                         (int)HaarIface::AlbumTagRelation::TagExclusive);
     d->albumTagRelation->setCurrentIndex(ApplicationSettings::instance()->getDuplicatesAlbumTagRelation());
 
+    const auto refSelMethod            = ApplicationSettings::instance()->getDuplicatesRefImageSelMethod();
+    d->refImageSelMethod               = new SqueezedComboBox();
+    d->refImageSelMethod->addSqueezedItem(i18nc("@label:listbox similarity reference selection method",
+                                                "Older or Larger"),
+                                          (int)HaarIface::RefImageSelMethod::OlderOrLarger);
+    d->refImageSelMethod->addSqueezedItem(i18nc("@label:listbox similarity reference selection method",
+                                                "Prefer selected folder as reference"),
+                                          (int)HaarIface::RefImageSelMethod::PreferFolder);
+    d->refImageSelMethod->addSqueezedItem(i18nc("@label:listbox similarity reference selection method",
+                                                "Prefer other than selected folder as reference"),
+                                          (int)HaarIface::RefImageSelMethod::ExcludeFolder);
+    d->refImageSelMethod->addSqueezedItem(i18nc("@label:listbox similarity reference selection method",
+                                                "Prefer Newer Creation Date"),
+                                          (int)HaarIface::RefImageSelMethod::NewerCreationDate);
+    d->refImageSelMethod->addSqueezedItem(i18nc("@label:listbox similarity reference selection method",
+                                                "Prefer Newer Modification Date"),
+                                          (int)HaarIface::RefImageSelMethod::NewerModificationDate);
+    d->refImageSelMethod->setCurrentIndex(d->refImageSelMethod->findData((int)refSelMethod));
+    d->refImageSelMethod->setWhatsThis(i18nc("@label:listbox similarity reference selection method",
+                                             "Select method for reference image selection"));
+
+    d->refImageAlbumSelector           = new AlbumSelectors(i18nc("@label", "Reference"),
+                                                            QLatin1String("Select Reference"),
+                                                            nullptr, AlbumSelectors::AlbumType::PhysAlbum, true);
+    d->refImageAlbumSelector->setVisible((refSelMethod == HaarIface::RefImageSelMethod::ExcludeFolder) ||
+                                         (refSelMethod == HaarIface::RefImageSelMethod::PreferFolder));
+
+    auto* const refImageselectionGroup = new QGroupBox(i18nc("@group", "Reference Image Selection Method"));
+    auto* const layout                 = new QVBoxLayout;
+    layout->addWidget(d->refImageSelMethod);
+    layout->addWidget(d->refImageAlbumSelector);
+    refImageselectionGroup->setLayout(layout);
+
     QString tip = i18nc("@info",
                         "Use this option to decide about the relation of the selected albums and tags.\n"
                         "\"One of\" means that the images are either in the selected albums or tags.\n"
@@ -195,7 +245,6 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
                         "\"Albums but not tags\" means that images must be in the selected albums but not tags.\n"
                         "\"Tags but not albums\" means that images must be in the selected tags but not albums.\n"
                         "\"Only selected tab\" means that only the selected tab is used.");
-
     d->albumTagRelation->setToolTip(tip);
 
     // Load the last choice from application settings.
@@ -206,7 +255,7 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
 
     d->albumTagRelation->setCurrentIndex(d->albumTagRelation->findData(relation));
 
-    d->removeDuplicatesBtn   = new QPushButton(i18nc("@action", "Remove Duplicates"));
+    d->removeDuplicatesBtn = new QPushButton(i18nc("@action", "Remove Duplicates"));
     d->removeDuplicatesBtn->setIcon(QIcon::fromTheme(QLatin1String("user-trash")));
     d->removeDuplicatesBtn->setWhatsThis(i18nc("@info", "Use this button to delete all duplicate images."));
 
@@ -216,16 +265,17 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
 
     QGridLayout* const mainLayout = new QGridLayout();
     mainLayout->addWidget(d->listView,                0, 0, 1, -1);
-    mainLayout->addWidget(d->albumTagRelationLabel,   1, 0, 1,  2);
-    mainLayout->addWidget(d->albumTagRelation,        1, 2, 1, -1);
-    mainLayout->addWidget(d->albumSelectors,          2, 0, 1, -1);
-    mainLayout->addWidget(d->similarityLabel,         3, 0, 1,  1);
-    mainLayout->addWidget(d->similarityRange,         3, 2, 1,  1);
-    mainLayout->addWidget(d->restrictResultsLabel,    4, 0, 1,  2);
-    mainLayout->addWidget(d->searchResultRestriction, 4, 2, 1, -1);
-    mainLayout->addWidget(d->updateFingerPrtBtn,      5, 0, 1, -1);
-    mainLayout->addWidget(d->findDuplicatesBtn,       6, 0, 1, -1);
-    mainLayout->addWidget(d->removeDuplicatesBtn,     7, 0, 1, -1);
+    mainLayout->addWidget(refImageselectionGroup,     1, 0, 1, -1);
+    mainLayout->addWidget(d->albumTagRelationLabel,   2, 0, 1,  2);
+    mainLayout->addWidget(d->albumTagRelation,        2, 2, 1, -1);
+    mainLayout->addWidget(d->albumSelectors,          3, 0, 1, -1);
+    mainLayout->addWidget(d->similarityLabel,         4, 0, 1,  1);
+    mainLayout->addWidget(d->similarityRange,         4, 2, 1,  1);
+    mainLayout->addWidget(d->restrictResultsLabel,    5, 0, 1,  2);
+    mainLayout->addWidget(d->searchResultRestriction, 5, 2, 1, -1);
+    mainLayout->addWidget(d->updateFingerPrtBtn,      6, 0, 1, -1);
+    mainLayout->addWidget(d->findDuplicatesBtn,       7, 0, 1, -1);
+    mainLayout->addWidget(d->removeDuplicatesBtn,     8, 0, 1, -1);
 
     mainLayout->setRowStretch(0, 10);
     mainLayout->setColumnStretch(2, 10);
@@ -255,11 +305,16 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
 
     connect(d->settings, SIGNAL(setupChanged()),
             this, SLOT(slotApplicationSettingsChanged()));
+
+    connect(d->refImageSelMethod, QOverload<int>::of(&SqueezedComboBox::currentIndexChanged),
+            this, &FindDuplicatesView::slotReferenceSelectionMethodChanged);
 }
 
 FindDuplicatesView::~FindDuplicatesView()
 {
     d->albumSelectors->saveState();
+    d->refImageAlbumSelector->saveState();
+
     delete d;
 }
 
@@ -277,8 +332,8 @@ void FindDuplicatesView::initAlbumUpdateConnections()
     connect(AlbumManager::instance(), SIGNAL(signalAlbumsCleared()),
             this, SLOT(slotClear()));
 
-    connect(AlbumManager::instance(),SIGNAL(signalUpdateDuplicatesAlbums(QList<SAlbum*>,QList<qlonglong>)),
-            this,SLOT(slotUpdateDuplicates(QList<SAlbum*>,QList<qlonglong>)));
+    connect(AlbumManager::instance(), SIGNAL(signalUpdateDuplicatesAlbums(QList<SAlbum*>,QList<qlonglong>)),
+            this, SLOT(slotUpdateDuplicates(QList<SAlbum*>,QList<qlonglong>)));
 }
 
 void FindDuplicatesView::setActive(bool val)
@@ -309,6 +364,8 @@ void FindDuplicatesView::populateTreeView()
 
         if (salbum && salbum->isDuplicatesSearch() && !salbum->extraData(this))
         {
+            // Adding item to listView by creating an item and passing listView as parent
+
             FindDuplicatesAlbumItem* const item = new FindDuplicatesAlbumItem(d->listView, salbum);
             salbum->setExtraData(this, item);
         }
@@ -325,6 +382,7 @@ void FindDuplicatesView::populateTreeView()
     d->listView->sortByColumn(1, Qt::DescendingOrder);
 
     d->albumSelectors->loadState();
+    d->refImageAlbumSelector->loadState();
 
     if (waitCursor)
     {
@@ -455,6 +513,7 @@ void FindDuplicatesView::enableControlWidgets(bool val)
     d->albumTagRelation->setEnabled(val);
     d->similarityRange->setEnabled(val);
     d->albumSelectors->setEnabled(val);
+    d->refImageSelMethod->setEnabled(val);
 
     d->albumTagRelationLabel->setEnabled(val);
     d->restrictResultsLabel->setEnabled(val);
@@ -464,11 +523,13 @@ void FindDuplicatesView::enableControlWidgets(bool val)
 void FindDuplicatesView::slotFindDuplicates()
 {
     d->albumSelectors->saveState();
+    d->refImageAlbumSelector->saveState();
     enableControlWidgets(false);
     slotClear();
 
     AlbumList albums;
     AlbumList tags;
+    AlbumList referenceImageSelector;
 
     if (d->albumTagRelation->itemData(d->albumTagRelation->currentIndex()).toInt() == HaarIface::AlbumTagRelation::NoMix)
     {
@@ -487,13 +548,21 @@ void FindDuplicatesView::slotFindDuplicates()
         tags   = d->albumSelectors->selectedTags();
     }
 
+    const auto referenceImageSelectionMethod = (HaarIface::RefImageSelMethod)d->refImageSelMethod->itemData(d->refImageSelMethod->currentIndex()).toInt();
+
+    if (referenceImageSelectionMethod != HaarIface::RefImageSelMethod::OlderOrLarger)
+    {
+        referenceImageSelector = d->refImageAlbumSelector->selectedAlbums();
+    }
+
     AlbumManager::instance()->clearCurrentAlbums();
     SimilarityDbAccess().db()->clearImageSimilarity();
 
     DuplicatesFinder* const finder = new DuplicatesFinder(albums, tags,
                                                           d->albumTagRelation->itemData(d->albumTagRelation->currentIndex()).toInt(),
                                                           d->similarityRange->minValue(), d->similarityRange->maxValue(),
-                                                          d->searchResultRestriction->itemData(d->searchResultRestriction->currentIndex()).toInt());
+                                                          d->searchResultRestriction->itemData(d->searchResultRestriction->currentIndex()).toInt(),
+                                                          referenceImageSelectionMethod, referenceImageSelector);
 
     connect(finder, SIGNAL(signalComplete()),
             this, SLOT(slotComplete()));
@@ -524,6 +593,13 @@ void FindDuplicatesView::slotApplicationSettingsChanged()
     d->similarityRange->setRange(d->settings->getMinimumSimilarityBound(), 100);
 }
 
+void FindDuplicatesView::slotReferenceSelectionMethodChanged(int index)
+{
+   auto method = static_cast<HaarIface::RefImageSelMethod>(d->refImageSelMethod->itemData(index).toInt());
+   d->refImageAlbumSelector->setVisible((method == HaarIface::RefImageSelMethod::ExcludeFolder) ||
+                                        (method == HaarIface::RefImageSelMethod::PreferFolder));
+}
+
 void FindDuplicatesView::slotComplete()
 {
     enableControlWidgets(true);
@@ -636,3 +712,5 @@ void FindDuplicatesView::slotRemoveDuplicates()
 }
 
 } // namespace Digikam
+
+#include "moc_findduplicatesview.cpp"
