@@ -6,7 +6,7 @@
  * Date        : 2009-12-01
  * Description : Google-Maps-backend for geolocation interface
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014      by Justus Schwartz <justus at gmx dot li>
  *
@@ -18,13 +18,15 @@
 
 // Qt includes
 
-#include <QBuffer>
-#include <QActionGroup>
 #include <QMenu>
+#include <QTimer>
+#include <QAction>
+#include <QBuffer>
 #include <QPointer>
 #include <QResizeEvent>
-#include <QAction>
-#include <QTimer>
+#include <QActionGroup>
+#include <QApplication>
+#include <QStandardPaths>
 
 // KDE includes
 
@@ -33,7 +35,11 @@
 
 // Marble includes
 
-#include <marble/GeoDataLatLonAltBox.h>
+#ifdef HAVE_GEOLOCATION
+
+#   include "GeoDataLatLonAltBox.h"
+
+#endif
 
 // Local includes
 
@@ -44,9 +50,13 @@
 #include "geomodelhelper.h"
 
 #ifdef HAVE_QWEBENGINE
+
 #   include "htmlwidget_qwebengine.h"
+
 #else
+
 #   include "htmlwidget_qwebkit.h"
+
 #endif
 
 namespace Digikam
@@ -84,6 +94,7 @@ public:
         showMapTypeControlAction    (nullptr),
         showNavigationControlAction (nullptr),
         showScaleControlAction      (nullptr),
+        htmlFileName                (QLatin1String("backend-googlemaps.html")),
         cacheMapType                (QLatin1String("ROADMAP")),
         cacheShowMapTypeControl     (true),
         cacheShowNavigationControl  (true),
@@ -107,7 +118,7 @@ public:
     QAction*                                  showMapTypeControlAction;
     QAction*                                  showNavigationControlAction;
     QAction*                                  showScaleControlAction;
-
+    QString                                   htmlFileName;
     QString                                   cacheMapType;
     bool                                      cacheShowMapTypeControl;
     bool                                      cacheShowNavigationControl;
@@ -243,6 +254,9 @@ QWidget* BackendGoogleMaps::mapWidget()
         connect(d->htmlWidget, SIGNAL(signalHTMLEvents(QStringList)),
                 this, SLOT(slotHTMLEvents(QStringList)));
 
+        connect(d->htmlWidget, SIGNAL(signalMessageEvent(QString)),
+                this, SLOT(slotMessageEvent(QString)));
+
         connect(d->htmlWidget, SIGNAL(selectionHasBeenMade(Digikam::GeoCoordinates::Pair)),
                 this, SLOT(slotSelectionHasBeenMade(Digikam::GeoCoordinates::Pair)));
 
@@ -255,15 +269,22 @@ QWidget* BackendGoogleMaps::mapWidget()
         }
         else
         {
-            const QUrl htmlUrl = GeoIfaceGlobalObject::instance()->locateDataFile(QLatin1String("backend-googlemaps.html"));
-
-            d->htmlWidget->load(htmlUrl);
+            reload();
         }
     }
 
     return d->htmlWidgetWrapper.data();
 }
 
+void BackendGoogleMaps::reload()
+{
+    if (d->htmlWidget)
+    {
+        const QUrl htmlUrl = GeoIfaceGlobalObject::instance()->locateDataFile(d->htmlFileName);
+        d->htmlWidget->load(htmlUrl);
+    }
+}
+
 GeoCoordinates BackendGoogleMaps::getCenter() const
 {
     return d->cacheCenter;
@@ -282,8 +303,8 @@ void BackendGoogleMaps::setCenter(const GeoCoordinates& coordinate)
 void BackendGoogleMaps::slotSetCenterTimer()
 {
     d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetCenter(%1, %2);")
-                             .arg(d->cacheCenter.latString())
-                             .arg(d->cacheCenter.lonString()));
+                                 .arg(d->cacheCenter.latString())
+                                 .arg(d->cacheCenter.lonString()));
 }
 
 bool BackendGoogleMaps::isReady() const
@@ -295,8 +316,8 @@ void BackendGoogleMaps::slotHTMLInitialized()
 {
     d->isReady     = true;
     d->htmlWidget->runScript(QString::fromLatin1("kgeomapWidgetResized(%1, %2)")
-                             .arg(d->htmlWidgetWrapper->width())
-                             .arg(d->htmlWidgetWrapper->height()));
+                                 .arg(d->htmlWidgetWrapper->width())
+                                 .arg(d->htmlWidgetWrapper->height()));
 
     // TODO: call javascript directly here and update action availability in one shot
 
@@ -384,6 +405,10 @@ void BackendGoogleMaps::addActionsToConfigurationMenu(QMenu* const configuration
     floatItemsSubMenu->addAction(d->showNavigationControlAction);
     floatItemsSubMenu->addAction(d->showScaleControlAction);
 
+    configurationMenu->addSeparator();
+
+    addCommonOptions(configurationMenu);
+
     updateActionAvailability();
 }
 
@@ -411,9 +436,9 @@ void BackendGoogleMaps::readSettingsFromGroup(const KConfigGroup* const group)
         return;
     }
 
-    setMapType(group->readEntry("GoogleMaps Map Type", "ROADMAP"));
-    setShowScaleControl(group->readEntry("GoogleMaps Show Scale Control", true));
-    setShowMapTypeControl(group->readEntry("GoogleMaps Show Map Type Control", true));
+    setMapType(group->readEntry("GoogleMaps Map Type",                              "ROADMAP"));
+    setShowScaleControl(group->readEntry("GoogleMaps Show Scale Control",           true));
+    setShowMapTypeControl(group->readEntry("GoogleMaps Show Map Type Control",      true));
     setShowNavigationControl(group->readEntry("GoogleMaps Show Navigation Control", true));
 }
 
@@ -430,7 +455,7 @@ void BackendGoogleMaps::slotUngroupedModelChanged(const int mindex)
 
     // this can happen when a model was removed and we are simply asked to remove its markers
 
-    if (mindex > s->ungroupedModels.count())
+    if (mindex >= s->ungroupedModels.count())
     {
         return;
     }
@@ -471,13 +496,15 @@ void BackendGoogleMaps::slotUngroupedModelChanged(const int mindex)
         // TODO: use the pixmap supplied by the modelHelper
 
         d->htmlWidget->runScript(QString::fromLatin1("kgeomapAddMarker(%1, %2, %3, %4, %5, %6);")
-                .arg(mindex)
-                .arg(row)
-                .arg(currentCoordinates.latString())
-                .arg(currentCoordinates.lonString())
-                .arg(itemFlags.testFlag(GeoModelHelper::FlagMovable) ? QLatin1String("true") : QLatin1String("false"))
-                .arg(itemFlags.testFlag(GeoModelHelper::FlagSnaps) ? QLatin1String("true") : QLatin1String("false"))
-            );
+                                     .arg(mindex)
+                                     .arg(row)
+                                     .arg(currentCoordinates.latString())
+                                     .arg(currentCoordinates.lonString())
+                                     .arg(itemFlags.testFlag(GeoModelHelper::FlagMovable) ? QLatin1String("true")
+                                                                                          : QLatin1String("false"))
+                                     .arg(itemFlags.testFlag(GeoModelHelper::FlagSnaps) ? QLatin1String("true")
+                                                                                        : QLatin1String("false"))
+                                );
 
         QPoint     markerCenterPoint;
         QSize      markerSize;
@@ -823,20 +850,24 @@ void BackendGoogleMaps::updateClusters()
                               s->markerModel->tilerFlags().testFlag(AbstractMarkerTiler::FlagMovable);
 
     d->htmlWidget->runScript(QLatin1String("kgeomapClearClusters();"));
-    d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetIsInEditMode(%1);").arg(s->showThumbnails?QLatin1String("false" ):QLatin1String("true" )));
+    d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetIsInEditMode(%1);")
+                                 .arg(s->showThumbnails ? QLatin1String("false")
+                                                        : QLatin1String("true"))
+                            );
 
     for (int currentIndex = 0 ; currentIndex < s->clusterList.size() ; ++currentIndex)
     {
         const GeoIfaceCluster& currentCluster = s->clusterList.at(currentIndex);
 
         d->htmlWidget->runScript(QString::fromLatin1("kgeomapAddCluster(%1, %2, %3, %4, %5, %6);")
-                .arg(currentIndex)
-                .arg(currentCluster.coordinates.latString())
-                .arg(currentCluster.coordinates.lonString())
-                .arg(canMoveItems ? QLatin1String("true") : QLatin1String("false"))
-                .arg(currentCluster.markerCount)
-                .arg(currentCluster.markerSelectedCount)
-            );
+                                     .arg(currentIndex)
+                                     .arg(currentCluster.coordinates.latString())
+                                     .arg(currentCluster.coordinates.lonString())
+                                     .arg(canMoveItems ? QLatin1String("true")
+                                                       : QLatin1String("false"))
+                                     .arg(currentCluster.markerCount)
+                                     .arg(currentCluster.markerSelectedCount)
+                                );
 
         // TODO: for now, only set generated pixmaps when not in edit mode
         // this can be changed once we figure out how to appropriately handle
@@ -887,8 +918,8 @@ bool BackendGoogleMaps::geoCoordinates(const QPoint& point, GeoCoordinates* cons
 
     const bool isValid = d->htmlWidget->runScript2Coordinates(
         QString::fromLatin1("kgeomapPixelToLatLng(%1, %2);")
-                .arg(point.x())
-                .arg(point.y()),
+            .arg(point.x())
+            .arg(point.y()),
             coordinates);
 
     return isValid;
@@ -934,9 +965,10 @@ void BackendGoogleMaps::setShowScaleControl(const bool state)
         return;
     }
 
-    d->htmlWidget->runScript(
-        QString::fromLatin1("kgeomapSetShowScaleControl(%1);")
-        .arg(state ? QLatin1String("true") : QLatin1String("false")));
+    d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetShowScaleControl(%1);")
+                                 .arg(state ? QLatin1String("true")
+                                            : QLatin1String("false"))
+                            );
 }
 
 void BackendGoogleMaps::setShowNavigationControl(const bool state)
@@ -953,9 +985,10 @@ void BackendGoogleMaps::setShowNavigationControl(const bool state)
         return;
     }
 
-    d->htmlWidget->runScript(
-        QString::fromLatin1("kgeomapSetShowNavigationControl(%1);")
-        .arg(state ? QLatin1String("true") : QLatin1String("false")));
+    d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetShowNavigationControl(%1);")
+                                 .arg(state ? QLatin1String("true")
+                                            : QLatin1String("false"))
+                            );
 }
 
 void BackendGoogleMaps::setShowMapTypeControl(const bool state)
@@ -972,9 +1005,10 @@ void BackendGoogleMaps::setShowMapTypeControl(const bool state)
         return;
     }
 
-    d->htmlWidget->runScript(
-        QString::fromLatin1("kgeomapSetShowMapTypeControl(%1);")
-        .arg(state ? QLatin1String("true") : QLatin1String("false")));
+    d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetShowMapTypeControl(%1);")
+                                 .arg(state ? QLatin1String("true")
+                                            : QLatin1String("false"))
+                            );
 }
 
 void BackendGoogleMaps::slotClustersNeedUpdating()
@@ -1181,13 +1215,13 @@ void BackendGoogleMaps::setClusterPixmap(const int clusterId, const QPoint& cent
 
     const QString imageData = QString::fromLatin1("data:image/png;base64,%1").arg(QString::fromLatin1(bytes.toBase64()));
     d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetClusterPixmap(%1,%5,%6,%2,%3,'%4');")
-                    .arg(clusterId)
-                    .arg(centerPoint.x())
-                    .arg(centerPoint.y())
-                    .arg(imageData)
-                    .arg(clusterPixmap.width())
-                    .arg(clusterPixmap.height())
-                );
+                                 .arg(clusterId)
+                                 .arg(centerPoint.x())
+                                 .arg(centerPoint.y())
+                                 .arg(imageData)
+                                 .arg(clusterPixmap.width())
+                                 .arg(clusterPixmap.height())
+                            );
 }
 
 void BackendGoogleMaps::setMarkerPixmap(const int modelId, const int markerId,
@@ -1203,14 +1237,14 @@ void BackendGoogleMaps::setMarkerPixmap(const int modelId, const int markerId,
 
     const QString imageData = QString::fromLatin1("data:image/png;base64,%1").arg(QString::fromLatin1(bytes.toBase64()));
     d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetMarkerPixmap(%7,%1,%5,%6,%2,%3,'%4');")
-                    .arg(markerId)
-                    .arg(centerPoint.x())
-                    .arg(centerPoint.y())
-                    .arg(imageData)
-                    .arg(markerPixmap.width())
-                    .arg(markerPixmap.height())
-                    .arg(modelId)
-                );
+                                 .arg(markerId)
+                                 .arg(centerPoint.x())
+                                 .arg(centerPoint.y())
+                                 .arg(imageData)
+                                 .arg(markerPixmap.width())
+                                 .arg(markerPixmap.height())
+                                 .arg(modelId)
+                            );
 }
 
 void BackendGoogleMaps::setMarkerPixmap(const int modelId, const int markerId,
@@ -1220,14 +1254,14 @@ void BackendGoogleMaps::setMarkerPixmap(const int modelId, const int markerId,
     /// @todo Sort the parameters
 
     d->htmlWidget->runScript(QString::fromLatin1("kgeomapSetMarkerPixmap(%7,%1,%5,%6,%2,%3,'%4');")
-                    .arg(markerId)
-                    .arg(centerPoint.x())
-                    .arg(centerPoint.y())
-                    .arg(iconUrl.url()) /// @todo Escape characters like apostrophe
-                    .arg(iconSize.width())
-                    .arg(iconSize.height())
-                    .arg(modelId)
-                );
+                                 .arg(markerId)
+                                 .arg(centerPoint.x())
+                                 .arg(centerPoint.y())
+                                 .arg(iconUrl.url()) /// @todo Escape characters like apostrophe
+                                 .arg(iconSize.width())
+                                 .arg(iconSize.height())
+                                 .arg(modelId)
+                            );
 }
 
 bool BackendGoogleMaps::eventFilter(QObject* object, QEvent* event)
@@ -1246,8 +1280,9 @@ bool BackendGoogleMaps::eventFilter(QObject* object, QEvent* event)
                 if (d->isReady)
                 {
                     d->htmlWidget->runScript(QString::fromLatin1("kgeomapWidgetResized(%1, %2)")
-                                             .arg(d->htmlWidgetWrapper->width())
-                                             .arg(d->htmlWidgetWrapper->height()));
+                                                 .arg(d->htmlWidgetWrapper->width())
+                                                 .arg(d->htmlWidgetWrapper->height())
+                                            );
                 }
             }
         }
@@ -1290,24 +1325,6 @@ void BackendGoogleMaps::slotSelectionHasBeenMade(const Digikam::GeoCoordinates::
     Q_EMIT signalSelectionHasBeenMade(searchCoordinates);
 }
 
-void BackendGoogleMaps::centerOn( const Marble::GeoDataLatLonBox& latLonBox, const bool useSaneZoomLevel)
-{
-    /// @todo Buffer this call if there is no widget or if inactive!
-
-    if (!d->htmlWidget)
-    {
-        return;
-    }
-
-    const qreal boxWest  = latLonBox.west(Marble::GeoDataCoordinates::Degree);
-    const qreal boxNorth = latLonBox.north(Marble::GeoDataCoordinates::Degree);
-    const qreal boxEast  = latLonBox.east(Marble::GeoDataCoordinates::Degree);
-    const qreal boxSouth = latLonBox.south(Marble::GeoDataCoordinates::Degree);
-
-    d->htmlWidget->centerOn(boxWest, boxNorth, boxEast, boxSouth, useSaneZoomLevel);
-    qCDebug(DIGIKAM_GEOIFACE_LOG) << getZoom();
-}
-
 void BackendGoogleMaps::setActive(const bool state)
 {
     const bool oldState = d->activeState;
@@ -1585,4 +1602,35 @@ void BackendGoogleMaps::slotTrackVisibilityChanged(const bool newState)
     }
 }
 
+void BackendGoogleMaps::slotMessageEvent(const QString& /*message*/)
+{
+/*
+    qCDebug(DIGIKAM_GEOIFACE_LOG) << "Javascript Message:" << message;
+*/
+}
+
+#ifdef HAVE_GEOLOCATION
+
+void BackendGoogleMaps::centerOn(const Marble::GeoDataLatLonBox& latLonBox, const bool useSaneZoomLevel)
+{
+    /// @todo Buffer this call if there is no widget or if inactive!
+
+    if (!d->htmlWidget)
+    {
+        return;
+    }
+
+    const qreal boxWest  = latLonBox.west(Marble::GeoDataCoordinates::Degree);
+    const qreal boxNorth = latLonBox.north(Marble::GeoDataCoordinates::Degree);
+    const qreal boxEast  = latLonBox.east(Marble::GeoDataCoordinates::Degree);
+    const qreal boxSouth = latLonBox.south(Marble::GeoDataCoordinates::Degree);
+
+    d->htmlWidget->centerOn(boxWest, boxNorth, boxEast, boxSouth, useSaneZoomLevel);
+    qCDebug(DIGIKAM_GEOIFACE_LOG) << getZoom();
+}
+
+#endif
+
 } // namespace Digikam
+
+#include "moc_backendgooglemaps.cpp"
