@@ -6,20 +6,11 @@
  * Date        : 2009-12-08
  * Description : Marble-backend for geolocation interface
  *
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2014      by Justus Schwartz <justus at gmx dot li>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2014      by Justus Schwartz <justus at gmx dot li>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -31,6 +22,7 @@
 #include <QMouseEvent>
 #include <QPointer>
 #include <QAction>
+#include <QActionGroup>
 #include <QStandardItemModel>
 
 // KDE includes
@@ -40,24 +32,25 @@
 
 // Marble includes
 
-#include <marble/GeoDataLinearRing.h>
-#include <marble/GeoDataLatLonAltBox.h>
-#include <marble/GeoPainter.h>
-#include <marble/MarbleMap.h>
-#include <marble/MarbleWidget.h>
-#include <marble/ViewportParams.h>
-#include <marble/AbstractFloatItem.h>
-#include <marble/MarbleWidgetPopupMenu.h>
-#include <marble/MapThemeManager.h>
+#include "GeoDataLinearRing.h"
+#include "GeoDataLatLonAltBox.h"
+#include "GeoPainter.h"
+#include "MarbleMap.h"
+#include "MarbleDirs.h"
+#include "MarbleWidget.h"
+#include "ViewportParams.h"
+#include "AbstractFloatItem.h"
+#include "MarbleWidgetPopupMenu.h"
+#include "MapThemeManager.h"
 
 // Local includes
 
+#include "digikam_debug.h"
+#include "digikam_config.h"
 #include "backendmarblelayer.h"
 #include "abstractmarkertiler.h"
 #include "mapwidget.h"
 #include "geomodelhelper.h"
-#include "trackmanager.h"
-#include "digikam_debug.h"
 
 namespace Digikam
 {
@@ -66,12 +59,9 @@ class Q_DECL_HIDDEN BMInternalWidgetInfo
 {
 public:
 
-    explicit BMInternalWidgetInfo()
-      : bmLayer(nullptr)
-    {
-    }
+    BMInternalWidgetInfo() = default;
 
-    BackendMarbleLayer* bmLayer;
+    BackendMarbleLayer* bmLayer = nullptr;
 };
 
 } // namespace Digikam
@@ -94,11 +84,11 @@ public:
         actionShowScaleBar              (nullptr),
         actionShowNavigation            (nullptr),
         actionShowOverviewMap           (nullptr),
-        cacheMapTheme                   (QLatin1String("earth/srtm/srtm.dgml")),
+        cacheMapTheme                   (QLatin1String("earth/openstreetmap/openstreetmap.dgml")),
         cacheProjection                 (QLatin1String("spherical")),
         cacheShowCompass                (false),
         cacheShowScaleBar               (false),
-        cacheShowNavigation             (false),
+        cacheShowNavigation             (true),
         cacheShowOverviewMap            (false),
         cacheZoom                       (900),
         havePotentiallyMouseMovingObject(false),
@@ -175,7 +165,7 @@ BackendMarble::BackendMarble(const QExplicitlySharedDataPointer<GeoIfaceSharedDa
       d         (new Private())
 {
     d->marbleMapThemeManager = new Marble::MapThemeManager(this);
-    createActions();
+    this->createActions();
 }
 
 BackendMarble::~BackendMarble()
@@ -236,19 +226,6 @@ QWidget* BackendMarble::mapWidget()
             d->marbleWidget->addLayer(d->bmLayer);
         }
 
-        // hide Marble bookmark action in the right button context menu
-        // TODO: check with a new Marble version if the bookmark action position is still valid
-
-        if (d->marbleWidget->popupMenu())
-        {
-            QList<QAction*> actions = d->marbleWidget->popupMenu()->findChildren<QAction*>();
-
-            if ((actions.count() > 4) && actions[4])
-            {
-                actions[4]->setVisible(false);
-            }
-        }
-
         d->marbleWidget->installEventFilter(this);
 
         connect(d->marbleWidget, SIGNAL(zoomChanged(int)),
@@ -259,7 +236,7 @@ QWidget* BackendMarble::mapWidget()
 
         applyCacheToWidget();
 
-        emit signalBackendReadyChanged(backendName());
+        Q_EMIT signalBackendReadyChanged(backendName());
     }
 
     return d->marbleWidget;
@@ -284,7 +261,7 @@ void BackendMarble::releaseWidget(GeoIfaceInternalWidgetInfo* const info)
     d->marbleWidget    = nullptr;
     d->bmLayer         = nullptr;
 
-    emit signalBackendReadyChanged(backendName());
+    Q_EMIT signalBackendReadyChanged(backendName());
 }
 
 GeoCoordinates BackendMarble::getCenter() const
@@ -310,7 +287,7 @@ void BackendMarble::setCenter(const GeoCoordinates& coordinate)
 
 bool BackendMarble::isReady() const
 {
-    return d->marbleWidget != nullptr;
+    return (d->marbleWidget != nullptr);
 }
 
 void BackendMarble::zoomIn()
@@ -345,11 +322,12 @@ void BackendMarble::createActions()
     connect(d->actionGroupMapTheme, &QActionGroup::triggered,
             this, &BackendMarble::slotMapThemeActionTriggered);
 
-
     QList<QPair<QString, QString>> mainThemes;
-    mainThemes.append({i18n("Atlas map"), QLatin1String("earth/srtm/srtm.dgml")});
-    mainThemes.append({i18n("Satellite map"), QLatin1String("earth/bluemarble/bluemarble.dgml")});
-    mainThemes.append({i18n("OpenStreetMap"), QLatin1String("earth/openstreetmap/openstreetmap.dgml")});
+    mainThemes.append( { i18n("Atlas map"),              QLatin1String("earth/srtm/srtm.dgml")                   } );
+    mainThemes.append( { i18n("Satellite map"),          QLatin1String("earth/bluemarble/bluemarble.dgml")       } );
+    mainThemes.append( { i18n("OpenStreetMap"),          QLatin1String("earth/openstreetmap/openstreetmap.dgml") } );
+    mainThemes.append( { i18n("OpenStreetMap (Vector)"), QLatin1String("earth/vectorosm/vectorosm.dgml")         } );
+
     for (auto& theme : mainThemes)
     {
         QAction* const mapAction = new QAction(d->actionGroupMapTheme);
@@ -359,7 +337,8 @@ void BackendMarble::createActions()
         d->mainMarbleThemes.append(theme.second);
     }
 
-    QStringList blackListedMarbleThemes {
+    QStringList blackListedMarbleThemes
+    {
         QLatin1String("earth/behaim1492/behaim1492.dgml"),
         QLatin1String("earth/citylights/citylights.dgml"),
         QLatin1String("earth/plain/plain.dgml"),
@@ -367,42 +346,48 @@ void BackendMarble::createActions()
         QLatin1String("earth/precip-dec/precip-dec.dgml"),
         QLatin1String("earth/precip-july/precip-july.dgml"),
         QLatin1String("earth/schagen1689/schagen1689.dgml"),
-        QLatin1String("earth/sentinel2/sentinel2.dgml"),
+        QLatin1String("earth/openstreetmap/openstreetmap.dgml"),
         QLatin1String("earth/temp-dec/temp-dec.dgml"),
-        QLatin1String("earth/temp-july/temp-july.dgml")};
+        QLatin1String("earth/temp-july/temp-july.dgml")
+    };
 
     // add all available marble earth themes
+
     auto* themeModel = d->marbleMapThemeManager->mapThemeModel();
-    for (int i = 0; i < themeModel->rowCount(); ++i)
+
+    for (int i = 0 ; i < themeModel->rowCount() ; ++i)
     {
-        auto* item = themeModel->item(i);
-        auto themeId = item->data(Qt::UserRole + 1).toString();
+        auto* item     = themeModel->item(i);
+        auto themeId   = item->data(Qt::UserRole + 1).toString();
         auto themeName = item->data(Qt::DisplayRole).toString();
-        if (d->mainMarbleThemes.contains(themeId)
-            || blackListedMarbleThemes.contains(themeId)
-            || !themeId.startsWith(QLatin1String("earth/"))) {
+
+        if (d->mainMarbleThemes.contains(themeId)     ||
+            blackListedMarbleThemes.contains(themeId) ||
+            !themeId.startsWith(QLatin1String("earth/")))
+        {
             continue;
         }
+
         QAction* const mapAction = new QAction(d->actionGroupMapTheme);
         mapAction->setCheckable(true);
         mapAction->setText(themeName);
         mapAction->setData(themeId);
     }
 
-    // projection:
+    // projection
 
-    d->actionGroupProjection = new QActionGroup(this);
+    d->actionGroupProjection             = new QActionGroup(this);
     d->actionGroupProjection->setExclusive(true);
 
     connect(d->actionGroupProjection, &QActionGroup::triggered,
             this, &BackendMarble::slotProjectionActionTriggered);
 
-    QAction* const actionSpherical = new QAction(d->actionGroupProjection);
+    QAction* const actionSpherical       = new QAction(d->actionGroupProjection);
     actionSpherical->setCheckable(true);
     actionSpherical->setText(i18nc("Spherical projection", "Spherical"));
     actionSpherical->setData(QLatin1String("spherical"));
 
-    QAction* const actionMercator = new QAction(d->actionGroupProjection);
+    QAction* const actionMercator        = new QAction(d->actionGroupProjection);
     actionMercator->setCheckable(true);
     actionMercator->setText(i18n("Mercator"));
     actionMercator->setData(QLatin1String("mercator"));
@@ -412,7 +397,7 @@ void BackendMarble::createActions()
     actionEquirectangular->setText(i18n("Equirectangular"));
     actionEquirectangular->setData(QLatin1String("equirectangular"));
 
-    // float items:
+    // float items
 
     d->actionGroupFloatItems = new QActionGroup(this);
     d->actionGroupFloatItems->setExclusive(false);
@@ -420,17 +405,17 @@ void BackendMarble::createActions()
     connect(d->actionGroupFloatItems, &QActionGroup::triggered,
             this, &BackendMarble::slotFloatSettingsTriggered);
 
-    d->actionShowCompass = new QAction(i18n("Show compass"), d->actionGroupFloatItems);
+    d->actionShowCompass     = new QAction(i18n("Show compass"), d->actionGroupFloatItems);
     d->actionShowCompass->setData(QLatin1String("showcompass"));
     d->actionShowCompass->setCheckable(true);
     d->actionGroupFloatItems->addAction(d->actionShowCompass);
 
-    d->actionShowScaleBar = new QAction(i18n("Show scale bar"), d->actionGroupFloatItems);
+    d->actionShowScaleBar    = new QAction(i18n("Show scale bar"), d->actionGroupFloatItems);
     d->actionShowScaleBar->setData(QLatin1String("showscalebar"));
     d->actionShowScaleBar->setCheckable(true);
     d->actionGroupFloatItems->addAction(d->actionShowScaleBar);
 
-    d->actionShowNavigation = new QAction(i18n("Show navigation"), d->actionGroupFloatItems);
+    d->actionShowNavigation  = new QAction(i18n("Show navigation"), d->actionGroupFloatItems);
     d->actionShowNavigation->setData(QLatin1String("shownavigation"));
     d->actionShowNavigation->setCheckable(true);
     d->actionGroupFloatItems->addAction(d->actionShowNavigation);
@@ -449,6 +434,7 @@ void BackendMarble::addActionsToConfigurationMenu(QMenu* const configurationMenu
 
     const QList<QAction*> mapThemeActions = d->actionGroupMapTheme->actions();
     QMenu* const extraMarbleMenu          = new QMenu(i18n("Other Marble Themes"), configurationMenu);
+
     for (auto* action : mapThemeActions)
     {
         if (d->mainMarbleThemes.contains(action->data().toString()))
@@ -460,6 +446,7 @@ void BackendMarble::addActionsToConfigurationMenu(QMenu* const configurationMenu
             extraMarbleMenu->addAction(action);
         }
     }
+
     if (extraMarbleMenu->isEmpty())
     {
         delete extraMarbleMenu;
@@ -469,7 +456,6 @@ void BackendMarble::addActionsToConfigurationMenu(QMenu* const configurationMenu
         configurationMenu->addMenu(extraMarbleMenu);
     }
 
-
     configurationMenu->addSeparator();
 
     // TODO: we need a parent for this guy!
@@ -492,6 +478,10 @@ void BackendMarble::addActionsToConfigurationMenu(QMenu* const configurationMenu
         floatItemsSubMenu->addAction(floatActions.at(i));
     }
 
+    configurationMenu->addSeparator();
+
+    addCommonOptions(configurationMenu);
+
     updateActionAvailability();
 }
 
@@ -510,7 +500,8 @@ QString BackendMarble::getMapTheme() const
 void BackendMarble::setMapTheme(const QString& newMapTheme)
 {
     // convert old ids to themeIds
-    if (newMapTheme == QLatin1String("atlas"))
+
+    if      (newMapTheme == QLatin1String("atlas"))
     {
         d->cacheMapTheme = QLatin1String("earth/srtm/srtm.dgml");
     }
@@ -532,7 +523,6 @@ void BackendMarble::setMapTheme(const QString& newMapTheme)
         d->cacheMapTheme = newMapTheme;
     }
 
-
     if (!d->marbleWidget)
     {
         return;
@@ -617,14 +607,19 @@ void BackendMarble::readSettingsFromGroup(const KConfigGroup* const group)
 }
 
 void BackendMarble::updateMarkers()
+{
+    // just redraw, that's it:
+
+    reload();
+}
+
+void BackendMarble::reload()
 {
     if (!d->marbleWidget)
     {
         return;
     }
 
-    // just redraw, that's it:
-
     d->marbleWidget->update();
 }
 
@@ -1186,7 +1181,7 @@ void BackendMarble::slotMarbleZoomChanged()
     s->worldMapWidget->markClustersAsDirty();
     updateActionAvailability();
 
-    emit signalZoomChanged(newZoomString);
+    Q_EMIT signalZoomChanged(newZoomString);
 }
 
 void BackendMarble::setZoom(const QString& newZoom)
@@ -1428,7 +1423,7 @@ bool BackendMarble::eventFilter(QObject* object, QEvent* event)
                 d->firstSelectionPoint.clear();
                 d->displayedRectangle.first.clear();
 
-                emit signalSelectionHasBeenMade(selectionCoordinates);
+                Q_EMIT signalSelectionHasBeenMade(selectionCoordinates);
             }
 
             doFilterEvent = true;
@@ -1587,7 +1582,7 @@ bool BackendMarble::eventFilter(QObject* object, QEvent* event)
                 s->haveMovingCluster                = false;
                 doFilterEvent                       = true;
 
-                emit signalClustersClicked(QIntList() << mouseMoveClusterIndex);
+                Q_EMIT signalClustersClicked(QIntList() << mouseMoveClusterIndex);
             }
             else
             {
@@ -1629,9 +1624,9 @@ bool BackendMarble::eventFilter(QObject* object, QEvent* event)
                     QList<QPersistentModelIndex> markerIndices;
                     markerIndices << d->mouseMoveMarkerIndex;
 
-                    // also emit a signal that the marker was moved:
+                    // also Q_EMIT a signal that the marker was moved:
 
-                    emit signalSpecialMarkersMoved(markerIndices);
+                    Q_EMIT signalSpecialMarkersMoved(markerIndices);
 */
                 }
                 else
@@ -1639,7 +1634,7 @@ bool BackendMarble::eventFilter(QObject* object, QEvent* event)
                     // a cluster is being moved
 
                     s->clusterList[d->mouseMoveClusterIndex].coordinates = newCoordinates;
-                    emit signalClustersMoved(QIntList() << d->mouseMoveClusterIndex, snapTargetIndex);
+                    Q_EMIT signalClustersMoved(QIntList() << d->mouseMoveClusterIndex, snapTargetIndex);
                 }
             }
 
@@ -2055,7 +2050,7 @@ void BackendMarble::slotTracksChanged(const QList<TrackManager::TrackChanges>& t
 {
     // invalidate the cache for all changed tracks
 
-    foreach (const TrackManager::TrackChanges& tc, trackChanges)
+    Q_FOREACH (const TrackManager::TrackChanges& tc, trackChanges)
     {
         if (tc.second & (TrackManager::ChangeTrackPoints | TrackManager::ChangeRemoved))
         {
@@ -2077,3 +2072,5 @@ void BackendMarble::slotScheduleUpdate()
 }
 
 } // namespace Digikam
+
+#include "moc_backendmarble.cpp"
