@@ -6,19 +6,10 @@
  * Date        : 2009-11-21
  * Description : Central object for managing bookmarks
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -36,7 +27,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "bookmarksmngr.h"
 #include "bookmarknode.h"
 #include "gpsbookmarkowner.h"
 #include "gpsundocommand.h"
@@ -83,7 +73,7 @@ void GPSBookmarkModelHelper::Private::addBookmarkGroupToModel(BookmarkNode* cons
         return;
     }
 
-    foreach (BookmarkNode* const currentBookmark, list)
+    Q_FOREACH (BookmarkNode* const currentBookmark, list)
     {
         if (currentBookmark)
         {
@@ -204,7 +194,7 @@ void GPSBookmarkModelHelper::setVisible(const bool state)
 {
     d->visible = state;
 
-    emit signalVisibilityChanged();
+    Q_EMIT signalVisibilityChanged();
 }
 
 GeoModelHelper::PropertyFlags GPSBookmarkModelHelper::modelFlags() const
@@ -252,7 +242,9 @@ void GPSBookmarkModelHelper::snapItemsTo(const QModelIndex& targetIndex,
     undoCommand->setText(i18np("1 image snapped to '%2'",
                                "%1 images snapped to '%2'", snappedIndices.count(), targetIndex.data(Qt::DisplayRole).toString()));
 
-    emit signalUndoCommand(undoCommand);
+    Q_EMIT signalUndoCommand(undoCommand);
 }
 
 } // namespace Digikam
+
+#include "moc_gpsbookmarkmodelhelper.cpp"
