@@ -6,19 +6,10 @@
  * Date        : 2009-11-21
  * Description : Central object for managing bookmarks
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -28,6 +19,7 @@
 
 #include <QStandardItemModel>
 #include <QStandardPaths>
+#include <QPointer>
 
 // KDE includes
 
@@ -58,13 +50,14 @@ public:
     {
     }
 
-    QWidget*                 parent;
-    BookmarksManager*        bookmarkManager;
-    BookmarksMenu*           bookmarkMenu;
-    bool                     addBookmarkEnabled;
-    GPSBookmarkModelHelper*  bookmarkModelHelper;
-    GeoCoordinates           lastCoordinates;
-    QString                  lastTitle;
+    QWidget*                  parent;
+    BookmarksManager*         bookmarkManager;
+    BookmarksMenu*            bookmarkMenu;
+    QPointer<BookmarksDialog> bookmarksDialog;
+    bool                      addBookmarkEnabled;
+    GPSBookmarkModelHelper*   bookmarkModelHelper;
+    GeoCoordinates            lastCoordinates;
+    QString                   lastTitle;
 };
 
 GPSBookmarkOwner::GPSBookmarkOwner(GPSItemModel* const gpsItemModel, QWidget* const parent)
@@ -121,14 +114,24 @@ void GPSBookmarkOwner::slotOpenBookmark(const QUrl& url)
     {
         GPSDataContainer position;
         position.setCoordinates(coordinate);
-        emit positionSelected(position);
+        Q_EMIT positionSelected(position);
     }
 }
 
 void GPSBookmarkOwner::slotShowBookmarksDialog()
 {
-    BookmarksDialog* const dlg = new BookmarksDialog(d->parent, d->bookmarkManager);
-    dlg->show();
+    if (d->bookmarksDialog &&
+        (d->bookmarksDialog->isMinimized() || !d->bookmarksDialog->isHidden()))
+    {
+        d->bookmarksDialog->showNormal();       // krazy:exclude=qmethods
+        d->bookmarksDialog->activateWindow();
+        d->bookmarksDialog->raise();
+    }
+    else
+    {
+        d->bookmarksDialog = new BookmarksDialog(d->parent, d->bookmarkManager);
+        d->bookmarksDialog->show();
+    }
 }
 
 void GPSBookmarkOwner::slotAddBookmark()
@@ -187,3 +190,5 @@ void GPSBookmarkOwner::setPositionAndTitle(const GeoCoordinates& coordinates,
 }
 
 } // namespace Digikam
+
+#include "moc_gpsbookmarkowner.cpp"
