@@ -6,7 +6,7 @@
  * Date        : 2014-06-09
  * Description : A model to list the tracks
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -21,7 +21,6 @@
 
 // Local includes
 
-#include "trackmanager.h"
 
 namespace Digikam
 {
@@ -38,12 +37,9 @@ class Q_DECL_HIDDEN TrackListModel::Private
 {
 public:
 
-    explicit Private()
-      : trackManager(nullptr)
-    {
-    }
+    Private() = default;
 
-    TrackManager* trackManager;
+    TrackManager* trackManager = nullptr;
 };
 
 TrackListModel::TrackListModel(TrackManager* const trackManager, QObject* const parent)
@@ -104,7 +100,7 @@ QVariant TrackListModel::data(const QModelIndex& index, int role) const
     switch (role)
     {
         case Qt::DisplayRole:
-
+        {
             switch (columnNumber)
             {
                 case ColumnFilename:
@@ -124,10 +120,11 @@ QVariant TrackListModel::data(const QModelIndex& index, int role) const
             }
 
             break;
+        }
 
         case Qt::BackgroundRole:
         case Qt::DecorationRole:
-
+        {
             switch (columnNumber)
             {
                 case ColumnVisible:
@@ -137,6 +134,7 @@ QVariant TrackListModel::data(const QModelIndex& index, int role) const
             }
 
             break;
+        }
     }
 
     return QVariant();
@@ -268,3 +266,5 @@ TrackManager::Track TrackListModel::getTrackForIndex(const QModelIndex& index) c
 }
 
 } // namespace Digikam
+
+#include "moc_track_listmodel.cpp"
