@@ -6,7 +6,7 @@
  * Date        : 2010-03-21
  * Description : A container to hold GPS information about an item.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,23 +44,38 @@ bool setExifXmpTagDataVariant(DMetadata* const meta, const char* const exifTagNa
     if (success)
     {
         /**
-         * @todo Here we save all data types as XMP Strings. Is that okay or do we have to store them as some other type?
+         * @todo Here we save all data types as XMP Strings.
+         * Is that okay or do we have to store them as some other type?
          */
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        switch (static_cast<QMetaType::Type>(value.typeId()))
+
+#else
+
         switch (value.type())
+
+#endif
+
         {
             case QVariant::Int:
             case QVariant::UInt:
             case QVariant::Bool:
             case QVariant::LongLong:
             case QVariant::ULongLong:
+            {
                 success = meta->setXmpTagString(xmpTagName, QString::number(value.toInt()));
+
                 break;
+            }
 
             case QVariant::Double:
             {
                 long num, den;
                 meta->convertToRationalSmallDenominator(value.toDouble(), &num, &den);
                 success = meta->setXmpTagString(xmpTagName, QString::fromLatin1("%1/%2").arg(num).arg(den));
+
                 break;
             }
 
@@ -81,6 +96,7 @@ bool setExifXmpTagDataVariant(DMetadata* const meta, const char* const exifTagNa
                 }
 
                 success = meta->setXmpTagString(xmpTagName, QString::fromLatin1("%1/%2").arg(num).arg(den));
+
                 break;
             }
 
@@ -101,19 +117,27 @@ bool setExifXmpTagDataVariant(DMetadata* const meta, const char* const exifTagNa
 
             case QVariant::String:
             case QVariant::Char:
+            {
                 success = meta->setXmpTagString(xmpTagName, value.toString());
+
                 break;
+            }
 
             case QVariant::ByteArray:
-
+            {
                 /// @todo I don't know a straightforward way to convert a byte array to XMP
 
                 success = false;
+
                 break;
+            }
 
             default:
+            {
                 success = false;
+
                 break;
+            }
         }
     }
 
@@ -131,9 +155,7 @@ GPSItemContainer::GPSItemContainer(const QUrl& url)
       m_tagList     (),
       m_savedTagList(),
       m_writeXmpTags(true),
-      m_writeMetaLoc(true),
-      m_saveTags    (true),
-      m_saveGPS     (true)
+      m_writeMetaLoc(true)
 {
 }
 
@@ -228,6 +250,8 @@ bool GPSItemContainer::loadImageData()
         {
             m_dateTime = qMin(ctime, mtime);
         }
+
+        m_dateTime.setTimeSpec(Qt::UTC);
     }
 
     if (!meta)
@@ -461,20 +485,30 @@ QVariant GPSItemContainer::data(const int column, const int role) const
             switch (warningLevel)
             {
                 case 1:
+                {
                     return QBrush(Qt::green);
+                }
 
                 case 2:
+                {
                     return QBrush(Qt::yellow);
+                }
 
                 case 3:
+                {
                     // orange
                     return QBrush(QColor(0xff, 0x80, 0x00));
+                }
 
                 case 4:
+                {
                     return QBrush(Qt::red);
+                }
 
                 default:
+                {
                     break;
+                }
             }
         }
     }
@@ -605,13 +639,19 @@ bool GPSItemContainer::lessThan(const GPSItemContainer* const otherItem, const i
     switch (column)
     {
         case ColumnThumbnail:
+        {
             return false;
+        }
 
         case ColumnFilename:
+        {
             return (m_url < otherItem->m_url);
+        }
 
         case ColumnDateTime:
+        {
             return (m_dateTime < otherItem->m_dateTime);
+        }
 
         case ColumnAltitude:
         {
@@ -671,6 +711,7 @@ bool GPSItemContainer::lessThan(const GPSItemContainer* const otherItem, const i
                 return !m_gpsData.hasDop();
             }
 
+            // cppcheck-suppress knownConditionTrueFalse
             if (m_gpsData.hasDop() && otherItem->m_gpsData.hasDop())
             {
                 return (m_gpsData.getDop() < otherItem->m_gpsData.getDop());
@@ -681,6 +722,7 @@ bool GPSItemContainer::lessThan(const GPSItemContainer* const otherItem, const i
                 return m_gpsData.hasFixType();
             }
 
+            // cppcheck-suppress knownConditionTrueFalse
             if (m_gpsData.hasFixType() && otherItem->m_gpsData.hasFixType())
             {
                 return (m_gpsData.getFixType() > otherItem->m_gpsData.getFixType());
@@ -691,6 +733,7 @@ bool GPSItemContainer::lessThan(const GPSItemContainer* const otherItem, const i
                 return m_gpsData.hasNSatellites();
             }
 
+            // cppcheck-suppress knownConditionTrueFalse
             if (m_gpsData.hasNSatellites() && otherItem->m_gpsData.hasNSatellites())
             {
                 return (m_gpsData.getNSatellites() > otherItem->m_gpsData.getNSatellites());
@@ -824,7 +867,7 @@ QString GPSItemContainer::saveChanges()
 
     // first try to write the information to the image file
 
-    bool success1 = true;
+    bool success = true;
     QScopedPointer<DMetadata> meta(getMetadataForFile());
 
     if (!meta)
@@ -832,91 +875,94 @@ QString GPSItemContainer::saveChanges()
         // TODO: more verbosity!
 
         returnString = i18n("Failed to open file.");
-        success1     = false;
+        success      = false;
     }
     else
     {
-        if (m_saveGPS && p.shouldWriteCoordinates)
+        if (p.shouldWriteCoordinates)
         {
             if (p.shouldWriteAltitude)
             {
-                success1 = meta->setGPSInfo(p.altitude, p.latitude, p.longitude);
+                success = meta->setGPSInfo(p.altitude, p.latitude, p.longitude);
             }
             else
             {
-                success1 = meta->setGPSInfo(nullptr,
-                                            p.latitude, p.longitude);
+                success = meta->setGPSInfo(nullptr,
+                                           p.latitude, p.longitude);
             }
 
             // write all other GPS information here too
 
-            if (success1 && m_gpsData.hasSpeed())
+            if (success && m_gpsData.hasSpeed())
             {
-                success1 = setExifXmpTagDataVariant(meta.data(),
-                                                    "Exif.GPSInfo.GPSSpeedRef",
-                                                    "Xmp.exif.GPSSpeedRef",
-                                                    QVariant(QLatin1String("K")));
+                success = setExifXmpTagDataVariant(meta.data(),
+                                                   "Exif.GPSInfo.GPSSpeedRef",
+                                                   "Xmp.exif.GPSSpeedRef",
+                                                   QVariant(QLatin1String("K")));
 
-                if (success1)
+                if (success)
                 {
                     const qreal speedInMetersPerSecond   = m_gpsData.getSpeed();
 
                     // km/h = 0.001 * m / ( s * 1/(60*60) ) = 3.6 * m/s
 
                     const qreal speedInKilometersPerHour = 3.6 * speedInMetersPerSecond;
-                    success1                             = setExifXmpTagDataVariant(meta.data(), "Exif.GPSInfo.GPSSpeed", "Xmp.exif.GPSSpeed", QVariant(speedInKilometersPerHour));
+                    success                              = setExifXmpTagDataVariant(meta.data(),
+                                                                                    "Exif.GPSInfo.GPSSpeed",
+                                                                                    "Xmp.exif.GPSSpeed",
+                                                                                    QVariant(speedInKilometersPerHour));
                 }
             }
 
-            if (success1 && m_gpsData.hasNSatellites())
+            if (success && m_gpsData.hasNSatellites())
             {
                 /**
                  * @todo According to the EXIF 2.2 spec, GPSSatellites is a free form field which can either hold only the
                  * number of satellites or more details about each satellite used. For now, we just write
                  * the number of satellites. Are we using the correct format for the number of satellites here?
                  */
-                success1 = setExifXmpTagDataVariant(meta.data(),
-                                                    "Exif.GPSInfo.GPSSatellites", "Xmp.exif.GPSSatellites",
-                                                    QVariant(QString::number(m_gpsData.getNSatellites())));
+                success = setExifXmpTagDataVariant(meta.data(),
+                                                   "Exif.GPSInfo.GPSSatellites", "Xmp.exif.GPSSatellites",
+                                                   QVariant(QString::number(m_gpsData.getNSatellites())));
             }
 
-            if (success1 && m_gpsData.hasFixType())
+            if (success && m_gpsData.hasFixType())
             {
-                success1 = setExifXmpTagDataVariant(meta.data(),
-                                                    "Exif.GPSInfo.GPSMeasureMode", "Xmp.exif.GPSMeasureMode",
-                                                    QVariant(QString::number(m_gpsData.getFixType())));
+                success = setExifXmpTagDataVariant(meta.data(),
+                                                   "Exif.GPSInfo.GPSMeasureMode", "Xmp.exif.GPSMeasureMode",
+                                                   QVariant(QString::number(m_gpsData.getFixType())));
             }
 
             // write DOP
 
-            if (success1 && m_gpsData.hasDop())
+            if (success && m_gpsData.hasDop())
             {
-                success1 = setExifXmpTagDataVariant(meta.data(),
-                                                    "Exif.GPSInfo.GPSDOP",
-                                                    "Xmp.exif.GPSDOP",
-                                                    QVariant(m_gpsData.getDop()));
+                success = setExifXmpTagDataVariant(meta.data(),
+                                                   "Exif.GPSInfo.GPSDOP",
+                                                   "Xmp.exif.GPSDOP",
+                                                   QVariant(m_gpsData.getDop()));
             }
 
 
-            if (!success1)
+            if (!success)
             {
                 returnString = i18n("Failed to add GPS info to image.");
             }
         }
 
-        if (m_saveGPS && p.shouldRemoveCoordinates)
+        if (success && p.shouldRemoveCoordinates)
         {
             // TODO: remove only the altitude if requested
 
-            success1 = meta->removeGPSInfo();
+            success = meta->removeGPSInfo();
 
-            if (!success1)
+            if (!success)
             {
                 returnString = i18n("Failed to remove GPS info from image");
             }
         }
 
-        if (m_saveTags && !m_tagList.isEmpty() && (m_writeXmpTags || m_writeMetaLoc))
+        if (success && !m_tagList.isEmpty() && (m_writeXmpTags || m_writeMetaLoc))
         {
             if (m_writeXmpTags)
             {
@@ -937,28 +983,30 @@ QString GPSItemContainer::saveChanges()
 
                     tag.remove(0, 1);
 
-                    if (!tagSeq.contains(tag))
+                    if (!tag.isEmpty() && !tagSeq.contains(tag))
                     {
                         tagSeq.append(tag);
                     }
                 }
 
-                bool success2 = meta->setXmpTagStringSeq("Xmp.digiKam.TagsList", tagSeq);
+                success = meta->setXmpTagStringSeq("Xmp.digiKam.TagsList", tagSeq);
 
-                if (!success2)
+                if (!success)
                 {
                     returnString = i18n("Failed to save tags to file.");
                 }
-
-                success2 = meta->setXmpTagStringSeq("Xmp.dc.subject", tagSeq);
-
-                if (!success2)
+                else
                 {
-                    returnString = i18n("Failed to save tags to file.");
+                    success = meta->setXmpTagStringSeq("Xmp.dc.subject", tagSeq);
+
+                    if (!success)
+                    {
+                        returnString = i18n("Failed to save tags to file.");
+                    }
                 }
             }
 
-            if (m_writeMetaLoc)
+            if (success && m_writeMetaLoc)
             {
                 IptcCoreLocationInfo locationInfo;
 
@@ -973,9 +1021,9 @@ QString GPSItemContainer::saveChanges()
                     }
                 }
 
-                bool success3 = meta->setIptcCoreLocation(locationInfo);
+                success = meta->setIptcCoreLocation(locationInfo);
 
-                if (!success3)
+                if (!success)
                 {
                     returnString = i18n("Failed to save tags to file.");
                 }
@@ -983,14 +1031,11 @@ QString GPSItemContainer::saveChanges()
         }
     }
 
-    if (success1)
+    if (success)
     {
-        if (m_saveGPS || (m_saveTags && !m_tagList.isEmpty() && (m_writeXmpTags || m_writeMetaLoc)))
-        {
-            success1 = meta->save(m_url.toLocalFile());
-        }
+        success = meta->save(m_url.toLocalFile());
 
-        if (!success1)
+        if (!success)
         {
             returnString = i18n("Unable to save changes to file");
         }
@@ -1174,6 +1219,11 @@ void GPSItemContainer::setLocationInfo(const TagData& tagData, IptcCoreLocationI
     {
         locationInfo.location      = tagData.tagName;
     }
+    else if (!locationInfo.location.isEmpty() &&
+             (tagData.tipName == QLatin1String("{House number}")))
+    {
+        locationInfo.location.append(QLatin1Char(' ') + tagData.tagName);
+    }
 }
 
 } // namespace Digikam
