@@ -29,7 +29,6 @@
 #include <QTreeView>
 #include <QVBoxLayout>
 #include <QMenu>
-#include <QUrl>
 #include <QInputDialog>
 #include <QAction>
 #include <QComboBox>
@@ -43,11 +42,9 @@
 
 // local includes
 
-#include "geoifacetypes.h"
 #include "dlayoutbox.h"
 #include "gpsundocommand.h"
 #include "gpsitemmodel.h"
-#include "gpsitemcontainer.h"
 #include "backend-geonames-rg.h"
 #include "backend-osm-rg.h"
 #include "backend-geonamesUS-rg.h"
@@ -502,9 +499,9 @@ void RGWidget::slotRGReady(QList<RGInfo>& returnedRGList)
     {
         /// @todo This collides with the message box displayed if the user aborts the RG process
 
-        QMessageBox::critical(this, qApp->applicationName(), errorString);
+        QMessageBox::critical(QApplication::activeWindow(), i18nc("@title:window", "Reverse Geo-coding Error"), errorString);
 
-        d->receivedRGCount+=returnedRGList.count();
+        d->receivedRGCount += returnedRGList.count();
 
         Q_EMIT signalSetUIEnabled(true);
 
@@ -796,8 +793,8 @@ void RGWidget::readSettingsFromGroup(const KConfigGroup* const group)
     d->hideOptions = !(group->readEntry("Hide options",                false));
     slotHideOptions();
 
-    d->tagsLoc->setChecked(group->readEntry("Tags location",           false));
-    d->metaLoc->setChecked(group->readEntry("Metadata location",       true));
+    d->tagsLoc->setChecked(group->readEntry("Tags location",           true));
+    d->metaLoc->setChecked(group->readEntry("Metadata location",       false));
 }
 
 /**
@@ -999,7 +996,7 @@ void RGWidget::slotRGCanceled()
         }
 
         const int result = DMessageBox::showYesNo(QMessageBox::Warning, this,
-                                                  i18n("Abort reverse geocoding?"),
+                                                  i18nc("@title:window", "Abort reverse geocoding?"),
                                                   question);
 
         d->currentlyAskingCancelQuestion = false;
@@ -1316,3 +1313,5 @@ void RGWidget::createCountryCodeMap()
 }
 
 } // namespace Digikam
+
+#include "moc_rgwidget.cpp"
