@@ -6,19 +6,10 @@
  * Date        : 2010-07-17
  * Description : A marker tiler operating on item models
  *
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -197,7 +188,7 @@ void ItemMarkerTiler::slotSelectionChanged(const QItemSelection& selected, const
     }
 /*
     d->isDirty=true;
-    emit signalTilesOrSelectionChanged();
+    Q_EMIT signalTilesOrSelectionChanged();
     return;
 */
 
@@ -276,7 +267,7 @@ void ItemMarkerTiler::slotSelectionChanged(const QItemSelection& selected, const
         }
     }
 
-    emit signalTilesOrSelectionChanged();
+    Q_EMIT signalTilesOrSelectionChanged();
 }
 
 void ItemMarkerTiler::slotSourceModelDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
@@ -286,7 +277,7 @@ void ItemMarkerTiler::slotSourceModelDataChanged(const QModelIndex& topLeft, con
 
     if (d->activeState)
     {
-        emit signalTilesOrSelectionChanged();
+        Q_EMIT signalTilesOrSelectionChanged();
     }
 
     // TODO: if only a few items were changed, try to see whether they are still in the right tiles
@@ -308,12 +299,12 @@ void ItemMarkerTiler::slotSourceModelRowsInserted(const QModelIndex& parentIndex
         addMarkerIndexToGrid(QPersistentModelIndex(d->markerModel->index(i, 0, parentIndex)));
     }
 
-    emit signalTilesOrSelectionChanged();
+    Q_EMIT signalTilesOrSelectionChanged();
 }
 
 void ItemMarkerTiler::slotSourceModelRowsAboutToBeRemoved(const QModelIndex& parentIndex, int start, int end)
 {
-    // TODO: emit signalTilesOrSelectionChanged(); in rowsWereRemoved
+    // TODO: Q_EMIT signalTilesOrSelectionChanged(); in rowsWereRemoved
 
     if (isDirty())
     {
@@ -335,7 +326,7 @@ void ItemMarkerTiler::slotSourceModelRowsAboutToBeRemoved(const QModelIndex& par
 
 void ItemMarkerTiler::slotThumbnailAvailableForIndex(const QPersistentModelIndex& index, const QPixmap& pixmap)
 {
-    emit signalThumbnailAvailableForIndex(QVariant::fromValue(index), pixmap);
+    Q_EMIT signalThumbnailAvailableForIndex(QVariant::fromValue(index), pixmap);
 }
 
 void ItemMarkerTiler::slotSourceModelReset()
@@ -823,3 +814,5 @@ GeoGroupState ItemMarkerTiler::getGlobalGroupState()
 }
 
 } // namespace Digikam
+
+#include "moc_itemmarkertiler.cpp"
