@@ -7,7 +7,7 @@
  * Description : digital camera controller
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2006      by Stephan Kulow <coolo at kde dot org>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
@@ -27,7 +27,6 @@
 #include <QImage>
 #include <QFile>
 #include <QRegularExpression>
-#include <QFileInfo>
 #include <QUrl>
 #include <QDir>
 #include <QMessageBox>
@@ -78,7 +77,13 @@ public:
         cam_capture
     };
 
-    Action                  action;
+public:
+
+    CameraCommand() = default;
+
+public:
+
+    Action                  action = cam_none;
     QMap<QString, QVariant> map;
 };
 
@@ -86,27 +91,19 @@ class Q_DECL_HIDDEN CameraController::Private
 {
 public:
 
-    explicit Private()
-      : close       (false),
-        canceled    (false),
-        running     (false),
-        parent      (nullptr),
-        timer       (nullptr),
-        camera      (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                  close;
-    bool                  canceled;
-    bool                  running;
+    bool                  close     = false;
+    bool                  canceled  = false;
+    bool                  running   = false;
 
     QStringList           folderList;
 
-    QWidget*              parent;
+    QWidget*              parent    = nullptr;
 
-    QTimer*               timer;
+    QTimer*               timer     = nullptr;
 
-    DKCamera*             camera;
+    DKCamera*             camera    = nullptr;
 
     QMutex                mutex;
     QWaitCondition        condVar;
@@ -444,16 +441,16 @@ void CameraController::executeCommand(CameraCommand* const cmd)
 
         case (CameraCommand::cam_freeSpace):
         {
-            unsigned long kBSize  = 0;
-            unsigned long kBAvail = 0;
+            qint64 bytesSize  = 0;
+            qint64 bytesAvail = 0;
 
-            if (!d->camera->getFreeSpace(kBSize, kBAvail))
+            if (!d->camera->getFreeSpace(bytesSize, bytesAvail))
             {
                 sendLogMsg(i18n("Failed to get free space from camera"),
                            DHistoryView::ErrorEntry);
             }
 
-            Q_EMIT signalFreeSpace(kBSize, kBAvail);
+            Q_EMIT signalFreeSpace(bytesSize, bytesAvail);
             break;
         }
 
@@ -711,7 +708,7 @@ void CameraController::executeCommand(CameraCommand* const cmd)
                     SafeTemporaryFile* const temp2 = new SafeTemporaryFile(tempTemplate.arg(dest).arg(convFile));
                     temp2->setAutoRemove(false);
                     temp2->open();
-                    convFile                        = temp2->safeFilePath();
+                    convFile                       = temp2->safeFilePath();
                     delete temp2;
 
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Convert to LossLess: " << file;
@@ -795,15 +792,35 @@ void CameraController::executeCommand(CameraCommand* const cmd)
 
             if (!script.isEmpty())
             {
-                qCDebug(DIGIKAM_IMPORTUI_LOG) << "Got a script, processing: " << script;
+                qCDebug(DIGIKAM_IMPORTUI_LOG) << "Got a script, processing:" << script;
 
-                QFileInfo fileInfo(tempFile);
-                QString s = script;
+                QString s;
+
+                if (QFileInfo::exists(script))
+                {
+                    QFile sFile(script);
+
+                    if (!sFile.open(QIODevice::ReadOnly))
+                    {
+                        sendLogMsg(xi18n("Failed to open script for <filename>%1</filename>", file),
+                                         DHistoryView::ErrorEntry,  folder, file);
+                    }
+                    else
+                    {
+                        s = QString::fromUtf8(sFile.readAll());
+                    }
+                }
+
+                if (s.isEmpty())
+                {
+                    s = script;
+                }
 
                 if (s.indexOf(QLatin1Char('%')) > -1)
                 {
                     // %filename must be replaced before %file
 
+                    QFileInfo fileInfo(tempFile);
                     s.replace(QLatin1String("%orgfilename"), file,                Qt::CaseSensitive);
                     s.replace(QLatin1String("%filename"),    fileInfo.fileName(), Qt::CaseSensitive);
                     s.replace(QLatin1String("%orgpath"),     folder,              Qt::CaseSensitive);
@@ -812,25 +829,16 @@ void CameraController::executeCommand(CameraCommand* const cmd)
                 }
                 else
                 {
-                    s.append(QLatin1String(" \"") + dest + QLatin1String("\""));
-                }
+                    if      (s.endsWith(QLatin1String("\r\n")))
+                    {
+                        s.chop(2);
+                    }
+                    else if (s.endsWith(QLatin1String("\n")))
+                    {
+                        s.chop(1);
+                    }
 
-                // Parse script name
-
-                QTextStream stream(s.toStdString().c_str());
-                QString scriptName;
-                stream >> scriptName;
-                qCDebug(DIGIKAM_IMPORTUI_LOG) << "Script name: " << scriptName;
-
-                // Parse arguments
-
-                QStringList arguments;
-
-                while (!stream.atEnd())
-                {
-                    QString str;
-                    stream >> str;
-                    arguments << str;
+                    s.append(QLatin1String(" \"") + tempFile + QLatin1String("\""));
                 }
 
                 // Start the process
@@ -838,8 +846,34 @@ void CameraController::executeCommand(CameraCommand* const cmd)
                 QProcess process;
                 process.setProcessChannelMode(QProcess::SeparateChannels);
                 process.setProcessEnvironment(adjustedEnvironmentForAppImage());
-                process.start(scriptName, QStringList() << arguments);
 
+#ifdef Q_OS_WIN
+
+                QString dir                   = QDir::temp().path();
+                SafeTemporaryFile* const temp = new SafeTemporaryFile(dir + QLatin1String("/ImportScript-XXXXXX.cmd"));
+                temp->setAutoRemove(false);
+                temp->open();
+                QString scriptPath            = temp->safeFilePath();
+
+                // Crash fix: a QTemporaryFile is not properly closed until its destructor is called.
+
+                delete temp;
+
+                QFile tempFile(scriptPath);
+
+                if (tempFile.open(QIODevice::WriteOnly))
+                {
+                    tempFile.write(s.toUtf8());
+                    tempFile.close();
+                }
+
+                process.start(QLatin1String("cmd.exe"), QStringList() << QLatin1String("/C") << scriptPath);
+
+#else
+
+                process.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << s);
+
+#endif
                 if (!process.waitForFinished(60000))
                 {
                     sendLogMsg(xi18n("Timeout from script for <filename>%1</filename>", file),
@@ -855,6 +889,13 @@ void CameraController::executeCommand(CameraCommand* const cmd)
 
                 qCDebug(DIGIKAM_IMPORTUI_LOG) << "stdout" << process.readAllStandardOutput();
                 qCDebug(DIGIKAM_IMPORTUI_LOG) << "stderr" << process.readAllStandardError();
+
+#ifdef Q_OS_WIN
+
+                tempFile.remove();
+
+#endif
+
             }
 
             Q_EMIT signalDownloaded(folder, file, tempFile, CamItemInfo::DownloadedYes);
@@ -1032,6 +1073,7 @@ void CameraController::slotDeleteFailed(const QString& folder, const QString& fi
 void CameraController::slotLockFailed(const QString& folder, const QString& file)
 {
     Q_EMIT signalLocked(folder, file, false);
+
     sendLogMsg(xi18n("Failed to lock <filename>%1</filename>", file),
                DHistoryView::ErrorEntry, folder, file);
 
@@ -1271,3 +1313,5 @@ void CameraController::openFile(const QString& folder, const QString& file)
 }
 
 } // namespace Digikam
+
+#include "moc_cameracontroller.cpp"
