@@ -7,7 +7,7 @@
  * Description : Gphoto2 camera interface
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -81,8 +81,8 @@ public:
 
 #ifdef HAVE_GPHOTO2
 
-        context = gp_context_new();
         cancel  = false;
+        context = gp_context_new();
         gp_context_set_cancel_func(context, cancel_func, nullptr);
 
 #   ifdef GPHOTO2_DEBUG
@@ -113,12 +113,12 @@ public:
 
 #ifdef HAVE_GPHOTO2
 
-    GPContext*  context;
+    GPContext* context = nullptr;
 
     static GPContextFeedback cancel_func(GPContext*, void*)
     {
-        return (cancel ? GP_CONTEXT_FEEDBACK_CANCEL :
-                GP_CONTEXT_FEEDBACK_OK);
+        return (cancel ? GP_CONTEXT_FEEDBACK_CANCEL
+                       : GP_CONTEXT_FEEDBACK_OK);
     }
 
 #   ifdef GPHOTO2_DEBUG
@@ -137,8 +137,8 @@ public:
     {
         Q_UNUSED(data);
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "start:" << target << "- text:" << text;
-        return 0;
 
+        return 0;
     }
 
     static void update_func(GPContext*, unsigned int id, float target, void *data)
@@ -168,28 +168,17 @@ class Q_DECL_HIDDEN GPCamera::Private
 
 public:
 
-    explicit Private()
+    Private() = default;
 
 #ifdef HAVE_GPHOTO2
 
-        : cameraInitialized(false),
-          camera           (nullptr),
-          status           (nullptr)
+    bool            cameraInitialized = false;
 
-#endif // HAVE_GPHOTO2
-
-    {
-    }
-
-#ifdef HAVE_GPHOTO2
-
-    bool            cameraInitialized;
-
-    Camera*         camera;
+    Camera*         camera            = nullptr;
 
     CameraAbilities cameraAbilities;
 
-    GPStatus*       status;
+    GPStatus*       status            = nullptr;
 
 #endif // HAVE_GPHOTO2
 
@@ -287,8 +276,8 @@ bool GPCamera::doConnect()
     gp_port_info_list_new(&infoList);
     gp_port_info_list_load(infoList);
 
-    int modelNum     = gp_abilities_list_lookup_model(abilList, m_model.toLatin1().constData());
-    int portNum      = gp_port_info_list_lookup_path(infoList, m_port.toLatin1().constData());
+    int modelNum = gp_abilities_list_lookup_model(abilList, m_model.toLatin1().constData());
+    int portNum  = gp_port_info_list_lookup_path(infoList, m_port.toLatin1().constData());
 
     gp_abilities_list_get_abilities(abilList, modelNum, &d->cameraAbilities);
 
@@ -302,6 +291,7 @@ bool GPCamera::doConnect()
         d->camera = nullptr;
         gp_abilities_list_free(abilList);
         gp_port_info_list_free(infoList);
+
         return false;
     }
 
@@ -318,6 +308,7 @@ bool GPCamera::doConnect()
             d->camera = nullptr;
             gp_abilities_list_free(abilList);
             gp_port_info_list_free(infoList);
+
             return false;
         }
     }
@@ -377,6 +368,7 @@ bool GPCamera::doConnect()
         printGphotoErrorDescription(errorCode);
         gp_camera_unref(d->camera);
         d->camera = nullptr;
+
         return false;
     }
 
@@ -412,7 +404,7 @@ void GPCamera::cancel()
 
 }
 
-bool GPCamera::getFreeSpace(unsigned long& kBSize, unsigned long& kBAvail)
+bool GPCamera::getFreeSpace(qint64& bytesSize, qint64& bytesAvail)
 {
 
 #ifdef HAVE_GPHOTO2
@@ -429,6 +421,7 @@ bool GPCamera::getFreeSpace(unsigned long& kBSize, unsigned long& kBAvail)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Getting storage information not supported for this camera!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -439,17 +432,28 @@ bool GPCamera::getFreeSpace(unsigned long& kBSize, unsigned long& kBAvail)
             switch (sinfos[i].fstype)
             {
                 case GP_STORAGEINFO_FST_UNDEFINED:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage fstype: undefined";
                     break;
+                }
+
                 case GP_STORAGEINFO_FST_GENERICFLAT:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage fstype: flat, all in one directory";
                     break;
+                }
+
                 case GP_STORAGEINFO_FST_GENERICHIERARCHICAL:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage fstype: generic tree hierarchy";
                     break;
+                }
+
                 case GP_STORAGEINFO_FST_DCF:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "DCIM style storage";
                     break;
+                }
             }
         }
 
@@ -482,19 +486,27 @@ bool GPCamera::getFreeSpace(unsigned long& kBSize, unsigned long& kBAvail)
             switch (sinfos[i].access)
             {
                 case GP_STORAGEINFO_AC_READWRITE:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage access: R/W";
                     break;
+                }
 
                 case GP_STORAGEINFO_AC_READONLY:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage access: RO";
                     break;
+                }
 
                 case GP_STORAGEINFO_AC_READONLY_WITH_DELETE:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage access: RO + Del";
                     break;
+                }
 
                 default:
+                {
                     break;
+                }
             }
         }
 
@@ -503,48 +515,58 @@ bool GPCamera::getFreeSpace(unsigned long& kBSize, unsigned long& kBAvail)
             switch (sinfos[i].type)
             {
                 case GP_STORAGEINFO_ST_FIXED_ROM:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage type: fixed ROM";
                     break;
+                }
 
                 case GP_STORAGEINFO_ST_REMOVABLE_ROM:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage type: removable ROM";
                     break;
+                }
 
                 case GP_STORAGEINFO_ST_FIXED_RAM:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage type: fixed RAM";
                     break;
+                }
 
                 case GP_STORAGEINFO_ST_REMOVABLE_RAM:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage type: removable RAM";
                     break;
+                }
 
                 case GP_STORAGEINFO_ST_UNKNOWN:
                 default:
+                {
                     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage type: unknown";
                     break;
+                }
             }
         }
 
         if (sinfos[i].fields & GP_STORAGEINFO_MAXCAPACITY)
         {
-            kBSize += sinfos[i].capacitykbytes;
-            qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage capacity: " << kBSize;
+            bytesSize += sinfos[i].capacitykbytes * 1024;
+            qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage capacity: " << bytesSize;
         }
 
         if (sinfos[i].fields & GP_STORAGEINFO_FREESPACEKBYTES)
         {
-            kBAvail += sinfos[i].freekbytes;
-            qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage free-space: " << kBAvail;
+            bytesAvail += sinfos[i].freekbytes * 1024;
+            qCDebug(DIGIKAM_IMPORTUI_LOG) << "Storage free-space: " << bytesAvail;
         }
-     }
-
+    }
 
     return true;
 
 #else
 
-    Q_UNUSED(kBSize);
-    Q_UNUSED(kBAvail);
+    Q_UNUSED(bytesSize);
+    Q_UNUSED(bytesAvail);
+
     return false;
 
 #endif // HAVE_GPHOTO2
@@ -571,6 +593,7 @@ bool GPCamera::getPreview(QImage& preview)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to initialize camera preview mode!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -581,17 +604,20 @@ bool GPCamera::getPreview(QImage& preview)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get preview from camera!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
-    preview.loadFromData((const uchar*) data, (uint) size);
+    preview.loadFromData((const uchar*)data, (uint)size);
 
     gp_file_unref(cfile);
+
     return true;
 
 #else
 
     Q_UNUSED(preview);
+
     return false;
 
 #endif // HAVE_GPHOTO2
@@ -613,6 +639,7 @@ bool GPCamera::capture(CamItemInfo& itemInfo)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to take camera capture!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -630,6 +657,7 @@ bool GPCamera::capture(CamItemInfo& itemInfo)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item information!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -642,9 +670,11 @@ bool GPCamera::capture(CamItemInfo& itemInfo)
     itemInfo.readPermissions  = -1;
     itemInfo.writePermissions = -1;
 
-    /* The mime type returned by Gphoto2 is dummy with all RAW files.
+/*  The mime type returned by Gphoto2 is dummy with all RAW files.
+
     if (info.file.fields & GP_FILE_INFO_TYPE)
-        itemInfo.mime = info.file.type;*/
+        itemInfo.mime = info.file.type;
+*/
 
     itemInfo.mime = mimeType(itemInfo.name.section(QLatin1Char('.'), -1).toLower());
 
@@ -706,6 +736,7 @@ bool GPCamera::capture(CamItemInfo& itemInfo)
 #else
 
     Q_UNUSED(itemInfo);
+
     return false;
 
 #endif // HAVE_GPHOTO2
@@ -729,6 +760,7 @@ bool GPCamera::getFolders(const QString& folder)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get folders list from camera!";
         printGphotoErrorDescription(errorCode);
         gp_list_unref(clist);
+
         return false;
     }
 
@@ -750,6 +782,7 @@ bool GPCamera::getFolders(const QString& folder)
             qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get folder name from camera!";
             printGphotoErrorDescription(errorCode);
             gp_list_unref(clist);
+
             return false;
         }
 
@@ -772,6 +805,7 @@ bool GPCamera::getFolders(const QString& folder)
 }
 
 // TODO unused, remove?
+
 bool GPCamera::getItemsList(const QString& folder, QStringList& itemsList)
 {
 
@@ -791,6 +825,7 @@ bool GPCamera::getItemsList(const QString& folder, QStringList& itemsList)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get folder files list from camera!";
         printGphotoErrorDescription(errorCode);
         gp_list_unref(clist);
+
         return false;
     }
 
@@ -805,6 +840,7 @@ bool GPCamera::getItemsList(const QString& folder, QStringList& itemsList)
             qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get file name from camera!";
             printGphotoErrorDescription(errorCode);
             gp_list_unref(clist);
+
             return false;
         }
 
@@ -845,6 +881,7 @@ bool GPCamera::getItemsInfoList(const QString& folder, bool useMetadata, CamItem
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get folder files list from camera!";
         printGphotoErrorDescription(errorCode);
         gp_list_unref(clist);
+
         return false;
     }
 
@@ -859,10 +896,12 @@ bool GPCamera::getItemsInfoList(const QString& folder, bool useMetadata, CamItem
             qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get file name from camera!";
             printGphotoErrorDescription(errorCode);
             gp_list_unref(clist);
+
             return false;
         }
 
-        // TODO for further speed-up, getItemInfoInternal call could be called separately when needed
+        // TODO: for further speed-up, getItemInfoInternal call could be called separately when needed
+
         CamItemInfo info;
         getItemInfoInternal(folder, QFile::decodeName(cname), info, useMetadata);
         items.append(info);
@@ -972,6 +1011,7 @@ void GPCamera::getItemInfoInternal(const QString& folder, const QString& itemNam
         if (useMetadata)
         {
             // Try to use file metadata
+
             QScopedPointer<DMetadata> meta(new DMetadata);
             getMetadata(folder, itemName, *meta);
             fillItemInfoFromMetadata(info, *meta);
@@ -988,11 +1028,14 @@ void GPCamera::getItemInfoInternal(const QString& folder, const QString& itemNam
                 {
                     info.ctime = QDateTime::currentDateTime();
                 }
+
+                info.ctime.setTimeSpec(Qt::UTC);
             }
         }
         else
         {
             // Only use properties provided by camera.
+
             if (cfinfo.file.fields & GP_FILE_INFO_MTIME)
             {
                 info.ctime = QDateTime::fromSecsSinceEpoch(cfinfo.file.mtime);
@@ -1002,6 +1045,8 @@ void GPCamera::getItemInfoInternal(const QString& folder, const QString& itemNam
                 info.ctime = QDateTime::currentDateTime();
             }
 
+            info.ctime.setTimeSpec(Qt::UTC);
+
             if (cfinfo.file.fields & GP_FILE_INFO_WIDTH)
             {
                 info.width = cfinfo.file.width;
@@ -1027,6 +1072,7 @@ void GPCamera::getItemInfoInternal(const QString& folder, const QString& itemNam
 
 bool GPCamera::getThumbnail(const QString& folder, const QString& itemName, QImage& thumbnail)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int                errorCode;
@@ -1047,6 +1093,7 @@ bool GPCamera::getThumbnail(const QString& folder, const QString& itemName, QIma
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item!" << folder << itemName;
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1057,12 +1104,14 @@ bool GPCamera::getThumbnail(const QString& folder, const QString& itemName, QIma
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get thumbnail from camera item!" << folder << itemName;
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
     thumbnail.loadFromData((const uchar*) data, (uint) size);
 
     gp_file_unref(cfile);
+
     return !thumbnail.isNull();
 
 #else
@@ -1079,6 +1128,7 @@ bool GPCamera::getThumbnail(const QString& folder, const QString& itemName, QIma
 
 bool GPCamera::getMetadata(const QString& folder, const QString& itemName, DMetadata& meta)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int               errorCode;
@@ -1099,6 +1149,7 @@ bool GPCamera::getMetadata(const QString& folder, const QString& itemName, DMeta
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1109,6 +1160,7 @@ bool GPCamera::getMetadata(const QString& folder, const QString& itemName, DMeta
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get Exif data from camera item!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1131,10 +1183,11 @@ bool GPCamera::getMetadata(const QString& folder, const QString& itemName, DMeta
         {
             qCDebug(DIGIKAM_IMPORTUI_LOG) << "Exif header found at position " << i;
             i = i + sizeof(exifHeader);
-            QByteArray data;
-            data.resize(exifData.size() - i);
-            memcpy(data.data(), exifData.data() + i, data.size());
-            meta.setExif(data);
+            QByteArray ba;
+            ba.resize(exifData.size() - i);
+            memcpy(ba.data(), exifData.data() + i, ba.size());
+            meta.setExif(ba);
+
             return true;
         }
     }
@@ -1150,11 +1203,13 @@ bool GPCamera::getMetadata(const QString& folder, const QString& itemName, DMeta
     return false;
 
 #endif // HAVE_GPHOTO2
+
 }
 
 bool GPCamera::downloadItem(const QString& folder, const QString& itemName,
                             const QString& saveFile)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int         errorCode;
@@ -1166,15 +1221,18 @@ bool GPCamera::downloadItem(const QString& folder, const QString& itemName,
     if (!file.open(QIODevice::ReadWrite))
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to open file" << file.fileName() << file.errorString();
+
         return false;
     }
 
     // dup fd, passing fd control to gphoto2 later
+
     int handle = dup(file.handle());
 
     if (handle == -1)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to dup file descriptor";
+
         return false;
     }
 
@@ -1184,6 +1242,7 @@ bool GPCamera::downloadItem(const QString& folder, const QString& itemName,
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -1197,6 +1256,7 @@ bool GPCamera::downloadItem(const QString& folder, const QString& itemName,
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1228,6 +1288,7 @@ bool GPCamera::downloadItem(const QString& folder, const QString& itemName,
 
 bool GPCamera::setLockItem(const QString& folder, const QString& itemName, bool lock)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int errorCode;
@@ -1241,6 +1302,7 @@ bool GPCamera::setLockItem(const QString& folder, const QString& itemName, bool
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item properties!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -1249,16 +1311,19 @@ bool GPCamera::setLockItem(const QString& folder, const QString& itemName, bool
         if (lock)
         {
             // Lock the file to set read only flag
+
             info.file.permissions = (CameraFilePermissions)GP_FILE_PERM_READ;
         }
         else
         {
             // Unlock the file to set read/write flag
+
             info.file.permissions = (CameraFilePermissions)(GP_FILE_PERM_READ | GP_FILE_PERM_DELETE);
         }
     }
 
     // Some gphoto2 drivers need to have only the right flag at on to process properties update in camera.
+
     info.file.fields    = GP_FILE_INFO_PERMISSIONS;
     info.preview.fields = GP_FILE_INFO_NONE;
     info.audio.fields   = GP_FILE_INFO_NONE;
@@ -1270,6 +1335,7 @@ bool GPCamera::setLockItem(const QString& folder, const QString& itemName, bool
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to set camera item lock properties!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -1289,6 +1355,7 @@ bool GPCamera::setLockItem(const QString& folder, const QString& itemName, bool
 
 bool GPCamera::deleteItem(const QString& folder, const QString& itemName)
 {
+
 #ifdef HAVE_GPHOTO2
 
     d->status->cancel = false;
@@ -1300,6 +1367,7 @@ bool GPCamera::deleteItem(const QString& folder, const QString& itemName)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to delete camera item!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -1318,8 +1386,10 @@ bool GPCamera::deleteItem(const QString& folder, const QString& itemName)
 
 // TODO fix to go through all folders
 // TODO this was never even used.
+
 bool GPCamera::deleteAllItems(const QString& folder)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int         errorCode;
@@ -1333,6 +1403,7 @@ bool GPCamera::deleteAllItems(const QString& folder)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to delete camera folder!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -1350,6 +1421,7 @@ bool GPCamera::deleteAllItems(const QString& folder)
 
 bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const QString& localFile, CamItemInfo& itemInfo)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int         errorCode;
@@ -1361,6 +1433,7 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to init new camera file instance!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
@@ -1371,6 +1444,7 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to open file!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1381,6 +1455,7 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to rename item from camera!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1405,6 +1480,7 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to upload item to camera!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1422,6 +1498,7 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera item information!";
         printGphotoErrorDescription(errorCode);
         gp_file_unref(cfile);
+
         return false;
     }
 
@@ -1434,10 +1511,11 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
     itemInfo.readPermissions  = -1;
     itemInfo.writePermissions = -1;
 
-    /* The mime type returned by Gphoto2 is dummy with all RAW files.
+/*  The mime type returned by Gphoto2 is dummy with all RAW files.
+
     if (info.file.fields & GP_FILE_INFO_TYPE)
         itemInfo.mime = info.file.type;
-    */
+*/
 
     itemInfo.mime = mimeType(itemInfo.name.section(QLatin1Char('.'), -1).toLower());
 
@@ -1513,6 +1591,7 @@ bool GPCamera::uploadItem(const QString& folder, const QString& itemName, const
 
 bool GPCamera::cameraSummary(QString& summary)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int        errorCode;
@@ -1525,11 +1604,13 @@ bool GPCamera::cameraSummary(QString& summary)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera summary!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
     // we do not expect title/model/etc. to contain newlines,
     // so we just escape HTML characters
+
     summary =  i18nc("@info List of device properties",
                      "Title: \"%1\"\n"
                      "Model: \"%2\"\n"
@@ -1553,6 +1634,7 @@ bool GPCamera::cameraSummary(QString& summary)
 
     // here we need to make sure whitespace and newlines
     // are converted to HTML properly
+
     summary.append(Qt::convertFromPlainText(QString::fromLocal8Bit(sum.text), Qt::WhiteSpacePre));
 
     return true;
@@ -1569,6 +1651,7 @@ bool GPCamera::cameraSummary(QString& summary)
 
 bool GPCamera::cameraManual(QString& manual)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int        errorCode;
@@ -1581,11 +1664,13 @@ bool GPCamera::cameraManual(QString& manual)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get camera manual!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
     // I guess manual is plain text and not HTML?
     // Can't test it. (Michael G. Hansen)
+
     manual = Qt::convertFromPlainText(QString::fromLocal8Bit(man.text), Qt::WhiteSpacePre);
 
     return true;
@@ -1602,6 +1687,7 @@ bool GPCamera::cameraManual(QString& manual)
 
 bool GPCamera::cameraAbout(QString& about)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int        errorCode;
@@ -1614,11 +1700,13 @@ bool GPCamera::cameraAbout(QString& about)
     {
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get information about camera!";
         printGphotoErrorDescription(errorCode);
+
         return false;
     }
 
     // here we need to make sure whitespace and newlines
     // are converted to HTML properly
+
     about = Qt::convertFromPlainText(QString::fromLocal8Bit(abt.text), Qt::WhiteSpacePre);
     about.append(QString::fromUtf8("<br/><br/>To report problems about this driver, please contact "
                  "the gphoto2 team at:<br/><br/>http://gphoto.org/bugs"));      // krazy:exclude=insecurenet
@@ -1639,6 +1727,7 @@ bool GPCamera::cameraAbout(QString& about)
 
 void GPCamera::printGphotoErrorDescription(int errorCode)
 {
+
 #ifdef HAVE_GPHOTO2
 
     qCDebug(DIGIKAM_IMPORTUI_LOG) << "Libgphoto2 error: " << gp_result_as_string(errorCode)
@@ -1675,6 +1764,7 @@ void GPCamera::getSupportedCameras(int& count, QStringList& clist)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get list of cameras!";
         printGphotoErrorDescription(count);
         gp_context_unref(context);
+
         return;
     }
     else
@@ -1722,6 +1812,7 @@ void GPCamera::getSupportedPorts(QStringList& plist)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get list of ports!";
         printGphotoErrorDescription(numPorts);
         gp_port_info_list_free(list);
+
         return;
     }
     else
@@ -1835,6 +1926,7 @@ int GPCamera::autoDetect(QString& model, QString& port)
         qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to autodetect camera!";
         printGphotoErrorDescription(count);
         gp_list_free(camList);
+
         return -1;
     }
 
@@ -1847,6 +1939,7 @@ int GPCamera::autoDetect(QString& model, QString& port)
         {
             qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to autodetect camera!";
             gp_list_free(camList);
+
             return -1;
         }
 
@@ -1854,6 +1947,7 @@ int GPCamera::autoDetect(QString& model, QString& port)
         {
             qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to autodetect camera!";
             gp_list_free(camList);
+
             return -1;
         }
 
@@ -1862,6 +1956,7 @@ int GPCamera::autoDetect(QString& model, QString& port)
             model = QLatin1String(camModel_);
             port  = QLatin1String(camPort_);
             gp_list_free(camList);
+
             return 0;
         }
     }
@@ -1890,20 +1985,26 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
     GPContext*           context  = nullptr;
     CameraList*          camList  = nullptr;
     bool                 success  = false;
+
     // get name and port of detected camera
+
     const char* model_str         = nullptr;
     const char* port_str          = nullptr;
     context                       = gp_context_new();
 
     // get list of all ports
+
     gp_port_info_list_new(&list);
     gp_port_info_list_load(list);
 
     gp_abilities_list_new(&abilList);
+
     // get list of all supported cameras
+
     gp_abilities_list_load(abilList, context);
 
     // autodetect all cameras, then match the list to the passed in USB ids
+
     gp_list_new (&camList);
     gp_abilities_list_detect(abilList, list, camList, context);
     gp_context_unref(context);
@@ -1915,17 +2016,21 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
     {
         const char* xmodel = nullptr;
         gp_list_get_name(camList, i, &xmodel);
-        int model          = gp_abilities_list_lookup_model (abilList, xmodel);
+        int modelId        = gp_abilities_list_lookup_model (abilList, xmodel);
         CameraAbilities ab;
-        gp_abilities_list_get_abilities(abilList, model, &ab);
+        gp_abilities_list_get_abilities(abilList, modelId, &ab);
 
         if (ab.port != GP_PORT_USB)
+        {
             continue;
+        }
 
-        /* KDE provides us USB Vendor and Product, but we might just
+        /*
+         * KDE framework provides us USB Vendor and Product, but we might just
          * have covered this via a class match. Check class matched
          * cameras also for matchingo USB vendor/product id
          */
+
         if (ab.usb_vendor == 0)
         {
             int ret;
@@ -1933,24 +2038,30 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
             const char* xport = nullptr;
             GPPort* gpport    = nullptr;
 
-            /* get the port path so we only look at this bus position */
+            // get the port path so we only look at this bus position.
+
             gp_list_get_value(camList, i, &xport);
             ret = gp_port_info_list_lookup_path (list, xport);
 
-            if (ret < GP_OK) /* should not happen */
+            if (ret < GP_OK) // should not happen.
+            {
                 continue;
+            }
+
+            // get the lowlevel port info  for the path.
 
-            /* get the lowlevel port info  for the path
-             */
             gp_port_info_list_get_info(list, ret, &info);
 
-            /* open lowlevel driver interface briefly to search */
+            // open lowlevel driver interface briefly to search.
+
             gp_port_new(&gpport);
             gp_port_set_info(gpport, info);
 
-            /* And now call into the lowlevel usb driver to see if the bus position
+            /*
+             * And now call into the lowlevel usb driver to see if the bus position
              * has that specific vendor/product id
              */
+
             if (gp_port_usb_find_device(gpport, vendorId, productId) == GP_OK)
             {
                 ab.usb_vendor  = vendorId;
@@ -1961,13 +2072,17 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
         }
 
         if (ab.usb_vendor != vendorId)
+        {
             continue;
+        }
 
         if (ab.usb_product != productId)
+        {
             continue;
+        }
+
+        // keep it, and continue iterating, in case we find another one.
 
-        /* keep it, and continue iterating, in case we find another one
-         */
         gp_list_get_name (camList, i, &model_str);
         gp_list_get_value(camList, i, &port_str);
 
@@ -1996,6 +2111,7 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
     }
 
     gp_list_free(camList);
+
     return success;
 
 #else
@@ -2013,3 +2129,5 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
 }
 
 } // namespace Digikam
+
+#include "moc_gpcamera.cpp"
