@@ -7,7 +7,7 @@
  * Description : Item delegate for import interface items.
  *
  * SPDX-FileCopyrightText: 2012      by Islam Wazery <wazery at ubuntu dot com>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -29,7 +29,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "itemdelegateoverlay.h"
 #include "thememanager.h"
 #include "itemscanner.h"
 #include "itempropertiestab.h"
@@ -41,20 +40,22 @@ namespace Digikam
 {
 
 ItemViewImportDelegatePrivate::ItemViewImportDelegatePrivate()
-    : spacing(0),
-      thumbSize(ThumbnailSize(0)),
-      q(nullptr),
-      radius(3),       // painting constants
-      margin(5)
+    : spacing      (0),
+      thumbSize    (ThumbnailSize(0)),
+      q            (nullptr),
+      displayWidget(nullptr),
+      radius       (3),       // painting constants
+      margin       (5)
 {
     makeStarPolygon();
 
     ratingPixmaps = QVector<QPixmap>(10);
 }
 
-void ItemViewImportDelegatePrivate::init(ItemViewImportDelegate* const _q)
+void ItemViewImportDelegatePrivate::init(ItemViewImportDelegate* const _q, QWidget* const _widget)
 {
-    q = _q;
+    q             = _q;
+    displayWidget = _widget;
 
     q->connect(ThemeManager::instance(), SIGNAL(signalThemeChanged()),
                q, SLOT(slotThemeChanged()));
@@ -77,16 +78,16 @@ void ItemViewImportDelegatePrivate::makeStarPolygon()
 
 // ---- ItemViewImportDelegate -----------------------------------------------
 
-ItemViewImportDelegate::ItemViewImportDelegate(QObject* const parent)
+ItemViewImportDelegate::ItemViewImportDelegate(QWidget* const parent)
     : DItemDelegate(parent), d_ptr(new ItemViewImportDelegatePrivate)
 {
-    d_ptr->init(this);
+    d_ptr->init(this, parent);
 }
 
-ItemViewImportDelegate::ItemViewImportDelegate(ItemViewImportDelegatePrivate& dd, QObject* const parent)
+ItemViewImportDelegate::ItemViewImportDelegate(ItemViewImportDelegatePrivate& dd, QWidget* const parent)
     : DItemDelegate(parent), d_ptr(&dd)
 {
-    d_ptr->init(this);
+    d_ptr->init(this, parent);
 }
 
 ItemViewImportDelegate::~ItemViewImportDelegate()
@@ -104,6 +105,13 @@ ThumbnailSize ItemViewImportDelegate::thumbnailSize() const
     return d->thumbSize;
 }
 
+double ItemViewImportDelegate::displayRatio() const
+{
+    Q_D(const ItemViewImportDelegate);
+
+    return d->displayWidget->devicePixelRatio();
+}
+
 void ItemViewImportDelegate::setThumbnailSize(const ThumbnailSize& thumbSize)
 {
     Q_D(ItemViewImportDelegate);
@@ -263,10 +271,10 @@ QRect ItemViewImportDelegate::drawThumbnail(QPainter* p, const QRect& thumbRect,
         return QRect();
     }
 
-    QRect r      = thumbRect;
-    double ratio = thumbnail.devicePixelRatio();
-    int thumbW   = qRound((double)thumbnail.width()  / ratio);
-    int thumbH   = qRound((double)thumbnail.height() / ratio);
+    QRect r    = thumbRect;
+    double dpr =  thumbnail.devicePixelRatio();
+    int thumbW = qRound((double)thumbnail.width()  / dpr);
+    int thumbH = qRound((double)thumbnail.height() / dpr);
 
     QRect actualPixmapRect(r.x() + (r.width()  - thumbW) / 2,
                            r.y() + (r.height() - thumbH) / 2,
@@ -434,10 +442,14 @@ void ItemViewImportDelegate::drawGeolocationIndicator(QPainter* p, const QRect&
     if (!r.isNull())
     {
         QIcon icon(QIcon::fromTheme(QLatin1String("globe")).pixmap(r.size()));
-        qreal op = p->opacity();
-        p->setOpacity(0.5);
+        QBrush brush = p->brush();
+        p->setOpacity(0.50);
+        p->setPen(QPen(p->background().color()));
+        p->setBrush(QBrush(p->background().color()));
+        p->drawEllipse(r);
+        p->setBrush(brush);
+        p->setOpacity(1.0);
         icon.paint(p, r);
-        p->setOpacity(op);
     }
 }
 
@@ -646,7 +658,11 @@ void ItemViewImportDelegate::prepareRatingPixmaps(bool composeOverBackground)
             basePix.fill(Qt::transparent);
         }
 
-        for (int rating=1; rating<=5; ++rating)
+        double dpr = displayRatio();
+        basePix    = basePix.scaled(d->ratingRect.size() * dpr);
+        basePix.setDevicePixelRatio(dpr);
+
+        for (int rating = 1; rating <= 5; ++rating)
         {
             // we store first the 5 regular, then the 5 selected pixmaps, for simplicity
 
@@ -720,3 +736,5 @@ QPixmap ItemViewImportDelegate::ratingPixmap(int rating, bool selected) const
 }
 
 } // namespace Digikam
+
+#include "moc_itemviewimportdelegate.cpp"
