@@ -6,19 +6,10 @@
  * Date        : 2012-07-15
  * Description : Settings for the import tool
  *
- * Copyright (C) 2012      by Islam Wazery <wazery at ubuntu dot com>
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012      by Islam Wazery <wazery at ubuntu dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -338,7 +329,7 @@ void ImportSettings::readSettings()
 
     // ---------------------------------------------------------------------
 
-    emit setupChanged();
+    Q_EMIT setupChanged();
 }
 
 void ImportSettings::saveSettings()
@@ -393,7 +384,7 @@ void ImportSettings::saveSettings()
 
 void ImportSettings::emitSetupChanged()
 {
-    emit setupChanged();
+    Q_EMIT setupChanged();
 }
 
 void ImportSettings::setImageSortOrder(int order)
@@ -763,3 +754,5 @@ bool ImportSettings::getIconShowCoordinates() const
 }
 
 } // namespace Digikam
+
+#include "moc_importsettings.cpp"
