@@ -6,18 +6,9 @@
  * Date        : 2010-12-16
  * Description : Import filter combobox
  *
- * Copyright (C) 2010-2011 by Petri Damstén <petri dot damsten at iki dot fi>
+ * SPDX-FileCopyrightText: 2010-2011 by Petri Damstén <petri dot damsten at iki dot fi>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -30,7 +21,7 @@
 
 // Local includes
 
-#include "filter.h"
+#include "importfilter.h"
 
 namespace Digikam
 {
@@ -48,6 +39,9 @@ public:
 
     Filter* currentFilter();
     void saveSettings();
+    void updateFilter();
+
+public:
 
     static void  defaultFilters(FilterList* const filters);
     static const QString defaultIgnoreNames;
