@@ -6,7 +6,7 @@
  * Date        : 2007-03-05
  * Description : digiKam light table GUI
  *
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -1074,6 +1074,20 @@ void LightTableWindow::slotLeftSideBarActivateAssignedTags()
     d->leftSideBar->imageDescEditTab()->activateAssignedTagsButton();
 }
 
+void LightTableWindow::slotLeftPreviewSelected(bool b)
+{
+    QFont fnt(d->leftFileName->font());
+    fnt.setBold(b);
+    d->leftFileName->setFont(fnt);
+}
+
+void LightTableWindow::slotRightPreviewSelected(bool b)
+{
+    QFont fnt(d->rightFileName->font());
+    fnt.setBold(b);
+    d->rightFileName->setFont(fnt);
+}
+
 void LightTableWindow::slotToggleColorManagedView()
 {
     if (!IccSettings::instance()->isEnabled())
@@ -1121,3 +1135,5 @@ DInfoInterface* LightTableWindow::infoIface(DPluginAction* const ac)
 }
 
 } // namespace Digikam
+
+#include "moc_lighttablewindow.cpp"
