@@ -6,7 +6,7 @@
  * Date        : 2004-11-22
  * Description : digiKam light table - Configure
  *
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -156,7 +156,7 @@ void LightTableWindow::setupActions()
     d->rightZoomPlusAction->setEnabled(false);
     ac->addAction(QLatin1String("lighttable_zoomplus_right"), d->rightZoomPlusAction);
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
     ac->setDefaultShortcut(d->rightZoomPlusAction, QKeySequence(QKeyCombination(Qt::ShiftModifier, d->rightZoomPlusAction->shortcut()[0].key())));
 
@@ -170,7 +170,7 @@ void LightTableWindow::setupActions()
     d->rightZoomMinusAction->setEnabled(false);
     ac->addAction(QLatin1String("lighttable_zoomminus_right"), d->rightZoomMinusAction);
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
     ac->setDefaultShortcut(d->rightZoomMinusAction, QKeySequence(QKeyCombination(Qt::ShiftModifier, d->rightZoomMinusAction->shortcut()[0].key())));
 
@@ -357,6 +357,12 @@ void LightTableWindow::setupConnections()
 
     // View connections ---------------------------------------------
 
+    connect(d->previewView, SIGNAL(signalLeftPreviewSelected(bool)),
+            this, SLOT(slotLeftPreviewSelected(bool)));
+
+    connect(d->previewView, SIGNAL(signalRightPreviewSelected(bool)),
+            this, SLOT(slotRightPreviewSelected(bool)));
+
     connect(d->previewView, SIGNAL(signalLeftPopupTagsView()),
             d->leftSideBar, SLOT(slotPopupTagsView()));
 
