@@ -7,7 +7,7 @@
  * Description : batch face detection
  *
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -43,7 +43,6 @@
 #include "albumpointer.h"
 #include "facepipeline.h"
 #include "facescansettings.h"
-#include "iteminfo.h"
 #include "iteminfojob.h"
 #include "facetags.h"
 
@@ -267,13 +266,6 @@ void FacesDetector::slotStart()
 {
     MaintenanceTool::slotStart();
 
-    if (ProgressManager::instance()->findItembyId(id()))
-    {
-        slotDone();
-
-        return;
-    }
-
     setThumbnail(QIcon::fromTheme(QLatin1String("edit-image-face-show")).pixmap(22));
 
     // set label depending on settings
@@ -468,7 +460,8 @@ void FacesDetector::slotDone()
 
     // Switch on scanned for faces flag on digiKam config file.
 
-    KSharedConfig::openConfig()->group("General Settings").writeEntry("Face Scanner First Run", true);
+    KSharedConfig::openConfig()->group(QLatin1String("General Settings"))
+                                       .writeEntry("Face Scanner First Run", true);
 
     MaintenanceTool::slotDone();
 }
@@ -492,3 +485,5 @@ void FacesDetector::slotShowOneDetected(const FacePipelinePackage& /*package*/)
 } // namespace Digikam
 
 #include "facesdetector.moc"
+
+#include "moc_facesdetector.cpp"
