@@ -6,7 +6,7 @@
  * Date        : 2012-12-17
  * Description : workflow manager.
  *
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -29,7 +29,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "queuesettings.h"
 #include "batchtoolsfactory.h"
 
 namespace Digikam
@@ -513,11 +512,16 @@ bool WorkflowManager::load(QStringList& failed)
                             QString type  = e3.attribute(QLatin1String("type"));
                             QVariant var(val3);
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                             var.convert(QMetaType().fromName(type.toLatin1().constData()));
+
 #else
+
                             var.convert(QVariant::nameToType(type.toLatin1().constData()));
+
 #endif
+
 /*
                             qCDebug(DIGIKAM_GENERAL_LOG) << "name=" << pname << " :: "
                                                          << "type=" << type << " :: "
@@ -567,3 +571,5 @@ bool WorkflowManager::load(QStringList& failed)
 }
 
 } // namespace Digikam
+
+#include "moc_workflowmanager.cpp"
