@@ -6,7 +6,7 @@
  * Date        : 2008-11-21
  * Description : Batch Queue Manager items list.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -26,7 +26,6 @@
 #include <QDrag>
 #include <QMenu>
 #include <QAction>
-#include <QIcon>
 
 // KDE includes
 
@@ -378,12 +377,17 @@ Qt::DropActions QueueListView::supportedDropActions() const
     return (Qt::CopyAction | Qt::MoveAction);
 }
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
 QMimeData* QueueListView::mimeData(const QList<QTreeWidgetItem*>& items) const
+
 #else
+
 // cppcheck-suppress passedByValue
 QMimeData* QueueListView::mimeData(const QList<QTreeWidgetItem*> items) const    // clazy:exclude=function-args-by-ref
+
 #endif
+
 {
     QList<QUrl> urls;
     QList<int> albumIDs;
@@ -1233,3 +1237,5 @@ void QueueListView::slotProgressTimerDone()
 }
 
 } // namespace Digikam
+
+#include "moc_queuelist.cpp"
