@@ -7,7 +7,7 @@
  * Description : User interface for searches
  *
  * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -118,7 +118,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
     {
         SearchFieldRangeDouble* const field = new SearchFieldRangeDouble(parent);
         field->setFieldName(name);
-        field->setText(i18n("File Size"), i18n("Size of the file"));
+        field->setText(i18n("File Size"), i18n("Size of the file in megabytes"));
         field->setBetweenText(i18nc("Size of the file ...-...", "-"));
         field->setNumberPrefixAndSuffix(QString(), QLatin1String("MiB"));
         field->setBoundary(0, 1000000, 1, 0.5);
@@ -126,6 +126,17 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
 
         return field;
     }
+    else if (name == QLatin1String("bytesize"))
+    {
+        SearchFieldRangeInt* const field = new SearchFieldRangeInt(parent);
+        field->setFieldName(name);
+        field->setText(i18n("File Size"), i18n("Size of the file in bytes"));
+        field->setBetweenText(i18nc("Size of the file ...-...", "-"));
+        field->setNumberPrefixAndSuffix(QString(), QLatin1String("B"));
+        field->setBoundary(0, 1024 * 1024, 100);
+
+        return field;
+    }
     else if (name == QLatin1String("monthday"))
     {
         SearchFieldMonthDay* const field = new SearchFieldMonthDay(parent);
@@ -821,9 +832,10 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("Frame Rate"), i18n("Return video with the frame rate"));
         field->setBetweenText(i18nc("Find video with frame rate between...and...", "and"));
         field->setNumberPrefixAndSuffix(QString(), i18nc("Frames per Second", "fps"));
-        field->setBoundary(10, 60, 5);
+        field->setBoundary(10, 600, 5);
         field->setSuggestedValues(QList<int>()
-                                  << 10 << 15 << 20 << 25 << 30 << 35 << 40 << 45 << 55 << 60
+                                  << 10 << 15 << 20 << 25 << 30 << 35 << 40 << 45 << 55 << 60 << 120
+                                  << 180 << 240 << 300 << 360 << 420 << 480 << 540 << 600
                                   // TODO : adjust default values
                                  );
         field->setSuggestedInitialValue(10);
