@@ -6,19 +6,10 @@
  * Date        : 2003-02-10
  * Description : camera setup tab.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -50,8 +41,8 @@
 // KDE includes
 
 #include <kconfiggroup.h>
-#include <klocalizedstring.h>
 #include <ksharedconfig.h>
+#include <klocalizedstring.h>
 
 // Local includes
 
@@ -151,7 +142,7 @@ void CameraAutoDetectThread::run()
 {
     d->result = GPCamera::autoDetect(d->model, d->port);
 
-    emit signalComplete();
+    Q_EMIT signalComplete();
 }
 
 int CameraAutoDetectThread::result() const
@@ -289,7 +280,8 @@ SetupCamera::SetupCamera(QWidget* const parent)
     setWidget(d->tab);
     setWidgetResizable(true);
 
-    const int spacing    = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing    = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     QWidget* const panel = new QWidget(d->tab);
 
@@ -362,7 +354,7 @@ SetupCamera::SetupCamera(QWidget* const parent)
     grid->addItem(spacer,                4, 1, 1, 1);
     grid->addWidget(gphotoLogoLabel,     5, 1, 1, 1);
 
-    d->tab->insertTab(0, panel, i18n("Devices"));
+    d->tab->insertTab(Devices, panel, i18n("Devices"));
 
     // -------------------------------------------------------------
 
@@ -399,7 +391,7 @@ SetupCamera::SetupCamera(QWidget* const parent)
     boxLayout->setColumnStretch(2, 1);
     conflictBox->setLayout(boxLayout);
 
-    d->tab->insertTab(1, panel2, i18n("Behavior"));
+    d->tab->insertTab(Behavior, panel2, i18n("Behavior"));
 
     layout->setContentsMargins(spacing, spacing, spacing, spacing);
     layout->setSpacing(spacing);
@@ -431,10 +423,14 @@ SetupCamera::SetupCamera(QWidget* const parent)
     QLabel* const label               = new QLabel(groupBox);
     verticalLayout->addWidget(label);
     d->ignoreNamesEdit                = new QLineEdit(groupBox);
+    d->ignoreNamesEdit->setToolTip(i18n("Use a space as a separator to specify "
+                                        "multiple file names to ignore."));
     verticalLayout->addWidget(d->ignoreNamesEdit);
     QLabel* const label2              = new QLabel(groupBox);
     verticalLayout->addWidget(label2);
     d->ignoreExtensionsEdit           = new QLineEdit(groupBox);
+    d->ignoreExtensionsEdit->setToolTip(i18n("Use a space as a separator to specify "
+                                             "multiple file extensions to ignore."));
     verticalLayout->addWidget(d->ignoreExtensionsEdit);
 
     groupBox->setTitle(i18n("Always ignore"));
@@ -459,7 +455,7 @@ SetupCamera::SetupCamera(QWidget* const parent)
     importGrid->addWidget(d->importEditButton,   2, 1, 1, 1);
     importGrid->addItem(spacer2,                 3, 1, 1, 1);
 
-    d->tab->insertTab(2, panel3, i18n("Import Filters"));
+    d->tab->insertTab(ImportFilters, panel3, i18n("Import Filters"));
 
     // -- Import Icon View ----------------------------------------------------------
 
@@ -568,7 +564,7 @@ SetupCamera::SetupCamera(QWidget* const parent)
     layout2->addWidget(d->fullScreenSettings);
     layout2->addStretch();
 
-    d->tab->insertTab(3, panel4, i18nc("@title:tab import tool GUI settings", "Import Window"));
+    d->tab->insertTab(ImportWindow, panel4, i18nc("@title:tab import tool GUI settings", "Import Window"));
 
     // -------------------------------------------------------------
 
@@ -629,6 +625,16 @@ SetupCamera::~SetupCamera()
     delete d;
 }
 
+void SetupCamera::setActiveTab(CameraTab tab)
+{
+    d->tab->setCurrentIndex(tab);
+}
+
+SetupCamera::CameraTab SetupCamera::activeTab() const
+{
+    return (CameraTab)d->tab->currentIndex();
+}
+
 bool SetupCamera::useFileMetadata()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
@@ -647,7 +653,7 @@ void SetupCamera::readSettings()
     {
         QList<CameraType*>* const cl = clist->cameraList();
 
-        foreach (CameraType* const ctype, *cl)
+        Q_FOREACH (CameraType* const ctype, *cl)
         {
             new SetupCameraItem(d->listView, ctype);
         }
@@ -688,7 +694,7 @@ void SetupCamera::readSettings()
 
     ImportFilterComboBox::defaultFilters(&d->filters);
 
-    foreach (Filter* const f, d->filters)
+    Q_FOREACH (Filter* const f, d->filters)
     {
         new QListWidgetItem(f->name, d->importListView);
     }
@@ -1038,3 +1044,5 @@ void SetupCamera::slotPreviewFullImageSizeClicked()
 }
 
 } // namespace Digikam
+
+#include "moc_setupcamera.cpp"
