@@ -7,7 +7,7 @@
  * Description : collections setup tab model/view
  *
  * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -46,7 +46,6 @@
 #include "dmessagebox.h"
 #include "dfiledialog.h"
 #include "applicationsettings.h"
-#include "collectionlocation.h"
 #include "collectionmanager.h"
 #include "newitemsfinder.h"
 #include "dtextedit.h"
@@ -750,7 +749,7 @@ void SetupCollectionModel::addCollection(int category)
     QString label;
     QString path = lastAddedCollectionPath;
 
-    if (askForNewCollectionPath(category, &path, &label))
+    if (askForNewCollectionPath(true, category, &path, &label))
     {
         // Add new item to model. Adding to CollectionManager is done in apply()!
 
@@ -817,7 +816,7 @@ void SetupCollectionModel::updateCollection(int internalId)
 
         item.deleted = true;
 
-        if (askForNewCollectionPath(parentId, &path, &label))
+        if (askForNewCollectionPath(false, parentId, &path, &label))
         {
             item.parentId = parentId;
             item.label    = label;
@@ -846,6 +845,7 @@ void SetupCollectionModel::deleteCollection(int internalId)
     int result    = QMessageBox::No;
     Item& item    = m_collections[index.internalId()];
     QString label = data(indexForId(internalId, (int)ColumnName), Qt::DisplayRole).toString();
+    Q_UNUSED(result);
 
     // Ask for confirmation
 
@@ -1432,6 +1432,11 @@ QList<QModelIndex> SetupCollectionModel::categoryIndexes() const
 
 QModelIndex SetupCollectionModel::indexForId(int id, int column) const
 {
+    if (id >= m_collections.size())
+    {
+        return QModelIndex();
+    }
+
     int   row             = 0;
     const Item& indexItem = m_collections.at(id);
 
@@ -1475,7 +1480,7 @@ SetupCollectionModel::Category SetupCollectionModel::typeToCategory(CollectionLo
     }
 }
 
-bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const newPath, QString* const newLabel)
+bool SetupCollectionModel::askForNewCollectionPath(bool adding, int category, QString* const newPath, QString* const newLabel)
 {
     QString picPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
 
@@ -1563,8 +1568,23 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
         case CollectionManager::LocationNotAllowed:
         case CollectionManager::LocationInvalidCheck:
         {
-            QMessageBox::warning(m_dialogParentWidget, i18nc("@title:window", "Problem Adding Collection"), messageFromManager);
+            QString warning;
+
+            if (adding)
+            {
+                warning = i18nc("@title:window",
+                                "Problem Adding Collection");
+            }
+            else
+            {
+                warning = i18nc("@title:window",
+                                "Problem updating Collection");
+            }
+
+            QMessageBox::warning(m_dialogParentWidget, warning, messageFromManager);
+
             // fail
+
             return false;
         }
     }
@@ -1572,11 +1592,28 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
     // Create a dialog that displays volume information and allows to change the name of the collection
 
     QDialog* const dialog     = new QDialog(m_dialogParentWidget);
-    dialog->setWindowTitle(i18nc("@title:window", "Adding Collection"));
+
+    if (adding)
+    {
+        dialog->setWindowTitle(i18nc("@title:window", "Adding Collection"));
+    }
+    else
+    {
+        dialog->setWindowTitle(i18nc("@title:window", "Update Collection"));
+    }
 
     QWidget* const mainWidget = new QWidget(dialog);
     QLabel* const nameLabel   = new QLabel;
-    nameLabel->setText(i18n("Your new collection will be created with this name:"));
+
+    if (adding)
+    {
+        nameLabel->setText(i18n("Your new collection will be created with this name:"));
+    }
+    else
+    {
+        nameLabel->setText(i18n("Your collection will be updated to this name:"));
+    }
+
     nameLabel->setWordWrap(true);
 
     // lineedit for collection name
@@ -1746,3 +1783,5 @@ void SetupCollectionModel::slotHelp()
 }
 
 } // namespace Digikam
+
+#include "moc_setupcollectionview.cpp"
