@@ -6,18 +6,9 @@
  * Date        : 2015-06-16
  * Description : Advanced Configuration tab for metadata.
  *
- * Copyright (C) 2015 by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail.com>
+ * SPDX-FileCopyrightText: 2015 by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail.com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -32,22 +23,26 @@
 #include <QCheckBox>
 #include <QPushButton>
 #include <QListView>
+#include <QStandardPaths>
 #include <QStandardItemModel>
 #include <QStandardItem>
-#include <QDebug>
 #include <QLabel>
+#include <QUrl>
 
 // KDE includes
 
+#include <kconfig.h>
+#include <kconfiggroup.h>
 #include <klocalizedstring.h>
 
 // Local includes
 
+#include "digikam_debug.h"
 #include "dmetadatasettings.h"
 #include "namespacelistview.h"
 #include "namespaceeditdlg.h"
 #include "dmessagebox.h"
-#include "digikam_debug.h"
+#include "dfiledialog.h"
 
 namespace Digikam
 {
@@ -65,8 +60,11 @@ public:
         moveUpButton    (nullptr),
         moveDownButton  (nullptr),
         revertChanges   (nullptr),
+        saveProfile     (nullptr),
+        loadProfile     (nullptr),
         resetButton     (nullptr),
         unifyReadWrite  (nullptr),
+        readingAllTags  (nullptr),
         namespaceView   (nullptr),
         metadataTypeSize(0),
         changed         (false)
@@ -81,8 +79,11 @@ public:
     QPushButton*                moveUpButton;
     QPushButton*                moveDownButton;
     QPushButton*                revertChanges;
+    QPushButton*                saveProfile;
+    QPushButton*                loadProfile;
     QPushButton*                resetButton;
     QCheckBox*                  unifyReadWrite;
+    QCheckBox*                  readingAllTags;
     QList<QStandardItemModel*>  models;
     NamespaceListView*          namespaceView;
     DMetadataSettingsContainer  container;
@@ -103,10 +104,14 @@ AdvancedMetadataTab::AdvancedMetadataTab(QWidget* const parent)
     connectButtons();
 
     d->unifyReadWrite->setChecked(d->container.unifyReadWrite());
+    d->readingAllTags->setChecked(d->container.readingAllTags());
 
     connect(d->unifyReadWrite, SIGNAL(toggled(bool)),
             this, SLOT(slotUnifyChecked(bool)));
 
+    connect(d->readingAllTags, SIGNAL(toggled(bool)),
+            this, SLOT(slotAllTagsChecked(bool)));
+
     connect(d->metadataType, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotIndexChanged()));
 
@@ -131,11 +136,82 @@ AdvancedMetadataTab::~AdvancedMetadataTab()
     delete d;
 }
 
+void AdvancedMetadataTab::slotSaveProfile()
+{
+    QString metaPath = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+
+    QString savePath = DFileDialog::getSaveFileName(qApp->activeWindow(),
+                                                    i18nc("@title:window", "Save Advanced Metadata Profile"),
+                                                    metaPath, QLatin1String("*.dkamp"), nullptr,
+                                                    QFileDialog::DontConfirmOverwrite);
+
+    if (savePath.isEmpty())
+    {
+        return;
+    }
+
+    if (!savePath.endsWith(QLatin1String(".dkamp")))
+    {
+        savePath.append(QLatin1String(".dkamp"));
+    }
+
+    KConfig config(savePath);
+    KConfigGroup group1 = config.group(QLatin1String("General"));
+    KConfigGroup group2 = config.group(QLatin1String("Metadata"));
+    group1.writeEntry(QLatin1String("AMPVersion"), 1);
+    d->container.writeToConfig(group2);
+    config.sync();
+}
+
+void AdvancedMetadataTab::slotLoadProfile()
+{
+    QString metaPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                              QLatin1String("digikam/metadata"),
+                                              QStandardPaths::LocateDirectory);
+
+    QString loadPath = DFileDialog::getOpenFileName(qApp->activeWindow(),
+                                                    i18nc("@title:window", "Load Advanced Metadata Profile"),
+                                                    metaPath, QLatin1String("*.dkamp"));
+
+    if (loadPath.isEmpty())
+    {
+        return;
+    }
+
+    KConfig config(loadPath);
+    KConfigGroup group1 = config.group(QLatin1String("General"));
+    KConfigGroup group2 = config.group(QLatin1String("Metadata"));
+    int version         = group1.readEntry(QLatin1String("AMPVersion"), 0);
+
+    if (version != 1)
+    {
+        return;
+    }
+
+    DMetadataSettingsContainer container;
+    container.readFromConfig(group2);
+
+    if (container.mappingKeys().size() != 5)
+    {
+        return;
+    }
+
+    d->container = container;
+
+    d->unifyReadWrite->setChecked(d->container.unifyReadWrite());
+    d->readingAllTags->setChecked(d->container.readingAllTags());
+
+    d->revertChanges->setEnabled(false);
+    d->changed = false;
+
+    setModels();
+}
+
 void AdvancedMetadataTab::slotResetToDefault()
 {
     const int result = DMessageBox::showContinueCancel(QMessageBox::Warning,
                                                        this,
-                                                       i18nc("@title: reset to default warning dialog", "Warning"),
+                                                       i18nc("@title:window, reset to default warning dialog", "Warning"),
                                                        i18nc("@info", "This option will reset configuration to default\n"
                                                                       "All your changes will be lost.\n "
                                                                       "Do you want to continue?"));
@@ -246,9 +322,18 @@ void AdvancedMetadataTab::slotUnifyChecked(bool value)
     slotIndexChanged();
 }
 
+void AdvancedMetadataTab::slotAllTagsChecked(bool value)
+{
+    d->container.setReadingAllTags(value);
+}
+
 void AdvancedMetadataTab::slotIndexChanged()
 {
     d->namespaceView->setModel(d->models.at(getModelIndex()));
+
+    bool val = (d->metadataType->currentData().toString() ==
+                NamespaceEntry::DM_TAG_CONTAINER());
+    d->readingAllTags->setEnabled(val);
 }
 
 void AdvancedMetadataTab::slotRevertChangesAvailable()
@@ -273,6 +358,12 @@ void AdvancedMetadataTab::connectButtons()
     connect(d->deleteButton, SIGNAL(clicked()),
             d->namespaceView, SLOT(slotDeleteSelected()));
 
+    connect(d->saveProfile, SIGNAL(clicked()),
+            this, SLOT(slotSaveProfile()));
+
+    connect(d->loadProfile, SIGNAL(clicked()),
+            this, SLOT(slotLoadProfile()));
+
     connect(d->resetButton, SIGNAL(clicked()),
             this, SLOT(slotResetToDefault()));
 
@@ -286,7 +377,7 @@ void AdvancedMetadataTab::connectButtons()
             d->namespaceView, SLOT(slotMoveItemDown()));
 }
 
-void AdvancedMetadataTab::setModelData(QStandardItemModel* model,
+void AdvancedMetadataTab::setModelData(QStandardItemModel* const model,
                                        const QList<NamespaceEntry>& container)
 {
     QStandardItem* const root = model->invisibleRootItem();
@@ -307,7 +398,7 @@ void AdvancedMetadataTab::setModelData(QStandardItemModel* model,
 void AdvancedMetadataTab::setUi()
 {
     QVBoxLayout* const advancedConfLayout = new QVBoxLayout(this);
-    QHBoxLayout* const topLayout          = new QHBoxLayout();
+    QGridLayout* const topLayout          = new QGridLayout();
     QHBoxLayout* const bottomLayout       = new QHBoxLayout();
 
     QLabel* const tipLabel = new QLabel(this);
@@ -320,16 +411,20 @@ void AdvancedMetadataTab::setUi()
 
     //--- Top layout ----------------
 
-    d->metadataType  = new QComboBox(this);
-    d->operationType = new QComboBox(this);
+    d->metadataType   = new QComboBox(this);
+    d->operationType  = new QComboBox(this);
 
-    d->operationType->insertItems(0, QStringList() << i18n("Read Options") << i18n("Write Options"));
+    d->operationType->insertItems(0, QStringList() << i18n("Read Options")
+                                                   << i18n("Write Options"));
 
     d->unifyReadWrite = new QCheckBox(i18n("Unify read and write"));
+    d->readingAllTags = new QCheckBox(i18n("Read all metadata for tags"));
+    d->readingAllTags->setEnabled(false);
 
-    topLayout->addWidget(d->metadataType);
-    topLayout->addWidget(d->operationType);
-    topLayout->addWidget(d->unifyReadWrite);
+    topLayout->addWidget(d->metadataType,   0, 0, 1, 1);
+    topLayout->addWidget(d->operationType,  0, 1, 1, 1);
+    topLayout->addWidget(d->unifyReadWrite, 0, 2, 1, 1);
+    topLayout->addWidget(d->readingAllTags, 1, 2, 1, 1);
 
     //------------ Bottom Layout-------------
 
@@ -363,6 +458,12 @@ void AdvancedMetadataTab::setUi()
     // Revert changes is disabled, until a change is made
 
     d->revertChanges->setEnabled(false);
+    d->saveProfile = new QPushButton(QIcon::fromTheme(QLatin1String("document-save-as")),
+                                     i18n("Save Profile"));
+
+    d->loadProfile = new QPushButton(QIcon::fromTheme(QLatin1String("document-open")),
+                                     i18n("Load Profile"));
+
     d->resetButton = new QPushButton(QIcon::fromTheme(QLatin1String("view-refresh")),
                                      i18n("Reset to Default"));
 
@@ -372,6 +473,8 @@ void AdvancedMetadataTab::setUi()
     buttonsLayout->addWidget(d->moveUpButton);
     buttonsLayout->addWidget(d->moveDownButton);
     buttonsLayout->addWidget(d->revertChanges);
+    buttonsLayout->addWidget(d->saveProfile);
+    buttonsLayout->addWidget(d->loadProfile);
     buttonsLayout->addWidget(d->resetButton);
 
     QVBoxLayout* const vbox = new QVBoxLayout();
@@ -385,7 +488,7 @@ void AdvancedMetadataTab::setUi()
     advancedConfLayout->addLayout(bottomLayout);
 }
 
-void AdvancedMetadataTab::setDataToItem(QStandardItem* item, NamespaceEntry& entry)
+void AdvancedMetadataTab::setDataToItem(QStandardItem* const item, const NamespaceEntry& entry)
 {
     item->setData(entry.namespaceName,  Qt::DisplayRole);
     item->setData(entry.namespaceName,  NAME_ROLE);
@@ -452,15 +555,25 @@ QList<NamespaceEntry>& AdvancedMetadataTab::getCurrentContainer()
 
 void AdvancedMetadataTab::setModels()
 {
+    d->metadataType->blockSignals(true);
+    d->metadataType->clear();
+
     QList<QString> keys = d->container.mappingKeys();
 
-    foreach (const QString& str, keys)
+    Q_FOREACH (const QString& str, keys)
     {
-        d->metadataType->addItem(i18n(str.toUtf8().constData()), str);
+        d->metadataType->addItem(d->container.translateMappingKey(str), str);
     }
 
     d->metadataTypeSize = keys.size();
 
+    for (int i = 0 ; i < d->models.size() ; ++i)
+    {
+        d->models.at(i)->clear();
+    }
+
+    d->models.clear();
+
     for (int i = 0 ; i < keys.size() * 2 ; ++i)
     {
         d->models.append(new QStandardItemModel(this));
@@ -468,16 +581,19 @@ void AdvancedMetadataTab::setModels()
 
     int index = 0;
 
-    foreach (const QString& str, keys)
+    Q_FOREACH (const QString& str, keys)
     {
         setModelData(d->models.at(index++), d->container.getReadMapping(str));
     }
 
-    foreach (const QString& str, keys)
+    Q_FOREACH (const QString& str, keys)
     {
         setModelData(d->models.at(index++), d->container.getWriteMapping(str));
     }
 
+    d->metadataType->setCurrentIndex(0);
+    d->metadataType->blockSignals(false);
+
     slotIndexChanged();
 }
 
@@ -486,20 +602,20 @@ void AdvancedMetadataTab::updateContainer()
     QList<QString> keys = d->container.mappingKeys();
     int index           = 0;
 
-    foreach (const QString& str, keys)
+    Q_FOREACH (const QString& str, keys)
     {
         d->container.getReadMapping(str).clear();
         saveModelData(d->models.at(index++), d->container.getReadMapping(str));
     }
 
-    foreach (const QString& str, keys)
+    Q_FOREACH (const QString& str, keys)
     {
         d->container.getWriteMapping(str).clear();
         saveModelData(d->models.at(index++), d->container.getWriteMapping(str));
     }
 }
 
-void AdvancedMetadataTab::saveModelData(QStandardItemModel* model,
+void AdvancedMetadataTab::saveModelData(QStandardItemModel* const model,
                                         QList<NamespaceEntry>& container)
 {
     QStandardItem* const root = model->invisibleRootItem();
@@ -549,3 +665,5 @@ void AdvancedMetadataTab::saveModelData(QStandardItemModel* model,
 }
 
 } // namespace Digikam
+
+#include "moc_advancedmetadatatab.cpp"
