@@ -7,7 +7,7 @@
  * Description : digiKam setup dialog.
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -48,8 +48,8 @@
 #include "dxmlguiwindow.h"
 #include "onlineversiondlg.h"
 
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-#   include "setupvideo.h"
+#ifdef HAVE_GEOLOCATION
+#   include "setupgeolocation.h"
 #endif
 
 namespace Digikam
@@ -64,16 +64,16 @@ public:
         page_collections        (nullptr),
         page_albumView          (nullptr),
         page_tooltip            (nullptr),
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-        page_video              (nullptr),
-
-#endif
-
         page_metadata           (nullptr),
         page_template           (nullptr),
         page_lighttable         (nullptr),
+
+#ifdef HAVE_GEOLOCATION
+
+        page_geolocation        (nullptr),
+
+#endif
+
         page_editor             (nullptr),
         page_imagequalitysorter (nullptr),
         page_icc                (nullptr),
@@ -84,16 +84,16 @@ public:
         collectionsPage         (nullptr),
         albumViewPage           (nullptr),
         tooltipPage             (nullptr),
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-        videoPage               (nullptr),
-
-#endif
-
         metadataPage            (nullptr),
         templatePage            (nullptr),
         lighttablePage          (nullptr),
+
+#ifdef HAVE_GEOLOCATION
+
+        geolocationPage         (nullptr),
+
+#endif
+
         editorPage              (nullptr),
         imageQualitySorterPage  (nullptr),
         iccPage                 (nullptr),
@@ -107,16 +107,16 @@ public:
     DConfigDlgWdgItem*       page_collections;
     DConfigDlgWdgItem*       page_albumView;
     DConfigDlgWdgItem*       page_tooltip;
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-    DConfigDlgWdgItem*       page_video;
-
-#endif
-
     DConfigDlgWdgItem*       page_metadata;
     DConfigDlgWdgItem*       page_template;
     DConfigDlgWdgItem*       page_lighttable;
+
+#ifdef HAVE_GEOLOCATION
+
+    DConfigDlgWdgItem*       page_geolocation;
+
+#endif
+
     DConfigDlgWdgItem*       page_editor;
     DConfigDlgWdgItem*       page_imagequalitysorter;
     DConfigDlgWdgItem*       page_icc;
@@ -128,16 +128,16 @@ public:
     SetupCollections*        collectionsPage;
     SetupAlbumView*          albumViewPage;
     SetupToolTip*            tooltipPage;
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-    SetupVideo*              videoPage;
-
-#endif
-
     SetupMetadata*           metadataPage;
     SetupTemplate*           templatePage;
     SetupLightTable*         lighttablePage;
+
+#ifdef HAVE_GEOLOCATION
+
+    SetupGeolocation*        geolocationPage;
+
+#endif
+
     SetupEditor*             editorPage;
     SetupImageQualitySorter* imageQualitySorterPage;
     SetupICC*                iccPage;
@@ -185,15 +185,6 @@ Setup::Setup(QWidget* const parent)
     d->page_tooltip->setHeader(i18nc("@title", "Items Tool-Tip Settings\nCustomize information in item tool-tips"));
     d->page_tooltip->setIcon(QIcon::fromTheme(QLatin1String("dialog-information")));
 
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-    d->videoPage  = new SetupVideo();
-    d->page_video = addPage(d->videoPage, i18nc("@title: settings section", "Video"));
-    d->page_video->setHeader(i18nc("@title", "Video Preview Settings\nCustomize settings to play video media"));
-    d->page_video->setIcon(QIcon::fromTheme(QLatin1String("video-x-generic")));
-
-#endif
-
     d->metadataPage  = new SetupMetadata();
     d->page_metadata = addPage(d->metadataPage, i18nc("@title: settings section", "Metadata"));
     d->page_metadata->setHeader(i18nc("@title", "Embedded Image Information Management\nSetup relations between images and metadata"));
@@ -216,9 +207,18 @@ Setup::Setup(QWidget* const parent)
 
     d->lighttablePage  = new SetupLightTable();
     d->page_lighttable = addPage(d->lighttablePage, i18nc("@title: settings section", "Light Table"));
-    d->page_lighttable->setHeader(i18nc("@title", "Light Table Settings\nCustomize tool used to compare images"));
+    d->page_lighttable->setHeader(i18nc("@title", "Light Table Settings\nCustomize tool used to compare items"));
     d->page_lighttable->setIcon(QIcon::fromTheme(QLatin1String("lighttable")));
 
+#ifdef HAVE_GEOLOCATION
+
+    d->geolocationPage  = new SetupGeolocation();
+    d->page_geolocation = addPage(d->geolocationPage, i18nc("@title: settings section", "Geolocation"));
+    d->page_geolocation->setHeader(i18nc("@title", "Geolocation Settings\nCustomize view to geolocalize items"));
+    d->page_geolocation->setIcon(QIcon::fromTheme(QLatin1String("map-globe")));
+
+#endif
+
     d->imageQualitySorterPage = new SetupImageQualitySorter();
     d->page_imagequalitysorter = addPage(d->imageQualitySorterPage, i18nc("@title: settings section", "Image Quality Sorter"));
     d->page_imagequalitysorter->setHeader(i18nc("@title", "Image Quality Sorter Settings\nCustomize default settings to perform image triaging by quality"));
@@ -285,16 +285,16 @@ Setup::~Setup()
     group.writeEntry(QLatin1String("Setup Page"),      (int)activePageIndex());
     group.writeEntry(QLatin1String("Albumview Tab"),   (int)d->albumViewPage->activeTab());
     group.writeEntry(QLatin1String("ToolTip Tab"),     (int)d->tooltipPage->activeTab());
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-    group.writeEntry(QLatin1String("Video Tab"),       (int)d->videoPage->activeTab());
-
-#endif
-
     group.writeEntry(QLatin1String("Metadata Tab"),    (int)d->metadataPage->activeTab());
     group.writeEntry(QLatin1String("Metadata SubTab"), (int)d->metadataPage->activeSubTab());
     group.writeEntry(QLatin1String("Editor Tab"),      (int)d->editorPage->activeTab());
+
+#ifdef HAVE_GEOLOCATION
+
+    group.writeEntry(QLatin1String("Geolocation Tab"), (int)d->geolocationPage->activeTab());
+
+#endif
+
     group.writeEntry(QLatin1String("ICC Tab"),         (int)d->iccPage->activeTab());
     group.writeEntry(QLatin1String("Camera Tab"),      (int)d->cameraPage->activeTab());
     group.writeEntry(QLatin1String("Plugin Tab"),      (int)d->pluginsPage->activeTab());
@@ -415,6 +415,38 @@ bool Setup::execTemplateEditor(QWidget* const parent, const Template& t)
     return success;
 }
 
+#ifdef HAVE_GEOLOCATION
+
+bool Setup::execGeolocation(QWidget* const parent, int tab)
+{
+    QPointer<Setup> setup        = new Setup(parent);
+    setup->showPage(GeolocationPage);
+    setup->setFaceType(Plain);
+
+    DConfigDlgWdgItem* const cur   = setup->currentPage();
+
+    if (!cur)
+    {
+        return false;
+    }
+
+    SetupGeolocation* const widget = dynamic_cast<SetupGeolocation*>(cur->widget());
+
+    if (!widget)
+    {
+        return false;
+    }
+
+    widget->setActiveTab((SetupGeolocation::GeolocationTab)tab);
+
+    bool success                   = (setup->DConfigDlg::exec() == QDialog::Accepted);
+    delete setup;
+
+    return success;
+}
+
+#endif
+
 bool Setup::execMetadataFilters(QWidget* const parent, int tab)
 {
     QPointer<Setup> setup        = new Setup(parent);
@@ -547,16 +579,16 @@ void Setup::slotOkClicked()
     d->collectionsPage->applySettings();
     d->albumViewPage->applySettings();
     d->tooltipPage->applySettings();
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-    d->videoPage->applySettings();
-
-#endif
-
     d->metadataPage->applySettings();
     d->templatePage->applySettings();
     d->lighttablePage->applySettings();
+
+#ifdef HAVE_GEOLOCATION
+
+    d->geolocationPage->applySettings();
+
+#endif
+
     d->editorPage->applySettings();
     d->imageQualitySorterPage->applySettings();
     d->iccPage->applySettings();
@@ -579,9 +611,9 @@ void Setup::slotOkClicked()
 void Setup::slotCancelClicked()
 {
 
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+#ifdef HAVE_GEOLOCATION
 
-    d->videoPage->cancel();
+    d->geolocationPage->cancel();
 
 #endif
 
@@ -599,15 +631,15 @@ void Setup::showPage(Setup::Page page)
         item = d->pageItem((Page)group.readEntry(QLatin1String("Setup Page"), (int)CollectionsPage));
         d->albumViewPage->setActiveTab((SetupAlbumView::AlbumTab)group.readEntry(QLatin1String("AlbumView Tab"), (int)SetupAlbumView::IconView));
         d->tooltipPage->setActiveTab((SetupToolTip::ToolTipTab)group.readEntry(QLatin1String("ToolTip Tab"), (int)SetupToolTip::IconItems));
+        d->metadataPage->setActiveTab((SetupMetadata::MetadataTab)group.readEntry(QLatin1String("Metadata Tab"), (int)SetupMetadata::Behavior));
+        d->metadataPage->setActiveSubTab((SetupMetadata::MetadataSubTab)group.readEntry(QLatin1String("Metadata SubTab"), (int)SetupMetadata::ExifViewer));
 
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+#ifdef HAVE_GEOLOCATION
 
-        d->videoPage->setActiveTab((SetupVideo::VideoTab)group.readEntry(QLatin1String("Video Tab"), (int)SetupVideo::Decoder));
+        d->geolocationPage->setActiveTab((SetupGeolocation::GeolocationTab)group.readEntry(QLatin1String("Geolocation Tab"), (int)SetupGeolocation::MarbleView));
 
 #endif
 
-        d->metadataPage->setActiveTab((SetupMetadata::MetadataTab)group.readEntry(QLatin1String("Metadata Tab"), (int)SetupMetadata::Behavior));
-        d->metadataPage->setActiveSubTab((SetupMetadata::MetadataSubTab)group.readEntry(QLatin1String("Metadata SubTab"), (int)SetupMetadata::ExifViewer));
         d->editorPage->setActiveTab((SetupEditor::EditorTab)group.readEntry(QLatin1String("Editor Tab"), (int)SetupEditor::EditorWindow));
         d->iccPage->setActiveTab((SetupICC::ICCTab)group.readEntry(QLatin1String("ICC Tab"), (int)SetupICC::Behavior));
         d->cameraPage->setActiveTab((SetupCamera::CameraTab)group.readEntry(QLatin1String("Camera Tab"), (int)SetupCamera::Devices));
@@ -646,15 +678,6 @@ Setup::Page Setup::activePageIndex() const
         return ToolTipPage;
     }
 
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-    if (cur == d->page_video)
-    {
-        return VideoPage;
-    }
-
-#endif
-
     if (cur == d->page_metadata)
     {
         return MetadataPage;
@@ -670,6 +693,15 @@ Setup::Page Setup::activePageIndex() const
         return LightTablePage;
     }
 
+#ifdef HAVE_GEOLOCATION
+
+    if (cur == d->page_geolocation)
+    {
+        return GeolocationPage;
+    }
+
+#endif
+
     if (cur == d->page_editor)
     {
         return EditorPage;
@@ -727,15 +759,6 @@ DConfigDlgWdgItem* Setup::Private::pageItem(Setup::Page page) const
             return page_tooltip;
         }
 
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-        case Setup::VideoPage:
-        {
-            return page_video;
-        }
-
-#endif
-
         case Setup::MetadataPage:
         {
             return page_metadata;
@@ -751,6 +774,15 @@ DConfigDlgWdgItem* Setup::Private::pageItem(Setup::Page page) const
             return page_lighttable;
         }
 
+#ifdef HAVE_GEOLOCATION
+
+        case Setup::GeolocationPage:
+        {
+            return page_geolocation;
+        }
+
+#endif
+
         case Setup::EditorPage:
         {
             return page_editor;
@@ -807,3 +839,5 @@ void Setup::onlineVersionCheck()
 }
 
 } // namespace Digikam
+
+#include "moc_setup.cpp"
