@@ -7,7 +7,7 @@
  * Description : Color management setup tab.
  *
  * SPDX-FileCopyrightText: 2005-2007 by F.J. Cruz <fj dot cruz at supercable dot es>
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,13 +20,10 @@
 
 #include <QButtonGroup>
 #include <QCheckBox>
-#include <QDir>
-#include <QUrl>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QIcon>
 #include <QLabel>
-#include <QMap>
 #include <QPixmap>
 #include <QPushButton>
 #include <QRadioButton>
@@ -988,3 +985,5 @@ bool SetupICC::iccRepositoryIsValid()
 }
 
 } // namespace Digikam
+
+#include "moc_setupicc.cpp"
