@@ -6,18 +6,9 @@
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -188,7 +179,8 @@ SetupToolTip::SetupToolTip(QWidget* const parent)
     setWidget(panel);
     setWidgetResizable(true);
 
-    const int spacing        = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing        = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     QVBoxLayout* const vlay  = new QVBoxLayout(panel);
 
@@ -467,9 +459,9 @@ SetupToolTip::SetupToolTip(QWidget* const parent)
 
     // --------------------------------------------------------
 
-    d->tab->insertTab(0, vbox,  i18n("Icon Items"));
-    d->tab->insertTab(1, vbox2, i18n("Album Items"));
-    d->tab->insertTab(2, vbox3, i18n("Import Items"));
+    d->tab->insertTab(IconItems,   vbox,  i18n("Icon Items"));
+    d->tab->insertTab(AlbumItems,  vbox2, i18n("Album Items"));
+    d->tab->insertTab(ImportItems, vbox3, i18n("Import Items"));
 
     vlay->addWidget(d->fontSelect);
     vlay->addWidget(d->tab);
@@ -508,6 +500,16 @@ SetupToolTip::~SetupToolTip()
     delete d;
 }
 
+void SetupToolTip::setActiveTab(ToolTipTab tab)
+{
+    d->tab->setCurrentIndex(tab);
+}
+
+SetupToolTip::ToolTipTab SetupToolTip::activeTab() const
+{
+    return (ToolTipTab)d->tab->currentIndex();
+}
+
 void SetupToolTip::applySettings()
 {
     ApplicationSettings* const settings = ApplicationSettings::instance();
@@ -691,3 +693,5 @@ void SetupToolTip::refreshCameraOptions()
 }
 
 } // namespace Digikam
+
+#include "moc_setuptooltip.cpp"
