@@ -2,7 +2,7 @@
 
 # Configuration for script to build AppImage bundle.
 #
-# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -42,28 +42,24 @@ DK_GITURL="git@invent.kde.org:graphics/digikam.git"
 # Location to build source code.
 DK_BUILDTEMP=$BUILDING_DIR/dktemp
 
+# Qt version to use in bundle. Possible values:
+# - 5:    stable Qt5 release.
+# - 6:    stable Qt6 release.
+
+#DK_QTVERSION="6"
+DK_QTVERSION="5"
+
+# KDE Plasma version.
+# See official release here: https://download.kde.org/stable/plasma/
+DK_KP_VERSION="5.27.10"
+
 # KDE Application version.
 # See official release here: https://download.kde.org/stable/release-service/
-DK_KA_VERSION="22.12.3"
-
-# KDE KF5 frameworks version.
-# See official release here: https://download.kde.org/stable/frameworks/
-DK_KF5_VERSION="5.104"
+DK_KA_VERSION="23.08.5"
 
 # Installer will include or not digiKam debug symbols
 DK_DEBUG=0
 
-# Qt version to use in bundle. Possible values:
-# - 5.15:     stable Qt5 release.
-# - 5.15-LTS: rolling release version 5 (can be not stbilized)
-# - 6.3.1:    stable Qt6 release.
-
-#DK_QTVERSION="6.3.1"
-DK_QTVERSION="5.15"
-
-# QtWebEngine version to use in bundle when 5.15-LTS is used.
-DK_QTWEBENGINEVERSION="5.15.9"
-
 # Option to use QtWebEngine instead QtWebkit
 DK_QTWEBENGINE=1
 
@@ -76,4 +72,18 @@ DK_SIGN=0
 # Upload automatically bundle to files.kde.org (pre-release only).
 DK_UPLOAD=1
 DK_UPLOADURL="digikam@tinami.kde.org"
-DK_UPLOADDIR="/srv/archives/files/digikam/"
+
+# KDE frameworks version + Upload URL.
+# See official release here: https://download.kde.org/stable/frameworks/
+
+if [[ $DK_QTVERSION == 5 ]] ; then
+
+    DK_KDE_VERSION="5.115"
+    DK_UPLOADDIR="/srv/archives/files/digikam/"
+
+else
+
+    DK_KDE_VERSION="master"                                 # Qt6 version use master code for the moment.
+    DK_UPLOADDIR="/srv/archives/files/digikam/unstable"     # Qt6 version is considerated unstable for the moment.
+
+fi
