@@ -3,10 +3,9 @@
 # Script to install extra libs dependency pass as name as first argument (ex: "kimageformats")
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Halt and catch errors
@@ -23,8 +22,8 @@ fi
 #################################################################################################
 # Pre-processing checks
 
-. ../config.sh
 . ../common.sh
+. ../config.sh
 ChecksRunAsRoot
 StartScript
 ChecksCPUCores
@@ -39,16 +38,16 @@ cd $BUILDING_DIR
 
 rm -rf $BUILDING_DIR/* || true
 
-/opt/cmake/bin/cmake $ORIG_WD/../3rdparty \
+cmake $ORIG_WD/../3rdparty \
       -DCMAKE_INSTALL_PREFIX:PATH=/usr \
       -DINSTALL_ROOT=/usr \
       -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
       -DKA_VERSION=$DK_KA_VERSION \
-      -DKF5_VERSION=$DK_KF5_VERSION \
+      -DKDE_VERSION=$DK_KDE_VERSION \
       -DENABLE_QTVERSION=$DK_QTVERSION \
       -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE
 
-/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_$1 -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_$1 -- -j$CPU_CORES
 
 #################################################################################################
 
