@@ -3,8 +3,8 @@
 # Script to build a bundle Macports installation with all digiKam dependencies in a dedicated directory
 # This script must be run as sudo
 #
-# SPDX-FileCopyrightText: 2015      by Shanti, <listaccount at revenant dot org>
-# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015      by Shanti <listaccount at revenant dot org>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -256,13 +256,7 @@ echo -e "\n"
 
 if [[ $ARCH_TARGET = "x86_64" ]] ; then
 
-    # Note: subversion is used to checkout translations from KDE repositories.
-    # Subversion do not compile under arm64 and XCode drop svn supports.
-    # KDE team plan to migrate svn to git: https://phabricator.kde.org/T13514
-
-    port install \
-                 ld64 +ld64_xcode \
-                 subversion
+    port install ld64 +ld64_xcode
 
 fi
 
@@ -286,7 +280,6 @@ port install \
              libxml2 \
              libxslt \
              libical \
-             lensfun \
              bison \
              py38-lxml \
              x265 \
@@ -304,6 +297,7 @@ port install \
              qt5-qttools \
              qt5-qttranslations \
              qt5-qtimageformats \
+             qt5-qtmultimedia
              qt5-qtnetworkauth \
              qt5-sqlite-plugin \
              qt5-mysql-plugin $MP_MARIADB_VARIANT
@@ -358,7 +352,8 @@ cmake $ORIG_WD/../3rdparty \
        -DINSTALL_ROOT=$INSTALL_PREFIX \
        -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
        -DKA_VERSION=$DK_KA_VERSION \
-       -DKF5_VERSION=$DK_KF5_VERSION \
+       -DKP_VERSION=$DK_KP_VERSION \
+       -DKDE_VERSION=$DK_KDE_VERSION \
        -DENABLE_QTVERSION=$DK_QTVERSION \
        -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE \
        -Wno-dev
