@@ -5,7 +5,7 @@
 # This script must be run as sudo
 #
 # SPDX-FileCopyrightText: 2015      by Shanti, <listaccount at revenant dot org>
-# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -77,6 +77,7 @@ Applications/digiKam.org \
 # Other apps - non-MacOS binaries & libraries to be included with required dylibs
 OTHER_APPS="\
 lib/plugins/imageformats/*.so \
+lib/plugins/styles/*.so \
 lib/plugins/digikam/bqm/*.so \
 lib/plugins/digikam/generic/*.so \
 lib/plugins/digikam/editor/*.so \
@@ -91,6 +92,7 @@ lib/mariadb$MARIADB_SUFFIX/mysql/*.dylib \
 lib/mariadb$MARIADB_SUFFIX/plugin/*.so \
 bin/kbuildsycoca5 \
 bin/solid-hardware5 \
+bin/ffmpeg \
 libexec/qt5/plugins/imageformats/*.dylib \
 libexec/qt5/plugins/sqldrivers/*.dylib \
 libexec/qt5/plugins/printsupport/*.dylib \
@@ -107,7 +109,7 @@ libexec/qt5/plugins/bearer/*.dylib \
 binaries="$OTHER_APPS"
 
 # Additional Files/Directories - to be copied recursively but not checked for dependencies
-# Note: dSYM directories aee copied as well and cleaned later if debug symbols must be removed in final bundle.
+# Note: dSYM directories are copied as well and cleaned later if debug symbols must be removed in final bundle.
 OTHER_DIRS="\
 libexec/qt5/translations \
 lib/libdigikam*.dSYM \
@@ -133,8 +135,6 @@ share/k* \
 share/lensfun \
 share/mime \
 Library/Application/ \
-Marble.app/Contents/Resources/ \
-Marble.app/Contents/MacOS/resources/ \
 "
 
 # Packaging tool paths
@@ -340,6 +340,9 @@ cd "$ORIG_WD"
 cp -a $TEMPROOT/lib/plugins $TEMPROOT/libexec/qt5/
 rm -rf $TEMPROOT/lib/plugins
 
+# See bug #476290
+rm -fr $TEMPROOT/libexec/qt5/plugins/imageformats/libqjp2.dylib
+
 #################################################################################################
 # Merge Manifest files
 
@@ -455,7 +458,7 @@ fi
 #
 # https://stackoverflow.com/questions/9263256/can-you-please-help-me-understand-how-mach-o-libraries-work-in-mac-os-x
 # https://matthew-brett.github.io/docosx/mac_runtime_link.html
-# http://thecourtsofchaos.com/2013/09/16/how-to-copy-and-relink-binaries-on-osx/
+# https://thecourtsofchaos.com/2013/09/16/how-to-copy-and-relink-binaries-on-osx/
 
 echo -e "\n---------- Relocatable binary files"
 
@@ -603,9 +606,9 @@ cd $DOWNLOAD_DIR
 #fi
 
 tar -xvf "$DOWNLOAD_DIR/Image-ExifTool.tar.gz" -C "$TEMPROOT/digikam.app/Contents/bin"
-ln -s "$TEMPROOT/digikam.app/Contents/bin/Image-ExifTool*" "$TEMPROOT/digikam.app/Contents/bin/Image-ExifTool"
-
 cd $TEMPROOT/digikam.app/Contents/bin
+EXIFTOOL_DIR=$(ls -d Image-ExifTool*)
+ln -sv "./$EXIFTOOL_DIR" "./Image-ExifTool"
 ln -sv "./Image-ExifTool/exiftool" "exiftool"
 
 #################################################################################################
