@@ -2,10 +2,9 @@
 
 # Script to build a bundle MXE installation with all digiKam low level dependencies in a dedicated directory.
 #
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Halt and catch errors
@@ -125,12 +124,10 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      libxslt \
      libjpeg-turbo \
      libpng \
-     djvulibre \
      tiff \
      boost \
      expat \
      lcms \
-     liblqr-1 \
      eigen \
      jasper \
      zlib \
@@ -139,7 +136,9 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      pthreads \
      libgphoto2 \
      icu4c \
+     brotli \
      qtbase qtbase_CONFIGURE_OPTS=-icu \
+     qtnetworkauth \
      qttranslations \
      qtimageformats \
      qttools \
@@ -163,9 +162,11 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      openal \
      fftw \
      libltdl \
-     openexr
+     openexr \
+     nsis
 
 #     libical \
+#     djvulibre \
 
 echo -e "\n"
 
@@ -188,6 +189,9 @@ if [ ! -d $DOWNLOAD_DIR ] ; then
     mkdir -p $DOWNLOAD_DIR
 fi
 
+# For legacy compatibility with bootstrap.mxe
+ln -sf $MXE_ROOT_DIR $ORIG_WD/build.win64
+
 cd $BUILDING_DIR
 rm -rf $BUILDING_DIR/* || true
 
@@ -210,7 +214,8 @@ ${MXE_BUILD_TARGETS}-cmake $ORIG_WD/../3rdparty \
                            -DINSTALL_ROOT=${MXE_INSTALL_PREFIX} \
                            -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
                            -DKA_VERSION=$DK_KA_VERSION \
-                           -DKF5_VERSION=$DK_KF5_VERSION \
+                           -DKP_VERSION=$DK_KP_VERSION \
+                           -DKDE_VERSION=$DK_KDE_VERSION \
                            -DENABLE_QTVERSION=$DK_QTVERSION \
                            -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE
 
@@ -225,6 +230,7 @@ ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_ffmpeg
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_imagemagick -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_opencv      -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_drmingw     -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_heif        -- -j$CPU_CORES
 
 #################################################################################################
 
