@@ -4,10 +4,9 @@
 # and create a Windows installer file with NSIS application
 # Dependency : NSIS makensis program for Linux.
 #
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Halt and catch errors
@@ -40,9 +39,9 @@ RegisterRemoteServers
 #################################################################################################
 # Check if NSIS CLI tools is installed
 
-if ! which makensis ; then
+if ! which ${MXE_BUILDROOT}/usr/bin/x86_64-w64-mingw32.shared-makensis ; then
     echo "NSIS CLI tool is not installed"
-    echo "See http://nsis.sourceforge.net/ for details."
+    echo "See https://nsis.sourceforge.io for details."
     exit 1
 else
     echo "Check NSIS CLI tools passed..."
@@ -78,7 +77,8 @@ rm -f *.rcc > /dev/null
 cmake -DCMAKE_COLOR_MAKEFILE=ON \
       -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
       -DKA_VERSION=$DK_KA_VERSION \
-      -DKF5_VERSION=$DK_KF5_VERSION \
+      -DKP_VERSION=$DK_KP_VERSION \
+      -DKDE_VERSION=$DK_KDE_VERSION \
       -DENABLE_QTVERSION=$DK_QTVERSION \
       -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE \
       -Wno-dev \
@@ -110,36 +110,38 @@ mkdir -p $BUNDLEDIR/translations
 
 # Data files ---------------------------------------------------------------------------------
 
-echo -e "\n---------- Marble data"
-cp -r $MXE_INSTALL_PREFIX/data/*                                        $BUNDLEDIR/data             2>/dev/null
-
 echo -e "\n---------- Generics data"
-cp -r $MXE_INSTALL_PREFIX/share/lensfun                                 $BUNDLEDIR/data             2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/data/digikam                              $BUNDLEDIR/data             2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/data/showfoto                             $BUNDLEDIR/data             2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/data/solid                                $BUNDLEDIR/data             2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/data/k*                                   $BUNDLEDIR/data             2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/share/lensfun                                 $BUNDLEDIR/data                 2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/digikam                              $BUNDLEDIR/data                 2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/showfoto                             $BUNDLEDIR/data                 2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/solid                                $BUNDLEDIR/data                 2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/k*                                   $BUNDLEDIR/data                 2>/dev/null
 
 # Copy digiKam hi-colors PNG icons-set to the bundle
 
-cp -r $MXE_INSTALL_PREFIX/bin/data/icons                                $BUNDLEDIR/data             2>/dev/null
-rm -fr $BUNDLEDIR/data/icons/breeze*                                                                2>/dev/null
-rm -fr $BUNDLEDIR/data/icons/*.qrc                                                                  2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/icons                                $BUNDLEDIR/data                 2>/dev/null
+rm -fr $BUNDLEDIR/data/icons/breeze*                                                                    2>/dev/null
+rm -fr $BUNDLEDIR/data/icons/*.qrc                                                                      2>/dev/null
 
 echo -e "\n---------- Qt config"
-cp    $BUILDDIR/data/qt.conf                                            $BUNDLEDIR/                 2>/dev/null
+cp    $BUILDDIR/data/qt.conf                                            $BUNDLEDIR/                     2>/dev/null
 
 echo -e "\n---------- icons-set"
-cp    $BUILDDIR/icon-rcc/breeze-icons.rcc                               $BUNDLEDIR/breeze.rcc       2>/dev/null
-cp    $BUILDDIR/icon-rcc/breeze-icons-dark.rcc                          $BUNDLEDIR/breeze-dark.rcc  2>/dev/null
+cp    $BUILDDIR/icon-rcc/breeze-icons.rcc                               $BUNDLEDIR/breeze.rcc           2>/dev/null
+cp    $BUILDDIR/icon-rcc/breeze-icons-dark.rcc                          $BUNDLEDIR/breeze-dark.rcc      2>/dev/null
 
 echo -e "\n---------- i18n"
-cp -r $MXE_INSTALL_PREFIX/qt5/translations/qt*                          $BUNDLEDIR/translations     2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/data/locale                               $BUNDLEDIR/data             2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/qt5/translations/qt*                          $BUNDLEDIR/translations         2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/locale                               $BUNDLEDIR/data                 2>/dev/null
 
 echo -e "\n---------- Xdg"
-cp -r $MXE_INSTALL_PREFIX/etc/xdg                                       $BUNDLEDIR/etc              2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/data/xdg                                  $BUNDLEDIR/share            2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/etc/xdg                                       $BUNDLEDIR/etc                  2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/data/xdg                                  $BUNDLEDIR/share                2>/dev/null
+
+# See bug 471058
+echo -e "\n---------- Freedesktop"
+mkdir -p $BUNDLEDIR/share/mime/packages/                                                                2>/dev/null
+cp -r /usr/share/mime/packages/freedesktop.org.xml                      $BUNDLEDIR/share/mime/packages  2>/dev/null
 
 echo -e "\n---------- Copy Git Revisions Manifest"
 
@@ -155,32 +157,26 @@ done
 # Plugins Shared libraries -------------------------------------------------------------------
 
 echo -e "\n---------- Qt5 plugins"
-cp -r $MXE_INSTALL_PREFIX/qt5/plugins                                   $BUNDLEDIR/                 2>/dev/null
-
-echo -e "\n---------- Marble plugins"
-cp -r $MXE_INSTALL_PREFIX/plugins/*.dll                                 $BUNDLEDIR/plugins          2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/qt5/plugins                                   $BUNDLEDIR/                     2>/dev/null
 
 echo -e "\n---------- digiKam and KF5 plugins"
-cp -r $MXE_INSTALL_PREFIX/lib/plugins                                   $BUNDLEDIR/                 2>/dev/null
-
-echo -e "\n---------- OpenAL for QtAV"
-cp -r $MXE_INSTALL_PREFIX/bin/OpenAL32.dll                              $BUNDLEDIR/                 2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/lib/plugins                                   $BUNDLEDIR/                     2>/dev/null
 
 echo -e "\n---------- DrMinGw run-time"
-cp -r $MXE_INSTALL_PREFIX/bin/exchndl.dll                               $BUNDLEDIR/                 2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/mgwhelp.dll                               $BUNDLEDIR/                 2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/dbgcore.dll                               $BUNDLEDIR/                 2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/symsrv.dll                                $BUNDLEDIR/                 2>/dev/null
-cp -r $MXE_INSTALL_PREFIX/bin/symsrv.yes                                $BUNDLEDIR/                 2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/exchndl.dll                               $BUNDLEDIR/                     2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/mgwhelp.dll                               $BUNDLEDIR/                     2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/dbgcore.dll                               $BUNDLEDIR/                     2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/symsrv.dll                                $BUNDLEDIR/                     2>/dev/null
+cp -r $MXE_INSTALL_PREFIX/bin/symsrv.yes                                $BUNDLEDIR/                     2>/dev/null
 
 # Do not include this file from DrMinGW as it require extra devel dll from Microsoft at run-time.
-#cp -r $MXE_INSTALL_PREFIX/bin/dbghelp.dll                               $BUNDLEDIR/                2>/dev/null
+#cp -r $MXE_INSTALL_PREFIX/bin/dbghelp.dll                               $BUNDLEDIR/                    2>/dev/null
 
 echo -e "\n---------- libgphoto2 drivers"
-mkdir $BUNDLEDIR/libgphoto2                                                                         2>/dev/null
-mkdir $BUNDLEDIR/libgphoto2_port                                                                    2>/dev/null
-cp $MXE_INSTALL_PREFIX/lib/libgphoto2/*/*.dll                           $BUNDLEDIR/libgphoto2       2>/dev/null
-cp $MXE_INSTALL_PREFIX/lib/libgphoto2_port/*/*.dll                      $BUNDLEDIR/libgphoto2_port  2>/dev/null
+mkdir $BUNDLEDIR/libgphoto2                                                                             2>/dev/null
+mkdir $BUNDLEDIR/libgphoto2_port                                                                        2>/dev/null
+cp $MXE_INSTALL_PREFIX/lib/libgphoto2/*/*.dll                           $BUNDLEDIR/libgphoto2           2>/dev/null
+cp $MXE_INSTALL_PREFIX/lib/libgphoto2_port/*/*.dll                      $BUNDLEDIR/libgphoto2_port      2>/dev/null
 
 echo -e "\n---------- Copy executables with recursive dependencies in bundle directory\n"
 
@@ -207,7 +203,6 @@ DLL_FILES="\
 `find  $MXE_INSTALL_PREFIX/plugins             -name "*.dll" -type f | sed 's|$MXE_INSTALL_PREFIX/plugins/||'`            \
 `find  $MXE_INSTALL_PREFIX/lib/libgphoto2      -name "*.dll" -type f | sed 's|$MXE_INSTALL_PREFIX/lib/libgphoto2||'`      \
 `find  $MXE_INSTALL_PREFIX/lib/libgphoto2_port -name "*.dll" -type f | sed 's|$MXE_INSTALL_PREFIX/lib/libgphoto2_port||'` \
-$MXE_INSTALL_PREFIX/bin/OpenAL32.dll \
 $MXE_INSTALL_PREFIX/bin/exchndl.dll  \
 $MXE_INSTALL_PREFIX/bin/mgwhelp.dll  \
 "
@@ -218,18 +213,34 @@ for app in $DLL_FILES ; do
 
 done
 
+# See bug #476290
+rm -fr $BUNDLEDIR/plugins/imageformats/qjp2.dll
+
 #################################################################################################
 # Cleanup symbols in binary files to free space.
+# NOTE: NSIS only support < 2Gb of file to package in the same installer. If size is bigger, a bus error exception is genenrated.
+# The following code to do lets all debug symbols in each digiKam components, else size will be largest than 2Gb.
+# only the digiKam/Showfoto executable and shared libraries debug symbols are preserved. All digiKam plugins are stripped.
 
 echo -e "\n---------- Strip symbols in binary files\n"
 
 if [[ $DK_DEBUG = 1 ]] ; then
 
-    find $BUNDLEDIR -name \*exe | grep -Ev '(digikam|showfoto)' | xargs ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip --strip-all
-    find $BUNDLEDIR -name \*dll | grep -Ev '(digikam|showfoto)' | xargs ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip --strip-all
+    DEBUG_EXE_STRIP_ALL="`find $BUNDLEDIR -name \*exe | grep -Ev '(digikam|showfoto)'`"
+    echo "DEBUG_EXE_STRIP_ALL=$DEBUG_EXE_STRIP_ALL"
+    ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip $DEBUG_EXE_STRIP_ALL
 
-    find $BUNDLEDIR -name \*exe | grep -E '(digikam|showfoto)'  | xargs ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip
-    find $BUNDLEDIR -name \*dll | grep -E '(digikam|showfoto)'  | xargs ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip
+    DEBUG_DLL_STRIP_ALL="`find $BUNDLEDIR -name \*dll | grep -Ev '(digikam|showfoto)'`"
+    echo "DEBUG_DLL_STRIP_ALL=$DEBUG_DLL_STRIP_ALL"
+    ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip $DEBUG_DLL_STRIP_ALL
+
+#    DEBUG_EXE_STRIP="`find $BUNDLEDIR -name \*exe | grep -E '(digikam|showfoto)'`"
+#    echo "DEBUG_EXE_STRIP=$DEBUG_EXE_STRIP"
+#    ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip --only-keep-debug $DEBUG_EXE_STRIP
+
+    DEBUG_DLL_STRIP="`find $BUNDLEDIR -name \*dll | grep -E '(digikam|showfoto)' | grep -Ev '(libdigikam|digikam.dll|showfoto.dll)'`"
+    echo "DEBUG_DLL_STRIP=$DEBUG_DLL_STRIP"
+    ${MXE_BUILDROOT}/usr/bin/${MXE_BUILD_TARGETS}-strip $DEBUG_DLL_STRIP
 
 else
 
@@ -261,7 +272,7 @@ fi
 if [[ $DK_VERSION != v* ]] ; then
 
     # with non-official release version, use build time-stamp as sub-version string.
-    DK_SUBVER="-`cat $ORIG_WD/data/BUILDDATE.txt`"
+    DK_SUBVER="$DK_SUBVER-`cat $ORIG_WD/data/BUILDDATE.txt`"
 
 else
 
@@ -296,7 +307,7 @@ fi
 
 cd $ORIG_WD/installer
 
-makensis -DVERSION=$DK_RELEASEID -DBUNDLEPATH=$BUNDLEDIR -DTARGETARCH=$MXE_ARCHBITS -DOUTPUT=$ORIG_WD/bundle/$TARGET_INSTALLER ./digikam.nsi
+${MXE_BUILDROOT}/usr/bin/x86_64-w64-mingw32.shared-makensis -DVERSION=$DK_RELEASEID -DBUNDLEPATH=$BUNDLEDIR -DTARGETARCH=$MXE_ARCHBITS -DOUTPUT=$ORIG_WD/bundle/$TARGET_INSTALLER ./digikam.nsi
 
 cd $ORIG_WD
 tar cf - `basename $BUNDLEDIR` --transform s/temp/digiKam/ | xz -4e > $ORIG_WD/bundle/$PORTABLE_FILE
