@@ -3,31 +3,13 @@
 # Python script that takes an EXE file, automatically figures out all the DLL dependencies,
 # and copies them next to the EXE.
 #
-# The MIT License (MIT)
-#
-# Copyright (c)      2015 by Martin Preisler <martin at preisler dot me>
-# Copyright (c) 2016-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText:      2015 by Martin Preisler <martin at preisler dot me>
+# SPDX-FileCopyrightText: 2016-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
 #
 # Blog post         : https://martin.preisler.me/2015/03/mingw-bundledlls-automatically-bundle-dlls/
 # Github repository : https://github.com/mpreisler/mingw-bundledlls
 #
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# SPDX-License-Identifier: BSD-3-Clause
 
 import subprocess
 import os.path
@@ -92,6 +74,8 @@ blacklist = [
     "ncrypt.dll",
     "dbghelp.dll",      # blacklisted dll from DrMinGW as it use MSVC dll to show debug dialog.
     "dbgcore.dll",      # blacklisted dll from DrMinGW.
+    "gdiplus.dll",
+    "urlmon.dll",
 ]
 
 # -----------------------------------------------
